;; Duration models autotrained by festvox
;; dur.S15.tree
(set! cmu_us_clb::phone_durs '
((pau 0.2 0.1)
 (oy_3 0.061358 0.042515)
 (oy_2 0.050247 0.025931)
 (oy_1 0.104074 0.038374)
 (uh_3 0.017909 0.017824)
 (uh_2 0.020061 0.027756)
 (uh_1 0.019 0.03127)
 (ow_3 0.03212 0.035905)
 (ow_2 0.060899 0.047129)
 (ow_1 0.046403 0.042647)
 (zh_3 0.02375 0.021393)
 (zh_2 0.044861 0.038125)
 (zh_1 0.050972 0.033377)
 (v_3 0.028807 0.026388)
 (v_2 0.027235 0.019989)
 (v_1 0.01795 0.014448)
 (ay_3 0.064315 0.032666)
 (ay_2 0.058569 0.039219)
 (ay_1 0.0432 0.046795)
 (aw_3 0.054426 0.036722)
 (aw_2 0.063319 0.041322)
 (aw_1 0.059085 0.05584)
 (l_3 0.022519 0.022955)
 (l_2 0.048863 0.041518)
 (l_1 0.040873 0.042817)
 (g_3 0.034709 0.022879)
 (g_2 0.024584 0.017427)
 (g_1 0.019515 0.017479)
 (f_3 0.034553 0.036965)
 (f_2 0.066317 0.041184)
 (f_1 0.023405 0.020912)
 (ah_3 0.020339 0.019367)
 (ah_2 0.031199 0.028879)
 (ah_1 0.018688 0.024578)
 (z_3 0.014053 0.011385)
 (z_2 0.051292 0.041555)
 (z_1 0.0396 0.025713)
 (iy_3 0.025789 0.026146)
 (iy_2 0.065251 0.048858)
 (iy_1 0.027693 0.024069)
 (n_3 0.019777 0.020191)
 (n_2 0.037366 0.027516)
 (n_1 0.024175 0.024301)
 (s_3 0.020411 0.01305)
 (s_2 0.091959 0.038555)
 (s_1 0.027695 0.019061)
 (b_3 0.014072 0.010446)
 (b_2 0.029313 0.030445)
 (b_1 0.037414 0.026144)
 (ax_3 0.013851 0.017168)
 (ax_2 0.022056 0.024323)
 (ax_1 0.010686 0.014635)
 (ae_3 0.034808 0.047746)
 (ae_2 0.049672 0.052444)
 (ae_1 0.017194 0.01862)
 (hh_3 0.024583 0.028184)
 (hh_2 0.03654 0.036267)
 (hh_1 0.017418 0.021791)
 (d_3 0.01976 0.018881)
 (d_2 0.015212 0.012717)
 (d_1 0.0151 0.01258)
 (jh_3 0.024279 0.015603)
 (jh_2 0.050048 0.02325)
 (jh_1 0.037692 0.024221)
 (ch_3 0.046103 0.028155)
 (ch_2 0.049897 0.031521)
 (ch_1 0.044231 0.022962)
 (pau_5 0.037197 0.026782)
 (th_3 0.017854 0.016989)
 (th_2 0.072099 0.041141)
 (th_1 0.025047 0.020159)
 (r_3 0.018112 0.021021)
 (r_2 0.033266 0.034082)
 (r_1 0.027104 0.034756)
 (pau_2 0.030504 0.027799)
 (p_3 0.047101 0.032764)
 (p_2 0.038142 0.023882)
 (p_1 0.023377 0.013613)
 (aa_3 0.023675 0.019291)
 (aa_2 0.058723 0.056645)
 (aa_1 0.022052 0.026038)
 (sh_3 0.020517 0.013338)
 (sh_2 0.094167 0.027885)
 (sh_1 0.027 0.010585)
 (ao_3 0.025959 0.023201)
 (ao_2 0.063818 0.067311)
 (ao_1 0.030186 0.034599)
 (t_3 0.032515 0.03018)
 (t_2 0.02198 0.0219)
 (t_1 0.016046 0.013961)
 (eh_3 0.022567 0.027258)
 (eh_2 0.041928 0.036869)
 (eh_1 0.017761 0.021516)
 (dh_3 0.017144 0.018016)
 (dh_2 0.026942 0.028019)
 (dh_1 0.023574 0.030368)
 (ng_3 0.030137 0.028453)
 (ng_2 0.05211 0.026534)
 (ng_1 0.042658 0.026342)
 (ih_3 0.0187 0.019574)
 (ih_2 0.026024 0.026115)
 (ih_1 0.013449 0.020128)
 (k_3 0.052006 0.033669)
 (k_2 0.034075 0.024845)
 (k_1 0.020803 0.01308)
 (ey_3 0.029583 0.032736)
 (ey_2 0.061445 0.044408)
 (ey_1 0.05758 0.047689)
 (m_3 0.021146 0.032375)
 (m_2 0.039628 0.034986)
 (m_1 0.036894 0.034902)
 (er_3 0.022535 0.027839)
 (er_2 0.048814 0.048198)
 (er_1 0.051466 0.054016)
 (w_3 0.022759 0.013607)
 (w_2 0.048016 0.039356)
 (w_1 0.022857 0.020869)
 (uw_3 0.027742 0.036315)
 (uw_2 0.033043 0.039643)
 (uw_1 0.035121 0.036413)
 (y_3 0.046365 0.038472)
 (y_2 0.039038 0.037996)
 (y_1 0.026404 0.028312)
 (pau_3 0.095219 0.040848)
 (pau_1 0.03119 0.041353))
)


(set! cmu_us_clb::zdur_tree '
((name is pau)
 ((p.R:SylStructure.parent.parent.pbreak is BB)
  ((0.0 2.0))
  ((0.0 0.0)))
((R:segstate.parent.nn.ph_vc is 0)
 ((R:segstate.parent.ph_vrnd is -)
  ((R:segstate.parent.p.ph_ctype is n)
   ((R:segstate.parent.ph_vheight is 3)
    ((1.14981 0.68059))
    ((R:segstate.parent.R:SylStructure.parent.R:Syllable.pp.lisp_cg_break
      <
      0.1)
     ((1.32962 0.784416))
     ((1.67719 1.28266))))
   ((R:segstate.parent.p.ph_vlng is d)
    ((1.24692 0.868292))
    ((R:segstate.parent.p.name is l)
     ((R:segstate.parent.R:SylStructure.parent.syl_in < 15)
      ((R:segstate.parent.R:SylStructure.parent.syl_in < 7.5)
       ((1.0524 0.888927))
       ((R:segstate.parent.R:SylStructure.parent.ssyl_in < 6.6)
        ((1.63283 1.23067))
        ((1.74869 0.938303))))
      ((1.5152 1.26261)))
     ((R:segstate.parent.R:SylStructure.parent.asyl_in < 4.5)
      ((R:segstate.parent.p.ph_cvox is +)
       ((R:segstate.parent.R:SylStructure.parent.R:Syllable.pp.lisp_cg_break
         <
         0.1)
        ((R:segstate.parent.R:SylStructure.parent.syl_in < 9)
         ((1.71042 1.35396))
         ((1.21753 0.939669)))
        ((R:segstate.parent.R:SylStructure.parent.syl_in < 12.5)
         ((R:segstate.parent.pp.ph_vheight is 2)
          ((1.63935 1.44651))
          ((1.79812 1.76358)))
         ((1.60812 1.18916))))
       ((R:segstate.parent.p.ph_cplace is a)
        ((R:segstate.parent.p.name is s)
         ((1.68687 1.36545))
         ((1.97692 1.66231)))
        ((1.45786 1.95254))))
      ((R:segstate.parent.pp.ph_vheight is 2)
       ((R:segstate.parent.R:SylStructure.parent.ssyl_in < 8)
        ((1.46561 1.17568))
        ((1.72068 1.67684)))
       ((R:segstate.parent.R:SylStructure.parent.asyl_in < 5.3)
        ((R:segstate.parent.R:SylStructure.parent.ssyl_in < 7.1)
         ((1.53503 1.09744))
         ((1.3206 0.652569)))
        ((1.73612 1.24883))))))))
  ((R:segstate.parent.p.ph_ctype is 0)
   ((R:segstate.parent.p.name is eh)
    ((R:segstate.parent.ph_ctype is r)
     ((1.72925 0.735207))
     ((R:segstate.parent.R:SylStructure.parent.syl_in < 8.2)
      ((R:segstate.parent.R:SylStructure.parent.ssyl_in < 2.1)
       ((1.05556 1.27848))
       ((1.07849 0.935603)))
      ((R:segstate.parent.R:SylStructure.parent.asyl_in < 3.5)
       ((R:segstate.parent.lisp_onset_fric is 0)
        ((0.904668 0.925682))
        ((1.72378 1.4483)))
       ((1.70898 1.75644)))))
    ((R:segstate.parent.p.name is ih)
     ((R:segstate.parent.R:SylStructure.parent.position_type is final)
      ((R:segstate.parent.ph_ctype is n)
       ((R:segstate.parent.R:SylStructure.parent.syl_in < 8.4)
        ((1.4081 0.836036))
        ((R:segstate.parent.R:SylStructure.parent.ssyl_in < 7.2)
         ((1.80856 0.257306))
         ((1.68169 0.629103))))
       ((R:segstate.parent.ph_ctype is s)
        ((0.874073 0.920462))
        ((R:segstate.parent.R:SylStructure.parent.R:Syllable.p.accented
          is
          0)
         ((2.13508 0.956068))
         ((1.62286 1.44476)))))
      ((R:segstate.parent.ph_ctype is n)
       ((R:segstate.parent.R:SylStructure.parent.R:Syllable.p.syl_codasize
         <
         1.3)
        ((1.66183 1.83652))
        ((R:segstate.parent.R:SylStructure.parent.asyl_in < 1.5)
         ((1.53982 1.7062))
         ((R:segstate.parent.R:SylStructure.parent.syl_in < 9.2)
          ((1.3665 0.851162))
          ((1.8149 1.35915)))))
       ((R:segstate.parent.R:SylStructure.parent.asyl_in < 1.4)
        ((1.02406 1.33446))
        ((R:segstate.parent.R:SylStructure.parent.ssyl_in < 6)
         ((1.28715 0.440437))
         ((1.99132 1.17246))))))
     ((R:segstate.parent.ph_cvox is -)
      ((R:segstate.parent.p.ph_vfront is 1)
       ((R:segstate.parent.R:SylStructure.parent.parent.gpos is in)
        ((1.19687 -0.0502318))
        ((R:segstate.parent.R:SylStructure.parent.position_type
          is
          single)
         ((R:segstate.parent.p.name is iy)
          ((1.13545 1.46089))
          ((R:segstate.parent.R:SylStructure.parent.R:Syllable.p.syl_codasize
            <
            1.2)
           ((R:segstate.parent.R:SylStructure.parent.R:Syllable.pp.accented
             is
             0)
            ((0.790749 0.974882))
            ((1.19304 1.33298)))
           ((R:segstate.parent.R:SylStructure.parent.last_accent < 2)
            ((1.18569 0.515042))
            ((1.06023 0.834681)))))
         ((R:segstate.parent.pp.ph_cvox is +)
          ((R:segstate.parent.pp.ph_cplace is a)
           ((R:segstate.parent.p.name is ey)
            ((0.909325 0.383524))
            ((1.03413 0.698929)))
           ((R:segstate.parent.p.name is ey)
            ((1.1428 1.01495))
            ((1.16413 0.72341))))
          ((R:segstate.parent.pp.ph_cplace is a)
           ((0.910991 0.691061))
           ((0.659593 0.471404))))))
       ((R:segstate.parent.R:SylStructure.parent.R:Syllable.p.stress
         is
         0)
        ((R:segstate.parent.pp.ph_cplace is l)
         ((1.25054 0.76926))
         ((R:segstate.parent.pp.ph_cplace is p)
          ((1.31329 1.37262))
          ((R:segstate.parent.ph_ctype is s)
           ((1.28611 1.41277))
           ((R:segstate.parent.R:SylStructure.parent.R:Syllable.p.syl_codasize
             <
             1.2)
            ((R:segstate.parent.pp.ph_cplace is a)
             ((R:segstate.parent.p.ph_vheight is 2)
              ((R:segstate.parent.p.name is ax)
               ((1.24747 1.27447))
               ((1.39511 1.27512)))
              ((R:segstate.parent.pp.ph_cvox is +)
               ((R:segstate.parent.p.name is aw)
                ((1.19552 1.03489))
                ((1.36299 1.09447)))
               ((1.00079 1.25884))))
             ((1.38639 0.880803)))
            ((1.32261 0.873832))))))
        ((R:segstate.parent.pp.ph_cplace is l)
         ((1.26167 1.53892))
         ((R:segstate.parent.R:SylStructure.parent.last_accent < 1.8)
          ((R:segstate.parent.ph_ctype is f)
           ((1.32974 0.880645))
           ((R:segstate.parent.pp.ph_cvox is +)
            ((1.30778 0.561776))
            ((1.16897 0.355634))))
          ((R:segstate.parent.p.name is ay)
           ((0.736855 0.66168))
           ((1.61199 1.33962)))))))
      ((R:segstate.parent.p.name is uw)
       ((R:segstate.parent.R:SylStructure.parent.ssyl_in < 5.4)
        ((1.63831 1.56032))
        ((1.35797 0.854258)))
       ((R:segstate.parent.ph_ctype is l)
        ((R:segstate.parent.lisp_onset_stop is 0)
         ((R:segstate.parent.pp.ph_cvox is +)
          ((1.34123 0.569063))
          ((1.69198 1.02903)))
         ((1.66779 1.32421)))
        ((R:segstate.parent.p.name is ax)
         ((R:segstate.parent.R:SylStructure.parent.R:Syllable.pp.accented
           is
           0)
          ((R:segstate.parent.ph_ctype is s)
           ((R:segstate.parent.R:SylStructure.parent.ssyl_in < 5.4)
            ((0.809191 0.604598))
            ((0.765861 0.250512)))
           ((R:segstate.parent.R:SylStructure.parent.syl_onsetsize
             <
             1.2)
            ((R:segstate.parent.pp.ph_cplace is a)
             ((1.40935 1.09253))
             ((R:segstate.parent.R:SylStructure.parent.asyl_in < 2.1)
              ((0.964577 0.521765))
              ((R:segstate.parent.R:SylStructure.parent.asyl_in < 3.4)
               ((0.82976 0.859315))
               ((R:segstate.parent.R:SylStructure.parent.parent.word_numsyls
                 <
                 2.4)
                ((1.15388 0.529946))
                ((R:segstate.parent.R:SylStructure.parent.ssyl_in
                  <
                  9.2)
                 ((1.06957 0.774709))
                 ((0.917038 0.70713)))))))
            ((1.05344 0.49989))))
          ((1.32085 1.17994)))
         ((R:segstate.parent.pp.ph_cvox is -)
          ((R:segstate.parent.R:SylStructure.parent.ssyl_in < 5)
           ((R:segstate.parent.p.name is ay)
            ((0.732148 0.572026))
            ((1.16342 0.201845)))
           ((R:segstate.parent.ph_ctype is n)
            ((R:segstate.parent.pp.ph_cplace is a)
             ((1.37589 1.32589))
             ((1.24023 0.764261)))
            ((R:segstate.parent.R:SylStructure.parent.R:Syllable.pp.lisp_cg_break
              <
              0.1)
             ((1.03167 0.397072))
             ((1.44292 0.598362)))))
          ((R:segstate.parent.R:SylStructure.parent.asyl_in < 1.4)
           ((R:segstate.parent.R:SylStructure.parent.syl_in < 6)
            ((0.912473 0.184542))
            ((R:segstate.parent.lisp_onset_stop is 0)
             ((1.32139 0.966223))
             ((1.13931 0.525821))))
           ((R:segstate.parent.R:SylStructure.parent.R:Syllable.pp.accented
             is
             0)
            ((R:segstate.parent.p.ph_vlng is d)
             ((1.05018 0.470375))
             ((R:segstate.parent.ph_ctype is n)
              ((1.12855 0.29978))
              ((R:segstate.parent.lisp_onset_stop is 0)
               ((0.782981 -0.358533))
               ((0.74745 0.126964)))))
            ((R:segstate.parent.pp.ph_cplace is a)
             ((0.902831 0.149764))
             ((1.60288 0.727081))))))))))))
   ((R:segstate.parent.p.name is n)
    ((R:segstate.parent.ph_cvox is +)
     ((R:segstate.parent.pp.ph_vheight is 3)
      ((R:segstate.parent.R:SylStructure.parent.R:Syllable.pp.lisp_cg_break
        <
        0.1)
       ((0.642778 0.234381))
       ((0.563381 -0.0654566)))
      ((R:segstate.parent.R:SylStructure.parent.syl_in < 11)
       ((1.01119 0.334667))
       ((1.09305 0.522909))))
     ((R:segstate.parent.ph_ctype is f)
      ((R:segstate.parent.R:SylStructure.parent.syl_in < 13.5)
       ((1.00363 0.752125))
       ((1.13634 0.387876)))
      ((R:segstate.parent.pos_in_syl is 1)
       ((1.14636 1.24674))
       ((R:segstate.parent.R:SylStructure.parent.R:Syllable.pp.accented
         is
         0)
        ((R:segstate.parent.pp.ph_vheight is 1)
         ((R:segstate.parent.pp.ph_vlng is l)
          ((0.756689 0.883665))
          ((0.829348 0.75771)))
         ((R:segstate.parent.R:SylStructure.parent.asyl_in < 1.5)
          ((R:segstate.parent.pp.ph_vlng is d)
           ((1.06608 0.881776))
           ((R:segstate.parent.pp.ph_vlng is a)
            ((0.990747 1.0237))
            ((R:segstate.parent.pp.ph_vheight is 2)
             ((1.33057 1.22877))
             ((R:segstate.parent.pp.ph_vlng is l)
              ((1.24809 1.14516))
              ((1.34228 0.863816))))))
          ((0.72123 0.94616))))
        ((0.837706 0.7163))))))
    ((R:segstate.parent.p.name is r)
     ((R:segstate.parent.ph_cvox is -)
      ((R:segstate.parent.R:SylStructure.parent.R:Syllable.p.syl_codasize
        <
        1.2)
       ((R:segstate.parent.pp.ph_vlng is l)
        ((1.38499 1.19463))
        ((R:segstate.parent.pp.ph_vheight is 1)
         ((1.51523 1.03855))
         ((1.90536 1.15553))))
       ((1.02162 0.932252)))
      ((R:segstate.parent.pos_in_syl is 3)
       ((1.72639 0.786491))
       ((1.17318 0.23021))))
     ((R:segstate.parent.lisp_coda_stop is 0)
      ((R:segstate.parent.pp.ph_cplace is p)
       ((1.06653 -0.00593128))
       ((R:segstate.parent.lisp_onset_stop is 0)
        ((R:segstate.parent.p.name is ng)
         ((1.22122 0.844821))
         ((R:segstate.parent.p.name is d)
          ((R:segstate.parent.pp.ph_vc is +)
           ((R:segstate.parent.pp.ph_vlng is s)
            ((R:segstate.parent.pp.ph_vheight is 2)
             ((1.24084 0.880035))
             ((1.43345 0.532869)))
            ((R:segstate.parent.pp.ph_vlng is l)
             ((1.17244 0.885442))
             ((R:segstate.parent.pp.ph_vlng is a)
              ((1.31013 0.880351))
              ((1.2389 0.902084)))))
           ((1.26434 0.50796)))
          ((R:segstate.parent.R:SylStructure.parent.syl_in < 13.3)
           ((R:segstate.parent.p.ph_cplace is d)
            ((1.13342 0.954732))
            ((R:segstate.parent.pp.ph_vlng is d)
             ((R:segstate.parent.p.name is t)
              ((0.914118 0.521817))
              ((R:segstate.parent.p.name is s)
               ((0.610658 0.598238))
               ((R:segstate.parent.p.ph_cplace is l)
                ((0.950342 0.786562))
                ((R:segstate.parent.p.ph_ctype is f)
                 ((R:segstate.parent.p.name is f)
                  ((0.814117 0.660067))
                  ((1.12166 0.767845)))
                 ((R:segstate.parent.pp.ph_vheight is 2)
                  ((R:segstate.parent.p.name is l)
                   ((1.06841 0.500382))
                   ((1.31131 0.658344)))
                  ((0.876336 0.658253)))))))
             ((R:segstate.parent.p.name is m)
              ((R:segstate.parent.pp.ph_vlng is s)
               ((R:segstate.parent.pp.ph_vheight is 1)
                ((0.981326 0.311529))
                ((1.06487 0.243533)))
               ((R:segstate.parent.pp.ph_vlng is a)
                ((1.00171 0.408044))
                ((1.0461 0.57044))))
              ((R:segstate.parent.pp.ph_vlng is a)
               ((R:segstate.parent.p.ph_ctype is s)
                ((R:segstate.parent.p.name is t)
                 ((1.38027 0.217465))
                 ((0.90658 0.272147)))
                ((R:segstate.parent.p.ph_ctype is f)
                 ((R:segstate.parent.p.name is s)
                  ((0.901007 0.396138))
                  ((0.910523 0.417775)))
                 ((0.975786 0.580044))))
               ((R:segstate.parent.p.name is k)
                ((R:segstate.parent.pp.ph_vlng is l)
                 ((0.83447 0.578964))
                 ((R:segstate.parent.pp.ph_vheight is 1)
                  ((0.528534 0.893201))
                  ((0.995155 0.772771))))
                ((R:segstate.parent.p.name is er)
                 ((R:segstate.parent.pp.ph_cplace is b)
                  ((0.64658 0.262656))
                  ((R:segstate.parent.pp.ph_cvox is +)
                   ((R:segstate.parent.pp.ph_cplace is a)
                    ((1.05341 0.432425))
                    ((R:segstate.parent.pp.ph_cplace is d)
                     ((1.12121 0.445655))
                     ((0.608114 0.339465))))
                   ((0.670495 0.464541))))
                 ((R:segstate.parent.p.ph_cplace is a)
                  ((R:segstate.parent.p.name is s)
                   ((R:segstate.parent.pp.ph_vheight is 1)
                    ((0.657218 0.361206))
                    ((R:segstate.parent.pp.ph_cplace is a)
                     ((R:segstate.parent.pp.ph_cvox is +)
                      ((0.913957 0.410435))
                      ((0.672273 0.450713)))
                     ((R:segstate.parent.pp.ph_cplace is l)
                      ((0.597325 0.425731))
                      ((0.599456 0.539767)))))
                   ((R:segstate.parent.pp.ph_vheight is 1)
                    ((R:segstate.parent.p.name is t)
                     ((R:segstate.parent.pp.ph_vlng is l)
                      ((0.703576 0.603636))
                      ((0.826399 0.326988)))
                     ((R:segstate.parent.pp.ph_vlng is l)
                      ((0.850546 0.483492))
                      ((0.82328 0.645225))))
                    ((R:segstate.parent.p.name is z)
                     ((R:segstate.parent.pp.ph_cplace is a)
                      ((1.12494 0.487332))
                      ((R:segstate.parent.pp.ph_cplace is b)
                       ((1.14592 0.420487))
                       ((0.97724 0.512266))))
                     ((R:segstate.parent.pp.ph_vheight is 3)
                      ((R:segstate.parent.p.name is l)
                       ((1.10608 0.472269))
                       ((1.14024 0.416726)))
                      ((R:segstate.parent.pp.ph_cvox is -)
                       ((R:segstate.parent.pp.ph_cplace is a)
                        ((0.939412 0.481658))
                        ((0.96938 0.609024)))
                       ((R:segstate.parent.pp.ph_vc is +)
                        ((1.2226 0.691419))
                        ((1.21117 0.698744))))))))
                  ((R:segstate.parent.R:SylStructure.parent.stress
                    is
                    0)
                   ((R:segstate.parent.p.ph_ctype is s)
                    ((R:segstate.parent.pp.ph_vheight is 3)
                     ((0.840066 0.483803))
                     ((R:segstate.parent.pp.ph_vheight is 2)
                      ((0.869367 0.689572))
                      ((0.941834 0.811273))))
                    ((R:segstate.parent.p.ph_cplace is p)
                     ((0.768126 0.688137))
                     ((R:segstate.parent.pp.ph_vlng is s)
                      ((1.27043 1.01547))
                      ((1.20447 0.765093)))))
                   ((R:segstate.parent.p.name is v)
                    ((1.63133 0.552272))
                    ((0.486123 0.55224)))))))))))
           ((1.68143 0.974803)))))
        ((R:segstate.parent.ph_vheight is 1)
         ((0.693968 1.35757))
         ((R:segstate.parent.pp.ph_cplace is a)
          ((1.65833 0.981198))
          ((1.5384 0.674238))))))
      ((R:segstate.parent.R:SylStructure.parent.last_accent < 1.4)
       ((R:segstate.parent.R:SylStructure.parent.R:Syllable.p.syl_codasize
         <
         1.2)
        ((R:segstate.parent.p.ph_cvox is +)
         ((0.766094 -0.422432))
         ((R:segstate.parent.R:SylStructure.parent.R:Syllable.pp.lisp_cg_break
           <
           0.1)
          ((0.987176 -0.106674))
          ((R:segstate.parent.pp.ph_vlng is a)
           ((0.940926 0.219005))
           ((1.26104 0.635871)))))
        ((R:segstate.parent.lisp_coda_fric is 0)
         ((R:segstate.parent.R:SylStructure.parent.syl_in < 11.4)
          ((1.25966 0.994127))
          ((1.43069 0.321942)))
         ((R:segstate.parent.R:SylStructure.parent.syl_in < 12)
          ((1.04995 -0.0405743))
          ((1.24643 0.423371)))))
       ((R:segstate.parent.lisp_coda_glide is 0)
        ((R:segstate.parent.p.ph_cplace is l)
         ((1.19486 0.752318))
         ((R:segstate.parent.R:SylStructure.parent.R:Syllable.p.syl_codasize
           <
           1.3)
          ((R:segstate.parent.R:SylStructure.parent.asyl_in < 1.5)
           ((1.24058 0.573435))
           ((1.1532 0.347035)))
          ((R:segstate.parent.R:SylStructure.parent.asyl_in < 3.5)
           ((0.979795 0.0512161))
           ((1.14184 0.434315)))))
        ((R:segstate.parent.R:SylStructure.parent.last_accent < 2.4)
         ((1.40555 0.608367))
         ((1.50479 1.07202))))))))))
 ((R:segstate.parent.R:SylStructure.parent.lisp_cg_break < 1.2)
  ((R:segstate.parent.p.ph_vlng is a)
   ((R:segstate.parent.R:SylStructure.parent.stress is 0)
    ((R:segstate.parent.R:SylStructure.parent.syl_codasize < 0.4)
     ((R:segstate.parent.n.ph_vc is +)
      ((R:segstate.parent.n.ph_vlng is s)
       ((R:segstate.parent.pp.ph_cvox is -)
        ((0.485094 -0.690043))
        ((0.608878 -0.381134)))
       ((1.11228 0.2269)))
      ((R:segstate.parent.pp.ph_cplace is a)
       ((0.485136 -0.790419))
       ((R:segstate.parent.pp.ph_vc is +)
        ((0.266648 -0.685909))
        ((0.492174 -0.459154)))))
     ((R:segstate.parent.nn.ph_cplace is a)
      ((R:segstate.parent.n.ph_vlng is a)
       ((R:segstate.parent.ph_ctype is l)
        ((0.886622 0.321664))
        ((R:segstate.parent.R:SylStructure.parent.ssyl_out < 8)
         ((R:segstate.parent.pp.ph_cvox is -)
          ((R:segstate.parent.R:SylStructure.parent.R:Syllable.n.lisp_cg_break
            <
            0.3)
           ((R:segstate.parent.R:SylStructure.parent.ssyl_in < 4.5)
            ((0.2644 -0.756857))
            ((0.4588 -0.519954)))
           ((R:segstate.parent.lisp_coda_fric is 0)
            ((R:segstate.parent.R:SylStructure.parent.parent.word_numsyls
              <
              3.1)
             ((R:segstate.parent.R:SylStructure.parent.ssyl_in < 3.1)
              ((1.00297 0.211844))
              ((0.886527 -0.186824)))
             ((0.41246 -0.395142)))
            ((0.698336 -0.502025))))
          ((R:segstate.parent.ph_cvox is +)
           ((R:segstate.parent.R:SylStructure.parent.syl_in < 9.8)
            ((R:segstate.parent.R:SylStructure.parent.last_accent
              <
              1.5)
             ((0.552326 -0.269662))
             ((0.861241 0.063325)))
            ((0.551919 -0.485534)))
           ((R:segstate.parent.R:SylStructure.parent.asyl_out < 1.4)
            ((0.313335 -0.193992))
            ((1.16367 0.159503)))))
         ((0.447214 -0.657943))))
       ((R:segstate.parent.R:SylStructure.parent.asyl_in < 0.6)
        ((R:segstate.parent.R:SylStructure.parent.R:Syllable.nn.lisp_cg_break
          <
          0.3)
         ((0.822631 -0.0382106))
         ((R:segstate.parent.R:SylStructure.parent.asyl_out < 4.2)
          ((R:segstate.parent.pp.ph_cvox is +)
           ((1.79958 0.857859))
           ((1.1065 0.265169)))
          ((0.943437 0.0555867))))
        ((R:segstate.parent.R:SylStructure.parent.asyl_out < 3.5)
         ((R:segstate.parent.R:SylStructure.parent.syl_codasize < 1.3)
          ((R:segstate.parent.R:SylStructure.parent.ssyl_out < 1.2)
           ((R:segstate.parent.R:SylStructure.parent.syl_in < 11)
            ((0.823143 0.110236))
            ((0.491647 -0.302118)))
           ((R:segstate.parent.R:SylStructure.parent.R:Syllable.pp.accented
             is
             0)
            ((1.78924 0.468327))
            ((1.0308 0.18433))))
          ((R:segstate.parent.pp.ph_cplace is a)
           ((R:segstate.parent.R:SylStructure.parent.asyl_out < 2)
            ((R:segstate.parent.R:SylStructure.parent.ssyl_out < 2.2)
             ((R:segstate.parent.R:SylStructure.parent.R:Syllable.n.syl_onsetsize
               <
               0.2)
              ((0.831173 -0.0700301))
              ((R:segstate.parent.pos_in_syl is 2)
               ((0.570147 -0.622263))
               ((0.492372 -0.391865))))
             ((0.26928 -0.813441)))
            ((0.651189 -0.0481382)))
           ((R:segstate.parent.pp.ph_cvox is +)
            ((R:segstate.parent.n.ph_ctype is s)
             ((R:segstate.parent.R:SylStructure.parent.syl_codasize
               <
               2.2)
              ((0.402942 -0.573951))
              ((0.820002 -0.260338)))
             ((0.880322 -0.0269269)))
            ((R:segstate.parent.R:SylStructure.parent.R:Syllable.nn.accented
              is
              0)
             ((R:segstate.parent.R:SylStructure.parent.syl_codasize
               <
               2.2)
              ((R:segstate.parent.R:SylStructure.parent.R:Syllable.pp.lisp_cg_break
                <
                0.1)
               ((0.739923 -0.247158))
               ((1.10978 0.153494)))
              ((1.37889 0.340171)))
             ((0.586833 -0.317429))))))
         ((R:segstate.parent.R:SylStructure.parent.parent.word_numsyls
           <
           2.3)
          ((R:segstate.parent.pp.ph_cvox is +)
           ((0.598067 -0.342741))
           ((0.931057 0.253755)))
          ((R:segstate.parent.R:SylStructure.parent.syl_out < 12.2)
           ((R:segstate.parent.pos_in_syl is 2)
            ((1.02838 0.0166005))
            ((1.70221 0.693619)))
           ((1.22371 0.0858246)))))))
      ((R:segstate.parent.R:SylStructure.parent.parent.gpos is to)
       ((1.0002 1.18657))
       ((R:segstate.parent.R:SylStructure.parent.asyl_in < 2.4)
        ((R:segstate.parent.syl_final is 0)
         ((R:segstate.parent.lisp_onset_fric is 0)
          ((R:segstate.parent.R:SylStructure.parent.lisp_cg_break
            <
            0.1)
           ((R:segstate.parent.R:SylStructure.parent.syl_in < 2.6)
            ((0.77127 -0.200642))
            ((R:segstate.parent.R:SylStructure.parent.ssyl_out < 5)
             ((R:segstate.parent.ph_ctype is s)
              ((R:segstate.parent.pp.ph_cplace is d)
               ((0.97136 0.135653))
               ((1.02588 0.510603)))
              ((0.760243 -0.101192)))
             ((1.74513 0.893786))))
           ((R:segstate.parent.n.ph_vlng is s)
            ((0.549526 -0.34976))
            ((R:segstate.parent.R:SylStructure.parent.asyl_out < 1.7)
             ((R:segstate.parent.R:SylStructure.parent.syl_in < 6)
              ((0.809001 -0.107752))
              ((0.586158 -0.477992)))
             ((R:segstate.parent.R:SylStructure.parent.R:Syllable.p.syl_codasize
               <
               1.2)
              ((R:segstate.parent.R:SylStructure.parent.asyl_in < 1.2)
               ((R:segstate.parent.nn.ph_vc is +)
                ((0.794974 0.0543952))
                ((R:segstate.parent.nn.ph_cplace is 0)
                 ((R:segstate.parent.R:SylStructure.parent.ssyl_out
                   <
                   4.5)
                  ((0.526395 -0.46824))
                  ((0.751352 -0.222045)))
                 ((R:segstate.parent.R:SylStructure.parent.syl_in
                   <
                   3.7)
                  ((0.858581 0.098926))
                  ((0.756702 -0.244906)))))
               ((R:segstate.parent.ph_ctype is n)
                ((1.19459 0.374123))
                ((R:segstate.parent.R:SylStructure.parent.asyl_out
                  <
                  2.6)
                 ((0.839471 0.173089))
                 ((0.813827 -0.23183)))))
              ((1.50395 0.476637))))))
          ((R:segstate.parent.pos_in_syl is 2)
           ((1.35821 0.716234))
           ((R:segstate.parent.R:SylStructure.parent.ssyl_out < 3.7)
            ((R:segstate.parent.R:SylStructure.parent.parent.word_numsyls
              <
              2.2)
             ((R:segstate.parent.R:SylStructure.parent.syl_out < 2.2)
              ((0.821158 0.09612))
              ((0.71291 0.334679)))
             ((0.833811 0.457761)))
            ((R:segstate.parent.R:SylStructure.parent.ssyl_in < 1.2)
             ((0.943954 0.29313))
             ((0.856088 -0.0666447))))))
         ((R:segstate.parent.ph_ctype is f)
          ((R:segstate.parent.R:SylStructure.parent.R:Syllable.p.stress
            is
            0)
           ((0.424066 -0.250458))
           ((R:segstate.parent.pos_in_syl is 2)
            ((R:segstate.parent.R:SylStructure.parent.R:Syllable.n.accented
              is
              0)
             ((R:segstate.parent.ph_cvox is +)
              ((0.602052 -0.0759889))
              ((0.870651 0.24508)))
             ((0.546768 -0.250752)))
            ((0.939256 0.293956))))
          ((R:segstate.parent.ph_ctype is l)
           ((R:segstate.parent.n.ph_ctype is 0)
            ((R:segstate.parent.R:SylStructure.parent.R:Syllable.p.syl_codasize
              <
              1.2)
             ((R:segstate.parent.pp.ph_cvox is -)
              ((1.61176 0.557464))
              ((1.00046 0.53099)))
             ((0.872781 0.0685091)))
            ((R:segstate.parent.R:SylStructure.parent.R:Syllable.n.lisp_cg_break
              <
              0.3)
             ((R:segstate.parent.pp.ph_cvox is +)
              ((1.06288 -0.176077))
              ((0.704349 -0.560262)))
             ((R:segstate.parent.R:SylStructure.parent.ssyl_out < 5.2)
              ((0.846809 -0.227748))
              ((1.23251 0.170154)))))
           ((R:segstate.parent.pos_in_syl is 1)
            ((R:segstate.parent.ph_ctype is n)
             ((R:segstate.parent.nn.ph_vlng is s)
              ((0.705967 -0.151185))
              ((1.19521 0.198028)))
             ((0.71392 -0.274255)))
            ((R:segstate.parent.lisp_onset_glide is 0)
             ((R:segstate.parent.n.ph_vlng is s)
              ((1.01843 -0.178542))
              ((R:segstate.parent.R:SylStructure.parent.asyl_out < 3.6)
               ((R:segstate.parent.ph_ctype is 0)
                ((R:segstate.parent.R:SylStructure.parent.ssyl_in
                  <
                  2.4)
                 ((0.893195 0.146785))
                 ((0.567964 -0.264892)))
                ((R:segstate.parent.pp.ph_cplace is a)
                 ((R:segstate.parent.n.ph_ctype is f)
                  ((1.97128 0.956502))
                  ((R:segstate.parent.n.ph_ctype is 0)
                   ((R:segstate.parent.R:SylStructure.parent.asyl_out
                     <
                     1.2)
                    ((1.09783 0.409643))
                    ((R:segstate.parent.R:SylStructure.parent.syl_out
                      <
                      5.4)
                     ((1.27408 0.88738))
                     ((1.21159 0.562881))))
                   ((R:segstate.parent.R:SylStructure.parent.asyl_in
                     <
                     1.2)
                    ((1.23121 0.360531))
                    ((0.640412 -0.0820998)))))
                 ((R:segstate.parent.R:SylStructure.parent.R:Syllable.p.accented
                   is
                   0)
                  ((R:segstate.parent.R:SylStructure.parent.ssyl_out
                    <
                    4.5)
                   ((R:segstate.parent.R:SylStructure.parent.ssyl_out
                     <
                     2.2)
                    ((0.88887 0.0175151))
                    ((R:segstate.parent.R:SylStructure.parent.last_accent
                      <
                      2.5)
                     ((1.26161 0.426641))
                     ((0.865041 0.183199))))
                   ((0.880487 -0.0297008)))
                  ((R:segstate.parent.pp.ph_cplace is v)
                   ((0.668277 0.141769))
                   ((R:segstate.parent.R:SylStructure.parent.R:Syllable.nn.stress
                     is
                     0)
                    ((1.57758 0.879647))
                    ((1.17199 0.362722)))))))
               ((R:segstate.parent.pp.ph_cplace is d)
                ((2.08679 1.3212))
                ((R:segstate.parent.R:SylStructure.parent.parent.word_numsyls
                  <
                  3.2)
                 ((R:segstate.parent.nn.ph_vlng is a)
                  ((1.85915 1.1514))
                  ((R:segstate.parent.R:SylStructure.parent.syl_out
                    <
                    12.5)
                   ((R:segstate.parent.R:SylStructure.parent.R:Syllable.nn.accented
                     is
                     0)
                    ((1.76695 0.904227))
                    ((R:segstate.parent.ph_ctype is n)
                     ((1.82681 0.792782))
                     ((1.12069 0.165716))))
                   ((R:segstate.parent.R:SylStructure.parent.position_type
                     is
                     final)
                    ((1.33667 0.518322))
                    ((0.675418 -0.0750133)))))
                 ((0.913738 0.117317))))))
             ((R:segstate.parent.n.ph_ctype is s)
              ((1.27011 -0.434163))
              ((R:segstate.parent.R:SylStructure.parent.syl_out < 8.4)
               ((0.786834 -0.0216692))
               ((1.11023 0.45861)))))))))
        ((R:segstate.parent.ph_vfront is 2)
         ((0.252152 -0.441955))
         ((R:segstate.parent.R:SylStructure.parent.R:Syllable.p.lisp_cg_break
           <
           0.1)
          ((R:segstate.parent.R:SylStructure.parent.asyl_out < 2.1)
           ((R:segstate.parent.lisp_onset_fric is 0)
            ((R:segstate.parent.R:SylStructure.parent.syl_out < 5.2)
             ((R:segstate.parent.R:SylStructure.parent.syl_out < 3)
              ((R:segstate.parent.n.ph_ctype is n)
               ((0.572865 -0.558806))
               ((R:segstate.parent.R:SylStructure.parent.last_accent
                 <
                 2.4)
                ((R:segstate.parent.ph_ctype is f)
                 ((1.18815 -0.463365))
                 ((R:segstate.parent.syl_final is 0)
                  ((R:segstate.parent.R:SylStructure.parent.parent.word_numsyls
                    <
                    3.2)
                   ((R:segstate.parent.R:SylStructure.parent.R:Syllable.p.accented
                     is
                     0)
                    ((0.445698 -0.581114))
                    ((0.728842 -0.185585)))
                   ((0.946433 0.143328)))
                  ((R:segstate.parent.R:SylStructure.parent.R:Syllable.n.lisp_cg_break
                    <
                    0.3)
                   ((1.45788 0.726822))
                   ((R:segstate.parent.R:SylStructure.parent.R:Syllable.pp.accented
                     is
                     0)
                    ((R:segstate.parent.nn.ph_vlng is l)
                     ((0.70148 -0.0766165))
                     ((0.874082 0.187795)))
                    ((0.828013 -0.223558))))))
                ((0.653274 -0.401505))))
              ((R:segstate.parent.lisp_onset_stop is 0)
               ((R:segstate.parent.R:SylStructure.parent.R:Syllable.nn.accented
                 is
                 0)
                ((R:segstate.parent.R:SylStructure.parent.syl_in < 12)
                 ((0.621713 -0.350248))
                 ((0.334718 -0.759459)))
                ((0.698002 -0.128372)))
               ((0.783378 -0.121612))))
             ((R:segstate.parent.n.ph_ctype is 0)
              ((0.911012 0.0110311))
              ((0.759521 0.242526))))
            ((R:segstate.parent.R:SylStructure.parent.syl_out < 2.6)
             ((0.638673 -0.13188))
             ((R:segstate.parent.n.ph_vc is +)
              ((0.792646 -0.153803))
              ((R:segstate.parent.nn.ph_vlng is s)
               ((0.856526 0.123291))
               ((1.22715 0.364795))))))
           ((R:segstate.parent.R:SylStructure.parent.asyl_in < 3.3)
            ((R:segstate.parent.R:SylStructure.parent.syl_in < 10)
             ((R:segstate.parent.R:SylStructure.parent.syl_in < 6.2)
              ((0.951459 0.179669))
              ((R:segstate.parent.R:SylStructure.parent.syl_in < 8.2)
               ((1.43194 0.81152))
               ((1.13112 0.580013))))
             ((0.797361 -0.0693325)))
            ((R:segstate.parent.ph_ctype is n)
             ((1.42916 0.182877))
             ((0.563612 -0.347117)))))
          ((R:segstate.parent.pp.ph_cvox is +)
           ((R:segstate.parent.R:SylStructure.parent.syl_codasize
             <
             1.1)
            ((1.01647 0.256499))
            ((1.65231 0.771894)))
           ((R:segstate.parent.R:SylStructure.parent.asyl_out < 2.4)
            ((R:segstate.parent.R:SylStructure.parent.R:Syllable.n.accented
              is
              0)
             ((1.31414 0.40887))
             ((0.712736 0.0522019)))
            ((0.562783 -0.215446))))))))))
    ((R:segstate.parent.ph_ctype is s)
     ((R:segstate.parent.syl_final is 0)
      ((R:segstate.parent.R:SylStructure.parent.parent.gpos is content)
       ((R:segstate.parent.pp.ph_cplace is p)
        ((1.05614 1.26974))
        ((R:segstate.parent.R:SylStructure.parent.position_type
          is
          single)
         ((R:segstate.parent.n.ph_vlng is l)
          ((R:segstate.parent.R:SylStructure.parent.syl_out < 6.2)
           ((0.924437 1.35069))
           ((0.989037 0.731085)))
          ((R:segstate.parent.R:SylStructure.parent.R:Syllable.nn.stress
            is
            0)
           ((R:segstate.parent.R:SylStructure.parent.R:Syllable.pp.accented
             is
             0)
            ((R:segstate.parent.R:SylStructure.parent.syl_in < 5.5)
             ((R:segstate.parent.n.ph_vlng is s)
              ((1.1427 0.50669))
              ((1.30986 0.929576)))
             ((R:segstate.parent.nn.ph_cplace is a)
              ((0.787764 0.650083))
              ((R:segstate.parent.R:SylStructure.parent.R:Syllable.n.lisp_cg_break
                <
                0.3)
               ((0.941612 0.432747))
               ((0.612967 0.224937)))))
            ((R:segstate.parent.ph_cvox is +)
             ((0.904349 0.0938866))
             ((0.74162 0.339634))))
           ((R:segstate.parent.nn.ph_cvox is +)
            ((R:segstate.parent.R:SylStructure.parent.syl_codasize
              <
              2.1)
             ((R:segstate.parent.R:SylStructure.parent.ssyl_out < 4.6)
              ((0.885271 0.367957))
              ((0.912197 1.05322)))
             ((0.777822 -0.0524777)))
            ((R:segstate.parent.R:SylStructure.parent.R:Syllable.n.syl_onsetsize
              <
              0.2)
             ((R:segstate.parent.R:SylStructure.parent.syl_in < 4.2)
              ((1.00714 0.433117))
              ((1.268 0.818659)))
             ((R:segstate.parent.R:SylStructure.parent.next_accent
               <
               2.1)
              ((R:segstate.parent.pp.ph_cvox is +)
               ((R:segstate.parent.R:SylStructure.parent.R:Syllable.nn.lisp_cg_break
                 <
                 0.3)
                ((1.2467 1.1748))
                ((1.02554 0.772467)))
               ((1.11107 0.539438)))
              ((1.12006 1.23494)))))))
         ((R:segstate.parent.n.ph_vlng is l)
          ((R:segstate.parent.n.ph_vheight is 1)
           ((R:segstate.parent.R:SylStructure.parent.asyl_out < 1.2)
            ((0.718478 0.878414))
            ((0.886296 0.519392)))
           ((R:segstate.parent.R:SylStructure.parent.R:Syllable.nn.stress
             is
             0)
            ((R:segstate.parent.R:SylStructure.parent.syl_out < 2.2)
             ((0.76278 0.367489))
             ((0.664103 0.0777354)))
            ((R:segstate.parent.R:SylStructure.parent.syl_in < 7)
             ((R:segstate.parent.pp.ph_cvox is +)
              ((0.828006 0.192799))
              ((0.683727 0.0329476)))
             ((0.621358 -0.139353)))))
          ((R:segstate.parent.R:SylStructure.parent.syl_codasize < 2.2)
           ((R:segstate.parent.R:SylStructure.parent.ssyl_out < 1.1)
            ((R:segstate.parent.n.ph_vlng is d)
             ((0.755235 0.754782))
             ((R:segstate.parent.pp.ph_cplace is a)
              ((R:segstate.parent.R:SylStructure.parent.syl_in < 9.2)
               ((0.752145 0.0423706))
               ((1.06405 0.436282)))
              ((R:segstate.parent.R:SylStructure.parent.syl_in < 12.5)
               ((0.752337 0.596992))
               ((0.667661 0.265988)))))
            ((R:segstate.parent.R:SylStructure.parent.R:Syllable.nn.lisp_cg_break
              <
              0.1)
             ((R:segstate.parent.R:SylStructure.parent.R:Syllable.pp.accented
               is
               0)
              ((1.09766 1.17621))
              ((1.26408 0.694611)))
             ((R:segstate.parent.lisp_coda_fric is 0)
              ((R:segstate.parent.R:SylStructure.parent.syl_out < 9.4)
               ((R:segstate.parent.R:SylStructure.parent.syl_out < 5.4)
                ((R:segstate.parent.R:SylStructure.parent.next_accent
                  <
                  1.2)
                 ((0.654613 0.226459))
                 ((R:segstate.parent.R:SylStructure.parent.parent.word_numsyls
                   <
                   2.3)
                  ((0.931272 0.814109))
                  ((0.662589 0.337302))))
                ((R:segstate.parent.R:SylStructure.parent.asyl_in
                  <
                  1.5)
                 ((R:segstate.parent.pp.ph_cplace is d)
                  ((0.838761 0.615558))
                  ((R:segstate.parent.R:SylStructure.parent.parent.word_numsyls
                    <
                    2.1)
                   ((0.930906 1.31133))
                   ((0.920194 0.730693))))
                 ((0.952538 0.517313))))
               ((R:segstate.parent.n.ph_vlng is s)
                ((R:segstate.parent.R:SylStructure.parent.syl_out
                  <
                  12.7)
                 ((0.706342 0.624306))
                 ((0.574061 0.507416)))
                ((R:segstate.parent.R:SylStructure.parent.syl_in < 2.8)
                 ((0.80997 0.268029))
                 ((0.79575 0.415942)))))
              ((0.869763 0.197624)))))
           ((1.03105 0.993208))))))
       ((R:segstate.parent.nn.ph_cvox is -)
        ((R:segstate.parent.pp.ph_cplace is a)
         ((0.721629 0.0102277))
         ((0.677736 -0.164232)))
        ((0.715021 0.0744333))))
      ((R:segstate.parent.R:SylStructure.parent.R:Syllable.p.syl_codasize
        <
        1.2)
       ((R:segstate.parent.R:SylStructure.parent.R:Syllable.nn.accented
         is
         0)
        ((0.966456 0.122196))
        ((1.28547 -0.093242)))
       ((1.00122 -0.368969))))
     ((R:segstate.parent.ph_ctype is n)
      ((R:segstate.parent.n.ph_vlng is l)
       ((R:segstate.parent.R:SylStructure.parent.position_type
         is
         single)
        ((R:segstate.parent.R:SylStructure.parent.last_accent < 1.8)
         ((1.22328 0.28809))
         ((1.72304 0.728384)))
        ((R:segstate.parent.R:SylStructure.parent.syl_in < 9)
         ((1.22992 0.177139))
         ((0.846256 -0.193216))))
       ((R:segstate.parent.R:SylStructure.parent.asyl_out < 5)
        ((R:segstate.parent.R:SylStructure.parent.last_accent < 4.5)
         ((R:segstate.parent.pp.ph_cvox is -)
          ((R:segstate.parent.n.ph_ctype is s)
           ((0.833509 -0.12912))
           ((R:segstate.parent.R:SylStructure.parent.last_accent < 1.3)
            ((R:segstate.parent.R:SylStructure.parent.syl_in < 5.2)
             ((1.20487 0.398842))
             ((0.945367 0.0731436)))
            ((0.88505 0.0328043))))
          ((R:segstate.parent.R:SylStructure.parent.syl_out < 5.6)
           ((R:segstate.parent.n.ph_vheight is 2)
            ((R:segstate.parent.R:SylStructure.parent.R:Syllable.pp.accented
              is
              0)
             ((1.14213 0.0525526))
             ((0.838271 -0.169492)))
            ((R:segstate.parent.R:SylStructure.parent.parent.word_numsyls
              <
              2)
             ((0.960828 -0.379441))
             ((0.912011 -0.00556536))))
           ((R:segstate.parent.R:SylStructure.parent.parent.word_numsyls
             <
             2.2)
            ((R:segstate.parent.pos_in_syl is 0)
             ((R:segstate.parent.R:SylStructure.parent.last_accent
               <
               1.3)
              ((1.24147 0.0564949))
              ((1.3037 0.275454)))
             ((0.679711 -0.00360172)))
            ((1.0462 -0.102035)))))
         ((0.733703 -0.214912)))
        ((0.857994 -0.266747))))
      ((R:segstate.parent.R:SylStructure.parent.parent.gpos is content)
       ((R:segstate.parent.ph_vheight is 1)
        ((2.13879 1.15305))
        ((R:segstate.parent.n.ph_vheight is 2)
         ((R:segstate.parent.nn.ph_cplace is l)
          ((R:segstate.parent.R:SylStructure.parent.syl_in < 2.4)
           ((0.792231 -0.133114))
           ((0.604449 0.174396)))
          ((R:segstate.parent.R:SylStructure.parent.parent.word_numsyls
            <
            3.5)
           ((R:segstate.parent.ph_cvox is -)
            ((R:segstate.parent.R:SylStructure.parent.next_accent
              <
              1.4)
             ((R:segstate.parent.R:SylStructure.parent.position_type
               is
               initial)
              ((R:segstate.parent.R:SylStructure.parent.syl_in < 6.1)
               ((1.12922 0.257254))
               ((0.441553 0.152544)))
              ((R:segstate.parent.p.name is ax)
               ((R:segstate.parent.n.ph_vlng is a)
                ((0.788369 0.408238))
                ((R:segstate.parent.R:SylStructure.parent.R:Syllable.n.accented
                  is
                  0)
                 ((0.995842 0.417939))
                 ((2.31079 0.920979))))
               ((R:segstate.parent.R:SylStructure.parent.parent.word_numsyls
                 <
                 2)
                ((1.0119 0.113981))
                ((1.44092 0.52356)))))
             ((R:segstate.parent.R:SylStructure.parent.ssyl_out < 4.2)
              ((R:segstate.parent.R:SylStructure.parent.ssyl_in < 3.5)
               ((R:segstate.parent.lisp_coda_glide is 0)
                ((0.856934 0.367184))
                ((1.10603 0.458834)))
               ((0.586998 0.050733)))
              ((0.709512 -0.148418))))
            ((R:segstate.parent.R:SylStructure.parent.position_type
              is
              final)
             ((R:segstate.parent.nn.ph_cplace is 0)
              ((0.645762 0.422156))
              ((1.09669 0.240092)))
             ((R:segstate.parent.R:SylStructure.parent.ssyl_in < 1.8)
              ((R:segstate.parent.R:SylStructure.parent.syl_out < 6.6)
               ((1.18819 1.07338))
               ((R:segstate.parent.nn.ph_cplace is a)
                ((1.35835 0.904241))
                ((1.23553 0.48882))))
              ((R:segstate.parent.p.name is ax)
               ((R:segstate.parent.pp.ph_cplace is d)
                ((R:segstate.parent.n.ph_vlng is s)
                 ((1.21874 0.311359))
                 ((1.22744 0.805092)))
                ((1.33341 0.966546)))
               ((1.08177 0.181316))))))
           ((R:segstate.parent.R:SylStructure.parent.ssyl_out < 2.2)
            ((1.08029 0.357073))
            ((0.619997 0.00100165)))))
         ((R:segstate.parent.nn.ph_cplace is p)
          ((R:segstate.parent.R:SylStructure.parent.asyl_out < 2.5)
           ((R:segstate.parent.ph_cvox is -)
            ((0.788436 0.0889978))
            ((0.897741 -0.325377)))
           ((0.883841 0.234148)))
          ((R:segstate.parent.n.ph_vheight is 1)
           ((R:segstate.parent.R:SylStructure.parent.ssyl_out < 8)
            ((R:segstate.parent.R:SylStructure.parent.R:Syllable.nn.accented
              is
              0)
             ((R:segstate.parent.ph_ctype is f)
              ((R:segstate.parent.R:SylStructure.parent.ssyl_in < 2.7)
               ((R:segstate.parent.R:SylStructure.parent.R:Syllable.nn.stress
                 is
                 0)
                ((0.691392 0.0692578))
                ((0.776712 -0.208332)))
               ((R:segstate.parent.R:SylStructure.parent.syl_codasize
                 <
                 1.1)
                ((0.861034 0.159731))
                ((1.36029 0.723585))))
              ((R:segstate.parent.R:SylStructure.parent.asyl_in < 0.4)
               ((1.04021 0.694324))
               ((R:segstate.parent.R:SylStructure.parent.syl_in < 7.5)
                ((0.995335 -0.00943323))
                ((1.18646 0.427866)))))
             ((R:segstate.parent.R:SylStructure.parent.syl_in < 11.5)
              ((R:segstate.parent.R:SylStructure.parent.syl_in < 9)
               ((R:segstate.parent.R:SylStructure.parent.asyl_out
                 <
                 3.5)
                ((1.16418 0.640019))
                ((1.16234 0.325705)))
               ((1.49741 1.12093)))
              ((1.09613 0.176494))))
            ((1.32093 0.990581)))
           ((R:segstate.parent.R:SylStructure.parent.parent.word_numsyls
             <
             3.5)
            ((R:segstate.parent.ph_vfront is 1)
             ((R:segstate.parent.R:SylStructure.parent.asyl_out < 1.4)
              ((0.874436 0.332511))
              ((2.39092 1.07946)))
             ((R:segstate.parent.R:SylStructure.parent.next_accent
               <
               3.3)
              ((R:segstate.parent.R:SylStructure.parent.syl_onsetsize
                <
                2.1)
               ((R:segstate.parent.n.ph_ctype is f)
                ((R:segstate.parent.R:SylStructure.parent.R:Syllable.nn.stress
                  is
                  0)
                 ((1.04829 0.229961))
                 ((R:segstate.parent.R:SylStructure.parent.ssyl_in
                   <
                   2.4)
                  ((0.793882 -0.170171))
                  ((0.768439 -0.0943406))))
                ((R:segstate.parent.R:SylStructure.parent.syl_out
                  <
                  11.8)
                 ((R:segstate.parent.R:SylStructure.parent.ssyl_out
                   <
                   5.4)
                  ((R:segstate.parent.nn.ph_vlng is s)
                   ((R:segstate.parent.pp.ph_cvox is +)
                    ((R:segstate.parent.R:SylStructure.parent.asyl_out
                      <
                      2.2)
                     ((0.909969 -0.273728))
                     ((0.997057 0.0277853)))
                    ((0.482633 0.250084)))
                   ((R:segstate.parent.R:SylStructure.parent.R:Syllable.n.lisp_cg_break
                     <
                     0.3)
                    ((R:segstate.parent.nn.ph_cvox is +)
                     ((R:segstate.parent.lisp_coda_stop is 0)
                      ((R:segstate.parent.R:SylStructure.parent.syl_out
                        <
                        4.7)
                       ((1.52673 0.463772))
                       ((0.965198 0.465599)))
                      ((1.15671 0.00588808)))
                     ((1.62843 0.819208)))
                    ((R:segstate.parent.R:SylStructure.parent.position_type
                      is
                      final)
                     ((R:segstate.parent.ph_cvox is +)
                      ((1.36573 0.126448))
                      ((0.903492 -0.185952)))
                     ((R:segstate.parent.nn.ph_cplace is v)
                      ((0.835597 -0.0635283))
                      ((R:segstate.parent.R:SylStructure.parent.R:Syllable.n.accented
                        is
                        0)
                       ((R:segstate.parent.R:SylStructure.parent.syl_in
                         <
                         9)
                        ((R:segstate.parent.R:SylStructure.parent.asyl_in
                          <
                          0.3)
                         ((R:segstate.parent.R:SylStructure.parent.asyl_out
                           <
                           2.2)
                          ((1.32748 0.254736))
                          ((1.78242 0.729175)))
                         ((R:segstate.parent.ph_ctype is f)
                          ((R:segstate.parent.pp.ph_cvox is -)
                           ((0.704037 0.0837289))
                           ((1.10608 0.324795)))
                          ((0.779792 -0.397445))))
                        ((R:segstate.parent.R:SylStructure.parent.last_accent
                          <
                          1.6)
                         ((1.22502 0.712805))
                         ((1.32842 0.494985))))
                       ((R:segstate.parent.R:SylStructure.parent.last_accent
                         <
                         2.2)
                        ((R:segstate.parent.ph_ctype is f)
                         ((R:segstate.parent.R:SylStructure.parent.R:Syllable.n.lisp_cg_break
                           <
                           1.2)
                          ((0.702139 -0.0968605))
                          ((0.664442 0.250495)))
                         ((1.04243 0.471989)))
                        ((R:segstate.parent.R:SylStructure.parent.ssyl_in
                          <
                          4.4)
                         ((1.16332 -0.21342))
                         ((1.28253 0.10027)))))))))
                  ((R:segstate.parent.R:SylStructure.parent.ssyl_in
                    <
                    1.5)
                   ((R:segstate.parent.R:SylStructure.parent.syl_out
                     <
                     9.4)
                    ((0.925628 0.475987))
                    ((1.30565 0.132436)))
                   ((1.19562 0.781868))))
                 ((R:segstate.parent.pp.ph_cplace is d)
                  ((0.554973 -0.207182))
                  ((R:segstate.parent.R:SylStructure.parent.ssyl_out
                    <
                    7.5)
                   ((0.78376 -0.104163))
                   ((1.10169 0.467177))))))
               ((R:segstate.parent.R:SylStructure.parent.R:Syllable.nn.accented
                 is
                 0)
                ((0.621075 -0.258397))
                ((0.956744 0.088528))))
              ((R:segstate.parent.lisp_coda_fric is 0)
               ((R:segstate.parent.lisp_onset_glide is 0)
                ((0.707835 0.192547))
                ((R:segstate.parent.nn.ph_cplace is a)
                 ((1.54153 0.519191))
                 ((0.947864 0.427415))))
               ((1.49716 0.773415)))))
            ((R:segstate.parent.pp.ph_cvox is +)
             ((R:segstate.parent.nn.ph_vc is +)
              ((0.980372 0.349659))
              ((0.950168 0.0491454)))
             ((0.562301 -0.323666))))))))
       ((R:segstate.parent.R:SylStructure.parent.syl_out < 7.8)
        ((R:segstate.parent.R:SylStructure.parent.asyl_out < 2.4)
         ((R:segstate.parent.ph_vheight is 2)
          ((0.632677 -0.286871))
          ((R:segstate.parent.R:SylStructure.parent.asyl_in < 1.2)
           ((0.778052 -0.0456069))
           ((0.862529 0.257433))))
         ((1.83911 0.604662)))
        ((R:segstate.parent.R:SylStructure.parent.R:Syllable.nn.lisp_cg_break
          <
          0.1)
         ((0.672155 -0.229892))
         ((0.522278 -0.615167))))))))
   ((R:segstate.parent.R:SylStructure.parent.syl_codasize < 0.5)
    ((R:segstate.parent.p.name is 0)
     ((R:segstate.parent.n.ph_vc is +)
      ((R:segstate.parent.n.ph_vheight is 2)
       ((R:segstate.parent.nn.ph_cplace is a)
        ((0.995219 0.216992))
        ((1.01859 0.295812)))
       ((R:segstate.parent.nn.ph_cplace is a)
        ((R:segstate.parent.n.ph_vheight is 1)
         ((R:segstate.parent.nn.ph_cvox is +)
          ((1.02198 0.404808))
          ((0.99578 0.344126)))
         ((R:segstate.parent.n.ph_vlng is d)
          ((1.02154 0.353883))
          ((0.976375 0.286524))))
        ((R:segstate.parent.nn.ph_cplace is l)
         ((1.03114 0.296229))
         ((R:segstate.parent.n.ph_vlng is d)
          ((1.02823 0.492585))
          ((1.05221 0.452338))))))
      ((R:segstate.parent.n.ph_ctype is f)
       ((R:segstate.parent.nn.ph_vlng is l)
        ((0.733152 0.0478705))
        ((R:segstate.parent.nn.ph_vlng is d)
         ((0.859958 0.254475))
         ((R:segstate.parent.nn.ph_vfront is 2)
          ((0.921563 0.257956))
          ((0.872689 0.210423)))))
       ((R:segstate.parent.nn.ph_cplace is g)
        ((0.65771 -0.0139175))
        ((R:segstate.parent.n.ph_ctype is 0)
         ((R:segstate.parent.nn.ph_cplace is 0)
          ((R:segstate.parent.nn.ph_vc is +)
           ((R:segstate.parent.nn.ph_vrnd is +)
            ((0.576268 -0.23313))
            ((R:segstate.parent.nn.ph_vlng is a)
             ((0.650859 -0.259281))
             ((R:segstate.parent.nn.ph_vlng is s)
              ((0.809192 -0.333359))
              ((0.777207 -0.418246)))))
           ((0.472548 -0.622528)))
          ((R:segstate.parent.nn.ph_cplace is p)
           ((R:segstate.parent.nn.ph_cvox is +)
            ((0.473982 -0.194766))
            ((0.633454 -0.199875)))
           ((R:segstate.parent.nn.ph_cplace is a)
            ((R:segstate.parent.nn.ph_cvox is +)
             ((0.663487 -0.305651))
             ((0.628353 -0.140138)))
            ((R:segstate.parent.nn.ph_cplace is b)
             ((0.544836 -0.266125))
             ((R:segstate.parent.nn.ph_cplace is l)
              ((0.628127 -0.310981))
              ((0.531985 -0.329649)))))))
         ((R:segstate.parent.nn.ph_vfront is 2)
          ((R:segstate.parent.nn.ph_vlng is a)
           ((0.528453 -0.49609))
           ((0.82629 -0.263811)))
          ((R:segstate.parent.n.ph_ctype is s)
           ((R:segstate.parent.nn.ph_vlng is l)
            ((0.654356 -0.252022))
            ((R:segstate.parent.nn.ph_vlng is s)
             ((0.835107 -0.185563))
             ((0.747758 -0.0614197))))
           ((R:segstate.parent.nn.ph_vfront is 1)
            ((0.869865 -0.128937))
            ((0.762796 0.0788341)))))))))
     ((R:segstate.parent.n.ph_vheight is 2)
      ((R:segstate.parent.p.name is pau)
       ((R:segstate.parent.nn.ph_cplace is a)
        ((0.341396 -0.716605))
        ((R:segstate.parent.nn.ph_cplace is l)
         ((0.726814 -0.96915))
         ((0.396247 -0.81597))))
       ((R:segstate.parent.n.ph_vlng is a)
        ((R:segstate.parent.p.ph_ctype is s)
         ((0.337019 -0.631058))
         ((R:segstate.parent.nn.ph_cplace is a)
          ((0.735665 0.150402))
          ((R:segstate.parent.pp.ph_cplace is 0)
           ((0.869797 -0.0185888))
           ((0.985651 -0.408628)))))
        ((R:segstate.parent.nn.ph_cvox is +)
         ((R:segstate.parent.nn.ph_cplace is b)
          ((R:segstate.parent.p.ph_ctype is f)
           ((0.688787 -0.26573))
           ((R:segstate.parent.p.ph_cplace is a)
            ((0.931486 0.216978))
            ((1.03648 -0.0466782))))
          ((R:segstate.parent.p.ph_ctype is f)
           ((1.07432 0.59006))
           ((0.81748 0.124903))))
         ((0.946353 0.938554)))))
      ((R:segstate.parent.n.ph_ctype is a)
       ((R:segstate.parent.pp.ph_vc is +)
        ((R:segstate.parent.p.ph_cplace is a)
         ((1.50358 0.0985183))
         ((1.16733 0.733982)))
        ((0.91757 -0.512403)))
       ((R:segstate.parent.n.ph_ctype is n)
        ((R:segstate.parent.p.name is pau)
         ((R:segstate.parent.nn.ph_vfront is 1)
          ((0.992695 0.264932))
          ((R:segstate.parent.nn.ph_vlng is d)
           ((R:segstate.parent.nn.ph_vfront is 2)
            ((0.824068 0.132159))
            ((0.818474 0.0591068)))
           ((0.726323 -0.263666))))
         ((R:segstate.parent.nn.ph_vlng is d)
          ((0.359733 -0.689273))
          ((R:segstate.parent.p.ph_cvox is -)
           ((0.503122 -0.43686))
           ((0.397468 -0.602648)))))
        ((R:segstate.parent.n.ph_vlng is l)
         ((R:segstate.parent.p.ph_cvox is +)
          ((R:segstate.parent.pp.ph_vheight is 3)
           ((0.878368 -0.0710379))
           ((0.955239 0.307568)))
          ((R:segstate.parent.p.name is pau)
           ((R:segstate.parent.pp.ph_cvox is -)
            ((0.554649 -0.735021))
            ((0.576889 -0.723303)))
           ((R:segstate.parent.p.ph_vc is +)
            ((0.600069 -0.335106))
            ((0.981996 -0.296572)))))
         ((R:segstate.parent.n.ph_ctype is 0)
          ((R:segstate.parent.p.name is pau)
           ((R:segstate.parent.n.ph_vc is +)
            ((R:segstate.parent.pp.ph_vc is -)
             ((R:segstate.parent.pp.ph_cplace is a)
              ((0.478392 -0.887154))
              ((R:segstate.parent.nn.ph_cvox is +)
               ((0.70642 -0.769038))
               ((0.708572 -0.803408))))
             ((R:segstate.parent.nn.ph_cvox is +)
              ((R:segstate.parent.n.ph_vlng is d)
               ((R:segstate.parent.nn.ph_cplace is l)
                ((0.672012 -0.517077))
                ((0.718217 -0.613544)))
               ((0.41918 -0.535896)))
              ((R:segstate.parent.nn.ph_cplace is a)
               ((0.306356 -0.622456))
               ((0.669802 -0.734576)))))
            ((R:segstate.parent.nn.ph_cplace is a)
             ((0.295358 -0.661727))
             ((R:segstate.parent.nn.ph_vlng is d)
              ((0.54668 -1.08845))
              ((R:segstate.parent.nn.ph_vrnd is -)
               ((0.435717 -0.820661))
               ((R:segstate.parent.nn.ph_cplace is 0)
                ((0.58953 -1.09045))
                ((R:segstate.parent.nn.ph_cvox is +)
                 ((R:segstate.parent.nn.ph_cplace is l)
                  ((0.72903 -0.928844))
                  ((0.52482 -1.00464)))
                 ((0.488632 -0.864688))))))))
           ((R:segstate.parent.n.ph_vc is +)
            ((R:segstate.parent.pp.ph_vlng is s)
             ((R:segstate.parent.p.ph_ctype is n)
              ((R:segstate.parent.pp.ph_vheight is 1)
               ((0.432128 -0.524567))
               ((0.828275 -0.108358)))
              ((R:segstate.parent.pp.ph_vheight is 1)
               ((1.01968 0.216601))
               ((0.70093 -0.205752))))
             ((R:segstate.parent.pp.ph_vlng is a)
              ((R:segstate.parent.n.ph_vheight is 1)
               ((0.467213 -0.5055))
               ((R:segstate.parent.p.ph_ctype is n)
                ((1.00573 0.238891))
                ((0.914525 -0.298851))))
              ((R:segstate.parent.p.ph_ctype is s)
               ((R:segstate.parent.pp.ph_cplace is a)
                ((0.715919 -0.18145))
                ((R:segstate.parent.pp.ph_vlng is d)
                 ((0.468421 -0.478465))
                 ((0.864619 -0.390586))))
               ((R:segstate.parent.p.ph_vfront is 3)
                ((0.868968 -0.199407))
                ((R:segstate.parent.n.ph_vheight is 1)
                 ((R:segstate.parent.pp.ph_cvox is +)
                  ((0.751482 -0.113945))
                  ((R:segstate.parent.p.ph_cvox is +)
                   ((0.59873 -0.491876))
                   ((0.524675 -0.670945))))
                 ((R:segstate.parent.pp.ph_vlng is d)
                  ((0.626358 -0.354701))
                  ((R:segstate.parent.p.ph_vc is +)
                   ((0.401984 -0.655834))
                   ((R:segstate.parent.p.ph_cplace is a)
                    ((R:segstate.parent.pp.ph_cplace is a)
                     ((0.818613 -0.598059))
                     ((0.809478 -0.477104)))
                    ((0.53904 -0.553674))))))))))
            ((R:segstate.parent.pp.ph_cvox is +)
             ((0.82857 -0.402863))
             ((R:segstate.parent.nn.ph_vlng is s)
              ((0.59105 -0.706093))
              ((0.649426 -0.76191))))))
          ((R:segstate.parent.p.name is pau)
           ((R:segstate.parent.n.ph_ctype is r)
            ((R:segstate.parent.nn.ph_vfront is 3)
             ((0.766908 -0.398822))
             ((R:segstate.parent.pp.ph_vc is -)
              ((0.675096 0.209659))
              ((R:segstate.parent.nn.ph_vlng is s)
               ((R:segstate.parent.nn.ph_vfront is 1)
                ((0.557606 -0.221322))
                ((0.897993 -0.0780838)))
               ((0.837134 -0.029511)))))
            ((R:segstate.parent.nn.ph_vlng is l)
             ((R:segstate.parent.nn.ph_vfront is 1)
              ((0.355997 -0.561691))
              ((R:segstate.parent.n.ph_ctype is f)
               ((0.634428 -0.0740446))
               ((0.667101 -0.1147))))
             ((R:segstate.parent.pp.ph_vc is 0)
              ((R:segstate.parent.nn.ph_vlng is d)
               ((R:segstate.parent.nn.ph_vfront is 1)
                ((0.680679 -0.506426))
                ((0.705724 -0.270637)))
               ((R:segstate.parent.nn.ph_vfront is 1)
                ((R:segstate.parent.n.ph_ctype is f)
                 ((0.621049 -0.261775))
                 ((1.06513 -0.164402)))
                ((R:segstate.parent.n.ph_ctype is f)
                 ((R:segstate.parent.nn.ph_vlng is s)
                  ((0.32397 -0.374426))
                  ((0.748129 -0.321725)))
                 ((0.741582 -0.444972)))))
              ((R:segstate.parent.nn.ph_vlng is s)
               ((0.843436 -0.396746))
               ((R:segstate.parent.nn.ph_vfront is 2)
                ((1.11833 0.117693))
                ((1.70492 -0.0642444)))))))
           ((R:segstate.parent.p.ph_cplace is p)
            ((R:segstate.parent.nn.ph_vlng is l)
             ((0.777679 -0.548955))
             ((1.52012 0.17384)))
            ((R:segstate.parent.p.name is v)
             ((0.792009 -0.167796))
             ((R:segstate.parent.p.ph_vfront is 1)
              ((R:segstate.parent.pp.ph_cvox is +)
               ((R:segstate.parent.n.ph_ctype is f)
                ((0.219101 -0.673547))
                ((0.351963 -0.457094)))
               ((0.738657 -0.284002)))
              ((R:segstate.parent.nn.ph_cplace is a)
               ((R:segstate.parent.pp.ph_vheight is 2)
                ((0.510128 -0.554652))
                ((R:segstate.parent.n.ph_ctype is f)
                 ((R:segstate.parent.p.ph_cvox is -)
                  ((0.257274 -0.784791))
                  ((0.247417 -0.740056)))
                 ((R:segstate.parent.p.ph_ctype is f)
                  ((0.643093 -0.804641))
                  ((0.315845 -0.848491)))))
               ((R:segstate.parent.p.ph_ctype is f)
                ((R:segstate.parent.pp.ph_cvox is +)
                 ((R:segstate.parent.p.name is s)
                  ((0.476686 -0.796963))
                  ((R:segstate.parent.nn.ph_vfront is 1)
                   ((0.256945 -0.713052))
                   ((0.500438 -0.546132))))
                 ((R:segstate.parent.pp.ph_vlng is a)
                  ((0.436929 -0.592526))
                  ((R:segstate.parent.n.ph_ctype is f)
                   ((0.708385 -0.188678))
                   ((R:segstate.parent.nn.ph_vfront is 1)
                    ((0.613572 -0.341708))
                    ((R:segstate.parent.p.name is z)
                     ((0.690067 -0.414833))
                     ((0.417053 -0.60936)))))))
                ((R:segstate.parent.n.ph_ctype is s)
                 ((R:segstate.parent.p.name is t)
                  ((R:segstate.parent.pp.ph_vc is +)
                   ((0.209063 -0.845064))
                   ((0.260415 -0.914359)))
                  ((R:segstate.parent.nn.ph_vfront is 2)
                   ((R:segstate.parent.p.ph_ctype is s)
                    ((0.367718 -0.641576))
                    ((R:segstate.parent.pp.ph_vheight is 2)
                     ((0.218326 -0.528316))
                     ((0.32462 -0.46763))))
                   ((R:segstate.parent.p.ph_ctype is s)
                    ((0.271686 -0.81307))
                    ((0.260972 -0.681077)))))
                 ((R:segstate.parent.nn.ph_vlng is s)
                  ((R:segstate.parent.pp.ph_vheight is 3)
                   ((R:segstate.parent.p.ph_ctype is s)
                    ((0.687361 -0.44938))
                    ((0.435626 -0.595746)))
                   ((R:segstate.parent.p.name is d)
                    ((R:segstate.parent.pp.ph_vc is +)
                     ((0.383194 -0.502434))
                     ((0.304659 -0.618965)))
                    ((R:segstate.parent.pp.ph_cvox is -)
                     ((0.248511 -0.662113))
                     ((R:segstate.parent.p.ph_cvox is +)
                      ((R:segstate.parent.p.ph_cplace is a)
                       ((0.180016 -0.732398))
                       ((0.18846 -0.77255)))
                      ((0.212338 -0.857944))))))
                  ((R:segstate.parent.pp.ph_cplace is a)
                   ((R:segstate.parent.nn.ph_vrnd is +)
                    ((0.581176 -0.467452))
                    ((0.760288 -0.307287)))
                   ((R:segstate.parent.p.name is ng)
                    ((0.525408 -0.354981))
                    ((R:segstate.parent.p.name is n)
                     ((R:segstate.parent.pp.ph_vlng is a)
                      ((0.560723 -0.419172))
                      ((0.207442 -0.63271)))
                     ((R:segstate.parent.pp.ph_vlng is a)
                      ((0.24914 -0.742119))
                      ((R:segstate.parent.pp.ph_vlng is s)
                       ((R:segstate.parent.nn.ph_vlng is a)
                        ((0.298188 -0.782166))
                        ((R:segstate.parent.pp.ph_vheight is 1)
                         ((0.656808 -0.535818))
                         ((0.363353 -0.733025))))
                       ((R:segstate.parent.p.name is t)
                        ((0.690896 -0.395676))
                        ((R:segstate.parent.p.ph_ctype is s)
                         ((0.361729 -0.74237))
                         ((R:segstate.parent.pp.ph_vc is +)
                          ((0.397157 -0.610037))
                          ((0.241217 -0.555263))))))))))))))))))))))))
    ((R:segstate.parent.R:SylStructure.parent.ssyl_in < 2.6)
     ((R:segstate.parent.pp.ph_vc is 0)
      ((R:segstate.parent.ph_vheight is 3)
       ((R:segstate.parent.R:SylStructure.parent.R:Syllable.n.syl_onsetsize
         <
         0.2)
        ((1.32921 0.342115))
        ((R:segstate.parent.n.ph_ctype is l)
         ((0.363906 -0.610541))
         ((R:segstate.parent.R:SylStructure.parent.parent.gpos
           is
           content)
          ((R:segstate.parent.R:SylStructure.parent.ssyl_out < 7)
           ((R:segstate.parent.R:SylStructure.parent.R:Syllable.n.accented
             is
             0)
            ((0.493929 -0.0847594))
            ((0.461371 -0.243635)))
           ((0.880669 -0.524057)))
          ((R:segstate.parent.R:SylStructure.parent.syl_codasize < 2.1)
           ((0.52401 -0.166228))
           ((R:segstate.parent.R:SylStructure.parent.ssyl_out < 6.6)
            ((0.836447 -0.118066))
            ((0.732685 -0.0433935)))))))
       ((R:segstate.parent.ph_ctype is f)
        ((R:segstate.parent.R:SylStructure.parent.asyl_out < 6.4)
         ((R:segstate.parent.R:SylStructure.parent.asyl_out < 3.6)
          ((R:segstate.parent.R:SylStructure.parent.syl_out < 10.6)
           ((R:segstate.parent.R:SylStructure.parent.ssyl_out < 5.6)
            ((R:segstate.parent.R:SylStructure.parent.parent.gpos
              is
              content)
             ((R:segstate.parent.R:SylStructure.parent.syl_out < 6.4)
              ((1.1152 0.579751))
              ((1.45536 0.875588)))
             ((1.03409 0.426784)))
            ((1.12247 0.331678)))
           ((0.869096 0.161774)))
          ((R:segstate.parent.R:SylStructure.parent.syl_out < 9.9)
           ((R:segstate.parent.R:SylStructure.parent.parent.gpos
             is
             content)
            ((0.9692 0.525718))
            ((1.26181 1.00143)))
           ((R:segstate.parent.R:SylStructure.parent.parent.gpos
             is
             content)
            ((R:segstate.parent.R:SylStructure.parent.syl_out < 12.4)
             ((R:segstate.parent.n.ph_vlng is l)
              ((R:segstate.parent.R:SylStructure.parent.ssyl_out < 8.4)
               ((1.17468 0.290455))
               ((1.0772 0.526036)))
              ((1.17427 0.646747)))
             ((R:segstate.parent.R:SylStructure.parent.ssyl_out < 9.2)
              ((1.53349 0.855371))
              ((0.927597 0.596384))))
            ((R:segstate.parent.nn.ph_cvox is -)
             ((0.836951 0.4468))
             ((0.978051 0.295247))))))
         ((0.856966 0.124519)))
        ((R:segstate.parent.ph_cvox is +)
         ((R:segstate.parent.R:SylStructure.parent.asyl_out < 1.8)
          ((0.616931 -0.587909))
          ((R:segstate.parent.R:SylStructure.parent.R:Syllable.nn.stress
            is
            0)
           ((R:segstate.parent.ph_ctype is s)
            ((R:segstate.parent.R:SylStructure.parent.syl_out < 11.4)
             ((0.648489 -0.444648))
             ((1.04093 -0.106812)))
            ((0.791859 0.149388)))
           ((R:segstate.parent.n.ph_vheight is 1)
            ((R:segstate.parent.R:SylStructure.parent.R:Syllable.n.accented
              is
              0)
             ((0.691151 0.0712074))
             ((1.32562 0.564503)))
            ((R:segstate.parent.ph_ctype is r)
             ((0.998009 0.326733))
             ((R:segstate.parent.R:SylStructure.parent.ssyl_out < 7.5)
              ((R:segstate.parent.R:SylStructure.parent.R:Syllable.n.accented
                is
                0)
               ((1.06233 0.0406998))
               ((1.01007 0.285781)))
              ((R:segstate.parent.R:SylStructure.parent.R:Syllable.n.accented
                is
                0)
               ((1.01627 -0.00617388))
               ((0.870653 -0.260571))))))))
         ((R:segstate.parent.n.ph_vlng is s)
          ((1.23251 -0.212647))
          ((R:segstate.parent.n.ph_ctype is 0)
           ((R:segstate.parent.nn.ph_cvox is +)
            ((R:segstate.parent.R:SylStructure.parent.syl_out < 7.4)
             ((1.20966 0.196679))
             ((1.33543 0.844255)))
            ((1.58848 1.28536)))
           ((R:segstate.parent.R:SylStructure.parent.syl_out < 16.7)
            ((R:segstate.parent.R:SylStructure.parent.parent.gpos
              is
              in)
             ((R:segstate.parent.R:SylStructure.parent.R:Syllable.n.accented
               is
               0)
              ((0.968634 0.449026))
              ((0.964112 0.689231)))
             ((R:segstate.parent.R:SylStructure.parent.syl_out < 10.4)
              ((R:segstate.parent.R:SylStructure.parent.R:Syllable.nn.lisp_cg_break
                <
                0.3)
               ((0.742646 0.212666))
               ((R:segstate.parent.R:SylStructure.parent.syl_out < 6)
                ((R:segstate.parent.nn.ph_cplace is l)
                 ((0.832149 0.19281))
                 ((0.915852 0.434515)))
                ((R:segstate.parent.R:SylStructure.parent.R:Syllable.n.accented
                  is
                  0)
                 ((0.942449 0.505024))
                 ((1.37024 0.746384)))))
              ((R:segstate.parent.R:SylStructure.parent.position_type
                is
                initial)
               ((0.796262 -0.0505205))
               ((R:segstate.parent.R:SylStructure.parent.asyl_out < 4)
                ((R:segstate.parent.R:SylStructure.parent.R:Syllable.nn.accented
                  is
                  0)
                 ((0.830444 0.212564))
                 ((0.727488 -0.0151683)))
                ((R:segstate.parent.R:SylStructure.parent.R:Syllable.nn.lisp_cg_break
                  <
                  0.1)
                 ((0.752559 0.250088))
                 ((1.37923 0.537701)))))))
            ((0.605127 -0.0363994))))))))
      ((R:segstate.parent.ph_ctype is 0)
       ((R:segstate.parent.n.ph_ctype is 0)
        ((R:segstate.parent.R:SylStructure.parent.parent.gpos is det)
         ((R:segstate.parent.n.ph_vheight is 1)
          ((0.844281 -0.324869))
          ((R:segstate.parent.p.name is dh)
           ((R:segstate.parent.nn.ph_cvox is +)
            ((R:segstate.parent.R:SylStructure.parent.syl_out < 9)
             ((2.92241 1.47414))
             ((3.43618 2.35307)))
            ((2.72208 0.875169)))
           ((1.16283 0.40227))))
         ((R:segstate.parent.n.ph_vc is +)
          ((R:segstate.parent.p.name is b)
           ((R:segstate.parent.n.ph_vlng is l)
            ((2.42589 1.28505))
            ((0.628358 0.0733696)))
           ((R:segstate.parent.R:SylStructure.parent.last_accent < 0.4)
            ((R:segstate.parent.ph_vrnd is +)
             ((R:segstate.parent.lisp_onset_glide is 0)
              ((R:segstate.parent.pp.ph_cplace is 0)
               ((R:segstate.parent.R:SylStructure.parent.syl_out
                 <
                 10.5)
                ((1.14356 0.686196))
                ((0.87682 0.337987)))
               ((R:segstate.parent.n.ph_vlng is s)
                ((0.840592 0.0547369))
                ((0.98106 0.351047))))
              ((0.765806 -0.216538)))
             ((R:segstate.parent.pos_in_syl is 1)
              ((R:segstate.parent.R:SylStructure.parent.ssyl_out < 6.5)
               ((R:segstate.parent.R:SylStructure.parent.R:Syllable.p.syl_codasize
                 <
                 2.4)
                ((R:segstate.parent.p.ph_ctype is n)
                 ((0.750049 -0.544229))
                 ((R:segstate.parent.n.ph_vlng is d)
                  ((1.05139 0.121171))
                  ((R:segstate.parent.R:SylStructure.parent.R:Syllable.p.syl_codasize
                    <
                    1.2)
                   ((R:segstate.parent.n.ph_vlng is s)
                    ((0.92423 -0.102686))
                    ((0.702522 -0.299923)))
                   ((0.632347 -0.418334)))))
                ((0.684377 0.105595)))
               ((R:segstate.parent.p.ph_cvox is +)
                ((R:segstate.parent.n.ph_vheight is 2)
                 ((1.19103 0.249235))
                 ((1.06582 -0.0890784)))
                ((0.567453 -0.273856))))
              ((0.854026 -0.480863))))
            ((R:segstate.parent.R:SylStructure.parent.next_accent
              <
              5.4)
             ((R:segstate.parent.ph_vheight is 2)
              ((R:segstate.parent.R:SylStructure.parent.next_accent
                <
                1.5)
               ((0.773704 0.0571467))
               ((R:segstate.parent.pp.ph_cplace is a)
                ((0.606922 -0.469738))
                ((0.775992 -0.182967))))
              ((R:segstate.parent.pos_in_syl is 1)
               ((R:segstate.parent.nn.ph_cplace is 0)
                ((0.867341 -0.199357))
                ((R:segstate.parent.R:SylStructure.parent.syl_in < 3.5)
                 ((R:segstate.parent.nn.ph_cvox is +)
                  ((R:segstate.parent.ph_vfront is 3)
                   ((0.812782 -0.22195))
                   ((R:segstate.parent.p.ph_cvox is +)
                    ((1.13888 0.728889))
                    ((0.621347 0.0578508))))
                  ((1.19318 0.852519)))
                 ((0.667302 -0.0859733))))
               ((R:segstate.parent.R:SylStructure.parent.lisp_cg_break
                 <
                 0.1)
                ((1.14707 0.304412))
                ((1.59379 0.948484)))))
             ((1.69919 0.981478)))))
          ((R:segstate.parent.lisp_onset_stop is 0)
           ((R:segstate.parent.nn.ph_cplace is l)
            ((1.11412 -0.200139))
            ((R:segstate.parent.R:SylStructure.parent.R:Syllable.p.syl_codasize
              <
              1.2)
             ((R:segstate.parent.nn.ph_vfront is 2)
              ((1.55588 1.10609))
              ((R:segstate.parent.R:SylStructure.parent.R:Syllable.n.accented
                is
                0)
               ((R:segstate.parent.pp.ph_vheight is 2)
                ((0.948881 0.219897))
                ((R:segstate.parent.nn.ph_vc is +)
                 ((1.65129 0.925238))
                 ((2.43646 1.29636))))
               ((1.14185 0.0213256))))
             ((R:segstate.parent.pp.ph_cvox is +)
              ((R:segstate.parent.p.ph_cplace is a)
               ((1.20111 0.639093))
               ((R:segstate.parent.R:SylStructure.parent.syl_out < 9)
                ((1.37594 0.426343))
                ((0.576112 -0.179339))))
              ((0.86178 -0.179141)))))
           ((R:segstate.parent.ph_vheight is 2)
            ((3.09315 2.11597))
            ((R:segstate.parent.pp.ph_cvox is +)
             ((2.61693 1.47972))
             ((0.927139 0.30227)))))))
        ((R:segstate.parent.lisp_onset_glide is 0)
         ((R:segstate.parent.n.ph_ctype is l)
          ((R:segstate.parent.p.ph_vlng is l)
           ((1.28264 0.227406))
           ((R:segstate.parent.p.name is n)
            ((0.955809 0.237393))
            ((R:segstate.parent.ph_vheight is 3)
             ((R:segstate.parent.nn.ph_cplace is a)
              ((R:segstate.parent.pp.ph_cvox is +)
               ((0.553983 -0.55843))
               ((R:segstate.parent.p.ph_ctype is 0)
                ((0.536479 -0.366883))
                ((0.940263 -0.200894))))
              ((R:segstate.parent.p.ph_cplace is l)
               ((0.939136 -0.434979))
               ((R:segstate.parent.p.ph_ctype is s)
                ((R:segstate.parent.R:SylStructure.parent.asyl_in
                  <
                  0.2)
                 ((0.942117 0.331722))
                 ((0.857846 0.115835)))
                ((R:segstate.parent.pp.ph_cplace is 0)
                 ((R:segstate.parent.R:SylStructure.parent.ssyl_in
                   <
                   0.2)
                  ((1.15699 0.0655979))
                  ((0.870052 -0.14925)))
                 ((R:segstate.parent.R:SylStructure.parent.next_accent
                   <
                   1.2)
                  ((0.642032 -0.164581))
                  ((0.825622 -0.455106)))))))
             ((R:segstate.parent.R:SylStructure.parent.syl_out < 4.8)
              ((R:segstate.parent.lisp_coda_stop is 0)
               ((R:segstate.parent.p.ph_ctype is s)
                ((1.00914 0.214879))
                ((R:segstate.parent.R:SylStructure.parent.syl_in < 3.5)
                 ((0.620991 -0.485041))
                 ((0.890305 -0.0759353))))
               ((0.449639 -0.622782)))
              ((R:segstate.parent.R:SylStructure.parent.stress is 0)
               ((R:segstate.parent.lisp_onset_stop is 0)
                ((R:segstate.parent.pp.ph_vheight is 2)
                 ((0.496505 -0.28425))
                 ((R:segstate.parent.p.ph_cvox is +)
                  ((R:segstate.parent.R:SylStructure.parent.ssyl_in
                    <
                    1.2)
                   ((R:segstate.parent.R:SylStructure.parent.syl_out
                     <
                     10.5)
                    ((0.144478 -0.494889))
                    ((0.140298 -0.43365)))
                   ((0.128477 -0.534212)))
                  ((0.301738 -0.360964))))
                ((R:segstate.parent.pp.ph_vheight is 1)
                 ((R:segstate.parent.R:SylStructure.parent.asyl_out
                   <
                   3.5)
                  ((0.172835 -0.49862))
                  ((0.302986 -0.400793)))
                 ((R:segstate.parent.R:SylStructure.parent.parent.word_numsyls
                   <
                   2.2)
                  ((0.168183 -0.619669))
                  ((0.189431 -0.497779)))))
               ((R:segstate.parent.nn.ph_cplace is 0)
                ((R:segstate.parent.nn.ph_vrnd is -)
                 ((R:segstate.parent.p.ph_ctype is f)
                  ((R:segstate.parent.R:SylStructure.parent.R:Syllable.p.syl_codasize
                    <
                    0.3)
                   ((R:segstate.parent.R:SylStructure.parent.ssyl_out
                     <
                     7.5)
                    ((0.345533 -0.455786))
                    ((0.341399 -0.348159)))
                   ((0.364929 -0.645956)))
                  ((0.70563 -0.0946003)))
                 ((0.915164 0.00555736)))
                ((R:segstate.parent.R:SylStructure.parent.lisp_cg_break
                  <
                  0.1)
                 ((0.1947 -0.717004))
                 ((R:segstate.parent.R:SylStructure.parent.R:Syllable.nn.lisp_cg_break
                   <
                   0.1)
                  ((R:segstate.parent.R:SylStructure.parent.syl_in
                    <
                    2.5)
                   ((0.351143 -0.401379))
                   ((0.378668 -0.58785)))
                  ((R:segstate.parent.R:SylStructure.parent.R:Syllable.pp.accented
                    is
                    0)
                   ((R:segstate.parent.R:SylStructure.parent.R:Syllable.p.lisp_cg_break
                     <
                     0.1)
                    ((0.66325 0.0154144))
                    ((0.883355 -0.35863)))
                   ((0.373004 -0.388544)))))))))))
          ((R:segstate.parent.R:SylStructure.parent.syl_codasize < 1.3)
           ((R:segstate.parent.p.name is dh)
            ((R:segstate.parent.nn.ph_vfront is 3)
             ((R:segstate.parent.ph_vfront is 1)
              ((0.621684 -0.446048))
              ((R:segstate.parent.pp.ph_cvox is -)
               ((R:segstate.parent.R:SylStructure.parent.R:Syllable.nn.lisp_cg_break
                 <
                 0.3)
                ((1.61911 0.371778))
                ((R:segstate.parent.R:SylStructure.parent.asyl_out
                  <
                  3.1)
                 ((0.936049 0.0856434))
                 ((0.47675 -0.272311))))
               ((R:segstate.parent.R:SylStructure.parent.asyl_out
                 <
                 2.1)
                ((0.557085 -0.0799322))
                ((0.57932 -0.308346)))))
             ((R:segstate.parent.pp.ph_cvox is -)
              ((R:segstate.parent.n.ph_ctype is f)
               ((R:segstate.parent.nn.ph_vlng is d)
                ((0.788459 -0.0729683))
                ((R:segstate.parent.R:SylStructure.parent.R:Syllable.nn.lisp_cg_break
                  <
                  0.3)
                 ((0.260189 -0.376502))
                 ((R:segstate.parent.R:SylStructure.parent.syl_out
                   <
                   9.2)
                  ((R:segstate.parent.R:SylStructure.parent.R:Syllable.p.syl_codasize
                    <
                    0.3)
                   ((0.488818 -0.34431))
                   ((0.50439 -0.329073)))
                  ((R:segstate.parent.R:SylStructure.parent.R:Syllable.nn.stress
                    is
                    0)
                   ((0.432729 -0.307312))
                   ((0.676631 -0.156051))))))
               ((R:segstate.parent.nn.ph_cplace is a)
                ((0.53905 -0.197061))
                ((R:segstate.parent.R:SylStructure.parent.R:Syllable.n.lisp_cg_break
                  <
                  0.1)
                 ((R:segstate.parent.R:SylStructure.parent.R:Syllable.nn.lisp_cg_break
                   <
                   0.1)
                  ((0.366824 -0.291798))
                  ((R:segstate.parent.R:SylStructure.parent.ssyl_out
                    <
                    5.1)
                   ((0.458093 -0.281349))
                   ((0.274348 -0.477896))))
                 ((R:segstate.parent.R:SylStructure.parent.syl_out < 9)
                  ((0.545899 -0.368417))
                  ((R:segstate.parent.R:SylStructure.parent.asyl_out
                    <
                    4.5)
                   ((0.456933 -0.689521))
                   ((0.397906 -0.405223)))))))
              ((R:segstate.parent.R:SylStructure.parent.ssyl_out < 3.7)
               ((R:segstate.parent.R:SylStructure.parent.R:Syllable.n.accented
                 is
                 0)
                ((0.317962 -0.241154))
                ((R:segstate.parent.R:SylStructure.parent.syl_in < 3.4)
                 ((0.425481 -0.419893))
                 ((0.297751 -0.323892))))
               ((R:segstate.parent.R:SylStructure.parent.R:Syllable.p.syl_codasize
                 <
                 2)
                ((R:segstate.parent.R:SylStructure.parent.R:Syllable.p.stress
                  is
                  0)
                 ((0.479147 -0.244305))
                 ((R:segstate.parent.nn.ph_vlng is s)
                  ((0.790758 0.165625))
                  ((R:segstate.parent.R:SylStructure.parent.syl_out
                    <
                    10)
                   ((0.668804 -0.0584128))
                   ((0.597017 -0.267916)))))
                ((0.477584 -0.310355))))))
            ((R:segstate.parent.p.name is hh)
             ((R:segstate.parent.R:SylStructure.parent.last_accent
               <
               0.3)
              ((R:segstate.parent.nn.ph_vfront is 1)
               ((R:segstate.parent.n.ph_ctype is f)
                ((R:segstate.parent.R:SylStructure.parent.syl_out
                  <
                  8.4)
                 ((0.676535 -0.201102))
                 ((R:segstate.parent.R:SylStructure.parent.ssyl_out
                   <
                   7.5)
                  ((0.846858 0.0403526))
                  ((0.753266 0.104943))))
                ((R:segstate.parent.R:SylStructure.parent.R:Syllable.n.accented
                  is
                  0)
                 ((0.374429 -0.402119))
                 ((R:segstate.parent.R:SylStructure.parent.syl_out
                   <
                   11.8)
                  ((0.616208 -0.19504))
                  ((0.663636 -0.154792)))))
               ((R:segstate.parent.R:SylStructure.parent.R:Syllable.pp.lisp_cg_break
                 <
                 0.1)
                ((R:segstate.parent.R:SylStructure.parent.next_accent
                  <
                  2)
                 ((R:segstate.parent.R:SylStructure.parent.asyl_out
                   <
                   5.2)
                  ((R:segstate.parent.n.ph_ctype is f)
                   ((0.427956 -0.321126))
                   ((R:segstate.parent.n.ph_ctype is s)
                    ((R:segstate.parent.R:SylStructure.parent.syl_out
                      <
                      10)
                     ((0.445767 -0.395935))
                     ((0.49616 -0.319039)))
                    ((0.352803 -0.441962))))
                  ((0.254028 -0.466099)))
                 ((R:segstate.parent.R:SylStructure.parent.syl_out
                   <
                   8.5)
                  ((0.296076 -0.339261))
                  ((R:segstate.parent.R:SylStructure.parent.next_accent
                    <
                    5.2)
                   ((0.448968 -0.143931))
                   ((0.708984 -0.293158)))))
                ((R:segstate.parent.R:SylStructure.parent.syl_in < 2.2)
                 ((0.507969 -0.392622))
                 ((0.307164 -0.567081)))))
              ((R:segstate.parent.n.ph_ctype is s)
               ((0.518167 -0.323362))
               ((R:segstate.parent.R:SylStructure.parent.asyl_out
                 <
                 2.1)
                ((0.703324 -0.020827))
                ((1.31807 0.326851)))))
             ((R:segstate.parent.R:SylStructure.parent.parent.gpos
               is
               det)
              ((R:segstate.parent.ph_vfront is 1)
               ((R:segstate.parent.p.name is pau)
                ((0.714571 0.00705756))
                ((0.690228 -0.270152)))
               ((R:segstate.parent.p.name is pau)
                ((R:segstate.parent.R:SylStructure.parent.syl_out
                  <
                  9.5)
                 ((1.6003 0.74942))
                 ((1.31467 0.166562)))
                ((R:segstate.parent.nn.ph_vlng is s)
                 ((R:segstate.parent.R:SylStructure.parent.syl_out
                   <
                   5.6)
                  ((0.96206 0.295705))
                  ((R:segstate.parent.R:SylStructure.parent.ssyl_out
                    <
                    6.5)
                   ((R:segstate.parent.R:SylStructure.parent.R:Syllable.n.lisp_cg_break
                     <
                     0.1)
                    ((0.558618 -0.332068))
                    ((0.645428 -0.03755)))
                   ((R:segstate.parent.R:SylStructure.parent.asyl_out
                     <
                     5.2)
                    ((0.807233 -0.0350629))
                    ((0.989518 0.326604)))))
                 ((R:segstate.parent.R:SylStructure.parent.ssyl_out
                   <
                   5.5)
                  ((R:segstate.parent.R:SylStructure.parent.syl_out
                    <
                    5.5)
                   ((R:segstate.parent.R:SylStructure.parent.R:Syllable.n.accented
                     is
                     0)
                    ((0.610541 0.0878009))
                    ((0.999435 0.360699)))
                   ((R:segstate.parent.R:SylStructure.parent.R:Syllable.nn.lisp_cg_break
                     <
                     0.1)
                    ((1.39498 0.799497))
                    ((1.22236 0.531194))))
                  ((R:segstate.parent.n.ph_ctype is s)
                   ((0.551296 -0.0886527))
                   ((R:segstate.parent.R:SylStructure.parent.asyl_out
                     <
                     4.2)
                    ((0.818921 0.299675))
                    ((0.767384 0.101814))))))))
              ((R:segstate.parent.p.name is n)
               ((R:segstate.parent.R:SylStructure.parent.R:Syllable.nn.lisp_cg_break
                 <
                 0.3)
                ((R:segstate.parent.pp.ph_vlng is s)
                 ((0.830764 0.131792))
                 ((R:segstate.parent.R:SylStructure.parent.syl_in
                   <
                   1.5)
                  ((1.03369 0.268971))
                  ((R:segstate.parent.R:SylStructure.parent.R:Syllable.pp.lisp_cg_break
                    <
                    0.1)
                   ((1.76392 0.874802))
                   ((0.595353 0.286949)))))
                ((R:segstate.parent.R:SylStructure.parent.R:Syllable.nn.accented
                  is
                  0)
                 ((R:segstate.parent.R:SylStructure.parent.syl_onsetsize
                   <
                   0.1)
                  ((0.599635 0.0652568))
                  ((R:segstate.parent.R:SylStructure.parent.ssyl_out
                    <
                    5.5)
                   ((R:segstate.parent.ph_vheight is 3)
                    ((0.900667 0.160494))
                    ((R:segstate.parent.R:SylStructure.parent.R:Syllable.p.syl_codasize
                      <
                      1.2)
                     ((1.46901 0.492289))
                     ((0.963596 0.286744))))
                   ((R:segstate.parent.R:SylStructure.parent.R:Syllable.p.syl_codasize
                     <
                     1.2)
                    ((0.894643 -0.047519))
                    ((1.29212 0.212618)))))
                 ((R:segstate.parent.nn.ph_vfront is 1)
                  ((0.977764 0.0441407))
                  ((0.711971 -0.228819)))))
               ((R:segstate.parent.nn.ph_vfront is 3)
                ((R:segstate.parent.n.ph_ctype is s)
                 ((R:segstate.parent.ph_vfront is 1)
                  ((1.43952 0.81631))
                  ((R:segstate.parent.p.ph_cvox is +)
                   ((0.809723 0.0808394))
                   ((R:segstate.parent.R:SylStructure.parent.ssyl_out
                     <
                     7.2)
                    ((0.471494 -0.507885))
                    ((0.470797 -0.164135)))))
                 ((R:segstate.parent.p.name is b)
                  ((0.310471 -0.802913))
                  ((R:segstate.parent.pp.ph_cvox is -)
                   ((R:segstate.parent.R:SylStructure.parent.ssyl_out
                     <
                     6.2)
                    ((R:segstate.parent.p.ph_cvox is -)
                     ((R:segstate.parent.R:SylStructure.parent.syl_out
                       <
                       7.2)
                      ((0.629154 -0.38101))
                      ((0.954733 -0.0833246)))
                     ((0.476466 -0.495942)))
                    ((R:segstate.parent.ph_vfront is 2)
                     ((0.572907 -0.355721))
                     ((0.247314 -0.582207))))
                   ((R:segstate.parent.R:SylStructure.parent.ssyl_out
                     <
                     7.3)
                    ((R:segstate.parent.ph_vfront is 1)
                     ((0.425195 -0.477906))
                     ((R:segstate.parent.p.ph_cplace is a)
                      ((0.389922 -0.369528))
                      ((0.718223 0.0752529))))
                    ((1.132 0.208339))))))
                ((R:segstate.parent.p.name is m)
                 ((R:segstate.parent.pp.ph_vheight is 1)
                  ((0.744426 0.160783))
                  ((R:segstate.parent.R:SylStructure.parent.next_accent
                    <
                    5.4)
                   ((R:segstate.parent.ph_vfront is 1)
                    ((R:segstate.parent.R:SylStructure.parent.ssyl_in
                      <
                      1.2)
                     ((R:segstate.parent.R:SylStructure.parent.R:Syllable.nn.stress
                       is
                       0)
                      ((0.842411 0.013128))
                      ((0.685149 -0.183392)))
                     ((0.613391 -0.386245)))
                    ((R:segstate.parent.R:SylStructure.parent.ssyl_out
                      <
                      2.2)
                     ((0.584712 -0.179489))
                     ((R:segstate.parent.pp.ph_cplace is 0)
                      ((0.227548 -0.544079))
                      ((0.925205 -0.367332)))))
                   ((0.823806 -0.0191))))
                 ((R:segstate.parent.R:SylStructure.parent.stress is 0)
                  ((R:segstate.parent.R:SylStructure.parent.R:Syllable.p.lisp_cg_break
                    <
                    0.3)
                   ((R:segstate.parent.ph_vfront is 1)
                    ((R:segstate.parent.p.ph_cvox is +)
                     ((R:segstate.parent.R:SylStructure.parent.asyl_out
                       <
                       1.7)
                      ((0.707824 0.130976))
                      ((0.457174 -0.192977)))
                     ((0.676047 -0.260734)))
                    ((R:segstate.parent.R:SylStructure.parent.position_type
                      is
                      mid)
                     ((R:segstate.parent.pp.ph_vlng is s)
                      ((0.439094 -0.199436))
                      ((R:segstate.parent.R:SylStructure.parent.R:Syllable.pp.lisp_cg_break
                        <
                        0.1)
                       ((0.448248 -0.0692979))
                       ((0.701315 0.191614))))
                     ((R:segstate.parent.n.ph_ctype is s)
                      ((0.909242 0.0464435))
                      ((R:segstate.parent.nn.ph_vlng is d)
                       ((0.769174 0.147278))
                       ((1.2507 0.733673))))))
                   ((R:segstate.parent.R:SylStructure.parent.asyl_out
                     <
                     5.6)
                    ((R:segstate.parent.n.ph_ctype is f)
                     ((R:segstate.parent.p.ph_cplace is l)
                      ((1.45247 0.318148))
                      ((R:segstate.parent.R:SylStructure.parent.syl_in
                        <
                        1.4)
                       ((0.792539 0.0438243))
                       ((R:segstate.parent.nn.ph_vfront is 1)
                        ((R:segstate.parent.pp.ph_cplace is a)
                         ((0.661013 0.039908))
                         ((0.354692 -0.181771)))
                        ((R:segstate.parent.R:SylStructure.parent.R:Syllable.n.lisp_cg_break
                          <
                          0.1)
                         ((0.514351 -0.165789))
                         ((0.279919 -0.426878))))))
                     ((R:segstate.parent.R:SylStructure.parent.asyl_out
                       <
                       4.5)
                      ((R:segstate.parent.R:SylStructure.parent.asyl_out
                        <
                        1.2)
                       ((R:segstate.parent.R:SylStructure.parent.ssyl_in
                         <
                         1.2)
                        ((0.44297 -0.201417))
                        ((0.45875 -0.536059)))
                       ((R:segstate.parent.R:SylStructure.parent.syl_onsetsize
                         <
                         0.1)
                        ((R:segstate.parent.R:SylStructure.parent.R:Syllable.pp.accented
                          is
                          0)
                         ((R:segstate.parent.R:SylStructure.parent.asyl_in
                           <
                           0.2)
                          ((0.770197 -0.0502446))
                          ((0.95187 0.250699)))
                         ((R:segstate.parent.R:SylStructure.parent.R:Syllable.n.accented
                           is
                           0)
                          ((0.952236 -0.164955))
                          ((0.661788 -0.233808))))
                        ((R:segstate.parent.R:SylStructure.parent.next_accent
                          <
                          1.6)
                         ((R:segstate.parent.pp.ph_cplace is a)
                          ((0.584383 -0.263901))
                          ((0.519878 -0.118103)))
                         ((0.331671 -0.352143)))))
                      ((0.415422 -0.45706))))
                    ((R:segstate.parent.p.ph_cplace is a)
                     ((0.454011 -0.151433))
                     ((0.939511 0.279525)))))
                  ((R:segstate.parent.R:SylStructure.parent.parent.gpos
                    is
                    content)
                   ((R:segstate.parent.p.ph_cvox is -)
                    ((R:segstate.parent.ph_vfront is 3)
                     ((R:segstate.parent.R:SylStructure.parent.R:Syllable.nn.stress
                       is
                       0)
                      ((R:segstate.parent.R:SylStructure.parent.asyl_out
                        <
                        2.2)
                       ((0.765992 0.0450948))
                       ((R:segstate.parent.R:SylStructure.parent.R:Syllable.p.syl_codasize
                         <
                         1.2)
                        ((1.37447 0.507145))
                        ((0.908921 0.830357))))
                      ((R:segstate.parent.R:SylStructure.parent.R:Syllable.p.accented
                        is
                        0)
                       ((R:segstate.parent.n.ph_ctype is f)
                        ((0.962447 0.416171))
                        ((R:segstate.parent.p.name is s)
                         ((0.773325 -0.275454))
                         ((R:segstate.parent.R:SylStructure.parent.ssyl_out
                           <
                           3.7)
                          ((0.880951 0.0627058))
                          ((0.894322 0.321058)))))
                       ((0.706009 -0.173809))))
                     ((R:segstate.parent.R:SylStructure.parent.R:Syllable.n.syl_onsetsize
                       <
                       0.2)
                      ((1.00106 0.475028))
                      ((R:segstate.parent.nn.ph_vfront is 2)
                       ((R:segstate.parent.n.ph_ctype is n)
                        ((1.23685 0.454922))
                        ((R:segstate.parent.R:SylStructure.parent.syl_out
                          <
                          12.4)
                         ((R:segstate.parent.R:SylStructure.parent.ssyl_in
                           <
                           1.2)
                          ((R:segstate.parent.R:SylStructure.parent.R:Syllable.nn.stress
                            is
                            0)
                           ((0.580887 -0.284309))
                           ((R:segstate.parent.R:SylStructure.parent.R:Syllable.pp.lisp_cg_break
                             <
                             0.1)
                            ((0.56743 -0.199882))
                            ((0.588941 0.0544481))))
                          ((R:segstate.parent.R:SylStructure.parent.last_accent
                            <
                            1.2)
                           ((R:segstate.parent.ph_vheight is 3)
                            ((0.836886 0.103667))
                            ((0.630499 -0.176376)))
                           ((0.57831 0.173411))))
                         ((R:segstate.parent.R:SylStructure.parent.next_accent
                           <
                           2.4)
                          ((1.03309 0.359315))
                          ((0.730514 -0.0718453)))))
                       ((R:segstate.parent.pp.ph_vlng is d)
                        ((0.53366 -0.38698))
                        ((R:segstate.parent.lisp_onset_fric is 0)
                         ((R:segstate.parent.n.ph_ctype is f)
                          ((R:segstate.parent.pp.ph_cvox is -)
                           ((0.558578 0.00851439))
                           ((0.339853 -0.124566)))
                          ((R:segstate.parent.pp.ph_cplace is a)
                           ((0.683532 -0.00358745))
                           ((R:segstate.parent.p.name is t)
                            ((0.551797 -0.0846707))
                            ((R:segstate.parent.R:SylStructure.parent.R:Syllable.nn.accented
                              is
                              0)
                             ((0.435266 -0.577542))
                             ((0.587872 -0.325072))))))
                         ((R:segstate.parent.R:SylStructure.parent.R:Syllable.n.syl_onsetsize
                           <
                           1.1)
                          ((R:segstate.parent.R:SylStructure.parent.R:Syllable.p.lisp_cg_break
                            <
                            0.1)
                           ((R:segstate.parent.ph_vheight is 1)
                            ((0.94388 0.322074))
                            ((0.567933 -0.0174222)))
                           ((R:segstate.parent.R:SylStructure.parent.syl_in
                             <
                             2.5)
                            ((0.734249 -0.0821926))
                            ((0.638481 0.00352941))))
                          ((0.525524 -0.169723))))))))
                    ((R:segstate.parent.R:SylStructure.parent.parent.word_numsyls
                      <
                      3)
                     ((R:segstate.parent.ph_vfront is 2)
                      ((R:segstate.parent.nn.ph_vlng is s)
                       ((0.766476 -0.234233))
                       ((0.823772 0.125704)))
                      ((R:segstate.parent.R:SylStructure.parent.asyl_out
                        <
                        4.5)
                       ((R:segstate.parent.R:SylStructure.parent.R:Syllable.nn.stress
                         is
                         0)
                        ((R:segstate.parent.ph_vheight is 2)
                         ((0.904991 0.199528))
                         ((1.34182 0.844074)))
                        ((R:segstate.parent.R:SylStructure.parent.R:Syllable.n.accented
                          is
                          0)
                         ((R:segstate.parent.pp.ph_cplace is a)
                          ((1.40113 0.580879))
                          ((R:segstate.parent.R:SylStructure.parent.next_accent
                            <
                            4.6)
                           ((R:segstate.parent.R:SylStructure.parent.R:Syllable.nn.accented
                             is
                             0)
                            ((0.900593 0.310086))
                            ((0.81526 0.0329733)))
                           ((0.779297 -0.0625835))))
                         ((0.737441 -0.0919294))))
                       ((R:segstate.parent.R:SylStructure.parent.R:Syllable.p.lisp_cg_break
                         <
                         0.1)
                        ((1.28375 0.654985))
                        ((1.14946 0.270508)))))
                     ((R:segstate.parent.R:SylStructure.parent.R:Syllable.p.syl_codasize
                       <
                       1.1)
                      ((0.626865 -0.233864))
                      ((1.19019 0.0987318)))))
                   ((R:segstate.parent.p.ph_cvox is -)
                    ((0.599935 -0.576065))
                    ((R:segstate.parent.R:SylStructure.parent.R:Syllable.p.syl_codasize
                      <
                      1.2)
                     ((1.32941 0.265266))
                     ((0.76089 -0.288827))))))))))))
           ((R:segstate.parent.R:SylStructure.parent.parent.gpos
             is
             content)
            ((R:segstate.parent.p.name is g)
             ((R:segstate.parent.n.ph_ctype is f)
              ((R:segstate.parent.pp.ph_vc is +)
               ((1.06601 0.526051))
               ((0.850825 0.0833566)))
              ((R:segstate.parent.R:SylStructure.parent.ssyl_in < 0.2)
               ((R:segstate.parent.R:SylStructure.parent.asyl_out
                 <
                 3.5)
                ((1.33527 1.41044))
                ((1.33812 0.827787)))
               ((R:segstate.parent.R:SylStructure.parent.position_type
                 is
                 final)
                ((1.25101 0.892081))
                ((1.09452 0.372473)))))
             ((R:segstate.parent.n.ph_ctype is n)
              ((R:segstate.parent.ph_vheight is 1)
               ((R:segstate.parent.R:SylStructure.parent.stress is 0)
                ((R:segstate.parent.nn.ph_vc is +)
                 ((0.243419 -0.463764))
                 ((R:segstate.parent.pp.ph_vheight is 1)
                  ((0.342812 -0.420424))
                  ((R:segstate.parent.R:SylStructure.parent.syl_in
                    <
                    1.5)
                   ((0.774321 0.000467869))
                   ((R:segstate.parent.nn.ph_cplace is l)
                    ((0.579456 -0.0714887))
                    ((R:segstate.parent.nn.ph_cvox is +)
                     ((0.417132 -0.431933))
                     ((R:segstate.parent.R:SylStructure.parent.ssyl_in
                       <
                       1.2)
                      ((R:segstate.parent.pp.ph_cplace is a)
                       ((0.443271 -0.313828))
                       ((0.30104 -0.389315)))
                      ((0.664973 -0.211729))))))))
                ((R:segstate.parent.lisp_coda_stop is 0)
                 ((R:segstate.parent.nn.ph_cplace is v)
                  ((0.333944 -0.341975))
                  ((R:segstate.parent.R:SylStructure.parent.asyl_out
                    <
                    1.4)
                   ((R:segstate.parent.pp.ph_cvox is -)
                    ((0.984191 0.0559174))
                    ((1.31919 0.435534)))
                   ((R:segstate.parent.p.ph_cvox is +)
                    ((R:segstate.parent.R:SylStructure.parent.R:Syllable.n.lisp_cg_break
                      <
                      0.1)
                     ((0.560663 -0.155446))
                     ((R:segstate.parent.p.ph_ctype is s)
                      ((1.04663 0.116164))
                      ((1.29971 0.409947))))
                    ((R:segstate.parent.lisp_onset_stop is 0)
                     ((R:segstate.parent.R:SylStructure.parent.R:Syllable.p.accented
                       is
                       0)
                      ((R:segstate.parent.R:SylStructure.parent.asyl_out
                        <
                        4.5)
                       ((0.758998 -0.100192))
                       ((1.46442 0.399316)))
                      ((R:segstate.parent.R:SylStructure.parent.R:Syllable.nn.stress
                        is
                        0)
                       ((0.488692 -0.110406))
                       ((0.537107 -0.214224))))
                     ((0.64901 -0.287557))))))
                 ((R:segstate.parent.R:SylStructure.parent.asyl_out
                   <
                   3)
                  ((0.649699 -0.220563))
                  ((0.401603 -0.491994)))))
               ((R:segstate.parent.ph_vfront is 3)
                ((R:segstate.parent.ph_vrnd is +)
                 ((R:segstate.parent.lisp_coda_stop is 0)
                  ((R:segstate.parent.pp.ph_cvox is -)
                   ((R:segstate.parent.R:SylStructure.parent.R:Syllable.nn.lisp_cg_break
                     <
                     0.1)
                    ((1.12986 0.198815))
                    ((1.77148 0.976697)))
                   ((0.96092 0.104489)))
                  ((0.701839 -0.196302)))
                 ((R:segstate.parent.R:SylStructure.parent.asyl_out
                   <
                   3.5)
                  ((1.73618 1.05986))
                  ((0.748149 0.300773))))
                ((R:segstate.parent.R:SylStructure.parent.ssyl_out
                  <
                  1.2)
                 ((R:segstate.parent.R:SylStructure.parent.ssyl_in
                   <
                   1.2)
                  ((0.977221 -0.0559043))
                  ((0.385021 -0.499068)))
                 ((R:segstate.parent.R:SylStructure.parent.R:Syllable.n.lisp_cg_break
                   <
                   0.1)
                  ((R:segstate.parent.p.ph_ctype is f)
                   ((R:segstate.parent.R:SylStructure.parent.R:Syllable.p.lisp_cg_break
                     <
                     0.3)
                    ((0.584043 -0.0370427))
                    ((0.721611 -0.36286)))
                   ((R:segstate.parent.R:SylStructure.parent.parent.word_numsyls
                     <
                     2.2)
                    ((R:segstate.parent.ph_vfront is 1)
                     ((1.17735 0.340811))
                     ((1.1655 0.0156089)))
                    ((R:segstate.parent.R:SylStructure.parent.asyl_out
                      <
                      3.1)
                     ((R:segstate.parent.R:SylStructure.parent.R:Syllable.pp.accented
                       is
                       0)
                      ((0.451007 -0.296251))
                      ((0.866574 -0.0146201)))
                     ((R:segstate.parent.R:SylStructure.parent.asyl_in
                       <
                       0.3)
                      ((0.864529 0.18217))
                      ((0.79055 -0.0220688))))))
                  ((R:segstate.parent.p.ph_vc is +)
                   ((0.654927 -0.218011))
                   ((R:segstate.parent.ph_vheight is 2)
                    ((R:segstate.parent.R:SylStructure.parent.syl_out
                      <
                      4.1)
                     ((R:segstate.parent.R:SylStructure.parent.ssyl_out
                       <
                       2.2)
                      ((0.664488 -0.304222))
                      ((0.948597 -0.00356558)))
                     ((R:segstate.parent.R:SylStructure.parent.sub_phrases
                       <
                       0.1)
                      ((R:segstate.parent.R:SylStructure.parent.next_accent
                        <
                        6)
                       ((R:segstate.parent.R:SylStructure.parent.asyl_out
                         <
                         5.2)
                        ((R:segstate.parent.nn.ph_cplace is 0)
                         ((R:segstate.parent.nn.ph_vfront is 2)
                          ((1.25083 0.157894))
                          ((R:segstate.parent.R:SylStructure.parent.asyl_out
                            <
                            3.2)
                           ((R:segstate.parent.p.ph_ctype is f)
                            ((1.17436 0.480647))
                            ((1.27044 0.236935)))
                           ((1.81004 0.798059))))
                         ((R:segstate.parent.R:SylStructure.parent.syl_in
                           <
                           1.5)
                          ((R:segstate.parent.nn.ph_cplace is a)
                           ((2.00422 1.02281))
                           ((R:segstate.parent.R:SylStructure.parent.ssyl_out
                             <
                             7.2)
                            ((R:segstate.parent.pp.ph_cvox is -)
                             ((1.09136 0.25968))
                             ((1.31861 0.362823)))
                            ((0.672876 0.0356117))))
                          ((R:segstate.parent.R:SylStructure.parent.position_type
                            is
                            initial)
                           ((0.67759 -0.144352))
                           ((R:segstate.parent.R:SylStructure.parent.R:Syllable.n.syl_onsetsize
                             <
                             0.2)
                            ((0.680746 -0.0871614))
                            ((R:segstate.parent.R:SylStructure.parent.asyl_in
                              <
                              0.2)
                             ((0.931314 -0.0903667))
                             ((R:segstate.parent.R:SylStructure.parent.ssyl_in
                               <
                               1.1)
                              ((R:segstate.parent.pp.ph_cvox is +)
                               ((0.98448 0.0506709))
                               ((1.04139 0.252772)))
                              ((R:segstate.parent.R:SylStructure.parent.next_accent
                                <
                                1.2)
                               ((1.01907 0.604248))
                               ((0.823062 0.343462)))))))))
                        ((R:segstate.parent.R:SylStructure.parent.R:Syllable.n.accented
                          is
                          0)
                         ((0.621249 -0.218098))
                         ((1.44385 0.284396))))
                       ((R:segstate.parent.R:SylStructure.parent.R:Syllable.nn.stress
                         is
                         0)
                        ((0.381042 -0.386119))
                        ((0.940707 0.251718))))
                      ((0.612486 -0.151638))))
                    ((R:segstate.parent.ph_vfront is 1)
                     ((R:segstate.parent.nn.ph_cplace is a)
                      ((R:segstate.parent.R:SylStructure.parent.R:Syllable.p.accented
                        is
                        0)
                       ((R:segstate.parent.pp.ph_cplace is 0)
                        ((2.07108 1.25359))
                        ((1.63659 0.734916)))
                       ((1.38239 0.494895)))
                      ((R:segstate.parent.R:SylStructure.parent.ssyl_in
                        <
                        1.2)
                       ((1.13515 -0.0954048))
                       ((1.91932 0.615855))))
                     ((R:segstate.parent.pp.ph_cplace is a)
                      ((1.19351 0.607431))
                      ((R:segstate.parent.R:SylStructure.parent.R:Syllable.pp.accented
                        is
                        0)
                       ((0.794836 -0.228816))
                       ((1.15856 0.226525)))))))))))
              ((R:segstate.parent.R:SylStructure.parent.position_type
                is
                final)
               ((R:segstate.parent.nn.ph_vlng is s)
                ((R:segstate.parent.p.name is t)
                 ((0.595951 -0.0239668))
                 ((0.887162 0.223933)))
                ((R:segstate.parent.nn.ph_cplace is 0)
                 ((R:segstate.parent.ph_vheight is 1)
                  ((R:segstate.parent.R:SylStructure.parent.ssyl_out
                    <
                    4.6)
                   ((0.681137 0.0225645))
                   ((1.10852 0.440445)))
                  ((R:segstate.parent.R:SylStructure.parent.R:Syllable.nn.stress
                    is
                    0)
                   ((R:segstate.parent.R:SylStructure.parent.ssyl_in
                     <
                     1.2)
                    ((1.27017 0.888888))
                    ((1.07316 0.242972)))
                   ((R:segstate.parent.R:SylStructure.parent.R:Syllable.n.syl_onsetsize
                     <
                     0.2)
                    ((1.12202 0.802388))
                    ((1.71407 1.3909)))))
                 ((R:segstate.parent.pp.ph_cvox is +)
                  ((0.825474 0.021701))
                  ((R:segstate.parent.R:SylStructure.parent.next_accent
                    <
                    3.6)
                   ((R:segstate.parent.nn.ph_cplace is l)
                    ((0.97649 0.153805))
                    ((R:segstate.parent.R:SylStructure.parent.asyl_out
                      <
                      4.2)
                     ((R:segstate.parent.lisp_coda_stop is 0)
                      ((R:segstate.parent.R:SylStructure.parent.syl_in
                        <
                        2.2)
                       ((1.39515 0.713653))
                       ((1.85247 0.878467)))
                      ((R:segstate.parent.R:SylStructure.parent.R:Syllable.pp.lisp_cg_break
                        <
                        0.3)
                       ((R:segstate.parent.R:SylStructure.parent.ssyl_out
                         <
                         3.7)
                        ((1.13541 0.488344))
                        ((1.4626 1.0039)))
                       ((R:segstate.parent.R:SylStructure.parent.R:Syllable.nn.accented
                         is
                         0)
                        ((0.668218 0.0846224))
                        ((0.911143 0.523359)))))
                     ((1.06406 0.211862))))
                   ((0.753015 0.0975081))))))
               ((R:segstate.parent.p.name is dh)
                ((R:segstate.parent.nn.ph_cplace is l)
                 ((R:segstate.parent.R:SylStructure.parent.next_accent
                   <
                   1.4)
                  ((R:segstate.parent.R:SylStructure.parent.asyl_out
                    <
                    4.2)
                   ((0.503716 -0.414249))
                   ((0.56464 -0.303841)))
                  ((R:segstate.parent.R:SylStructure.parent.syl_out
                    <
                    11)
                   ((1.10561 0.150389))
                   ((0.538555 -0.237997))))
                 ((R:segstate.parent.nn.ph_cplace is 0)
                  ((R:segstate.parent.R:SylStructure.parent.syl_out
                    <
                    8.5)
                   ((0.957758 -0.215975))
                   ((0.99467 0.210608)))
                  ((1.3259 0.425508))))
                ((R:segstate.parent.R:SylStructure.parent.position_type
                  is
                  single)
                 ((R:segstate.parent.nn.ph_vfront is 2)
                  ((R:segstate.parent.pp.ph_vc is +)
                   ((R:segstate.parent.R:SylStructure.parent.R:Syllable.p.stress
                     is
                     0)
                    ((0.865266 0.219867))
                    ((0.756475 0.00498593)))
                   ((R:segstate.parent.R:SylStructure.parent.next_accent
                     <
                     1.6)
                    ((R:segstate.parent.R:SylStructure.parent.R:Syllable.p.syl_codasize
                      <
                      1.2)
                     ((0.622331 -0.234907))
                     ((0.488494 0.0961234)))
                    ((0.443996 -0.282273))))
                  ((R:segstate.parent.p.name is m)
                   ((R:segstate.parent.R:SylStructure.parent.R:Syllable.nn.stress
                     is
                     0)
                    ((R:segstate.parent.lisp_coda_stop is 0)
                     ((R:segstate.parent.R:SylStructure.parent.ssyl_out
                       <
                       4.6)
                      ((0.674871 -0.0182657))
                      ((0.891198 0.142587)))
                     ((0.660864 -0.360802)))
                    ((R:segstate.parent.R:SylStructure.parent.asyl_out
                      <
                      2.5)
                     ((1.27028 0.597211))
                     ((R:segstate.parent.n.ph_ctype is s)
                      ((0.740849 -0.191136))
                      ((0.897254 0.294903)))))
                   ((R:segstate.parent.R:SylStructure.parent.syl_out
                     <
                     16.2)
                    ((R:segstate.parent.p.name is sh)
                     ((0.770384 -0.113665))
                     ((R:segstate.parent.nn.ph_cplace is 0)
                      ((R:segstate.parent.nn.ph_vc is +)
                       ((R:segstate.parent.p.name is n)
                        ((0.949891 0.510998))
                        ((R:segstate.parent.R:SylStructure.parent.asyl_out
                          <
                          2.4)
                         ((0.746052 0.0711501))
                         ((R:segstate.parent.R:SylStructure.parent.R:Syllable.p.accented
                           is
                           0)
                          ((0.798166 0.207849))
                          ((1.1807 0.415)))))
                       ((R:segstate.parent.n.ph_ctype is s)
                        ((R:segstate.parent.p.ph_ctype is s)
                         ((R:segstate.parent.ph_vfront is 1)
                          ((1.02719 0.0738569))
                          ((0.637759 0.482546)))
                         ((R:segstate.parent.pp.ph_vc is +)
                          ((R:segstate.parent.p.ph_ctype is f)
                           ((1.90658 0.798307))
                           ((1.70503 0.678156)))
                          ((R:segstate.parent.R:SylStructure.parent.syl_out
                            <
                            8)
                           ((0.866928 0.499636))
                           ((1.03246 0.237399)))))
                        ((R:segstate.parent.R:SylStructure.parent.asyl_out
                          <
                          2.5)
                         ((1.10767 0.428684))
                         ((R:segstate.parent.R:SylStructure.parent.ssyl_out
                           <
                           5.6)
                          ((1.79386 1.23344))
                          ((1.35438 0.806504))))))
                      ((R:segstate.parent.n.ph_ctype is r)
                       ((R:segstate.parent.ph_vheight is 3)
                        ((R:segstate.parent.lisp_coda_fric is 0)
                         ((R:segstate.parent.R:SylStructure.parent.next_accent
                           <
                           1.4)
                          ((0.957372 0.214041))
                          ((1.53012 0.606212)))
                         ((0.792771 -0.0470289)))
                        ((R:segstate.parent.R:SylStructure.parent.syl_out
                          <
                          7)
                         ((2.09735 1.41588))
                         ((2.0302 0.471524))))
                       ((R:segstate.parent.ph_vheight is 3)
                        ((R:segstate.parent.R:SylStructure.parent.asyl_out
                          <
                          6)
                         ((R:segstate.parent.nn.ph_cplace is a)
                          ((R:segstate.parent.R:SylStructure.parent.next_accent
                            <
                            1.2)
                           ((R:segstate.parent.p.name is n)
                            ((0.698237 0.462051))
                            ((1.18559 1.00149)))
                           ((1.06714 0.414429)))
                          ((R:segstate.parent.p.ph_cvox is -)
                           ((0.637596 0.0488034))
                           ((R:segstate.parent.R:SylStructure.parent.ssyl_out
                             <
                             6.6)
                            ((R:segstate.parent.R:SylStructure.parent.R:Syllable.nn.stress
                              is
                              0)
                             ((0.691946 0.225101))
                             ((R:segstate.parent.R:SylStructure.parent.R:Syllable.p.accented
                               is
                               0)
                              ((1.2214 0.839013))
                              ((0.909804 0.427034))))
                            ((0.854103 0.101458)))))
                         ((0.504343 -0.00988793)))
                        ((R:segstate.parent.p.ph_ctype is s)
                         ((R:segstate.parent.R:SylStructure.parent.syl_onsetsize
                           <
                           0.2)
                          ((1.19333 0.696721))
                          ((R:segstate.parent.R:SylStructure.parent.R:Syllable.nn.accented
                            is
                            0)
                           ((R:segstate.parent.R:SylStructure.parent.syl_in
                             <
                             2.5)
                            ((R:segstate.parent.nn.ph_cvox is +)
                             ((R:segstate.parent.R:SylStructure.parent.ssyl_out
                               <
                               5.8)
                              ((0.689143 0.057327))
                              ((0.74589 0.0749087)))
                             ((1.33734 0.461736)))
                            ((0.592403 -0.188437)))
                           ((R:segstate.parent.ph_vheight is 1)
                            ((1.02451 0.2998))
                            ((1.63355 0.704257)))))
                         ((R:segstate.parent.ph_vfront is 3)
                          ((0.790389 -0.145209))
                          ((R:segstate.parent.R:SylStructure.parent.syl_in
                            <
                            0.6)
                           ((0.597141 -0.0755489))
                           ((R:segstate.parent.p.ph_cvox is +)
                            ((R:segstate.parent.R:SylStructure.parent.R:Syllable.nn.accented
                              is
                              0)
                             ((1.21056 0.315056))
                             ((0.620846 -0.272796)))
                            ((R:segstate.parent.R:SylStructure.parent.asyl_out
                              <
                              4.5)
                             ((R:segstate.parent.R:SylStructure.parent.ssyl_out
                               <
                               4.2)
                              ((R:segstate.parent.R:SylStructure.parent.R:Syllable.nn.accented
                                is
                                0)
                               ((0.80619 0.0530283))
                               ((R:segstate.parent.ph_vheight is 1)
                                ((1.31036 0.394086))
                                ((0.827848 0.303317))))
                              ((0.688908 -0.122457)))
                             ((1.25604 0.47721)))))))))))
                    ((1.90905 1.02294)))))
                 ((R:segstate.parent.p.name is hh)
                  ((1.77643 0.900053))
                  ((R:segstate.parent.R:SylStructure.parent.R:Syllable.n.syl_onsetsize
                    <
                    2.1)
                   ((R:segstate.parent.pp.ph_cvox is -)
                    ((R:segstate.parent.R:SylStructure.parent.R:Syllable.p.accented
                      is
                      0)
                     ((R:segstate.parent.nn.ph_cplace is a)
                      ((R:segstate.parent.R:SylStructure.parent.syl_out
                        <
                        9)
                       ((0.548591 -0.260412))
                       ((0.705847 -0.00985266)))
                      ((0.870921 0.236838)))
                     ((0.577441 -0.494023)))
                    ((R:segstate.parent.R:SylStructure.parent.R:Syllable.n.lisp_cg_break
                      <
                      0.3)
                     ((R:segstate.parent.pp.ph_vc is +)
                      ((R:segstate.parent.R:SylStructure.parent.syl_onsetsize
                        <
                        0.1)
                       ((0.862281 -0.158466))
                       ((1.08115 0.188654)))
                      ((0.505324 -0.381022)))
                     ((R:segstate.parent.R:SylStructure.parent.syl_codasize
                       <
                       2.1)
                      ((R:segstate.parent.nn.ph_cplace is l)
                       ((0.55084 0.0134725))
                       ((R:segstate.parent.pp.ph_vlng is a)
                        ((0.758067 0.157564))
                        ((R:segstate.parent.R:SylStructure.parent.asyl_in
                          <
                          0.2)
                         ((1.04469 0.258514))
                         ((1.4211 0.431075)))))
                      ((0.961596 -0.0752077)))))
                   ((0.48628 -0.297228)))))))))
            ((R:segstate.parent.n.ph_ctype is r)
             ((R:segstate.parent.R:SylStructure.parent.parent.gpos
               is
               cc)
              ((1.58887 0.238277))
              ((R:segstate.parent.pp.ph_vlng is l)
               ((1.17969 -0.0388209))
               ((R:segstate.parent.p.name is dh)
                ((0.553338 -0.333328))
                ((R:segstate.parent.nn.ph_vlng is a)
                 ((0.337512 -0.622939))
                 ((R:segstate.parent.nn.ph_cplace is a)
                  ((0.126657 -0.842124))
                  ((R:segstate.parent.R:SylStructure.parent.R:Syllable.pp.lisp_cg_break
                    <
                    0.1)
                   ((R:segstate.parent.R:SylStructure.parent.R:Syllable.p.syl_codasize
                     <
                     1.2)
                    ((0.19625 -0.806424))
                    ((0.332447 -0.655823)))
                   ((0.114599 -0.823875))))))))
             ((R:segstate.parent.ph_vheight is 1)
              ((R:segstate.parent.R:SylStructure.parent.R:Syllable.n.lisp_cg_break
                <
                0.3)
               ((R:segstate.parent.pp.ph_cplace is a)
                ((R:segstate.parent.p.name is dh)
                 ((0.252453 -0.397786))
                 ((R:segstate.parent.R:SylStructure.parent.R:Syllable.pp.accented
                   is
                   0)
                  ((0.626281 0.108767))
                  ((0.65284 -0.126294))))
                ((R:segstate.parent.R:SylStructure.parent.last_accent
                  <
                  1.5)
                 ((R:segstate.parent.R:SylStructure.parent.last_accent
                   <
                   0.1)
                  ((R:segstate.parent.nn.ph_cvox is -)
                   ((0.671018 -0.02312))
                   ((R:segstate.parent.R:SylStructure.parent.ssyl_out
                     <
                     5.6)
                    ((0.414994 0.0910209))
                    ((0.818691 0.249916))))
                  ((1.33341 0.411938)))
                 ((0.623902 0.0050406))))
               ((R:segstate.parent.R:SylStructure.parent.asyl_out
                 <
                 3.5)
                ((R:segstate.parent.R:SylStructure.parent.R:Syllable.nn.accented
                  is
                  0)
                 ((R:segstate.parent.p.ph_cvox is -)
                  ((R:segstate.parent.nn.ph_cplace is 0)
                   ((1.40342 0.808742))
                   ((R:segstate.parent.pp.ph_cvox is +)
                    ((1.02111 0.547613))
                    ((R:segstate.parent.R:SylStructure.parent.R:Syllable.p.accented
                      is
                      0)
                     ((R:segstate.parent.p.ph_ctype is f)
                      ((0.94469 0.0675339))
                      ((1.10369 0.382378)))
                     ((0.698956 -0.0651414)))))
                  ((R:segstate.parent.n.ph_ctype is n)
                   ((1.32152 1.13273))
                   ((1.39323 0.569727))))
                 ((R:segstate.parent.R:SylStructure.parent.syl_out
                   <
                   4.4)
                  ((0.725781 0.00625831))
                  ((0.913303 0.31239))))
                ((R:segstate.parent.R:SylStructure.parent.ssyl_out
                  <
                  8.6)
                 ((R:segstate.parent.n.ph_ctype is f)
                  ((R:segstate.parent.R:SylStructure.parent.R:Syllable.n.syl_onsetsize
                    <
                    0.2)
                   ((1.06981 0.4007))
                   ((R:segstate.parent.pp.ph_cplace is 0)
                    ((R:segstate.parent.p.name is hh)
                     ((0.658091 0.0758873))
                     ((1.06187 0.351013)))
                    ((0.594874 -0.126998))))
                  ((R:segstate.parent.R:SylStructure.parent.R:Syllable.pp.accented
                    is
                    0)
                   ((0.40754 -0.415576))
                   ((0.96188 0.172675))))
                 ((R:segstate.parent.R:SylStructure.parent.syl_out
                   <
                   14.6)
                  ((1.12292 0.538686))
                  ((0.869797 0.17347))))))
              ((R:segstate.parent.ph_vfront is 3)
               ((R:segstate.parent.nn.ph_cvox is -)
                ((1.61997 0.829917))
                ((R:segstate.parent.R:SylStructure.parent.R:Syllable.nn.accented
                  is
                  0)
                 ((0.902763 0.284168))
                 ((0.483148 0.0151445))))
               ((R:segstate.parent.R:SylStructure.parent.syl_in < 1.6)
                ((R:segstate.parent.R:SylStructure.parent.sub_phrases
                  <
                  0.2)
                 ((R:segstate.parent.n.ph_ctype is f)
                  ((R:segstate.parent.nn.ph_cvox is +)
                   ((R:segstate.parent.nn.ph_cplace is l)
                    ((1.09074 -0.0170167))
                    ((0.645137 -0.384505)))
                   ((R:segstate.parent.R:SylStructure.parent.syl_onsetsize
                     <
                     0.1)
                    ((1.22609 0.406432))
                    ((0.654526 -0.172416))))
                  ((R:segstate.parent.pp.ph_cplace is a)
                   ((1.62194 0.721362))
                   ((R:segstate.parent.nn.ph_cplace is l)
                    ((R:segstate.parent.R:SylStructure.parent.syl_out
                      <
                      14.6)
                     ((R:segstate.parent.R:SylStructure.parent.asyl_out
                       <
                       2.4)
                      ((1.38176 0.285487))
                      ((1.61303 0.52695)))
                     ((0.998595 0.175011)))
                    ((R:segstate.parent.ph_vfront is 1)
                     ((R:segstate.parent.R:SylStructure.parent.R:Syllable.n.accented
                       is
                       0)
                      ((R:segstate.parent.pp.ph_vheight is 1)
                       ((1.43547 0.405209))
                       ((R:segstate.parent.R:SylStructure.parent.R:Syllable.nn.accented
                         is
                         0)
                        ((0.683686 -0.243213))
                        ((1.00506 0.0903261))))
                      ((R:segstate.parent.p.ph_ctype is 0)
                       ((0.685358 -0.137713))
                       ((0.59924 -0.36666))))
                     ((R:segstate.parent.R:SylStructure.parent.ssyl_out
                       <
                       5.4)
                      ((1.04168 0.404174))
                      ((R:segstate.parent.ph_vheight is 2)
                       ((R:segstate.parent.R:SylStructure.parent.syl_out
                         <
                         14)
                        ((R:segstate.parent.R:SylStructure.parent.syl_out
                          <
                          10)
                         ((0.972009 0.0439291))
                         ((0.829556 0.222413)))
                        ((0.701821 -0.0168052)))
                       ((0.627602 0.277741))))))))
                 ((R:segstate.parent.n.ph_ctype is n)
                  ((R:segstate.parent.R:SylStructure.parent.R:Syllable.p.stress
                    is
                    0)
                   ((R:segstate.parent.R:SylStructure.parent.R:Syllable.n.accented
                     is
                     0)
                    ((0.517175 -0.195633))
                    ((0.560476 -0.211383)))
                   ((R:segstate.parent.pp.ph_cvox is -)
                    ((0.416671 -0.451439))
                    ((0.449854 -0.207234))))
                  ((0.719026 0.0203766))))
                ((R:segstate.parent.p.ph_ctype is f)
                 ((R:segstate.parent.R:SylStructure.parent.asyl_in
                   <
                   1.2)
                  ((R:segstate.parent.R:SylStructure.parent.ssyl_out
                    <
                    4.2)
                   ((R:segstate.parent.R:SylStructure.parent.syl_out
                     <
                     4.2)
                    ((R:segstate.parent.p.name is hh)
                     ((1.29747 0.0770257))
                     ((1.0903 0.174013)))
                    ((R:segstate.parent.R:SylStructure.parent.R:Syllable.p.accented
                      is
                      0)
                     ((R:segstate.parent.R:SylStructure.parent.next_accent
                       <
                       3.5)
                      ((0.366773 -0.449565))
                      ((0.618023 -0.20804)))
                     ((0.864432 -0.0465287))))
                   ((R:segstate.parent.R:SylStructure.parent.ssyl_in
                     <
                     1.2)
                    ((R:segstate.parent.R:SylStructure.parent.syl_out
                      <
                      11)
                     ((R:segstate.parent.R:SylStructure.parent.ssyl_out
                       <
                       5.3)
                      ((0.327092 -0.469407))
                      ((0.667496 -0.222845)))
                     ((0.835912 -0.112467)))
                    ((R:segstate.parent.R:SylStructure.parent.syl_out
                      <
                      9.4)
                     ((0.548456 -0.357558))
                     ((0.203 -0.616859)))))
                  ((R:segstate.parent.R:SylStructure.parent.next_accent
                    <
                    1.2)
                   ((0.237684 -0.582047))
                   ((0.432771 -0.461112))))
                 ((R:segstate.parent.pp.ph_vheight is 3)
                  ((R:segstate.parent.ph_vfront is 1)
                   ((0.856344 0.00875871))
                   ((1.08116 0.315476)))
                  ((R:segstate.parent.R:SylStructure.parent.ssyl_in
                    <
                    1.2)
                   ((R:segstate.parent.R:SylStructure.parent.next_accent
                     <
                     2.2)
                    ((R:segstate.parent.R:SylStructure.parent.asyl_out
                      <
                      3.4)
                     ((R:segstate.parent.pp.ph_cvox is +)
                      ((0.525927 -0.411443))
                      ((R:segstate.parent.p.ph_ctype is 0)
                       ((0.904945 0.0952171))
                       ((0.761975 -0.239418))))
                     ((R:segstate.parent.pp.ph_cvox is -)
                      ((0.601593 -0.279121))
                      ((R:segstate.parent.R:SylStructure.parent.R:Syllable.nn.accented
                        is
                        0)
                       ((1.052 0.265375))
                       ((1.00624 -0.0713573)))))
                    ((0.467538 -0.356268)))
                   ((R:segstate.parent.R:SylStructure.parent.asyl_out
                     <
                     2.4)
                    ((R:segstate.parent.R:SylStructure.parent.asyl_out
                      <
                      1.1)
                     ((0.628038 -0.0928005))
                     ((1.36694 0.665673)))
                    ((R:segstate.parent.R:SylStructure.parent.asyl_out
                      <
                      4.5)
                     ((R:segstate.parent.n.ph_ctype is n)
                      ((1.10088 0.380478))
                      ((R:segstate.parent.nn.ph_cvox is +)
                       ((0.612237 -0.369167))
                       ((0.728272 -0.0576403))))
                     ((R:segstate.parent.R:SylStructure.parent.syl_codasize
                       <
                       2.1)
                      ((0.887202 -0.0830479))
                      ((0.432981 -0.498825)))))))))))))))
         ((R:segstate.parent.ph_vfront is 3)
          ((R:segstate.parent.p.name is y)
           ((R:segstate.parent.ph_vheight is 1)
            ((R:segstate.parent.R:SylStructure.parent.position_type
              is
              final)
             ((R:segstate.parent.R:SylStructure.parent.syl_in < 3.2)
              ((1.27394 0.157206))
              ((0.237744 -0.426425)))
             ((R:segstate.parent.R:SylStructure.parent.asyl_out < 2.2)
              ((R:segstate.parent.R:SylStructure.parent.R:Syllable.p.syl_codasize
                <
                0.3)
               ((1.08605 0.0529224))
               ((R:segstate.parent.R:SylStructure.parent.next_accent
                 <
                 1.2)
                ((0.368699 -0.350136))
                ((0.145048 -0.610744))))
              ((R:segstate.parent.R:SylStructure.parent.asyl_out < 4.2)
               ((R:segstate.parent.nn.ph_vrnd is +)
                ((0.129148 -0.685424))
                ((R:segstate.parent.R:SylStructure.parent.syl_out
                  <
                  10.5)
                 ((R:segstate.parent.R:SylStructure.parent.R:Syllable.p.accented
                   is
                   0)
                  ((0.161384 -0.618571))
                  ((0.200587 -0.554173)))
                 ((0.145773 -0.527993))))
               ((R:segstate.parent.R:SylStructure.parent.syl_out
                 <
                 10.6)
                ((0.171252 -0.525643))
                ((0.422552 -0.341658))))))
            ((R:segstate.parent.R:SylStructure.parent.asyl_in < 0.2)
             ((0.341329 -0.66629))
             ((0.0887106 -0.836738))))
           ((R:segstate.parent.R:SylStructure.parent.parent.gpos
             is
             aux)
            ((R:segstate.parent.nn.ph_cplace is d)
             ((R:segstate.parent.R:SylStructure.parent.R:Syllable.pp.lisp_cg_break
               <
               0.1)
              ((0.717966 -0.283136))
              ((1.64647 0.393282)))
             ((R:segstate.parent.nn.ph_cplace is v)
              ((0.323344 -0.535617))
              ((R:segstate.parent.R:SylStructure.parent.asyl_out < 1.4)
               ((0.91188 -0.103243))
               ((R:segstate.parent.R:SylStructure.parent.asyl_in < 1.2)
                ((R:segstate.parent.R:SylStructure.parent.ssyl_out < 8)
                 ((R:segstate.parent.R:SylStructure.parent.R:Syllable.pp.lisp_cg_break
                   <
                   0.3)
                  ((R:segstate.parent.R:SylStructure.parent.asyl_out
                    <
                    2.4)
                   ((0.752189 -0.177009))
                   ((R:segstate.parent.R:SylStructure.parent.ssyl_out
                     <
                     5.5)
                    ((R:segstate.parent.R:SylStructure.parent.syl_out
                      <
                      6.4)
                     ((0.462234 -0.472026))
                     ((R:segstate.parent.pp.ph_cplace is 0)
                      ((0.507944 -0.451744))
                      ((0.613451 -0.323377))))
                    ((R:segstate.parent.R:SylStructure.parent.R:Syllable.nn.stress
                      is
                      0)
                     ((0.895615 -0.102516))
                     ((0.581474 -0.346499)))))
                  ((R:segstate.parent.R:SylStructure.parent.R:Syllable.nn.stress
                    is
                    0)
                   ((0.537339 -0.459262))
                   ((0.523845 -0.337192))))
                 ((R:segstate.parent.pp.ph_cvox is -)
                  ((0.323921 -0.640716))
                  ((0.692891 -0.320486))))
                ((0.463105 -0.554537))))))
            ((R:segstate.parent.ph_vheight is 3)
             ((R:segstate.parent.R:SylStructure.parent.R:Syllable.p.syl_codasize
               <
               1.2)
              ((R:segstate.parent.n.ph_ctype is r)
               ((1.10162 0.547458))
               ((R:segstate.parent.lisp_onset_stop is 0)
                ((R:segstate.parent.R:SylStructure.parent.R:Syllable.nn.accented
                  is
                  0)
                 ((R:segstate.parent.R:SylStructure.parent.syl_codasize
                   <
                   2)
                  ((R:segstate.parent.nn.ph_vfront is 2)
                   ((0.529853 0.0785373))
                   ((0.889522 0.233562)))
                  ((0.563935 -0.0550497)))
                 ((0.701616 0.326699)))
                ((0.639223 -0.0832174))))
              ((R:segstate.parent.R:SylStructure.parent.position_type
                is
                initial)
               ((0.556024 -0.384497))
               ((R:segstate.parent.R:SylStructure.parent.ssyl_out
                 <
                 4.2)
                ((0.907844 0.222434))
                ((0.664013 -0.0802918)))))
             ((R:segstate.parent.R:SylStructure.parent.syl_out < 2.8)
              ((0.506246 -0.660808))
              ((R:segstate.parent.R:SylStructure.parent.asyl_out < 1.6)
               ((0.938444 -0.0465233))
               ((R:segstate.parent.R:SylStructure.parent.asyl_out
                 <
                 2.6)
                ((R:segstate.parent.lisp_coda_stop is 0)
                 ((0.330745 -0.767139))
                 ((0.319957 -0.310027)))
                ((R:segstate.parent.R:SylStructure.parent.syl_codasize
                  <
                  2.2)
                 ((R:segstate.parent.R:SylStructure.parent.syl_out
                   <
                   12)
                  ((R:segstate.parent.nn.ph_vrnd is -)
                   ((R:segstate.parent.n.ph_ctype is s)
                    ((0.526377 -0.3766))
                    ((0.609362 -0.265348)))
                   ((0.775033 0.0792819)))
                  ((0.40748 -0.446127)))
                 ((R:segstate.parent.pp.ph_cvox is -)
                  ((0.540859 -0.552914))
                  ((0.454855 -0.439656))))))))))
          ((R:segstate.parent.R:SylStructure.parent.lisp_cg_break
            <
            0.1)
           ((R:segstate.parent.ph_vheight is 1)
            ((R:segstate.parent.p.name is r)
             ((R:segstate.parent.pp.ph_cplace is 0)
              ((R:segstate.parent.R:SylStructure.parent.ssyl_out < 6.3)
               ((0.311505 -0.533148))
               ((0.285459 -0.786767)))
              ((R:segstate.parent.R:SylStructure.parent.last_accent
                <
                1.2)
               ((R:segstate.parent.R:SylStructure.parent.parent.word_numsyls
                 <
                 2.2)
                ((R:segstate.parent.pp.ph_cplace is a)
                 ((0.449917 -0.389765))
                 ((0.295587 -0.519986)))
                ((0.594965 -0.267921)))
               ((0.57448 -0.610203))))
             ((R:segstate.parent.R:SylStructure.parent.R:Syllable.nn.accented
               is
               0)
              ((R:segstate.parent.R:SylStructure.parent.next_accent
                <
                2.1)
               ((0.48128 -0.0700316))
               ((0.594774 -0.327914)))
              ((0.272176 -0.547318))))
            ((R:segstate.parent.R:SylStructure.parent.last_accent
              <
              1.5)
             ((R:segstate.parent.R:SylStructure.parent.R:Syllable.p.syl_codasize
               <
               2.1)
              ((R:segstate.parent.pp.ph_cvox is +)
               ((R:segstate.parent.R:SylStructure.parent.R:Syllable.p.syl_codasize
                 <
                 1.2)
                ((0.88181 0.0944991))
                ((R:segstate.parent.R:SylStructure.parent.syl_onsetsize
                  <
                  1.1)
                 ((0.694055 -0.0322162))
                 ((0.652123 -0.322203))))
               ((R:segstate.parent.R:SylStructure.parent.ssyl_out < 9)
                ((R:segstate.parent.nn.ph_vfront is 2)
                 ((R:segstate.parent.ph_vfront is 1)
                  ((0.506707 -0.246455))
                  ((0.456445 -0.398975)))
                 ((R:segstate.parent.nn.ph_vlng is l)
                  ((0.284415 -0.348419))
                  ((R:segstate.parent.R:SylStructure.parent.R:Syllable.pp.accented
                    is
                    0)
                   ((R:segstate.parent.R:SylStructure.parent.syl_out
                     <
                     8.6)
                    ((0.573558 -0.210162))
                    ((0.629738 0.0759844)))
                   ((R:segstate.parent.R:SylStructure.parent.next_accent
                     <
                     2.4)
                    ((0.650604 -0.187089))
                    ((0.50581 -0.348413))))))
                ((0.423161 -0.487396))))
              ((0.406317 -0.517055)))
             ((R:segstate.parent.ph_vheight is 2)
              ((R:segstate.parent.pp.ph_vc is +)
               ((0.377904 -0.341101))
               ((R:segstate.parent.R:SylStructure.parent.R:Syllable.nn.stress
                 is
                 0)
                ((0.413404 -0.411239))
                ((0.334171 -0.579617))))
              ((0.415008 -0.247283)))))
           ((R:segstate.parent.n.ph_ctype is f)
            ((R:segstate.parent.R:SylStructure.parent.parent.gpos
              is
              content)
             ((R:segstate.parent.R:SylStructure.parent.syl_out < 10.6)
              ((R:segstate.parent.pp.ph_cplace is 0)
               ((R:segstate.parent.R:SylStructure.parent.position_type
                 is
                 final)
                ((0.74725 -0.0971162))
                ((R:segstate.parent.pp.ph_vc is +)
                 ((R:segstate.parent.R:SylStructure.parent.asyl_out
                   <
                   1.5)
                  ((0.688573 0.110418))
                  ((1.06544 0.572568)))
                 ((0.818652 0.114465))))
               ((R:segstate.parent.ph_vheight is 3)
                ((R:segstate.parent.R:SylStructure.parent.last_accent
                  <
                  1.2)
                 ((0.712792 0.0200769))
                 ((0.817348 0.238403)))
                ((R:segstate.parent.R:SylStructure.parent.syl_in < 1.4)
                 ((0.655356 -0.0508564))
                 ((R:segstate.parent.R:SylStructure.parent.asyl_out
                   <
                   2.2)
                  ((0.574894 -0.347216))
                  ((0.591127 -0.165568))))))
              ((R:segstate.parent.R:SylStructure.parent.R:Syllable.nn.lisp_cg_break
                <
                0.1)
               ((R:segstate.parent.R:SylStructure.parent.asyl_out
                 <
                 4.5)
                ((1.37938 0.896657))
                ((0.892265 0.389692)))
               ((R:segstate.parent.nn.ph_cplace is 0)
                ((0.90342 0.426313))
                ((R:segstate.parent.R:SylStructure.parent.ssyl_out
                  <
                  7.5)
                 ((0.815091 0.00652822))
                 ((0.685872 0.0566635))))))
             ((R:segstate.parent.R:SylStructure.parent.R:Syllable.n.accented
               is
               0)
              ((0.237275 -0.471938))
              ((R:segstate.parent.R:SylStructure.parent.ssyl_out < 3.7)
               ((0.344238 -0.225995))
               ((0.398399 -0.081171)))))
            ((R:segstate.parent.R:SylStructure.parent.parent.gpos
              is
              in)
             ((0.286287 -0.593769))
             ((R:segstate.parent.pos_in_syl is 2)
              ((R:segstate.parent.ph_vfront is 1)
               ((R:segstate.parent.ph_vheight is 3)
                ((0.990151 0.252657))
                ((R:segstate.parent.R:SylStructure.parent.R:Syllable.p.syl_codasize
                  <
                  1.3)
                 ((R:segstate.parent.R:SylStructure.parent.ssyl_in
                   <
                   1.2)
                  ((0.901564 0.0998644))
                  ((0.678652 -0.163922)))
                 ((R:segstate.parent.R:SylStructure.parent.asyl_out
                   <
                   2.5)
                  ((0.866047 -0.140999))
                  ((0.371284 -0.561016)))))
               ((R:segstate.parent.R:SylStructure.parent.syl_out
                 <
                 11.8)
                ((R:segstate.parent.R:SylStructure.parent.R:Syllable.pp.lisp_cg_break
                  <
                  0.1)
                 ((0.937471 0.353947))
                 ((1.00053 -0.00378275)))
                ((1.29341 0.691387))))
              ((R:segstate.parent.p.name is l)
               ((R:segstate.parent.R:SylStructure.parent.syl_codasize
                 <
                 2.2)
                ((R:segstate.parent.ph_vfront is 1)
                 ((R:segstate.parent.pp.ph_cvox is +)
                  ((0.77749 0.0217594))
                  ((R:segstate.parent.R:SylStructure.parent.last_accent
                    <
                    0.4)
                   ((0.572152 -0.39862))
                   ((0.690177 -0.224701))))
                 ((R:segstate.parent.pp.ph_vheight is 2)
                  ((0.760383 -0.121956))
                  ((R:segstate.parent.pp.ph_cvox is -)
                   ((0.278966 -0.665222))
                   ((R:segstate.parent.R:SylStructure.parent.R:Syllable.nn.accented
                     is
                     0)
                    ((R:segstate.parent.R:SylStructure.parent.asyl_out
                      <
                      3.5)
                     ((0.272203 -0.56813))
                     ((0.139732 -0.542352)))
                    ((0.461074 -0.303573))))))
                ((0.763082 -0.0164512)))
               ((R:segstate.parent.R:SylStructure.parent.parent.gpos
                 is
                 md)
                ((0.170407 -0.638659))
                ((R:segstate.parent.R:SylStructure.parent.syl_onsetsize
                  <
                  1.2)
                 ((R:segstate.parent.ph_vheight is 1)
                  ((R:segstate.parent.pp.ph_vc is +)
                   ((R:segstate.parent.R:SylStructure.parent.R:Syllable.nn.stress
                     is
                     0)
                    ((1.16516 0.25599))
                    ((0.781691 -0.117083)))
                   ((R:segstate.parent.R:SylStructure.parent.R:Syllable.nn.lisp_cg_break
                     <
                     0.1)
                    ((0.724804 -0.495439))
                    ((R:segstate.parent.R:SylStructure.parent.syl_out
                      <
                      8.4)
                     ((0.61345 -0.102149))
                     ((0.641106 -0.380089)))))
                  ((R:segstate.parent.p.name is y)
                   ((0.696034 0.457811))
                   ((R:segstate.parent.nn.ph_cplace is g)
                    ((0.430439 -0.411117))
                    ((R:segstate.parent.ph_vfront is 1)
                     ((R:segstate.parent.R:SylStructure.parent.R:Syllable.n.syl_onsetsize
                       <
                       0.2)
                      ((0.574564 -0.263418))
                      ((R:segstate.parent.R:SylStructure.parent.R:Syllable.pp.lisp_cg_break
                        <
                        0.1)
                       ((0.815626 -0.157974))
                       ((0.832996 0.161777))))
                     ((R:segstate.parent.R:SylStructure.parent.last_accent
                       <
                       1.2)
                      ((R:segstate.parent.R:SylStructure.parent.last_accent
                        <
                        0.1)
                       ((R:segstate.parent.nn.ph_vrnd is -)
                        ((0.508271 -0.0685345))
                        ((R:segstate.parent.R:SylStructure.parent.R:Syllable.p.lisp_cg_break
                          <
                          0.1)
                         ((R:segstate.parent.R:SylStructure.parent.ssyl_out
                           <
                           5.5)
                          ((1.23043 0.358502))
                          ((0.614441 0.0596861)))
                         ((0.757826 -0.055586))))
                       ((R:segstate.parent.R:SylStructure.parent.R:Syllable.n.accented
                         is
                         0)
                        ((0.931425 0.516309))
                        ((0.995022 0.120711))))
                      ((0.884721 -0.153161)))))))
                 ((R:segstate.parent.R:SylStructure.parent.R:Syllable.pp.accented
                   is
                   0)
                  ((0.414018 -0.411437))
                  ((0.644033 -0.201921)))))))))))))
       ((R:segstate.parent.p.ph_ctype is n)
        ((R:segstate.parent.ph_cvox is +)
         ((R:segstate.parent.ph_ctype is r)
          ((R:segstate.parent.R:SylStructure.parent.R:Syllable.nn.stress
            is
            0)
           ((R:segstate.parent.R:SylStructure.parent.syl_out < 8.2)
            ((0.752139 -0.593234))
            ((0.852349 -0.102179)))
           ((R:segstate.parent.pp.ph_vheight is 1)
            ((1.19209 0.276667))
            ((R:segstate.parent.R:SylStructure.parent.asyl_in < 0.2)
             ((0.724461 0.125603))
             ((0.880685 -0.162131)))))
          ((R:segstate.parent.pp.ph_vheight is 3)
           ((R:segstate.parent.n.ph_ctype is s)
            ((R:segstate.parent.R:SylStructure.parent.asyl_out < 4.6)
             ((R:segstate.parent.R:SylStructure.parent.sub_phrases
               <
               0.1)
              ((1.11777 -0.0587875))
              ((0.453448 -0.480224)))
             ((0.318057 -0.664825)))
            ((R:segstate.parent.R:SylStructure.parent.parent.gpos
              is
              content)
             ((R:segstate.parent.R:SylStructure.parent.ssyl_out < 8.7)
              ((R:segstate.parent.R:SylStructure.parent.ssyl_out < 4.5)
               ((R:segstate.parent.pp.ph_vlng is l)
                ((0.443461 -0.319815))
                ((0.262897 -0.634867)))
               ((R:segstate.parent.pp.ph_vlng is d)
                ((R:segstate.parent.R:SylStructure.parent.ssyl_out
                  <
                  6.2)
                 ((0.262508 -0.639187))
                 ((0.466545 -0.437281)))
                ((R:segstate.parent.syl_final is 0)
                 ((0.198061 -0.825322))
                 ((0.149481 -0.717548)))))
              ((0.573284 -0.307551)))
             ((R:segstate.parent.R:SylStructure.parent.R:Syllable.p.syl_codasize
               <
               1.2)
              ((R:segstate.parent.nn.ph_vfront is 1)
               ((R:segstate.parent.R:SylStructure.parent.syl_out < 9)
                ((0.587776 -0.471486))
                ((0.296122 -0.629867)))
               ((R:segstate.parent.R:SylStructure.parent.R:Syllable.nn.accented
                 is
                 0)
                ((R:segstate.parent.R:SylStructure.parent.R:Syllable.nn.lisp_cg_break
                  <
                  0.1)
                 ((0.0950438 -0.772073))
                 ((0.214391 -0.693186)))
                ((0.236443 -0.649508))))
              ((R:segstate.parent.n.ph_ctype is 0)
               ((R:segstate.parent.nn.ph_cplace is v)
                ((0.0715493 -0.753356))
                ((R:segstate.parent.R:SylStructure.parent.ssyl_out
                  <
                  5.8)
                 ((0.317002 -0.543326))
                 ((0.149176 -0.698903))))
               ((R:segstate.parent.R:SylStructure.parent.ssyl_out
                 <
                 3.7)
                ((0.165976 -0.707778))
                ((R:segstate.parent.R:SylStructure.parent.R:Syllable.p.syl_codasize
                  <
                  2.1)
                 ((R:segstate.parent.R:SylStructure.parent.R:Syllable.nn.accented
                   is
                   0)
                  ((0.010139 -0.796299))
                  ((0.0107737 -0.794486)))
                 ((0.116362 -0.753578))))))))
           ((R:segstate.parent.n.ph_vlng is a)
            ((R:segstate.parent.R:SylStructure.parent.position_type
              is
              final)
             ((0.371972 -0.827391))
             ((R:segstate.parent.R:SylStructure.parent.R:Syllable.pp.accented
               is
               0)
              ((R:segstate.parent.R:SylStructure.parent.R:Syllable.pp.lisp_cg_break
                <
                0.1)
               ((0.317685 -0.582644))
               ((0.160027 -0.722774)))
              ((0.278887 -0.505065))))
            ((R:segstate.parent.p.name is m)
             ((R:segstate.parent.n.ph_vlng is s)
              ((0.392174 -0.557903))
              ((R:segstate.parent.R:SylStructure.parent.R:Syllable.p.stress
                is
                0)
               ((0.599194 -0.346751))
               ((R:segstate.parent.nn.ph_vfront is 2)
                ((0.586284 -0.222646))
                ((1.34324 0.21718)))))
             ((R:segstate.parent.R:SylStructure.parent.R:Syllable.p.accented
               is
               0)
              ((R:segstate.parent.R:SylStructure.parent.asyl_out < 4.2)
               ((R:segstate.parent.R:SylStructure.parent.syl_out
                 <
                 10.6)
                ((R:segstate.parent.R:SylStructure.parent.R:Syllable.pp.lisp_cg_break
                  <
                  0.3)
                 ((R:segstate.parent.nn.ph_cvox is +)
                  ((R:segstate.parent.pp.ph_vheight is 1)
                   ((0.456674 -0.525927))
                   ((0.443792 -0.429213)))
                  ((1.0192 0.000931435)))
                 ((R:segstate.parent.R:SylStructure.parent.R:Syllable.n.lisp_cg_break
                   <
                   0.3)
                  ((0.581095 -0.653517))
                  ((R:segstate.parent.R:SylStructure.parent.ssyl_out
                    <
                    3.1)
                   ((1.03901 -0.282771))
                   ((0.647914 -0.529022)))))
                ((0.484933 -0.686573)))
               ((R:segstate.parent.R:SylStructure.parent.ssyl_in < 1.2)
                ((0.915319 -0.325111))
                ((1.48293 0.481046))))
              ((R:segstate.parent.R:SylStructure.parent.syl_codasize
                <
                2.2)
               ((R:segstate.parent.pp.ph_vheight is 1)
                ((0.303914 -0.733303))
                ((R:segstate.parent.R:SylStructure.parent.next_accent
                  <
                  2.4)
                 ((R:segstate.parent.nn.ph_cvox is +)
                  ((0.426477 -0.656182))
                  ((0.644499 -0.502187)))
                 ((0.310587 -0.680405))))
               ((R:segstate.parent.n.ph_ctype is f)
                ((0.32289 -0.691039))
                ((R:segstate.parent.nn.ph_cplace is a)
                 ((0.399852 -0.568358))
                 ((R:segstate.parent.R:SylStructure.parent.position_type
                   is
                   final)
                  ((0.655237 -0.0108464))
                  ((0.863945 -0.259838)))))))))))
         ((R:segstate.parent.pos_in_syl is 0)
          ((R:segstate.parent.R:SylStructure.parent.position_type
            is
            single)
           ((R:segstate.parent.R:SylStructure.parent.R:Syllable.n.lisp_cg_break
             <
             0.3)
            ((R:segstate.parent.pp.ph_vlng is s)
             ((R:segstate.parent.R:SylStructure.parent.parent.gpos
               is
               content)
              ((0.602007 -0.405326))
              ((0.569882 -0.127308)))
             ((0.875254 0.128825)))
            ((R:segstate.parent.R:SylStructure.parent.ssyl_out < 8)
             ((R:segstate.parent.R:SylStructure.parent.parent.gpos
               is
               content)
              ((R:segstate.parent.R:SylStructure.parent.ssyl_out < 5.2)
               ((R:segstate.parent.pp.ph_vheight is 1)
                ((1.21445 0.66563))
                ((1.1497 0.345336)))
               ((R:segstate.parent.p.name is n)
                ((0.849334 -0.237086))
                ((1.05918 0.2566))))
              ((R:segstate.parent.R:SylStructure.parent.ssyl_out < 4.6)
               ((0.442834 -0.420933))
               ((0.693096 0.119702))))
             ((R:segstate.parent.n.ph_vheight is 2)
              ((1.78947 0.852821))
              ((1.11985 0.287412)))))
           ((R:segstate.parent.R:SylStructure.parent.stress is 0)
            ((R:segstate.parent.pp.ph_vheight is 2)
             ((R:segstate.parent.R:SylStructure.parent.R:Syllable.nn.stress
               is
               0)
              ((0.710752 -0.359167))
              ((R:segstate.parent.R:SylStructure.parent.next_accent
                <
                3.5)
               ((0.28296 -0.772289))
               ((0.578042 -0.642944))))
             ((R:segstate.parent.R:SylStructure.parent.asyl_out < 2.5)
              ((R:segstate.parent.R:SylStructure.parent.ssyl_out < 2.2)
               ((0.817509 -0.199205))
               ((1.41285 0.290468)))
              ((0.744847 -0.459067))))
            ((R:segstate.parent.p.name is m)
             ((R:segstate.parent.nn.ph_cplace is a)
              ((0.549813 -0.445098))
              ((1.09275 -0.105728)))
             ((R:segstate.parent.n.ph_vheight is 3)
              ((0.856964 -0.257065))
              ((R:segstate.parent.nn.ph_cvox is +)
               ((R:segstate.parent.R:SylStructure.parent.syl_codasize
                 <
                 1.2)
                ((R:segstate.parent.pp.ph_vlng is s)
                 ((0.938728 0.276295))
                 ((0.847624 -0.144443)))
                ((0.954271 0.440949)))
               ((R:segstate.parent.R:SylStructure.parent.R:Syllable.nn.stress
                 is
                 0)
                ((0.92771 0.125961))
                ((0.785599 -0.153631))))))))
          ((R:segstate.parent.R:SylStructure.parent.syl_codasize < 2.2)
           ((1.02124 0.0377462))
           ((R:segstate.parent.pp.ph_vheight is 1)
            ((0.489607 -0.86615))
            ((R:segstate.parent.R:SylStructure.parent.asyl_out < 4.5)
             ((R:segstate.parent.R:SylStructure.parent.syl_codasize
               <
               3.1)
              ((R:segstate.parent.R:SylStructure.parent.parent.word_numsyls
                <
                2.2)
               ((R:segstate.parent.R:SylStructure.parent.ssyl_out < 6)
                ((R:segstate.parent.R:SylStructure.parent.asyl_in
                  <
                  0.2)
                 ((R:segstate.parent.pp.ph_vlng is d)
                  ((0.664161 -0.310483))
                  ((0.624526 -0.639866)))
                 ((R:segstate.parent.nn.ph_vc is +)
                  ((1.22939 0.00604911))
                  ((0.917809 -0.226341))))
                ((0.899678 0.116385)))
               ((0.710696 -0.635846)))
              ((R:segstate.parent.R:SylStructure.parent.R:Syllable.pp.lisp_cg_break
                <
                0.3)
               ((0.434996 -0.459354))
               ((0.714373 -0.658367))))
             ((R:segstate.parent.lisp_onset_glide is 0)
              ((0.382575 -0.526999))
              ((0.264425 -0.826799))))))))
        ((R:segstate.parent.pos_in_syl is 0)
         ((R:segstate.parent.R:SylStructure.parent.R:Syllable.p.syl_codasize
           <
           2.5)
          ((R:segstate.parent.ph_ctype is n)
           ((R:segstate.parent.R:SylStructure.parent.stress is 0)
            ((R:segstate.parent.R:SylStructure.parent.ssyl_out < 6)
             ((R:segstate.parent.p.ph_vheight is 3)
              ((0.32988 -0.693521))
              ((R:segstate.parent.R:SylStructure.parent.R:Syllable.n.lisp_cg_break
                <
                0.3)
               ((0.824976 -0.225885))
               ((R:segstate.parent.pp.ph_cvox is -)
                ((0.703293 -0.328695))
                ((0.48014 -0.608843)))))
             ((R:segstate.parent.pp.ph_vc is +)
              ((0.574409 -0.494732))
              ((R:segstate.parent.R:SylStructure.parent.next_accent
                <
                2.4)
               ((R:segstate.parent.R:SylStructure.parent.parent.word_numsyls
                 <
                 2.3)
                ((R:segstate.parent.nn.ph_cvox is +)
                 ((0.634607 -0.35275))
                 ((0.783992 -0.0459141)))
                ((0.575058 -0.428069)))
               ((0.673511 -0.0239116)))))
            ((R:segstate.parent.p.ph_vc is +)
             ((R:segstate.parent.R:SylStructure.parent.syl_in < 3.4)
              ((R:segstate.parent.p.ph_vfront is 1)
               ((R:segstate.parent.R:SylStructure.parent.syl_codasize
                 <
                 1.2)
                ((1.04367 -0.00368665))
                ((R:segstate.parent.R:SylStructure.parent.ssyl_in
                  <
                  0.2)
                 ((1.12242 0.250697))
                 ((1.69638 0.572907))))
               ((R:segstate.parent.lisp_coda_stop is 0)
                ((R:segstate.parent.R:SylStructure.parent.next_accent
                  <
                  2.7)
                 ((R:segstate.parent.p.ph_vheight is 3)
                  ((0.88346 -0.106989))
                  ((1.09315 0.159674)))
                 ((0.978901 0.237838)))
                ((0.607003 -0.267622))))
              ((R:segstate.parent.R:SylStructure.parent.syl_codasize
                <
                1.1)
               ((0.672783 -0.319913))
               ((0.921601 -0.070949))))
             ((R:segstate.parent.lisp_coda_glide is 0)
              ((R:segstate.parent.p.name is l)
               ((1.48453 0.202573))
               ((R:segstate.parent.R:SylStructure.parent.syl_out
                 <
                 11.5)
                ((R:segstate.parent.nn.ph_cvox is -)
                 ((R:segstate.parent.R:SylStructure.parent.ssyl_out
                   <
                   1.8)
                  ((0.387807 -0.56833))
                  ((R:segstate.parent.n.ph_vlng is s)
                   ((0.490486 -0.454821))
                   ((R:segstate.parent.R:SylStructure.parent.R:Syllable.nn.stress
                     is
                     0)
                    ((R:segstate.parent.R:SylStructure.parent.syl_out
                      <
                      6.2)
                     ((0.550753 -0.283279))
                     ((0.85631 -0.0863323)))
                    ((R:segstate.parent.R:SylStructure.parent.syl_out
                      <
                      7.6)
                     ((R:segstate.parent.R:SylStructure.parent.syl_in
                       <
                       2.4)
                      ((0.653602 -0.157273))
                      ((0.4605 -0.333583)))
                     ((0.38209 -0.506429))))))
                 ((R:segstate.parent.R:SylStructure.parent.asyl_out
                   <
                   2.4)
                  ((R:segstate.parent.p.ph_ctype is f)
                   ((0.553329 -0.215115))
                   ((R:segstate.parent.R:SylStructure.parent.ssyl_in
                     <
                     1.2)
                    ((R:segstate.parent.R:SylStructure.parent.next_accent
                      <
                      1.5)
                     ((0.76351 -0.164927))
                     ((0.808672 -0.188336)))
                    ((1.44809 0.182832))))
                  ((R:segstate.parent.R:SylStructure.parent.asyl_in
                    <
                    0.2)
                   ((R:segstate.parent.nn.ph_cplace is a)
                    ((0.750664 -0.146888))
                    ((R:segstate.parent.R:SylStructure.parent.syl_out
                      <
                      7.5)
                     ((0.701858 -0.380701))
                     ((0.494755 -0.212605))))
                   ((0.585899 -0.487937)))))
                ((R:segstate.parent.R:SylStructure.parent.next_accent
                  <
                  4)
                 ((R:segstate.parent.R:SylStructure.parent.position_type
                   is
                   initial)
                  ((0.467804 -0.148041))
                  ((R:segstate.parent.p.ph_cvox is +)
                   ((0.907954 -0.120794))
                   ((1.00916 0.0810248))))
                 ((0.577548 -0.275414)))))
              ((R:segstate.parent.R:SylStructure.parent.next_accent
                <
                1.4)
               ((1.22198 0.289017))
               ((0.71213 -0.106114))))))
           ((R:segstate.parent.R:SylStructure.parent.stress is 0)
            ((R:segstate.parent.lisp_onset_glide is 0)
             ((R:segstate.parent.R:SylStructure.parent.position_type
               is
               final)
              ((R:segstate.parent.ph_ctype is s)
               ((R:segstate.parent.R:SylStructure.parent.R:Syllable.p.syl_codasize
                 <
                 1.1)
                ((R:segstate.parent.pp.ph_cplace is v)
                 ((0.833524 -0.112431))
                 ((R:segstate.parent.R:SylStructure.parent.R:Syllable.pp.accented
                   is
                   0)
                  ((R:segstate.parent.R:SylStructure.parent.ssyl_out
                    <
                    2.8)
                   ((0.52214 -0.307747))
                   ((R:segstate.parent.p.name is ih)
                    ((0.307715 -0.663605))
                    ((R:segstate.parent.R:SylStructure.parent.syl_in
                      <
                      3.5)
                     ((R:segstate.parent.R:SylStructure.parent.R:Syllable.n.lisp_cg_break
                       <
                       0.1)
                      ((0.554096 -0.24819))
                      ((R:segstate.parent.R:SylStructure.parent.ssyl_out
                        <
                        3.7)
                       ((0.349975 -0.603533))
                       ((R:segstate.parent.p.ph_vheight is 3)
                        ((0.375895 -0.571175))
                        ((R:segstate.parent.R:SylStructure.parent.ssyl_out
                          <
                          7.6)
                         ((0.619979 -0.24241))
                         ((0.387706 -0.478662))))))
                     ((R:segstate.parent.R:SylStructure.parent.syl_in
                       <
                       4.2)
                      ((0.334302 -0.664424))
                      ((0.532939 -0.511313))))))
                  ((R:segstate.parent.p.ph_vrnd is +)
                   ((0.658283 -0.12726))
                   ((R:segstate.parent.lisp_coda_stop is 0)
                    ((0.502418 -0.431089))
                    ((0.464699 -0.296764))))))
                ((R:segstate.parent.R:SylStructure.parent.ssyl_out < 7)
                 ((0.602191 -0.147546))
                 ((0.65082 0.124996))))
               ((R:segstate.parent.p.ph_ctype is s)
                ((0.493624 -0.439646))
                ((R:segstate.parent.p.name is ah)
                 ((1.13767 0.203433))
                 ((R:segstate.parent.lisp_coda_fric is 0)
                  ((R:segstate.parent.n.ph_vheight is 1)
                   ((0.609597 0.0136435))
                   ((R:segstate.parent.p.name is aw)
                    ((0.586535 -0.399357))
                    ((R:segstate.parent.R:SylStructure.parent.syl_codasize
                      <
                      1.2)
                     ((R:segstate.parent.R:SylStructure.parent.ssyl_in
                       <
                       1.2)
                      ((R:segstate.parent.R:SylStructure.parent.R:Syllable.pp.lisp_cg_break
                        <
                        0.3)
                       ((R:segstate.parent.nn.ph_cplace is 0)
                        ((0.584021 -0.204921))
                        ((0.717795 -0.0229569)))
                       ((R:segstate.parent.R:SylStructure.parent.next_accent
                         <
                         2.1)
                        ((0.517503 -0.440431))
                        ((0.749613 -0.19712))))
                      ((R:segstate.parent.R:SylStructure.parent.next_accent
                        <
                        2.4)
                       ((R:segstate.parent.p.ph_vrnd is -)
                        ((1.11614 0.117042))
                        ((0.753793 -0.0423645)))
                       ((0.633935 -0.171153))))
                     ((R:segstate.parent.pp.ph_cvox is -)
                      ((0.816625 -0.0568107))
                      ((R:segstate.parent.p.ph_vheight is 1)
                       ((0.619867 -0.215873))
                       ((0.49607 -0.435439)))))))
                  ((1.17827 0.144837))))))
              ((R:segstate.parent.p.name is d)
               ((R:segstate.parent.R:SylStructure.parent.R:Syllable.nn.stress
                 is
                 0)
                ((0.856138 -0.137707))
                ((R:segstate.parent.R:SylStructure.parent.ssyl_out
                  <
                  3.1)
                 ((0.626099 -0.35375))
                 ((0.288887 -0.568449))))
               ((R:segstate.parent.R:SylStructure.parent.parent.gpos
                 is
                 to)
                ((R:segstate.parent.R:SylStructure.parent.syl_in < 2.1)
                 ((1.17514 0.632056))
                 ((0.914955 0.0406565)))
                ((R:segstate.parent.ph_cvox is -)
                 ((R:segstate.parent.nn.ph_cvox is +)
                  ((R:segstate.parent.R:SylStructure.parent.ssyl_out
                    <
                    7)
                   ((R:segstate.parent.R:SylStructure.parent.R:Syllable.nn.lisp_cg_break
                     <
                     0.3)
                    ((0.64229 -0.0303352))
                    ((R:segstate.parent.pp.ph_vlng is l)
                     ((0.685744 -0.174242))
                     ((0.55762 -0.391056))))
                   ((0.362747 -0.525225)))
                  ((R:segstate.parent.R:SylStructure.parent.syl_in
                    <
                    0.6)
                   ((0.748788 -0.423401))
                   ((R:segstate.parent.R:SylStructure.parent.R:Syllable.pp.accented
                     is
                     0)
                    ((R:segstate.parent.R:SylStructure.parent.next_accent
                      <
                      2.4)
                     ((R:segstate.parent.R:SylStructure.parent.R:Syllable.p.syl_codasize
                       <
                       1.1)
                      ((0.478024 -0.390141))
                      ((1.00533 -0.0690339)))
                     ((0.665677 0.11154)))
                    ((0.817598 0.188737)))))
                 ((R:segstate.parent.nn.ph_cplace is 0)
                  ((R:segstate.parent.n.ph_ctype is r)
                   ((1.02182 0.104704))
                   ((R:segstate.parent.R:SylStructure.parent.syl_in
                     <
                     3.5)
                    ((R:segstate.parent.R:SylStructure.parent.R:Syllable.pp.accented
                      is
                      0)
                     ((R:segstate.parent.R:SylStructure.parent.R:Syllable.nn.lisp_cg_break
                       <
                       0.1)
                      ((0.873461 -0.178837))
                      ((1.03975 0.0816785)))
                     ((0.623957 -0.334662)))
                    ((R:segstate.parent.p.ph_vrnd is -)
                     ((0.551765 -0.312809))
                     ((0.480409 -0.500989)))))
                  ((R:segstate.parent.p.name is t)
                   ((R:segstate.parent.R:SylStructure.parent.asyl_out
                     <
                     2.2)
                    ((0.864387 -0.261059))
                    ((0.903029 0.0400322)))
                   ((R:segstate.parent.p.name is v)
                    ((0.694869 -0.146513))
                    ((R:segstate.parent.pp.ph_vheight is 2)
                     ((1.47716 0.644178))
                     ((R:segstate.parent.pp.ph_cplace is l)
                      ((0.834423 -0.180058))
                      ((R:segstate.parent.pp.ph_cplace is a)
                       ((R:segstate.parent.R:SylStructure.parent.R:Syllable.p.stress
                         is
                         0)
                        ((1.09883 0.452937))
                        ((R:segstate.parent.R:SylStructure.parent.asyl_out
                          <
                          3.1)
                         ((0.780445 -0.136186))
                         ((R:segstate.parent.R:SylStructure.parent.R:Syllable.n.lisp_cg_break
                           <
                           0.1)
                          ((0.654259 -0.0291504))
                          ((1.7829 0.668787)))))
                       ((R:segstate.parent.R:SylStructure.parent.R:Syllable.nn.lisp_cg_break
                         <
                         0.3)
                        ((R:segstate.parent.nn.ph_cvox is +)
                         ((0.547812 -0.259736))
                         ((0.86851 0.097373)))
                        ((R:segstate.parent.R:SylStructure.parent.position_type
                          is
                          initial)
                         ((0.799356 -0.149732))
                         ((R:segstate.parent.R:SylStructure.parent.last_accent
                           <
                           0.3)
                          ((R:segstate.parent.R:SylStructure.parent.syl_out
                            <
                            14.6)
                           ((R:segstate.parent.R:SylStructure.parent.R:Syllable.nn.stress
                             is
                             0)
                            ((R:segstate.parent.p.name is pau)
                             ((0.731683 -0.169518))
                             ((1.078 0.268537)))
                            ((R:segstate.parent.R:SylStructure.parent.ssyl_out
                              <
                              6.5)
                             ((1.22165 0.455651))
                             ((R:segstate.parent.R:SylStructure.parent.syl_out
                               <
                               11.2)
                              ((0.95341 0.0908804))
                              ((1.03898 0.236462)))))
                           ((1.13804 0.486842)))
                          ((R:segstate.parent.R:SylStructure.parent.ssyl_out
                            <
                            4.6)
                           ((0.932857 0.215206))
                           ((R:segstate.parent.R:SylStructure.parent.R:Syllable.nn.accented
                             is
                             0)
                            ((0.790016 0.079302))
                            ((0.72072 -0.201879)))))))))))))))))
             ((R:segstate.parent.p.ph_vc is +)
              ((R:segstate.parent.R:SylStructure.parent.syl_onsetsize
                <
                1.1)
               ((R:segstate.parent.R:SylStructure.parent.asyl_in < 1.2)
                ((R:segstate.parent.n.ph_vlng is l)
                 ((R:segstate.parent.R:SylStructure.parent.R:Syllable.nn.accented
                   is
                   0)
                  ((R:segstate.parent.nn.ph_cvox is -)
                   ((0.912157 0.18056))
                   ((1.28512 0.367793)))
                  ((0.491165 0.0207251)))
                 ((R:segstate.parent.R:SylStructure.parent.next_accent
                   <
                   3.2)
                  ((R:segstate.parent.R:SylStructure.parent.ssyl_out
                    <
                    9)
                   ((R:segstate.parent.nn.ph_cvox is +)
                    ((R:segstate.parent.R:SylStructure.parent.ssyl_out
                      <
                      3.1)
                     ((0.661578 -0.0180826))
                     ((1.44947 0.412375)))
                    ((R:segstate.parent.R:SylStructure.parent.ssyl_out
                      <
                      5.2)
                     ((R:segstate.parent.R:SylStructure.parent.syl_codasize
                       <
                       1.2)
                      ((1.86219 0.84639))
                      ((1.06827 0.433065)))
                     ((0.996658 0.119555))))
                   ((0.90935 0.820513)))
                  ((1.82649 0.898293))))
                ((0.837149 0.127506)))
               ((R:segstate.parent.R:SylStructure.parent.position_type
                 is
                 mid)
                ((0.970108 -0.248132))
                ((1.1595 0.276684))))
              ((R:segstate.parent.R:SylStructure.parent.parent.gpos
                is
                content)
               ((R:segstate.parent.p.ph_ctype is s)
                ((0.621554 -0.290524))
                ((R:segstate.parent.R:SylStructure.parent.R:Syllable.n.accented
                  is
                  0)
                 ((1.17908 0.0487446))
                 ((1.24014 0.36941))))
               ((R:segstate.parent.R:SylStructure.parent.ssyl_out
                 <
                 7.3)
                ((0.713047 -0.488129))
                ((0.462846 -0.337424))))))
            ((R:segstate.parent.p.ph_cvox is -)
             ((R:segstate.parent.ph_ctype is f)
              ((R:segstate.parent.pp.ph_vlng is s)
               ((R:segstate.parent.p.ph_ctype is s)
                ((R:segstate.parent.lisp_coda_glide is 0)
                 ((R:segstate.parent.R:SylStructure.parent.syl_out
                   <
                   11.8)
                  ((R:segstate.parent.R:SylStructure.parent.R:Syllable.n.lisp_cg_break
                    <
                    0.3)
                   ((0.956221 0.235961))
                   ((R:segstate.parent.R:SylStructure.parent.R:Syllable.n.accented
                     is
                     0)
                    ((R:segstate.parent.R:SylStructure.parent.R:Syllable.nn.lisp_cg_break
                      <
                      0.1)
                     ((0.836468 0.0658438))
                     ((0.863503 -0.235044)))
                    ((0.598804 -0.407762))))
                  ((0.517909 -0.405056)))
                 ((1.01579 0.322134)))
                ((R:segstate.parent.p.name is s)
                 ((0.622879 -0.99551))
                 ((R:segstate.parent.R:SylStructure.parent.ssyl_out
                   <
                   4.5)
                  ((0.799536 -0.306168))
                  ((0.799161 -0.742044)))))
               ((R:segstate.parent.pp.ph_vheight is 1)
                ((0.512429 -0.493311))
                ((R:segstate.parent.n.ph_vlng is a)
                 ((1.75519 0.865798))
                 ((R:segstate.parent.n.ph_vheight is 1)
                  ((R:segstate.parent.R:SylStructure.parent.R:Syllable.p.syl_codasize
                    <
                    1.2)
                   ((R:segstate.parent.R:SylStructure.parent.parent.gpos
                     is
                     content)
                    ((R:segstate.parent.R:SylStructure.parent.R:Syllable.n.syl_onsetsize
                      <
                      1.2)
                     ((R:segstate.parent.R:SylStructure.parent.asyl_out
                       <
                       5.4)
                      ((R:segstate.parent.R:SylStructure.parent.ssyl_out
                        <
                        8.8)
                       ((R:segstate.parent.nn.ph_cvox is +)
                        ((R:segstate.parent.R:SylStructure.parent.next_accent
                          <
                          1.8)
                         ((R:segstate.parent.R:SylStructure.parent.syl_out
                           <
                           10.6)
                          ((R:segstate.parent.R:SylStructure.parent.syl_out
                            <
                            5.5)
                           ((1.36456 0.438367))
                           ((R:segstate.parent.R:SylStructure.parent.position_type
                             is
                             initial)
                            ((1.21476 0.189155))
                            ((0.947354 0.0573858))))
                          ((1.34079 0.581362)))
                         ((1.37616 0.52868)))
                        ((R:segstate.parent.R:SylStructure.parent.asyl_out
                          <
                          3)
                         ((0.880646 0.236564))
                         ((0.920785 0.0191465))))
                       ((0.793692 0.0312174)))
                      ((R:segstate.parent.R:SylStructure.parent.ssyl_out
                        <
                        8.5)
                       ((1.06095 0.237149))
                       ((R:segstate.parent.R:SylStructure.parent.ssyl_out
                         <
                         9.2)
                        ((1.38874 0.729473))
                        ((1.14837 0.44339)))))
                     ((1.33321 0.989691)))
                    ((R:segstate.parent.R:SylStructure.parent.R:Syllable.nn.lisp_cg_break
                      <
                      0.1)
                     ((0.563911 -0.0496161))
                     ((R:segstate.parent.R:SylStructure.parent.asyl_out
                       <
                       3.1)
                      ((0.760546 -0.0407762))
                      ((R:segstate.parent.R:SylStructure.parent.syl_out
                        <
                        10.2)
                       ((0.65807 0.164153))
                       ((0.855027 0.184777))))))
                   ((R:segstate.parent.R:SylStructure.parent.ssyl_out
                     <
                     5.8)
                    ((R:segstate.parent.R:SylStructure.parent.syl_out
                      <
                      4.5)
                     ((0.919817 -0.0474644))
                     ((1.11945 0.545819)))
                    ((0.574881 -0.431831))))
                  ((R:segstate.parent.R:SylStructure.parent.syl_in
                    <
                    3.6)
                   ((R:segstate.parent.ph_cvox is +)
                    ((R:segstate.parent.R:SylStructure.parent.R:Syllable.n.accented
                      is
                      0)
                     ((R:segstate.parent.pp.ph_cvox is -)
                      ((R:segstate.parent.nn.ph_vc is +)
                       ((0.981434 0.313091))
                       ((R:segstate.parent.R:SylStructure.parent.syl_out
                         <
                         11.4)
                        ((R:segstate.parent.R:SylStructure.parent.asyl_out
                          <
                          2.2)
                         ((0.982516 0.297462))
                         ((0.813366 0.0518012)))
                        ((0.871067 -0.241508))))
                      ((1.28251 0.654831)))
                     ((R:segstate.parent.R:SylStructure.parent.R:Syllable.n.lisp_cg_break
                       <
                       0.1)
                      ((0.599677 -0.297102))
                      ((R:segstate.parent.R:SylStructure.parent.syl_out
                        <
                        8.8)
                       ((0.801215 -0.0382467))
                       ((0.977862 0.203348)))))
                    ((R:segstate.parent.nn.ph_cplace is p)
                     ((0.830882 -0.347072))
                     ((R:segstate.parent.R:SylStructure.parent.asyl_out
                       <
                       2.7)
                      ((R:segstate.parent.R:SylStructure.parent.R:Syllable.n.lisp_cg_break
                        <
                        0.3)
                       ((0.937715 -0.118851))
                       ((0.684115 -0.328643)))
                      ((R:segstate.parent.n.ph_vheight is 2)
                       ((R:segstate.parent.R:SylStructure.parent.syl_out
                         <
                         9.4)
                        ((0.988493 -0.000464526))
                        ((0.632315 -0.382576)))
                       ((R:segstate.parent.nn.ph_cplace is a)
                        ((R:segstate.parent.R:SylStructure.parent.ssyl_out
                          <
                          5.4)
                         ((1.13299 0.127532))
                         ((R:segstate.parent.R:SylStructure.parent.parent.gpos
                           is
                           content)
                          ((0.700808 -0.354738))
                          ((R:segstate.parent.R:SylStructure.parent.R:Syllable.n.syl_onsetsize
                            <
                            0.1)
                           ((0.948531 -0.0663725))
                           ((1.13028 -0.0418265)))))
                        ((R:segstate.parent.R:SylStructure.parent.R:Syllable.nn.accented
                          is
                          0)
                         ((1.34451 0.324282))
                         ((1.16134 -0.00355817))))))))
                   ((R:segstate.parent.nn.ph_cvox is +)
                    ((0.984555 0.112151))
                    ((1.38654 0.678022))))))))
              ((R:segstate.parent.pp.ph_vc is +)
               ((R:segstate.parent.R:SylStructure.parent.R:Syllable.p.lisp_cg_break
                 <
                 0.3)
                ((0.377429 -0.608132))
                ((R:segstate.parent.R:SylStructure.parent.syl_out
                  <
                  2.7)
                 ((0.950367 0.54897))
                 ((R:segstate.parent.nn.ph_vlng is d)
                  ((0.641842 -0.280841))
                  ((R:segstate.parent.n.ph_vheight is 3)
                   ((R:segstate.parent.R:SylStructure.parent.ssyl_out
                     <
                     3.7)
                    ((R:segstate.parent.R:SylStructure.parent.asyl_out
                      <
                      2.5)
                     ((R:segstate.parent.R:SylStructure.parent.ssyl_out
                       <
                       2)
                      ((0.701037 -0.0812305))
                      ((0.705433 -0.415587)))
                     ((0.476388 -0.0377752)))
                    ((R:segstate.parent.R:SylStructure.parent.R:Syllable.n.syl_onsetsize
                      <
                      0.1)
                     ((R:segstate.parent.R:SylStructure.parent.syl_out
                       <
                       10.2)
                      ((0.626535 -0.150003))
                      ((0.736459 0.0990713)))
                     ((R:segstate.parent.R:SylStructure.parent.R:Syllable.p.accented
                       is
                       0)
                      ((0.915773 0.069521))
                      ((R:segstate.parent.R:SylStructure.parent.ssyl_out
                        <
                        7.6)
                       ((1.05849 0.382471))
                       ((0.592418 0.261821))))))
                   ((R:segstate.parent.p.ph_cplace is a)
                    ((R:segstate.parent.ph_cvox is +)
                     ((R:segstate.parent.R:SylStructure.parent.R:Syllable.nn.lisp_cg_break
                       <
                       0.1)
                      ((1.08045 0.261108))
                      ((R:segstate.parent.R:SylStructure.parent.ssyl_out
                        <
                        5.6)
                       ((1.13043 0.885743))
                       ((1.32863 0.410612))))
                     ((1.04908 0.00836821)))
                    ((R:segstate.parent.ph_cvox is +)
                     ((R:segstate.parent.R:SylStructure.parent.position_type
                       is
                       initial)
                      ((0.575107 -0.359718))
                      ((R:segstate.parent.R:SylStructure.parent.syl_codasize
                        <
                        2)
                       ((0.786828 -0.058577))
                       ((1.1008 0.265477))))
                     ((1.07703 0.355776))))))))
               ((R:segstate.parent.ph_cvox is -)
                ((R:segstate.parent.R:SylStructure.parent.asyl_out
                  <
                  3.6)
                 ((R:segstate.parent.R:SylStructure.parent.ssyl_out
                   <
                   3.6)
                  ((1.01692 0.0436501))
                  ((0.928138 -0.281049)))
                 ((1.03077 0.357349)))
                ((R:segstate.parent.lisp_onset_glide is 0)
                 ((R:segstate.parent.R:SylStructure.parent.syl_out
                   <
                   11.2)
                  ((R:segstate.parent.n.ph_vheight is 3)
                   ((0.493458 -0.515334))
                   ((R:segstate.parent.R:SylStructure.parent.position_type
                     is
                     initial)
                    ((0.496996 -0.389887))
                    ((R:segstate.parent.R:SylStructure.parent.syl_codasize
                      <
                      1.2)
                     ((1.09349 0.106968))
                     ((R:segstate.parent.R:SylStructure.parent.R:Syllable.nn.accented
                       is
                       0)
                      ((0.921903 -0.119981))
                      ((0.279321 -0.464352))))))
                  ((R:segstate.parent.n.ph_vheight is 3)
                   ((0.311109 -0.671204))
                   ((0.40315 -0.552227))))
                 ((R:segstate.parent.R:SylStructure.parent.R:Syllable.p.lisp_cg_break
                   <
                   1.2)
                  ((R:segstate.parent.R:SylStructure.parent.asyl_out
                    <
                    3.2)
                   ((R:segstate.parent.n.ph_vheight is 3)
                    ((R:segstate.parent.R:SylStructure.parent.R:Syllable.n.lisp_cg_break
                      <
                      0.1)
                     ((0.642142 -0.35989))
                     ((R:segstate.parent.R:SylStructure.parent.syl_out
                       <
                       5.7)
                      ((0.50823 -0.260693))
                      ((0.713606 -0.0577147))))
                    ((R:segstate.parent.R:SylStructure.parent.next_accent
                      <
                      1.2)
                     ((R:segstate.parent.R:SylStructure.parent.syl_out
                       <
                       5.4)
                      ((0.747757 -0.025954))
                      ((R:segstate.parent.nn.ph_cvox is +)
                       ((1.00679 0.120583))
                       ((1.32153 0.55429))))
                     ((R:segstate.parent.n.ph_vheight is 2)
                      ((1.07806 0.164971))
                      ((0.629765 -0.328251)))))
                   ((R:segstate.parent.R:SylStructure.parent.syl_codasize
                     <
                     2)
                    ((R:segstate.parent.n.ph_vheight is 3)
                     ((R:segstate.parent.pp.ph_cplace is 0)
                      ((0.505901 -0.273111))
                      ((0.674906 0.00822534)))
                     ((R:segstate.parent.R:SylStructure.parent.ssyl_out
                       <
                       5.4)
                      ((0.440498 -0.541233))
                      ((R:segstate.parent.R:SylStructure.parent.syl_out
                        <
                        14)
                       ((R:segstate.parent.R:SylStructure.parent.parent.gpos
                         is
                         content)
                        ((R:segstate.parent.R:SylStructure.parent.syl_codasize
                          <
                          1.1)
                         ((0.495132 -0.294898))
                         ((0.744595 -0.0635527)))
                        ((0.417295 -0.389314)))
                       ((0.449453 -0.51247)))))
                    ((0.779603 0.081332))))
                  ((0.543819 -0.551735)))))))
             ((R:segstate.parent.ph_ctype is s)
              ((R:segstate.parent.R:SylStructure.parent.R:Syllable.p.stress
                is
                0)
               ((R:segstate.parent.R:SylStructure.parent.R:Syllable.pp.accented
                 is
                 0)
                ((R:segstate.parent.p.ph_vrnd is -)
                 ((R:segstate.parent.R:SylStructure.parent.last_accent
                   <
                   2.2)
                  ((R:segstate.parent.R:SylStructure.parent.syl_in
                    <
                    4.5)
                   ((R:segstate.parent.R:SylStructure.parent.position_type
                     is
                     final)
                    ((R:segstate.parent.R:SylStructure.parent.syl_out
                      <
                      6.2)
                     ((1.10459 0.722558))
                     ((0.792406 0.563306)))
                    ((1.23405 1.26582)))
                   ((1.0576 0.389486)))
                  ((0.816729 1.14699)))
                 ((R:segstate.parent.R:SylStructure.parent.last_accent
                   <
                   2.2)
                  ((1.15475 0.663345))
                  ((0.638368 0.368928))))
                ((R:segstate.parent.R:SylStructure.parent.R:Syllable.p.syl_codasize
                  <
                  1.1)
                 ((R:segstate.parent.R:SylStructure.parent.R:Syllable.n.accented
                   is
                   0)
                  ((R:segstate.parent.ph_cvox is +)
                   ((0.860232 0.204836))
                   ((1.1585 0.807812)))
                  ((R:segstate.parent.R:SylStructure.parent.R:Syllable.pp.lisp_cg_break
                    <
                    0.1)
                   ((0.832785 -0.232816))
                   ((0.945199 0.276868))))
                 ((1.25529 0.765389))))
               ((R:segstate.parent.R:SylStructure.parent.ssyl_out
                 <
                 3.6)
                ((R:segstate.parent.pp.ph_vheight is 3)
                 ((R:segstate.parent.R:SylStructure.parent.R:Syllable.pp.accented
                   is
                   0)
                  ((1.06961 0.517558))
                  ((1.01616 -0.0267134)))
                 ((R:segstate.parent.n.ph_vlng is s)
                  ((R:segstate.parent.R:SylStructure.parent.syl_out
                    <
                    2.4)
                   ((1.35232 0.949231))
                   ((R:segstate.parent.R:SylStructure.parent.R:Syllable.nn.accented
                     is
                     0)
                    ((1.10333 0.431286))
                    ((0.793711 0.0369902))))
                  ((R:segstate.parent.ph_cvox is +)
                   ((R:segstate.parent.nn.ph_cplace is 0)
                    ((1.31296 0.880906))
                    ((0.782002 0.450513)))
                   ((1.29496 1.11457)))))
                ((R:segstate.parent.R:SylStructure.parent.syl_codasize
                  <
                  2.2)
                 ((R:segstate.parent.ph_cvox is +)
                  ((R:segstate.parent.p.ph_ctype is s)
                   ((R:segstate.parent.R:SylStructure.parent.ssyl_out
                     <
                     6.4)
                    ((0.703461 -0.202465))
                    ((0.709489 -0.404712)))
                   ((R:segstate.parent.R:SylStructure.parent.position_type
                     is
                     initial)
                    ((1.08941 0.458386))
                    ((R:segstate.parent.R:SylStructure.parent.R:Syllable.nn.stress
                      is
                      0)
                     ((R:segstate.parent.R:SylStructure.parent.R:Syllable.nn.lisp_cg_break
                       <
                       0.1)
                      ((0.724245 -0.0238579))
                      ((1.53878 0.75426)))
                     ((R:segstate.parent.p.ph_vlng is d)
                      ((0.625282 0.0902716))
                      ((R:segstate.parent.nn.ph_cplace is a)
                       ((R:segstate.parent.p.ph_vrnd is -)
                        ((0.592418 0.101021))
                        ((0.826356 -0.0855261)))
                       ((0.868092 -0.287583)))))))
                  ((R:segstate.parent.R:SylStructure.parent.parent.gpos
                    is
                    content)
                   ((R:segstate.parent.R:SylStructure.parent.next_accent
                     <
                     1.6)
                    ((R:segstate.parent.R:SylStructure.parent.R:Syllable.p.syl_codasize
                      <
                      1.1)
                     ((1.18511 0.356879))
                     ((1.09144 0.825179)))
                    ((R:segstate.parent.R:SylStructure.parent.R:Syllable.nn.stress
                      is
                      0)
                     ((R:segstate.parent.nn.ph_cplace is 0)
                      ((1.19492 0.485258))
                      ((1.01918 0.389099)))
                     ((R:segstate.parent.p.ph_cplace is a)
                      ((0.833939 0.237114))
                      ((1.06245 0.0219016)))))
                   ((0.651492 -0.199158))))
                 ((R:segstate.parent.R:SylStructure.parent.R:Syllable.p.syl_codasize
                   <
                   1.1)
                  ((R:segstate.parent.n.ph_vlng is s)
                   ((1.12514 0.513794))
                   ((0.867356 0.92254)))
                  ((1.01902 0.0680419))))))
              ((R:segstate.parent.R:SylStructure.parent.parent.gpos
                is
                aux)
               ((R:segstate.parent.n.ph_vlng is l)
                ((R:segstate.parent.R:SylStructure.parent.ssyl_in
                  <
                  1.2)
                 ((R:segstate.parent.R:SylStructure.parent.R:Syllable.n.syl_onsetsize
                   <
                   0.2)
                  ((R:segstate.parent.p.ph_vlng is l)
                   ((0.786335 0.0942888))
                   ((2.14429 0.709339)))
                  ((R:segstate.parent.p.name is r)
                   ((R:segstate.parent.R:SylStructure.parent.syl_out
                     <
                     8.1)
                    ((0.911532 0.0757588))
                    ((1.17173 -0.199819)))
                   ((R:segstate.parent.R:SylStructure.parent.next_accent
                     <
                     1.8)
                    ((R:segstate.parent.R:SylStructure.parent.asyl_out
                      <
                      2.5)
                     ((1.01422 0.140012))
                     ((R:segstate.parent.p.name is iy)
                      ((1.0434 0.267542))
                      ((1.79053 0.531979))))
                    ((1.0172 0.0662981)))))
                 ((0.894611 -0.186887)))
                ((R:segstate.parent.R:SylStructure.parent.next_accent
                  <
                  2.2)
                 ((R:segstate.parent.R:SylStructure.parent.ssyl_out
                   <
                   4.6)
                  ((0.686492 -0.122657))
                  ((R:segstate.parent.R:SylStructure.parent.ssyl_out
                    <
                    8.5)
                   ((R:segstate.parent.lisp_coda_stop is 0)
                    ((0.391381 -0.515178))
                    ((0.61782 -0.338731)))
                   ((0.784341 -0.155287))))
                 ((R:segstate.parent.R:SylStructure.parent.R:Syllable.n.lisp_cg_break
                   <
                   0.1)
                  ((0.181117 -0.685814))
                  ((R:segstate.parent.R:SylStructure.parent.R:Syllable.nn.lisp_cg_break
                    <
                    0.1)
                   ((0.498309 -0.489234))
                   ((0.704847 -0.286604))))))
               ((R:segstate.parent.p.ph_ctype is f)
                ((R:segstate.parent.n.ph_vlng is l)
                 ((R:segstate.parent.R:SylStructure.parent.syl_out
                   <
                   6.2)
                  ((0.642353 -0.443225))
                  ((R:segstate.parent.R:SylStructure.parent.syl_in
                    <
                    2.2)
                   ((1.15373 0.0105706))
                   ((0.700009 -0.351363))))
                 ((R:segstate.parent.R:SylStructure.parent.asyl_out
                   <
                   4.2)
                  ((R:segstate.parent.pp.ph_vlng is s)
                   ((R:segstate.parent.n.ph_vheight is 2)
                    ((0.768183 -0.353189))
                    ((R:segstate.parent.R:SylStructure.parent.next_accent
                      <
                      1.2)
                     ((0.647269 -0.237354))
                     ((1.16284 0.0802097))))
                   ((R:segstate.parent.lisp_coda_glide is 0)
                    ((R:segstate.parent.nn.ph_cvox is +)
                     ((0.921112 -0.160111))
                     ((1.21052 0.143964)))
                    ((1.01125 0.249475))))
                  ((R:segstate.parent.p.name is v)
                   ((0.7878 0.0104399))
                   ((1.26113 0.432457)))))
                ((R:segstate.parent.n.ph_ctype is r)
                 ((R:segstate.parent.R:SylStructure.parent.R:Syllable.nn.accented
                   is
                   0)
                  ((R:segstate.parent.R:SylStructure.parent.syl_onsetsize
                    <
                    1.1)
                   ((1.06776 0.924753))
                   ((0.948378 0.451167)))
                  ((0.857101 0.124204)))
                 ((R:segstate.parent.R:SylStructure.parent.R:Syllable.n.lisp_cg_break
                   <
                   0.3)
                  ((R:segstate.parent.pp.ph_vheight is 1)
                   ((0.59305 -0.223098))
                   ((R:segstate.parent.R:SylStructure.parent.syl_out
                     <
                     5.8)
                    ((R:segstate.parent.R:SylStructure.parent.R:Syllable.p.stress
                      is
                      0)
                     ((0.704528 0.116929))
                     ((R:segstate.parent.nn.ph_cvox is +)
                      ((0.685089 -0.407399))
                      ((0.925406 -0.000826722))))
                    ((R:segstate.parent.lisp_coda_glide is 0)
                     ((R:segstate.parent.R:SylStructure.parent.parent.gpos
                       is
                       content)
                      ((R:segstate.parent.ph_ctype is f)
                       ((R:segstate.parent.p.name is iy)
                        ((0.578112 0.0688794))
                        ((R:segstate.parent.R:SylStructure.parent.ssyl_in
                          <
                          0.2)
                         ((1.31704 0.401142))
                         ((0.996697 0.0816316))))
                       ((1.1605 0.478017)))
                      ((0.660008 -0.0299723)))
                     ((0.738376 -0.251044)))))
                  ((R:segstate.parent.p.name is d)
                   ((R:segstate.parent.R:SylStructure.parent.syl_out
                     <
                     9.4)
                    ((R:segstate.parent.R:SylStructure.parent.R:Syllable.pp.accented
                      is
                      0)
                     ((R:segstate.parent.R:SylStructure.parent.R:Syllable.pp.lisp_cg_break
                       <
                       0.1)
                      ((0.822535 0.109548))
                      ((0.673967 -0.134125)))
                     ((0.691903 -0.369885)))
                    ((1.39359 0.501526)))
                   ((R:segstate.parent.p.ph_vrnd is -)
                    ((R:segstate.parent.R:SylStructure.parent.syl_out
                      <
                      14.6)
                     ((R:segstate.parent.ph_ctype is r)
                      ((R:segstate.parent.p.ph_vheight is 1)
                       ((R:segstate.parent.R:SylStructure.parent.R:Syllable.pp.accented
                         is
                         0)
                        ((1.32656 0.568007))
                        ((1.24497 0.405425)))
                       ((R:segstate.parent.R:SylStructure.parent.asyl_out
                         <
                         4.5)
                        ((R:segstate.parent.R:SylStructure.parent.syl_codasize
                          <
                          2.2)
                         ((1.18131 0.348493))
                         ((0.789352 0.134795)))
                        ((0.668453 -0.0388363))))
                      ((R:segstate.parent.n.ph_vheight is 2)
                       ((R:segstate.parent.n.ph_vlng is d)
                        ((1.45215 0.493232))
                        ((0.776647 0.039813)))
                       ((R:segstate.parent.R:SylStructure.parent.R:Syllable.pp.lisp_cg_break
                         <
                         0.1)
                        ((R:segstate.parent.R:SylStructure.parent.position_type
                          is
                          single)
                         ((R:segstate.parent.n.ph_vlng is l)
                          ((R:segstate.parent.nn.ph_cvox is -)
                           ((0.819036 -0.241747))
                           ((R:segstate.parent.pp.ph_cvox is -)
                            ((0.748529 0.175828))
                            ((0.789674 -0.0167132))))
                          ((0.742435 0.278544)))
                         ((R:segstate.parent.pp.ph_cplace is a)
                          ((0.414044 -0.218177))
                          ((0.643221 -0.341942))))
                        ((R:segstate.parent.R:SylStructure.parent.position_type
                          is
                          single)
                         ((R:segstate.parent.R:SylStructure.parent.syl_out
                           <
                           7)
                          ((0.66571 -0.107557))
                          ((0.645974 0.0408255)))
                         ((R:segstate.parent.R:SylStructure.parent.asyl_out
                           <
                           2.5)
                          ((R:segstate.parent.R:SylStructure.parent.syl_in
                            <
                            3.5)
                           ((1.32459 0.210294))
                           ((0.502793 -0.126763)))
                          ((R:segstate.parent.lisp_coda_fric is 0)
                           ((1.2525 0.399582))
                           ((0.883122 0.20113))))))))
                     ((R:segstate.parent.R:SylStructure.parent.lisp_cg_break
                       <
                       0.1)
                      ((0.874818 0.296128))
                      ((1.4328 0.736655))))
                    ((R:segstate.parent.R:SylStructure.parent.syl_out
                      <
                      4)
                     ((R:segstate.parent.R:SylStructure.parent.last_accent
                       <
                       1.2)
                      ((R:segstate.parent.R:SylStructure.parent.R:Syllable.pp.lisp_cg_break
                        <
                        0.1)
                       ((1.22383 0.406114))
                       ((1.89774 1.10297)))
                      ((1.03449 0.0469713)))
                     ((R:segstate.parent.R:SylStructure.parent.syl_out
                       <
                       5.2)
                      ((R:segstate.parent.R:SylStructure.parent.next_accent
                        <
                        1.2)
                       ((0.590912 -0.340186))
                       ((1.48203 0.362116)))
                      ((R:segstate.parent.R:SylStructure.parent.next_accent
                        <
                        5)
                       ((R:segstate.parent.p.ph_vheight is 1)
                        ((1.44522 0.714909))
                        ((R:segstate.parent.R:SylStructure.parent.next_accent
                          <
                          2.4)
                         ((R:segstate.parent.R:SylStructure.parent.R:Syllable.p.accented
                           is
                           0)
                          ((R:segstate.parent.R:SylStructure.parent.asyl_out
                            <
                            3.3)
                           ((1.07074 0.260403))
                           ((R:segstate.parent.R:SylStructure.parent.syl_out
                             <
                             9.2)
                            ((1.20603 0.918098))
                            ((1.29133 0.525892))))
                          ((R:segstate.parent.R:SylStructure.parent.position_type
                            is
                            initial)
                           ((0.813108 0.416066))
                           ((R:segstate.parent.R:SylStructure.parent.R:Syllable.pp.lisp_cg_break
                             <
                             0.1)
                            ((0.692472 -0.0413445))
                            ((1.24386 0.249214)))))
                         ((0.940188 -0.15482))))
                       ((R:segstate.parent.pp.ph_vlng is l)
                        ((0.948997 -0.0763601))
                        ((0.877002 0.121556))))))))))))))))
          ((R:segstate.parent.R:SylStructure.parent.stress is 0)
           ((R:segstate.parent.p.ph_ctype is f)
            ((0.84133 0.035543))
            ((R:segstate.parent.R:SylStructure.parent.ssyl_out < 8.7)
             ((R:segstate.parent.ph_cvox is +)
              ((R:segstate.parent.R:SylStructure.parent.syl_in < 3.6)
               ((R:segstate.parent.lisp_onset_glide is 0)
                ((R:segstate.parent.R:SylStructure.parent.syl_in < 1.2)
                 ((0.212881 -0.661109))
                 ((0.697189 -0.3824)))
                ((0.685391 -0.257038)))
               ((R:segstate.parent.nn.ph_cvox is -)
                ((0.384969 -0.798995))
                ((0.259876 -0.639269))))
              ((R:segstate.parent.R:SylStructure.parent.ssyl_out < 5.2)
               ((R:segstate.parent.R:SylStructure.parent.syl_out < 7)
                ((0.945178 0.0813048))
                ((0.605753 -0.338022)))
               ((R:segstate.parent.R:SylStructure.parent.syl_out
                 <
                 10.7)
                ((0.380302 -0.698281))
                ((0.62581 -0.306703)))))
             ((1.16941 -0.0826177))))
           ((R:segstate.parent.R:SylStructure.parent.R:Syllable.n.lisp_cg_break
             <
             0.3)
            ((R:segstate.parent.nn.ph_cvox is -)
             ((R:segstate.parent.R:SylStructure.parent.asyl_in < 0.2)
              ((0.763023 0.117138))
              ((R:segstate.parent.R:SylStructure.parent.R:Syllable.p.accented
                is
                0)
               ((0.399329 -0.405182))
               ((0.76057 -0.112207))))
             ((R:segstate.parent.R:SylStructure.parent.R:Syllable.nn.stress
               is
               0)
              ((R:segstate.parent.R:SylStructure.parent.syl_codasize
                <
                1.1)
               ((0.942577 -0.114896))
               ((R:segstate.parent.nn.ph_cplace is a)
                ((0.740639 -0.290534))
                ((0.572175 -0.511275))))
              ((R:segstate.parent.R:SylStructure.parent.syl_codasize
                <
                1.2)
               ((0.412373 -0.625434))
               ((0.499593 -0.416392)))))
            ((R:segstate.parent.n.ph_ctype is r)
             ((R:segstate.parent.lisp_coda_fric is 0)
              ((R:segstate.parent.R:SylStructure.parent.next_accent
                <
                1.2)
               ((0.91805 -0.207894))
               ((1.06568 0.187621)))
              ((1.1923 0.437729)))
             ((R:segstate.parent.nn.ph_cvox is -)
              ((R:segstate.parent.ph_ctype is s)
               ((R:segstate.parent.p.ph_ctype is s)
                ((1.21138 0.0539815))
                ((1.30051 0.337501)))
               ((R:segstate.parent.R:SylStructure.parent.R:Syllable.nn.accented
                 is
                 0)
                ((R:segstate.parent.R:SylStructure.parent.ssyl_out < 5)
                 ((1.21837 0.337854))
                 ((R:segstate.parent.R:SylStructure.parent.ssyl_in
                   <
                   0.2)
                  ((0.980084 0.0932247))
                  ((R:segstate.parent.R:SylStructure.parent.R:Syllable.pp.lisp_cg_break
                    <
                    0.1)
                   ((0.425193 -0.525913))
                   ((1.04381 -0.214991)))))
                ((0.541853 -0.463943))))
              ((R:segstate.parent.R:SylStructure.parent.position_type
                is
                single)
               ((R:segstate.parent.R:SylStructure.parent.R:Syllable.n.lisp_cg_break
                 <
                 1.2)
                ((R:segstate.parent.R:SylStructure.parent.syl_in < 1.4)
                 ((R:segstate.parent.n.ph_vheight is 2)
                  ((0.669564 -0.476534))
                  ((R:segstate.parent.n.ph_vlng is l)
                   ((0.713691 -0.226558))
                   ((1.22447 0.154588))))
                 ((R:segstate.parent.nn.ph_cplace is a)
                  ((R:segstate.parent.pp.ph_cvox is +)
                   ((R:segstate.parent.R:SylStructure.parent.asyl_out
                     <
                     3)
                    ((R:segstate.parent.R:SylStructure.parent.parent.gpos
                      is
                      content)
                     ((0.725435 -0.434642))
                     ((0.598518 -0.258061)))
                    ((1.03098 0.115204)))
                   ((0.624743 -0.410079)))
                  ((R:segstate.parent.R:SylStructure.parent.syl_in
                    <
                    3.2)
                   ((R:segstate.parent.ph_cvox is +)
                    ((0.555231 -0.414932))
                    ((R:segstate.parent.R:SylStructure.parent.R:Syllable.nn.stress
                      is
                      0)
                     ((0.44566 -0.629892))
                     ((0.294896 -0.792227))))
                   ((0.905297 -0.220546)))))
                ((1.22771 0.249658)))
               ((R:segstate.parent.R:SylStructure.parent.ssyl_out
                 <
                 2.7)
                ((0.891038 -0.392437))
                ((R:segstate.parent.R:SylStructure.parent.R:Syllable.pp.accented
                  is
                  0)
                 ((1.06132 0.0884594))
                 ((1.75541 0.483491))))))))))
         ((R:segstate.parent.ph_cvox is -)
          ((R:segstate.parent.lisp_coda_stop is 0)
           ((R:segstate.parent.p.name is ah)
            ((R:segstate.parent.R:SylStructure.parent.ssyl_in < 0.2)
             ((R:segstate.parent.R:SylStructure.parent.R:Syllable.p.lisp_cg_break
               <
               0.1)
              ((1.10518 0.512362))
              ((1.12206 0.260556)))
             ((0.953144 -0.00932636)))
            ((R:segstate.parent.pp.ph_cvox is -)
             ((R:segstate.parent.ph_ctype is a)
              ((1.09506 0.259118))
              ((R:segstate.parent.p.name is ih)
               ((R:segstate.parent.R:SylStructure.parent.R:Syllable.p.lisp_cg_break
                 <
                 0.1)
                ((0.481817 -0.359333))
                ((0.467115 -0.796125)))
               ((R:segstate.parent.R:SylStructure.parent.R:Syllable.nn.accented
                 is
                 0)
                ((R:segstate.parent.R:SylStructure.parent.R:Syllable.n.syl_onsetsize
                  <
                  0.2)
                 ((0.736662 -0.1623))
                 ((R:segstate.parent.R:SylStructure.parent.asyl_in
                   <
                   0.2)
                  ((0.680879 -0.368621))
                  ((0.524003 -0.541012))))
                ((0.907145 -0.0106772)))))
             ((R:segstate.parent.nn.ph_vlng is a)
              ((R:segstate.parent.lisp_onset_glide is 0)
               ((0.951149 -0.215916))
               ((0.603444 -0.62593)))
              ((R:segstate.parent.nn.ph_cplace is a)
               ((R:segstate.parent.R:SylStructure.parent.R:Syllable.n.syl_onsetsize
                 <
                 1.2)
                ((R:segstate.parent.R:SylStructure.parent.ssyl_out
                  <
                  3.1)
                 ((0.939392 0.116635))
                 ((R:segstate.parent.p.ph_vfront is 1)
                  ((0.576022 -0.297686))
                  ((R:segstate.parent.R:SylStructure.parent.asyl_out
                    <
                    3.2)
                   ((0.813159 -0.261146))
                   ((1.21086 -0.063537)))))
                ((0.66285 -0.469584)))
               ((R:segstate.parent.p.name is eh)
                ((R:segstate.parent.R:SylStructure.parent.syl_onsetsize
                  <
                  1.1)
                 ((0.417055 0.0852908))
                 ((0.590097 0.530024)))
                ((R:segstate.parent.n.ph_ctype is r)
                 ((R:segstate.parent.R:SylStructure.parent.lisp_cg_break
                   <
                   0.1)
                  ((0.648398 -0.174046))
                  ((R:segstate.parent.R:SylStructure.parent.R:Syllable.p.lisp_cg_break
                    <
                    0.1)
                   ((0.766332 0.091493))
                   ((R:segstate.parent.R:SylStructure.parent.syl_in
                     <
                     2.2)
                    ((1.00977 0.352966))
                    ((0.539724 0.385462)))))
                 ((R:segstate.parent.syl_final is 0)
                  ((0.746914 -0.276062))
                  ((R:segstate.parent.R:SylStructure.parent.syl_out
                    <
                    12.4)
                   ((R:segstate.parent.R:SylStructure.parent.position_type
                     is
                     final)
                    ((0.712685 -0.326631))
                    ((R:segstate.parent.nn.ph_vrnd is -)
                     ((R:segstate.parent.R:SylStructure.parent.last_accent
                       <
                       0.6)
                      ((0.809229 -0.20089))
                      ((R:segstate.parent.R:SylStructure.parent.syl_out
                        <
                        8.5)
                       ((0.990044 0.453481))
                       ((0.628366 0.0438929))))
                     ((R:segstate.parent.R:SylStructure.parent.R:Syllable.p.syl_codasize
                       <
                       1.2)
                      ((0.92453 -0.00307496))
                      ((R:segstate.parent.R:SylStructure.parent.R:Syllable.nn.stress
                        is
                        0)
                       ((0.628648 -0.123072))
                       ((0.349128 -0.396678))))))
                   ((1.06771 0.237701))))))))))
           ((R:segstate.parent.n.ph_ctype is r)
            ((R:segstate.parent.p.ph_vc is +)
             ((R:segstate.parent.R:SylStructure.parent.syl_onsetsize
               <
               0.2)
              ((R:segstate.parent.R:SylStructure.parent.syl_out < 12.6)
               ((R:segstate.parent.R:SylStructure.parent.ssyl_out
                 <
                 4.5)
                ((0.101628 -0.79535))
                ((0.158367 -0.714481)))
               ((R:segstate.parent.R:SylStructure.parent.ssyl_out
                 <
                 9.4)
                ((0.0637491 -0.830544))
                ((0.0957236 -0.809803))))
              ((R:segstate.parent.R:SylStructure.parent.parent.gpos
                is
                content)
               ((R:segstate.parent.R:SylStructure.parent.ssyl_out
                 <
                 5.1)
                ((0.707017 -0.210249))
                ((0.545445 -0.441108)))
               ((0.150079 -0.768752))))
             ((R:segstate.parent.pp.ph_vlng is s)
              ((0.734927 -0.317636))
              ((0.724771 0.136885))))
            ((R:segstate.parent.n.ph_vc is +)
             ((R:segstate.parent.R:SylStructure.parent.position_type
               is
               final)
              ((R:segstate.parent.pos_in_syl is 2)
               ((0.632328 -0.466793))
               ((R:segstate.parent.R:SylStructure.parent.ssyl_in < 1.2)
                ((R:segstate.parent.R:SylStructure.parent.next_accent
                  <
                  1.2)
                 ((0.635215 -0.0233203))
                 ((1.10261 0.393935)))
                ((0.484026 -0.301742))))
              ((R:segstate.parent.p.ph_cvox is -)
               ((R:segstate.parent.R:SylStructure.parent.asyl_out
                 <
                 4.2)
                ((R:segstate.parent.lisp_coda_fric is 0)
                 ((R:segstate.parent.R:SylStructure.parent.ssyl_in
                   <
                   0.2)
                  ((0.949927 0.0570499))
                  ((0.711622 -0.290542)))
                 ((R:segstate.parent.R:SylStructure.parent.syl_in
                   <
                   1.2)
                  ((0.467632 -0.527211))
                  ((R:segstate.parent.R:SylStructure.parent.syl_out
                    <
                    5)
                   ((0.359544 -0.356613))
                   ((1.00763 -0.200663)))))
                ((0.546164 -0.567694)))
               ((R:segstate.parent.p.ph_vfront is 1)
                ((R:segstate.parent.R:SylStructure.parent.last_accent
                  <
                  0.8)
                 ((R:segstate.parent.R:SylStructure.parent.R:Syllable.nn.stress
                   is
                   0)
                  ((0.207472 -0.667291))
                  ((R:segstate.parent.R:SylStructure.parent.ssyl_out
                    <
                    6.5)
                   ((R:segstate.parent.p.name is ih)
                    ((0.315405 -0.362426))
                    ((0.51724 -0.417047)))
                   ((0.287215 -0.621698))))
                 ((R:segstate.parent.lisp_onset_fric is 0)
                  ((0.744855 -0.183012))
                  ((0.38013 -0.459093))))
                ((R:segstate.parent.nn.ph_cplace is a)
                 ((R:segstate.parent.R:SylStructure.parent.R:Syllable.pp.accented
                   is
                   0)
                  ((R:segstate.parent.R:SylStructure.parent.R:Syllable.nn.accented
                    is
                    0)
                   ((0.150029 -0.760284))
                   ((0.426028 -0.566894)))
                  ((0.524246 -0.372393)))
                 ((R:segstate.parent.R:SylStructure.parent.ssyl_out
                   <
                   8)
                  ((R:segstate.parent.R:SylStructure.parent.R:Syllable.nn.lisp_cg_break
                    <
                    0.3)
                   ((0.188443 -0.668955))
                   ((R:segstate.parent.R:SylStructure.parent.syl_in
                     <
                     2.4)
                    ((0.102106 -0.809937))
                    ((0.156029 -0.766946))))
                  ((0.532289 -0.428447)))))))
             ((R:segstate.parent.p.name is t)
              ((R:segstate.parent.R:SylStructure.parent.syl_out < 5)
               ((0.607801 -0.795482))
               ((R:segstate.parent.R:SylStructure.parent.syl_in < 1.2)
                ((0.412334 -0.6068))
                ((1.0414 -0.446647))))
              ((R:segstate.parent.n.ph_ctype is a)
               ((1.50357 0.612617))
               ((R:segstate.parent.pp.ph_cplace is d)
                ((R:segstate.parent.R:SylStructure.parent.syl_out
                  <
                  8.2)
                 ((R:segstate.parent.n.ph_ctype is f)
                  ((0.993169 -0.0834235))
                  ((0.789211 -0.536986)))
                 ((R:segstate.parent.nn.ph_vrnd is -)
                  ((0.304084 -0.656679))
                  ((0.170968 -0.753926))))
                ((R:segstate.parent.p.name is aa)
                 ((R:segstate.parent.nn.ph_vfront is 3)
                  ((1.49275 0.294714))
                  ((R:segstate.parent.nn.ph_vfront is 2)
                   ((0.992812 -0.14081))
                   ((R:segstate.parent.R:SylStructure.parent.next_accent
                     <
                     2.4)
                    ((R:segstate.parent.R:SylStructure.parent.R:Syllable.nn.lisp_cg_break
                      <
                      0.3)
                     ((0.954431 -0.334908))
                     ((0.456224 -0.733269)))
                    ((0.340549 -0.763336)))))
                 ((R:segstate.parent.lisp_coda_fric is 0)
                  ((R:segstate.parent.R:SylStructure.parent.lisp_cg_break
                    <
                    0.1)
                   ((R:segstate.parent.R:SylStructure.parent.syl_in
                     <
                     2.1)
                    ((R:segstate.parent.pos_in_syl is 2)
                     ((0.745693 -0.504637))
                     ((1.04886 0.0823994)))
                    ((R:segstate.parent.R:SylStructure.parent.R:Syllable.p.syl_codasize
                      <
                      1.2)
                     ((0.603733 -0.592611))
                     ((R:segstate.parent.R:SylStructure.parent.ssyl_out
                       <
                       3.6)
                      ((0.961201 -0.287038))
                      ((0.721505 -0.466871)))))
                   ((R:segstate.parent.R:SylStructure.parent.syl_out
                     <
                     6.7)
                    ((R:segstate.parent.nn.ph_vfront is 2)
                     ((R:segstate.parent.p.ph_vlng is d)
                      ((1.02245 0.132116))
                      ((R:segstate.parent.R:SylStructure.parent.R:Syllable.p.syl_codasize
                        <
                        1.2)
                       ((1.62926 0.939245))
                       ((1.3371 0.544787))))
                     ((R:segstate.parent.R:SylStructure.parent.ssyl_in
                       <
                       0.2)
                      ((R:segstate.parent.R:SylStructure.parent.next_accent
                        <
                        1.2)
                       ((1.61343 0.187319))
                       ((1.73041 0.730916)))
                      ((R:segstate.parent.p.ph_vlng is d)
                       ((0.957888 -0.472828))
                       ((R:segstate.parent.n.ph_ctype is f)
                        ((0.450927 -0.274543))
                        ((R:segstate.parent.pp.ph_cvox is +)
                         ((1.09527 -0.105254))
                         ((0.991986 0.445011)))))))
                    ((R:segstate.parent.R:SylStructure.parent.ssyl_out
                      <
                      4)
                     ((0.770589 -0.497071))
                     ((R:segstate.parent.nn.ph_vlng is a)
                      ((R:segstate.parent.p.ph_vheight is 3)
                       ((1.23725 -0.13711))
                       ((1.05293 0.509642)))
                      ((R:segstate.parent.R:SylStructure.parent.R:Syllable.pp.lisp_cg_break
                        <
                        0.1)
                       ((R:segstate.parent.nn.ph_vc is +)
                        ((R:segstate.parent.R:SylStructure.parent.syl_codasize
                          <
                          2.1)
                         ((R:segstate.parent.R:SylStructure.parent.R:Syllable.nn.accented
                           is
                           0)
                          ((R:segstate.parent.R:SylStructure.parent.R:Syllable.p.accented
                            is
                            0)
                           ((R:segstate.parent.n.ph_ctype is f)
                            ((R:segstate.parent.R:SylStructure.parent.ssyl_out
                              <
                              7.1)
                             ((0.734459 -0.240192))
                             ((0.83898 0.0976308)))
                            ((0.691091 -0.393454)))
                           ((1.15764 0.184308)))
                          ((R:segstate.parent.R:SylStructure.parent.syl_out
                            <
                            10.7)
                           ((1.1403 0.312545))
                           ((0.913763 -0.0404736))))
                         ((1.02032 0.327402)))
                        ((R:segstate.parent.p.ph_vlng is s)
                         ((R:segstate.parent.R:SylStructure.parent.asyl_out
                           <
                           4.5)
                          ((0.622502 -0.53854))
                          ((0.816273 -0.138504)))
                         ((R:segstate.parent.nn.ph_cplace is a)
                          ((1.28422 0.179315))
                          ((0.8665 -0.22809)))))
                       ((R:segstate.parent.R:SylStructure.parent.R:Syllable.nn.accented
                         is
                         0)
                        ((R:segstate.parent.R:SylStructure.parent.asyl_in
                          <
                          0.2)
                         ((0.401494 -0.783223))
                         ((R:segstate.parent.pp.ph_cplace is a)
                          ((0.587414 -0.581365))
                          ((R:segstate.parent.nn.ph_vc is +)
                           ((0.527049 -0.340451))
                           ((1.09844 0.29331)))))
                        ((R:segstate.parent.pp.ph_cplace is a)
                         ((1.17358 0.0999736))
                         ((0.892864 -0.111045)))))))))
                  ((R:segstate.parent.pos_in_syl is 3)
                   ((R:segstate.parent.R:SylStructure.parent.syl_codasize
                     <
                     3.1)
                    ((R:segstate.parent.p.ph_ctype is s)
                     ((0.710632 -0.862647))
                     ((R:segstate.parent.R:SylStructure.parent.syl_out
                       <
                       5.2)
                      ((0.374046 -0.692671))
                      ((R:segstate.parent.n.ph_ctype is 0)
                       ((0.928738 -0.0907607))
                       ((R:segstate.parent.nn.ph_vlng is s)
                        ((0.677786 -0.132619))
                        ((R:segstate.parent.R:SylStructure.parent.last_accent
                          <
                          0.3)
                         ((R:segstate.parent.R:SylStructure.parent.syl_out
                           <
                           9.2)
                          ((0.359602 -0.548673))
                          ((0.271347 -0.618663)))
                         ((R:segstate.parent.R:SylStructure.parent.syl_out
                           <
                           10.2)
                          ((0.291309 -0.555586))
                          ((0.63668 -0.0843292))))))))
                    ((1.17368 0.115772)))
                   ((R:segstate.parent.nn.ph_cplace is a)
                    ((R:segstate.parent.p.ph_vheight is 2)
                     ((R:segstate.parent.R:SylStructure.parent.syl_in
                       <
                       1.6)
                      ((0.83011 0.0721779))
                      ((1.0707 0.158769)))
                     ((0.720105 -0.124943)))
                    ((R:segstate.parent.R:SylStructure.parent.R:Syllable.pp.accented
                      is
                      0)
                     ((R:segstate.parent.R:SylStructure.parent.ssyl_out
                       <
                       9)
                      ((R:segstate.parent.p.name is ae)
                       ((0.624761 -0.344062))
                       ((R:segstate.parent.R:SylStructure.parent.syl_codasize
                         <
                         3.2)
                        ((R:segstate.parent.lisp_onset_glide is 0)
                         ((R:segstate.parent.p.name is ih)
                          ((R:segstate.parent.R:SylStructure.parent.R:Syllable.n.accented
                            is
                            0)
                           ((1.03972 0.12093))
                           ((0.909288 -0.0183908)))
                          ((0.641563 -0.200531)))
                         ((1.17928 0.316465)))
                        ((0.636909 -0.319025))))
                      ((0.668467 -0.393628)))
                     ((R:segstate.parent.nn.ph_cplace is 0)
                      ((R:segstate.parent.R:SylStructure.parent.R:Syllable.n.syl_onsetsize
                        <
                        0.1)
                       ((0.529013 -0.360308))
                       ((0.508867 -0.0840907)))
                      ((0.574555 -0.496353))))))))))))))
          ((R:segstate.parent.p.ph_vrnd is -)
           ((R:segstate.parent.ph_ctype is s)
            ((R:segstate.parent.n.ph_vc is +)
             ((R:segstate.parent.p.name is ih)
              ((0.994637 0.521181))
              ((R:segstate.parent.R:SylStructure.parent.next_accent
                <
                1.8)
               ((R:segstate.parent.pp.ph_cplace is a)
                ((0.387395 -0.27459))
                ((0.295916 -0.565321)))
               ((0.532445 -0.11421))))
             ((R:segstate.parent.p.name is ih)
              ((R:segstate.parent.pp.ph_cplace is a)
               ((R:segstate.parent.R:SylStructure.parent.R:Syllable.nn.accented
                 is
                 0)
                ((R:segstate.parent.R:SylStructure.parent.R:Syllable.p.syl_codasize
                  <
                  1.2)
                 ((0.427274 -0.474664))
                 ((0.989635 -0.0994557)))
                ((1.09563 0.100027)))
               ((1.26125 0.385241)))
              ((R:segstate.parent.R:SylStructure.parent.R:Syllable.n.accented
                is
                0)
               ((R:segstate.parent.nn.ph_vlng is l)
                ((0.976244 -0.226485))
                ((R:segstate.parent.R:SylStructure.parent.ssyl_in
                  <
                  0.2)
                 ((R:segstate.parent.R:SylStructure.parent.position_type
                   is
                   final)
                  ((1.49522 0.855837))
                  ((R:segstate.parent.R:SylStructure.parent.R:Syllable.nn.stress
                    is
                    0)
                   ((1.34089 0.930913))
                   ((R:segstate.parent.lisp_onset_stop is 0)
                    ((R:segstate.parent.R:SylStructure.parent.R:Syllable.n.lisp_cg_break
                      <
                      0.1)
                     ((1.00424 0.188736))
                     ((1.38275 0.328281)))
                    ((0.682079 0.0141247)))))
                 ((R:segstate.parent.p.ph_vlng is s)
                  ((R:segstate.parent.lisp_onset_glide is 0)
                   ((R:segstate.parent.R:SylStructure.parent.ssyl_out
                     <
                     3.6)
                    ((1.44522 0.747931))
                    ((0.959314 0.0183552)))
                   ((0.67092 -0.0843916)))
                  ((0.620245 -0.294442)))))
               ((R:segstate.parent.R:SylStructure.parent.syl_out
                 <
                 13.6)
                ((R:segstate.parent.pp.ph_cvox is +)
                 ((R:segstate.parent.p.ph_vfront is 2)
                  ((1.06725 0.534661))
                  ((R:segstate.parent.R:SylStructure.parent.R:Syllable.nn.stress
                    is
                    0)
                   ((0.996958 -0.0128055))
                   ((1.09989 0.203983))))
                 ((R:segstate.parent.nn.ph_vrnd is -)
                  ((R:segstate.parent.R:SylStructure.parent.syl_out
                    <
                    9.4)
                   ((1.55738 0.799812))
                   ((1.24691 0.372443)))
                  ((0.925733 0.207901))))
                ((1.8183 0.99115))))))
            ((R:segstate.parent.p.ph_vheight is 3)
             ((R:segstate.parent.pp.ph_cplace is g)
              ((R:segstate.parent.R:SylStructure.parent.next_accent
                <
                2.2)
               ((R:segstate.parent.nn.ph_vfront is 2)
                ((0.801155 -0.280985))
                ((R:segstate.parent.R:SylStructure.parent.R:Syllable.p.syl_codasize
                  <
                  2.1)
                 ((R:segstate.parent.R:SylStructure.parent.R:Syllable.nn.stress
                   is
                   0)
                  ((0.974332 0.270981))
                  ((R:segstate.parent.R:SylStructure.parent.R:Syllable.p.syl_codasize
                    <
                    1.2)
                   ((0.826481 -0.0901292))
                   ((0.835414 0.116312))))
                 ((0.781158 -0.0820711))))
               ((1.57518 0.521685)))
              ((R:segstate.parent.R:SylStructure.parent.asyl_out < 5.6)
               ((R:segstate.parent.R:SylStructure.parent.asyl_out
                 <
                 3.5)
                ((R:segstate.parent.R:SylStructure.parent.ssyl_out < 6)
                 ((R:segstate.parent.nn.ph_cvox is +)
                  ((R:segstate.parent.R:SylStructure.parent.asyl_in
                    <
                    1.2)
                   ((R:segstate.parent.R:SylStructure.parent.R:Syllable.p.lisp_cg_break
                     <
                     1.2)
                    ((R:segstate.parent.pp.ph_cvox is -)
                     ((R:segstate.parent.n.ph_ctype is s)
                      ((0.9583 0.102667))
                      ((1.28899 0.711205)))
                     ((R:segstate.parent.R:SylStructure.parent.R:Syllable.n.syl_onsetsize
                       <
                       1.2)
                      ((R:segstate.parent.R:SylStructure.parent.R:Syllable.nn.stress
                        is
                        0)
                       ((0.791654 0.346538))
                       ((R:segstate.parent.R:SylStructure.parent.ssyl_in
                         <
                         1.2)
                        ((R:segstate.parent.R:SylStructure.parent.parent.gpos
                          is
                          aux)
                         ((1.07452 0.241227))
                         ((0.683226 -0.0806699)))
                        ((0.518726 -0.145806))))
                      ((0.731985 -0.166029))))
                    ((0.702769 -0.123268)))
                   ((R:segstate.parent.R:SylStructure.parent.parent.gpos
                     is
                     aux)
                    ((0.414237 -0.381306))
                    ((0.82292 -0.0865208))))
                  ((R:segstate.parent.nn.ph_vlng is s)
                   ((R:segstate.parent.pp.ph_cvox is +)
                    ((R:segstate.parent.R:SylStructure.parent.ssyl_out
                      <
                      2.5)
                     ((0.625207 -0.328221))
                     ((R:segstate.parent.R:SylStructure.parent.syl_out
                       <
                       6.5)
                      ((0.944415 0.176444))
                      ((0.815017 -0.160799))))
                    ((R:segstate.parent.R:SylStructure.parent.last_accent
                      <
                      0.4)
                     ((0.743695 0.0301567))
                     ((0.893225 0.425407))))
                   ((R:segstate.parent.R:SylStructure.parent.syl_in
                     <
                     4.2)
                    ((R:segstate.parent.nn.ph_vlng is d)
                     ((R:segstate.parent.R:SylStructure.parent.R:Syllable.nn.lisp_cg_break
                       <
                       0.1)
                      ((0.846399 0.227574))
                      ((0.913574 -0.271438)))
                     ((R:segstate.parent.R:SylStructure.parent.next_accent
                       <
                       5)
                      ((R:segstate.parent.R:SylStructure.parent.ssyl_out
                        <
                        3.5)
                       ((R:segstate.parent.R:SylStructure.parent.asyl_in
                         <
                         0.3)
                        ((R:segstate.parent.p.name is ae)
                         ((R:segstate.parent.R:SylStructure.parent.R:Syllable.n.syl_onsetsize
                           <
                           0.1)
                          ((0.471068 -0.409299))
                          ((R:segstate.parent.nn.ph_cplace is 0)
                           ((0.770645 -0.0495667))
                           ((0.329816 -0.339084))))
                         ((R:segstate.parent.R:SylStructure.parent.R:Syllable.nn.lisp_cg_break
                           <
                           0.3)
                          ((0.82175 -0.232844))
                          ((0.527376 -0.547729))))
                        ((R:segstate.parent.R:SylStructure.parent.R:Syllable.pp.accented
                          is
                          0)
                         ((1.05711 0.107858))
                         ((R:segstate.parent.pp.ph_cvox is -)
                          ((0.885034 -0.113618))
                          ((0.473287 -0.471669)))))
                       ((R:segstate.parent.R:SylStructure.parent.R:Syllable.nn.accented
                         is
                         0)
                        ((R:segstate.parent.R:SylStructure.parent.next_accent
                          <
                          2.4)
                         ((0.830026 0.110167))
                         ((0.866276 -0.074353)))
                        ((R:segstate.parent.R:SylStructure.parent.last_accent
                          <
                          0.3)
                         ((0.558416 -0.381881))
                         ((0.512555 -0.140087)))))
                      ((R:segstate.parent.nn.ph_vlng is a)
                       ((0.54619 -0.569917))
                       ((0.806321 -0.38682)))))
                    ((R:segstate.parent.nn.ph_vc is +)
                     ((0.831793 -0.096222))
                     ((1.2208 0.376857))))))
                 ((R:segstate.parent.pp.ph_cplace is a)
                  ((R:segstate.parent.pp.ph_cvox is +)
                   ((1.17131 0.684395))
                   ((1.0312 0.224529)))
                  ((R:segstate.parent.R:SylStructure.parent.R:Syllable.n.lisp_cg_break
                    <
                    0.1)
                   ((R:segstate.parent.nn.ph_vc is +)
                    ((0.952867 -0.259447))
                    ((0.958516 -0.204193)))
                   ((R:segstate.parent.nn.ph_cplace is a)
                    ((0.63135 -0.195257))
                    ((R:segstate.parent.ph_ctype is n)
                     ((0.966575 0.0684851))
                     ((1.10929 0.325538)))))))
                ((R:segstate.parent.nn.ph_cvox is -)
                 ((R:segstate.parent.pp.ph_cplace is 0)
                  ((0.464441 -0.167989))
                  ((R:segstate.parent.R:SylStructure.parent.ssyl_out
                    <
                    6.6)
                   ((R:segstate.parent.R:SylStructure.parent.R:Syllable.n.lisp_cg_break
                     <
                     0.1)
                    ((0.883983 -0.22637))
                    ((0.582376 -0.455241)))
                   ((0.414031 -0.53755))))
                 ((R:segstate.parent.R:SylStructure.parent.ssyl_in
                   <
                   1.2)
                  ((R:segstate.parent.R:SylStructure.parent.ssyl_out
                    <
                    5.7)
                   ((R:segstate.parent.nn.ph_vlng is s)
                    ((0.545286 -0.166282))
                    ((R:segstate.parent.R:SylStructure.parent.R:Syllable.p.syl_codasize
                      <
                      1.2)
                     ((1.15917 0.447025))
                     ((0.580895 0.00324176))))
                   ((R:segstate.parent.nn.ph_vfront is 1)
                    ((R:segstate.parent.pp.ph_cvox is -)
                     ((0.64557 -0.317876))
                     ((R:segstate.parent.R:SylStructure.parent.asyl_out
                       <
                       4.1)
                      ((1.28867 0.414031))
                      ((0.908232 0.0923621))))
                    ((R:segstate.parent.R:SylStructure.parent.R:Syllable.pp.accented
                      is
                      0)
                     ((R:segstate.parent.pp.ph_cvox is +)
                      ((R:segstate.parent.R:SylStructure.parent.ssyl_in
                        <
                        0.1)
                       ((R:segstate.parent.R:SylStructure.parent.asyl_out
                         <
                         4.1)
                        ((R:segstate.parent.R:SylStructure.parent.R:Syllable.nn.stress
                          is
                          0)
                         ((0.755412 0.0154085))
                         ((0.606485 -0.216538)))
                        ((0.681011 -0.343837)))
                       ((0.415028 -0.632078)))
                      ((R:segstate.parent.R:SylStructure.parent.syl_out
                        <
                        11.6)
                       ((0.659444 -0.258724))
                       ((R:segstate.parent.R:SylStructure.parent.R:Syllable.n.accented
                         is
                         0)
                        ((0.971431 0.210546))
                        ((0.853822 0.0263737)))))
                     ((R:segstate.parent.R:SylStructure.parent.syl_out
                       <
                       11.2)
                      ((0.649841 -0.276029))
                      ((0.426609 -0.591623))))))
                  ((R:segstate.parent.R:SylStructure.parent.parent.gpos
                    is
                    content)
                   ((0.893717 -0.163058))
                   ((0.565515 -0.499208))))))
               ((R:segstate.parent.lisp_onset_stop is 0)
                ((R:segstate.parent.R:SylStructure.parent.syl_onsetsize
                  <
                  0.1)
                 ((R:segstate.parent.nn.ph_cplace is 0)
                  ((0.799573 0.00884405))
                  ((R:segstate.parent.R:SylStructure.parent.R:Syllable.nn.stress
                    is
                    0)
                   ((1.12871 0.0308103))
                   ((1.07306 0.243076))))
                 ((R:segstate.parent.R:SylStructure.parent.R:Syllable.nn.stress
                   is
                   0)
                  ((0.701339 -0.0138564))
                  ((0.808987 -0.24341))))
                ((1.29443 0.614794)))))
             ((R:segstate.parent.n.ph_vc is +)
              ((R:segstate.parent.lisp_coda_glide is 0)
               ((R:segstate.parent.ph_ctype is n)
                ((R:segstate.parent.R:SylStructure.parent.syl_in < 3.5)
                 ((R:segstate.parent.R:SylStructure.parent.R:Syllable.p.syl_codasize
                   <
                   1.2)
                  ((R:segstate.parent.R:SylStructure.parent.ssyl_out
                    <
                    8.2)
                   ((R:segstate.parent.R:SylStructure.parent.R:Syllable.nn.stress
                     is
                     0)
                    ((0.466039 -0.295917))
                    ((R:segstate.parent.R:SylStructure.parent.syl_out
                      <
                      8)
                     ((0.889915 -0.333661))
                     ((0.317148 -0.722208))))
                   ((0.825257 -0.186779)))
                  ((R:segstate.parent.R:SylStructure.parent.asyl_in
                    <
                    0.2)
                   ((R:segstate.parent.R:SylStructure.parent.next_accent
                     <
                     2.4)
                    ((0.661238 -0.169273))
                    ((0.584844 -0.461958)))
                   ((1.04236 0.0768697))))
                 ((0.927344 0.100401)))
                ((R:segstate.parent.R:SylStructure.parent.parent.gpos
                  is
                  in)
                 ((R:segstate.parent.R:SylStructure.parent.syl_in
                   <
                   3.4)
                  ((1.23091 0.334487))
                  ((0.992827 0.0381919)))
                 ((R:segstate.parent.pp.ph_cvox is +)
                  ((0.632934 -0.355636))
                  ((R:segstate.parent.R:SylStructure.parent.R:Syllable.p.stress
                    is
                    0)
                   ((R:segstate.parent.R:SylStructure.parent.syl_out
                     <
                     11.4)
                    ((0.63503 -0.179099))
                    ((1.14282 -0.116111)))
                   ((1.0119 0.0858752))))))
               ((R:segstate.parent.R:SylStructure.parent.parent.gpos
                 is
                 content)
                ((R:segstate.parent.R:SylStructure.parent.syl_out
                  <
                  9.4)
                 ((1.36696 0.586108))
                 ((0.908935 0.1426)))
                ((0.819294 0.0743188))))
              ((R:segstate.parent.R:SylStructure.parent.parent.gpos
                is
                md)
               ((0.472097 -0.522729))
               ((R:segstate.parent.R:SylStructure.parent.lisp_cg_break
                 <
                 0.1)
                ((R:segstate.parent.nn.ph_vlng is d)
                 ((0.667818 0.552947))
                 ((R:segstate.parent.R:SylStructure.parent.stress is 0)
                  ((R:segstate.parent.nn.ph_vrnd is -)
                   ((R:segstate.parent.R:SylStructure.parent.R:Syllable.n.accented
                     is
                     0)
                    ((0.710527 -0.054961))
                    ((0.559695 0.0300783)))
                   ((R:segstate.parent.R:SylStructure.parent.R:Syllable.nn.stress
                     is
                     0)
                    ((0.721122 0.202572))
                    ((0.810225 0.277024))))
                  ((R:segstate.parent.R:SylStructure.parent.next_accent
                    <
                    3.3)
                   ((R:segstate.parent.R:SylStructure.parent.syl_out
                     <
                     11)
                    ((R:segstate.parent.R:SylStructure.parent.ssyl_out
                      <
                      4.8)
                     ((R:segstate.parent.R:SylStructure.parent.ssyl_in
                       <
                       1.2)
                      ((R:segstate.parent.lisp_onset_fric is 0)
                       ((R:segstate.parent.p.name is ah)
                        ((0.88869 -0.0319347))
                        ((1.23913 0.241313)))
                       ((0.747745 -0.128593)))
                      ((R:segstate.parent.pp.ph_cplace is a)
                       ((0.526439 -0.0645325))
                       ((0.483273 -0.332887))))
                     ((R:segstate.parent.R:SylStructure.parent.R:Syllable.pp.accented
                       is
                       0)
                      ((0.549752 -0.450151))
                      ((0.837244 -0.183653))))
                    ((R:segstate.parent.R:SylStructure.parent.asyl_out
                      <
                      4.1)
                     ((0.731975 0.0266605))
                     ((0.897078 0.203591))))
                   ((R:segstate.parent.R:SylStructure.parent.syl_out
                     <
                     7.5)
                    ((0.701724 0.0103423))
                    ((R:segstate.parent.R:SylStructure.parent.syl_in
                      <
                      2.4)
                     ((R:segstate.parent.pp.ph_cvox is +)
                      ((0.91636 -0.118796))
                      ((0.625863 -0.306126)))
                     ((0.578872 -0.48637)))))))
                ((R:segstate.parent.ph_ctype is n)
                 ((R:segstate.parent.lisp_coda_stop is 0)
                  ((R:segstate.parent.pp.ph_vlng is d)
                   ((0.70244 -0.280047))
                   ((R:segstate.parent.R:SylStructure.parent.ssyl_out
                     <
                     7.2)
                    ((R:segstate.parent.R:SylStructure.parent.syl_in
                      <
                      2.1)
                     ((R:segstate.parent.nn.ph_cplace is a)
                      ((1.53288 1.02142))
                      ((R:segstate.parent.n.ph_ctype is f)
                       ((R:segstate.parent.R:SylStructure.parent.R:Syllable.n.lisp_cg_break
                         <
                         0.3)
                        ((1.0561 0.700682))
                        ((R:segstate.parent.pp.ph_cplace is d)
                         ((1.09356 0.625274))
                         ((R:segstate.parent.pp.ph_cplace is a)
                          ((0.757322 -0.0133166))
                          ((R:segstate.parent.R:SylStructure.parent.syl_out
                            <
                            5.8)
                           ((1.4446 0.440952))
                           ((R:segstate.parent.R:SylStructure.parent.syl_out
                             <
                             9.5)
                            ((0.856418 -0.0919148))
                            ((1.75946 0.31998)))))))
                       ((R:segstate.parent.nn.ph_vlng is s)
                        ((R:segstate.parent.p.ph_vheight is 1)
                         ((1.58451 1.02104))
                         ((1.42024 0.638565)))
                        ((R:segstate.parent.R:SylStructure.parent.R:Syllable.pp.lisp_cg_break
                          <
                          0.3)
                         ((R:segstate.parent.nn.ph_vfront is 2)
                          ((1.28709 0.314312))
                          ((R:segstate.parent.R:SylStructure.parent.syl_out
                            <
                            6.4)
                           ((1.78064 0.825345))
                           ((1.51343 0.591596))))
                         ((R:segstate.parent.nn.ph_vlng is l)
                          ((0.97759 0.00538533))
                          ((1.14858 0.304742)))))))
                     ((R:segstate.parent.pp.ph_cplace is g)
                      ((1.07354 0.550816))
                      ((R:segstate.parent.R:SylStructure.parent.ssyl_out
                        <
                        6.3)
                       ((R:segstate.parent.R:SylStructure.parent.sub_phrases
                         <
                         0.1)
                        ((R:segstate.parent.p.name is eh)
                         ((0.680813 0.0394773))
                         ((R:segstate.parent.R:SylStructure.parent.next_accent
                           <
                           1.8)
                          ((R:segstate.parent.R:SylStructure.parent.R:Syllable.n.lisp_cg_break
                            <
                            0.3)
                           ((0.933799 0.165128))
                           ((R:segstate.parent.R:SylStructure.parent.ssyl_in
                             <
                             1.1)
                            ((0.986816 0.16035))
                            ((R:segstate.parent.n.ph_ctype is f)
                             ((1.05097 0.246351))
                             ((1.76006 0.688067)))))
                          ((R:segstate.parent.p.ph_vheight is 1)
                           ((R:segstate.parent.nn.ph_vfront is 2)
                            ((1.17704 0.0534763))
                            ((0.876128 0.351058)))
                           ((1.12278 -0.0327425)))))
                        ((0.616918 -0.0157544)))
                       ((0.712839 -0.126374)))))
                    ((R:segstate.parent.pp.ph_cplace is d)
                     ((0.539 -0.269154))
                     ((R:segstate.parent.p.name is ah)
                      ((0.910095 -0.149916))
                      ((R:segstate.parent.R:SylStructure.parent.syl_onsetsize
                        <
                        0.3)
                       ((R:segstate.parent.R:SylStructure.parent.syl_out
                         <
                         16)
                        ((0.638374 -0.176766))
                        ((1.15825 0.153064)))
                       ((R:segstate.parent.p.ph_vlng is s)
                        ((R:segstate.parent.R:SylStructure.parent.asyl_in
                          <
                          0.2)
                         ((1.46651 0.283329))
                         ((1.77619 0.70342)))
                        ((1.08155 0.134983))))))))
                  ((R:segstate.parent.pp.ph_cplace is l)
                   ((0.609787 -0.384151))
                   ((R:segstate.parent.nn.ph_cvox is +)
                    ((0.98171 0.119486))
                    ((R:segstate.parent.R:SylStructure.parent.R:Syllable.nn.stress
                      is
                      0)
                     ((0.938152 -0.0327506))
                     ((0.691366 -0.324204))))))
                 ((R:segstate.parent.R:SylStructure.parent.R:Syllable.n.syl_onsetsize
                   <
                   1.2)
                  ((R:segstate.parent.nn.ph_vfront is 3)
                   ((R:segstate.parent.p.ph_vheight is 1)
                    ((R:segstate.parent.R:SylStructure.parent.asyl_out
                      <
                      4.2)
                     ((R:segstate.parent.R:SylStructure.parent.R:Syllable.pp.accented
                       is
                       0)
                      ((1.42635 0.638045))
                      ((0.864525 -0.0788936)))
                     ((0.539459 -0.189012)))
                    ((R:segstate.parent.n.ph_ctype is f)
                     ((0.419054 -0.503446))
                     ((R:segstate.parent.R:SylStructure.parent.R:Syllable.p.syl_codasize
                       <
                       0.3)
                      ((R:segstate.parent.R:SylStructure.parent.R:Syllable.nn.accented
                        is
                        0)
                       ((0.547304 -0.24525))
                       ((0.176954 -0.479032)))
                      ((R:segstate.parent.R:SylStructure.parent.syl_out
                        <
                        5.8)
                       ((0.507806 -0.294555))
                       ((R:segstate.parent.R:SylStructure.parent.asyl_in
                         <
                         0.2)
                        ((0.922651 0.108207))
                        ((0.572491 -0.110347)))))))
                   ((R:segstate.parent.ph_ctype is a)
                    ((1.2376 0.565486))
                    ((R:segstate.parent.R:SylStructure.parent.R:Syllable.n.lisp_cg_break
                      <
                      0.3)
                     ((R:segstate.parent.R:SylStructure.parent.syl_out
                       <
                       4)
                      ((0.458359 -0.333527))
                      ((R:segstate.parent.nn.ph_vfront is 2)
                       ((R:segstate.parent.R:SylStructure.parent.ssyl_out
                         <
                         6)
                        ((0.538707 -0.443359))
                        ((1.04225 0.113834)))
                       ((R:segstate.parent.R:SylStructure.parent.R:Syllable.p.syl_codasize
                         <
                         1.2)
                        ((R:segstate.parent.R:SylStructure.parent.R:Syllable.p.lisp_cg_break
                          <
                          0.1)
                         ((0.752178 -0.0161167))
                         ((0.515776 -0.376884)))
                        ((R:segstate.parent.pp.ph_cplace is a)
                         ((0.747255 0.0450903))
                         ((R:segstate.parent.pp.ph_cvox is +)
                          ((1.61449 0.770862))
                          ((1.05423 0.228373)))))))
                     ((R:segstate.parent.p.name is ah)
                      ((R:segstate.parent.R:SylStructure.parent.last_accent
                        <
                        0.4)
                       ((R:segstate.parent.nn.ph_vlng is a)
                        ((0.959382 0.692697))
                        ((1.32518 0.477571)))
                       ((R:segstate.parent.pp.ph_cvox is +)
                        ((0.764633 -0.0341767))
                        ((R:segstate.parent.R:SylStructure.parent.asyl_out
                          <
                          3.4)
                         ((0.827481 0.188622))
                         ((0.642795 0.494861)))))
                      ((R:segstate.parent.R:SylStructure.parent.R:Syllable.p.syl_codasize
                        <
                        2.5)
                       ((R:segstate.parent.R:SylStructure.parent.ssyl_out
                         <
                         6.6)
                        ((R:segstate.parent.R:SylStructure.parent.syl_onsetsize
                          <
                          0.2)
                         ((R:segstate.parent.R:SylStructure.parent.asyl_out
                           <
                           2.5)
                          ((0.960336 0.133058))
                          ((0.661328 -0.304886)))
                         ((R:segstate.parent.nn.ph_vlng is s)
                          ((R:segstate.parent.p.ph_vheight is 1)
                           ((R:segstate.parent.R:SylStructure.parent.R:Syllable.n.accented
                             is
                             0)
                            ((0.404116 -0.0129092))
                            ((0.576152 -0.421214)))
                           ((1.17122 0.479493)))
                          ((R:segstate.parent.ph_ctype is l)
                           ((R:segstate.parent.R:SylStructure.parent.R:Syllable.nn.accented
                             is
                             0)
                            ((R:segstate.parent.nn.ph_cvox is +)
                             ((1.20648 0.178508))
                             ((1.1353 -0.0704473)))
                            ((0.960233 0.329562)))
                           ((R:segstate.parent.R:SylStructure.parent.R:Syllable.pp.lisp_cg_break
                             <
                             0.1)
                            ((R:segstate.parent.R:SylStructure.parent.R:Syllable.nn.accented
                              is
                              0)
                             ((0.912316 0.497649))
                             ((1.04333 0.0794266)))
                            ((2.05873 0.954924))))))
                        ((R:segstate.parent.nn.ph_vfront is 2)
                         ((R:segstate.parent.R:SylStructure.parent.R:Syllable.p.syl_codasize
                           <
                           0.2)
                          ((1.1792 0.381604))
                          ((0.950502 -0.0286921)))
                         ((R:segstate.parent.pp.ph_cvox is +)
                          ((R:segstate.parent.R:SylStructure.parent.R:Syllable.n.accented
                            is
                            0)
                           ((0.555449 -0.306436))
                           ((1.26176 -0.203827)))
                          ((1.00115 -0.0363679)))))
                       ((0.609275 -0.401795)))))))
                  ((R:segstate.parent.R:SylStructure.parent.R:Syllable.nn.stress
                    is
                    0)
                   ((0.594985 0.0602229))
                   ((R:segstate.parent.n.ph_ctype is f)
                    ((0.386497 -0.625219))
                    ((0.569882 -0.188709)))))))))))
           ((R:segstate.parent.R:SylStructure.parent.lisp_cg_break
             <
             0.1)
            ((R:segstate.parent.R:SylStructure.parent.syl_onsetsize
              <
              0.3)
             ((R:segstate.parent.R:SylStructure.parent.R:Syllable.p.stress
               is
               0)
              ((R:segstate.parent.n.ph_ctype is f)
               ((1.06668 -0.169178))
               ((0.623381 -0.520001)))
              ((R:segstate.parent.R:SylStructure.parent.asyl_in < 0.2)
               ((0.627493 -0.541151))
               ((0.228136 -0.749422))))
             ((R:segstate.parent.p.name is b)
              ((R:segstate.parent.R:SylStructure.parent.asyl_out < 2.5)
               ((0.747909 0.0430631))
               ((0.52155 -0.100095)))
              ((R:segstate.parent.n.ph_vheight is 3)
               ((R:segstate.parent.nn.ph_cplace is a)
                ((0.19995 -0.701528))
                ((R:segstate.parent.n.ph_vlng is l)
                 ((0.149434 -0.567402))
                 ((0.5418 -0.339085))))
               ((R:segstate.parent.R:SylStructure.parent.stress is 0)
                ((R:segstate.parent.lisp_onset_fric is 0)
                 ((R:segstate.parent.seg_onsetcoda is coda)
                  ((R:segstate.parent.R:SylStructure.parent.next_accent
                    <
                    2.4)
                   ((R:segstate.parent.pp.ph_vc is +)
                    ((0.793337 -0.161059))
                    ((0.753019 -0.287098)))
                   ((0.471762 -0.416395)))
                  ((R:segstate.parent.R:SylStructure.parent.asyl_out
                    <
                    2.5)
                   ((0.248492 -0.543355))
                   ((R:segstate.parent.nn.ph_cplace is a)
                    ((0.6428 -0.433599))
                    ((0.566686 -0.282112)))))
                 ((R:segstate.parent.p.ph_cplace is b)
                  ((R:segstate.parent.R:SylStructure.parent.R:Syllable.p.accented
                    is
                    0)
                   ((0.392574 -0.460708))
                   ((0.380515 -0.346396)))
                  ((0.438042 -0.544721))))
                ((R:segstate.parent.ph_vc is +)
                 ((R:segstate.parent.pp.ph_cplace is 0)
                  ((R:segstate.parent.R:SylStructure.parent.syl_out
                    <
                    7.2)
                   ((0.616704 -0.252003))
                   ((0.6769 -0.059992)))
                  ((0.968252 0.159501)))
                 ((R:segstate.parent.p.ph_vheight is 1)
                  ((1.06129 0.167603))
                  ((R:segstate.parent.p.name is g)
                   ((R:segstate.parent.R:SylStructure.parent.asyl_in
                     <
                     0.2)
                    ((0.615772 0.0660645))
                    ((0.530622 -0.203297)))
                   ((R:segstate.parent.R:SylStructure.parent.syl_out
                     <
                     13)
                    ((R:segstate.parent.p.name is p)
                     ((R:segstate.parent.nn.ph_cvox is -)
                      ((0.309935 -0.54032))
                      ((0.602233 -0.363497)))
                     ((R:segstate.parent.R:SylStructure.parent.R:Syllable.nn.lisp_cg_break
                       <
                       0.1)
                      ((R:segstate.parent.lisp_onset_fric is 0)
                       ((0.296091 -0.482963))
                       ((0.581227 -0.259772)))
                      ((R:segstate.parent.nn.ph_cplace is a)
                       ((R:segstate.parent.R:SylStructure.parent.next_accent
                         <
                         3.6)
                        ((1.10571 0.0108532))
                        ((0.430607 -0.179252)))
                       ((R:segstate.parent.lisp_onset_fric is 0)
                        ((0.4586 -0.381412))
                        ((R:segstate.parent.R:SylStructure.parent.asyl_out
                          <
                          3.1)
                         ((R:segstate.parent.R:SylStructure.parent.syl_onsetsize
                           <
                           1.2)
                          ((1.09457 -0.00807978))
                          ((0.587366 -0.190523)))
                         ((0.277792 -0.370687)))))))
                    ((R:segstate.parent.R:SylStructure.parent.syl_codasize
                      <
                      1.2)
                     ((0.498112 -0.258671))
                     ((0.486438 -0.649071)))))))))))
            ((R:segstate.parent.p.name is uh)
             ((R:segstate.parent.R:SylStructure.parent.R:Syllable.p.lisp_cg_break
               <
               0.1)
              ((1.60584 0.982592))
              ((R:segstate.parent.lisp_onset_stop is 0)
               ((R:segstate.parent.R:SylStructure.parent.R:Syllable.pp.accented
                 is
                 0)
                ((R:segstate.parent.nn.ph_vfront is 1)
                 ((1.25886 0.403315))
                 ((0.738775 -0.140745)))
                ((1.45545 0.766137)))
               ((R:segstate.parent.R:SylStructure.parent.syl_in < 1.3)
                ((0.836746 0.0207472))
                ((0.680098 -0.143905)))))
             ((R:segstate.parent.ph_ctype is s)
              ((R:segstate.parent.R:SylStructure.parent.next_accent
                <
                1.8)
               ((R:segstate.parent.lisp_onset_stop is 0)
                ((R:segstate.parent.nn.ph_vlng is s)
                 ((1.45215 0.509255))
                 ((R:segstate.parent.R:SylStructure.parent.R:Syllable.n.accented
                   is
                   0)
                  ((0.586782 -0.374919))
                  ((1.07767 0.0983015))))
                ((R:segstate.parent.p.name is l)
                 ((0.936702 -0.161777))
                 ((0.511773 -0.57309))))
               ((R:segstate.parent.p.name is v)
                ((1.24919 0.729225))
                ((R:segstate.parent.lisp_onset_stop is 0)
                 ((R:segstate.parent.R:SylStructure.parent.R:Syllable.p.accented
                   is
                   0)
                  ((R:segstate.parent.lisp_onset_fric is 0)
                   ((1.2859 0.381923))
                   ((0.810771 -0.00732473)))
                  ((0.721833 -0.210751)))
                 ((1.23272 0.506667)))))
              ((R:segstate.parent.lisp_onset_glide is 0)
               ((R:segstate.parent.n.ph_ctype is 0)
                ((R:segstate.parent.ph_ctype is r)
                 ((R:segstate.parent.R:SylStructure.parent.stress is 0)
                  ((R:segstate.parent.R:SylStructure.parent.R:Syllable.nn.lisp_cg_break
                    <
                    0.1)
                   ((1.06898 0.215078))
                   ((R:segstate.parent.nn.ph_cplace is a)
                    ((0.639188 -0.270297))
                    ((1.02769 -0.0030362))))
                  ((R:segstate.parent.p.name is ao)
                   ((R:segstate.parent.pp.ph_cplace is b)
                    ((0.961379 0.352982))
                    ((0.873167 0.105786)))
                   ((2.06132 0.789634))))
                 ((R:segstate.parent.pos_in_syl is 2)
                  ((1.08516 0.0963285))
                  ((R:segstate.parent.R:SylStructure.parent.next_accent
                    <
                    1.6)
                   ((R:segstate.parent.R:SylStructure.parent.last_accent
                     <
                     1.2)
                    ((0.981931 -0.0198116))
                    ((0.555916 -0.329039)))
                   ((0.453286 -0.374833)))))
                ((R:segstate.parent.pos_in_syl is 1)
                 ((R:segstate.parent.nn.ph_vrnd is -)
                  ((R:segstate.parent.pp.ph_cplace is a)
                   ((0.390581 -0.60546))
                   ((R:segstate.parent.R:SylStructure.parent.asyl_in
                     <
                     0.2)
                    ((R:segstate.parent.R:SylStructure.parent.parent.gpos
                      is
                      content)
                     ((0.592093 -0.401046))
                     ((R:segstate.parent.R:SylStructure.parent.last_accent
                       <
                       1.4)
                      ((0.718727 -0.132846))
                      ((0.551165 -0.272752))))
                    ((R:segstate.parent.R:SylStructure.parent.syl_out
                      <
                      6.4)
                     ((0.672349 0.0942619))
                     ((R:segstate.parent.R:SylStructure.parent.R:Syllable.nn.lisp_cg_break
                       <
                       0.1)
                      ((0.57901 -0.310869))
                      ((R:segstate.parent.nn.ph_vlng is s)
                       ((0.637597 -0.124736))
                       ((0.68849 0.0138316)))))))
                  ((R:segstate.parent.R:SylStructure.parent.R:Syllable.nn.accented
                    is
                    0)
                   ((R:segstate.parent.lisp_coda_glide is 0)
                    ((R:segstate.parent.n.ph_ctype is s)
                     ((R:segstate.parent.pp.ph_vlng is a)
                      ((1.00209 0.277448))
                      ((R:segstate.parent.R:SylStructure.parent.syl_in
                        <
                        2.4)
                       ((0.584923 -0.1572))
                       ((0.657553 -0.29605))))
                     ((R:segstate.parent.nn.ph_cvox is +)
                      ((1.31298 0.555723))
                      ((0.778132 0.103851))))
                    ((1.55187 0.775785)))
                   ((R:segstate.parent.R:SylStructure.parent.stress
                     is
                     0)
                    ((0.649968 -0.290067))
                    ((R:segstate.parent.R:SylStructure.parent.R:Syllable.p.lisp_cg_break
                      <
                      0.1)
                     ((1.10719 0.124677))
                     ((R:segstate.parent.R:SylStructure.parent.syl_codasize
                       <
                       2.1)
                      ((0.653479 -0.164721))
                      ((0.536023 -0.234444)))))))
                 ((R:segstate.parent.R:SylStructure.parent.syl_in
                   <
                   4.2)
                  ((R:segstate.parent.ph_ctype is r)
                   ((R:segstate.parent.R:SylStructure.parent.asyl_in
                     <
                     0.2)
                    ((R:segstate.parent.n.ph_ctype is s)
                     ((0.262479 -0.369513))
                     ((R:segstate.parent.nn.ph_vrnd is -)
                      ((0.659662 -0.239604))
                      ((0.47226 -0.0408947))))
                    ((R:segstate.parent.R:SylStructure.parent.ssyl_in
                      <
                      1.1)
                     ((R:segstate.parent.R:SylStructure.parent.R:Syllable.pp.accented
                       is
                       0)
                      ((0.438858 -0.268544))
                      ((0.443344 -0.40583)))
                     ((0.259613 -0.51141))))
                   ((R:segstate.parent.R:SylStructure.parent.syl_in
                     <
                     1.2)
                    ((R:segstate.parent.lisp_coda_fric is 0)
                     ((0.952568 -0.244301))
                     ((0.480802 -0.626259)))
                    ((R:segstate.parent.R:SylStructure.parent.R:Syllable.n.accented
                      is
                      0)
                     ((R:segstate.parent.nn.ph_vrnd is -)
                      ((R:segstate.parent.R:SylStructure.parent.ssyl_out
                        <
                        3.4)
                       ((0.600484 -0.0807166))
                       ((1.32239 0.29463)))
                      ((0.720256 -0.216095)))
                     ((1.03255 0.30146)))))
                  ((0.451262 -0.592388)))))
               ((R:segstate.parent.ph_ctype is l)
                ((R:segstate.parent.R:SylStructure.parent.syl_in < 1.2)
                 ((R:segstate.parent.nn.ph_cvox is +)
                  ((0.886121 -0.090429))
                  ((0.454746 -0.48072)))
                 ((R:segstate.parent.pp.ph_cvox is -)
                  ((0.674686 -0.148791))
                  ((R:segstate.parent.p.name is p)
                   ((0.336823 -0.633498))
                   ((R:segstate.parent.R:SylStructure.parent.asyl_in
                     <
                     0.2)
                    ((0.481569 -0.255766))
                    ((R:segstate.parent.pp.ph_cplace is a)
                     ((0.301292 -0.638394))
                     ((0.367151 -0.482025)))))))
                ((R:segstate.parent.syl_final is 0)
                 ((R:segstate.parent.pp.ph_vheight is 1)
                  ((R:segstate.parent.p.ph_cvox is +)
                   ((1.16898 0.589286))
                   ((0.921912 0.0815794)))
                  ((R:segstate.parent.R:SylStructure.parent.syl_codasize
                    <
                    1.3)
                   ((R:segstate.parent.p.ph_ctype is f)
                    ((0.820352 0.28174))
                    ((R:segstate.parent.pp.ph_vlng is a)
                     ((0.846239 0.175538))
                     ((0.661805 -0.257019))))
                   ((R:segstate.parent.p.name is g)
                    ((0.82795 0.154918))
                    ((R:segstate.parent.p.ph_vlng is l)
                     ((0.95798 0.0169865))
                     ((R:segstate.parent.p.name is b)
                      ((0.492434 -0.0354254))
                      ((R:segstate.parent.R:SylStructure.parent.R:Syllable.pp.lisp_cg_break
                        <
                        0.3)
                       ((R:segstate.parent.nn.ph_cplace is a)
                        ((R:segstate.parent.R:SylStructure.parent.syl_in
                          <
                          2.1)
                         ((0.529711 0.0475092))
                         ((0.518328 -0.234172)))
                        ((R:segstate.parent.lisp_coda_stop is 0)
                         ((0.524451 -0.220977))
                         ((0.463133 -0.51756))))
                       ((R:segstate.parent.lisp_onset_fric is 0)
                        ((R:segstate.parent.n.ph_vlng is l)
                         ((0.429941 -0.491091))
                         ((R:segstate.parent.R:SylStructure.parent.R:Syllable.n.accented
                           is
                           0)
                          ((R:segstate.parent.R:SylStructure.parent.position_type
                            is
                            final)
                           ((0.788677 -0.215775))
                           ((0.463918 -0.441629)))
                          ((0.350401 -0.447854))))
                        ((R:segstate.parent.n.ph_vlng is l)
                         ((0.695365 0.0176975))
                         ((R:segstate.parent.pp.ph_cvox is -)
                          ((R:segstate.parent.n.ph_vlng is d)
                           ((0.280407 -0.283944))
                           ((0.17844 -0.524495)))
                          ((0.712872 -0.150482)))))))))))
                 ((R:segstate.parent.R:SylStructure.parent.R:Syllable.p.accented
                   is
                   0)
                  ((R:segstate.parent.nn.ph_vlng is s)
                   ((0.520567 -0.394507))
                   ((R:segstate.parent.n.ph_ctype is s)
                    ((0.743775 -0.225857))
                    ((R:segstate.parent.nn.ph_vrnd is -)
                     ((1.10895 0.154308))
                     ((R:segstate.parent.R:SylStructure.parent.R:Syllable.n.syl_onsetsize
                       <
                       0.2)
                      ((0.777719 -0.00443996))
                      ((0.750114 -0.23365))))))
                  ((R:segstate.parent.R:SylStructure.parent.ssyl_out
                    <
                    5.8)
                   ((R:segstate.parent.pp.ph_vheight is 2)
                    ((0.495038 -0.484668))
                    ((R:segstate.parent.R:SylStructure.parent.syl_in
                      <
                      2.5)
                     ((0.660981 -0.128182))
                     ((0.475044 -0.464307))))
                   ((R:segstate.parent.R:SylStructure.parent.asyl_out
                     <
                     4.5)
                    ((0.23688 -0.673576))
                    ((0.443371 -0.508965)))))))))))))))))
     ((R:segstate.parent.p.ph_vheight is 1)
      ((R:segstate.parent.R:SylStructure.parent.R:Syllable.p.stress
        is
        0)
       ((R:segstate.parent.seg_onsetcoda is coda)
        ((R:segstate.parent.nn.ph_vlng is d)
         ((R:segstate.parent.nn.ph_vfront is 3)
          ((2.18589 0.780129))
          ((R:segstate.parent.R:SylStructure.parent.asyl_out < 1.2)
           ((R:segstate.parent.pp.ph_cvox is +)
            ((1.29197 0.358159))
            ((1.30459 0.26613)))
           ((0.670307 -0.167518))))
         ((R:segstate.parent.R:SylStructure.parent.next_accent < 3.5)
          ((R:segstate.parent.R:SylStructure.parent.asyl_in < 0.8)
           ((1.29742 0.475771))
           ((R:segstate.parent.R:SylStructure.parent.R:Syllable.nn.lisp_cg_break
             <
             0.3)
            ((R:segstate.parent.pp.ph_cplace is v)
             ((0.851141 0.319781))
             ((R:segstate.parent.R:SylStructure.parent.syl_in < 16.2)
              ((R:segstate.parent.R:SylStructure.parent.ssyl_in < 3.7)
               ((R:segstate.parent.R:SylStructure.parent.R:Syllable.nn.accented
                 is
                 0)
                ((0.467815 -0.485075))
                ((R:segstate.parent.nn.ph_cplace is 0)
                 ((0.989198 -0.0059973))
                 ((0.900582 -0.0816678))))
               ((R:segstate.parent.ph_cvox is -)
                ((R:segstate.parent.R:SylStructure.parent.asyl_out
                  <
                  1.3)
                 ((0.739323 -0.0146057))
                 ((0.797276 -0.299415)))
                ((R:segstate.parent.R:SylStructure.parent.syl_out
                  <
                  3.2)
                 ((R:segstate.parent.R:SylStructure.parent.syl_onsetsize
                   <
                   0.2)
                  ((R:segstate.parent.R:SylStructure.parent.asyl_in
                    <
                    4.6)
                   ((R:segstate.parent.n.ph_ctype is f)
                    ((0.63569 -0.224937))
                    ((0.917944 0.0621513)))
                   ((0.476018 -0.339265)))
                  ((R:segstate.parent.R:SylStructure.parent.asyl_in
                    <
                    2.2)
                   ((0.967958 0.333218))
                   ((R:segstate.parent.R:SylStructure.parent.syl_in
                     <
                     11)
                    ((0.668915 -0.333638))
                    ((0.910508 0.16685)))))
                 ((R:segstate.parent.R:SylStructure.parent.syl_out
                   <
                   5.6)
                  ((R:segstate.parent.pp.ph_cvox is -)
                   ((1.16873 0.582281))
                   ((1.3142 0.229859)))
                  ((R:segstate.parent.R:SylStructure.parent.asyl_in
                    <
                    2.4)
                   ((0.75844 0.19048))
                   ((0.998056 -0.0936031)))))))
              ((0.695245 -0.430843))))
            ((R:segstate.parent.R:SylStructure.parent.parent.word_numsyls
              <
              2.2)
             ((R:segstate.parent.R:SylStructure.parent.parent.gpos
               is
               pps)
              ((0.647694 -0.222308))
              ((R:segstate.parent.R:SylStructure.parent.last_accent
                <
                4)
               ((R:segstate.parent.lisp_coda_fric is 0)
                ((R:segstate.parent.nn.ph_vlng is a)
                 ((0.778954 -0.282656))
                 ((R:segstate.parent.R:SylStructure.parent.ssyl_in
                   <
                   3.9)
                  ((R:segstate.parent.R:SylStructure.parent.syl_in
                    <
                    5.3)
                   ((0.885629 -0.190407))
                   ((0.972735 0.0543435)))
                  ((R:segstate.parent.syl_final is 0)
                   ((0.565021 0.0227853))
                   ((R:segstate.parent.n.ph_ctype is f)
                    ((0.745048 0.0281459))
                    ((R:segstate.parent.nn.ph_cvox is +)
                     ((0.99527 0.0703256))
                     ((1.13787 0.421051)))))))
                ((R:segstate.parent.ph_cvox is +)
                 ((R:segstate.parent.R:SylStructure.parent.R:Syllable.pp.lisp_cg_break
                   <
                   0.1)
                  ((R:segstate.parent.R:SylStructure.parent.ssyl_out
                    <
                    2.2)
                   ((1.44149 0.409199))
                   ((1.3312 0.753663)))
                  ((0.960188 0.257261)))
                 ((0.447147 -0.120031))))
               ((R:segstate.parent.nn.ph_vc is +)
                ((1.28425 0.335541))
                ((1.68214 0.660205)))))
             ((R:segstate.parent.R:SylStructure.parent.next_accent
               <
               1.2)
              ((R:segstate.parent.R:SylStructure.parent.parent.word_numsyls
                <
                3.2)
               ((R:segstate.parent.R:SylStructure.parent.stress is 0)
                ((0.503008 -0.0953643))
                ((0.536925 -0.444471)))
               ((R:segstate.parent.R:SylStructure.parent.syl_out < 5.6)
                ((0.649269 0.171292))
                ((0.875836 -0.0657311))))
              ((R:segstate.parent.R:SylStructure.parent.parent.word_numsyls
                <
                3.2)
               ((0.866888 0.395345))
               ((0.680403 -0.0419651)))))))
          ((R:segstate.parent.R:SylStructure.parent.R:Syllable.n.lisp_cg_break
            <
            0.3)
           ((0.456041 -0.501427))
           ((0.617337 -0.029261)))))
        ((R:segstate.parent.n.ph_ctype is r)
         ((R:segstate.parent.R:SylStructure.parent.syl_out < 4.3)
          ((0.689989 0.362974))
          ((1.20808 0.948211)))
         ((R:segstate.parent.lisp_onset_glide is 0)
          ((R:segstate.parent.ph_ctype is s)
           ((R:segstate.parent.R:SylStructure.parent.R:Syllable.n.syl_onsetsize
             <
             0.3)
            ((R:segstate.parent.R:SylStructure.parent.asyl_in < 3.5)
             ((0.878661 0.888339))
             ((0.902562 0.457022)))
            ((R:segstate.parent.R:SylStructure.parent.R:Syllable.n.lisp_cg_break
              <
              0.3)
             ((0.781918 -0.166659))
             ((R:segstate.parent.ph_cvox is +)
              ((R:segstate.parent.pp.ph_cplace is a)
               ((0.87231 0.297165))
               ((0.845619 -0.0545256)))
              ((0.927929 0.787786)))))
           ((R:segstate.parent.R:SylStructure.parent.ssyl_out < 2.4)
            ((R:segstate.parent.R:SylStructure.parent.R:Syllable.n.lisp_cg_break
              <
              0.3)
             ((R:segstate.parent.p.name is ih)
              ((R:segstate.parent.R:SylStructure.parent.next_accent
                <
                1.2)
               ((0.707558 -0.255368))
               ((0.82201 0.0788493)))
              ((0.730732 0.119587)))
             ((R:segstate.parent.n.ph_vheight is 3)
              ((1.53051 0.644408))
              ((R:segstate.parent.R:SylStructure.parent.ssyl_out < 1.2)
               ((R:segstate.parent.R:SylStructure.parent.syl_codasize
                 <
                 1.2)
                ((0.958327 0.190383))
                ((0.957353 -0.122985)))
               ((R:segstate.parent.R:SylStructure.parent.syl_out < 3.5)
                ((1.21191 0.177625))
                ((1.53475 0.510603))))))
            ((R:segstate.parent.n.ph_vheight is 2)
             ((0.875455 0.0272235))
             ((R:segstate.parent.nn.ph_cvox is +)
              ((1.09708 -0.115595))
              ((0.71692 -0.353151))))))
          ((R:segstate.parent.pp.ph_cplace is a)
           ((R:segstate.parent.R:SylStructure.parent.R:Syllable.pp.accented
             is
             0)
            ((1.33889 0.54004))
            ((1.19687 0.243779)))
           ((1.57807 0.832267))))))
       ((R:segstate.parent.ph_cvox is -)
        ((R:segstate.parent.p.ph_vlng is l)
         ((R:segstate.parent.lisp_onset_glide is 0)
          ((R:segstate.parent.n.ph_vlng is d)
           ((0.573514 0.381811))
           ((R:segstate.parent.R:SylStructure.parent.next_accent < 1.2)
            ((R:segstate.parent.n.ph_vheight is 1)
             ((R:segstate.parent.ph_ctype is f)
              ((R:segstate.parent.R:SylStructure.parent.syl_in < 6.2)
               ((0.48236 -0.272724))
               ((0.825481 0.0749508)))
              ((0.441334 -0.557823)))
             ((R:segstate.parent.R:SylStructure.parent.parent.gpos
               is
               aux)
              ((0.517513 -0.319393))
              ((R:segstate.parent.n.ph_vlng is s)
               ((0.784124 0.282263))
               ((R:segstate.parent.R:SylStructure.parent.syl_out < 3)
                ((R:segstate.parent.R:SylStructure.parent.ssyl_in
                  <
                  5.5)
                 ((0.482511 -0.253798))
                 ((0.759532 0.0144328)))
                ((R:segstate.parent.pp.ph_cvox is +)
                 ((0.587799 0.221492))
                 ((0.448141 0.065421)))))))
            ((R:segstate.parent.ph_ctype is f)
             ((R:segstate.parent.R:SylStructure.parent.parent.gpos
               is
               content)
              ((R:segstate.parent.R:SylStructure.parent.asyl_in < 2.2)
               ((0.614495 -0.0920437))
               ((0.470352 0.0653028)))
              ((0.396641 -0.492418)))
             ((R:segstate.parent.R:SylStructure.parent.R:Syllable.nn.stress
               is
               0)
              ((0.482507 -0.340125))
              ((0.325605 -0.740321))))))
          ((R:segstate.parent.lisp_coda_fric is 0)
           ((R:segstate.parent.R:SylStructure.parent.ssyl_out < 2.2)
            ((0.933213 0.777644))
            ((1.38772 0.223102)))
           ((0.694748 -0.135178))))
         ((R:segstate.parent.lisp_coda_glide is 0)
          ((R:segstate.parent.nn.ph_vfront is 3)
           ((R:segstate.parent.R:SylStructure.parent.syl_onsetsize
             <
             0.2)
            ((0.105373 -0.795211))
            ((0.507775 -0.433354)))
           ((R:segstate.parent.pos_in_syl is 2)
            ((R:segstate.parent.R:SylStructure.parent.last_accent
              <
              1.5)
             ((R:segstate.parent.R:SylStructure.parent.R:Syllable.n.syl_onsetsize
               <
               0.2)
              ((0.627516 -0.363865))
              ((R:segstate.parent.R:SylStructure.parent.syl_in < 7.1)
               ((0.932202 -0.0257433))
               ((R:segstate.parent.nn.ph_vfront is 1)
                ((0.76022 0.0613528))
                ((1.38153 0.564678)))))
             ((R:segstate.parent.R:SylStructure.parent.ssyl_out < 3.6)
              ((R:segstate.parent.n.ph_ctype is 0)
               ((0.64646 -0.00424362))
               ((0.754687 -0.289212)))
              ((0.456568 -0.467368))))
            ((R:segstate.parent.R:SylStructure.parent.R:Syllable.p.accented
              is
              0)
             ((R:segstate.parent.R:SylStructure.parent.parent.word_numsyls
               <
               2.2)
              ((R:segstate.parent.syl_final is 0)
               ((R:segstate.parent.R:SylStructure.parent.next_accent
                 <
                 1.2)
                ((0.921762 0.0147211))
                ((0.840828 0.111079)))
               ((R:segstate.parent.pp.ph_cvox is -)
                ((1.43075 0.149809))
                ((R:segstate.parent.R:SylStructure.parent.syl_in < 7.7)
                 ((0.783968 -0.668238))
                 ((0.955888 0.0171131)))))
              ((R:segstate.parent.R:SylStructure.parent.syl_in < 9.4)
               ((R:segstate.parent.ph_ctype is f)
                ((0.562278 -0.323778))
                ((0.65996 -0.539714)))
               ((0.655761 -0.121086))))
             ((R:segstate.parent.lisp_coda_stop is 0)
              ((R:segstate.parent.pp.ph_cvox is +)
               ((R:segstate.parent.nn.ph_cvox is +)
                ((0.693422 -0.131606))
                ((0.422075 -0.355429)))
               ((R:segstate.parent.pp.ph_cplace is a)
                ((0.629359 -0.313103))
                ((0.474197 -0.476045))))
              ((0.66952 -0.560393))))))
          ((0.192018 -0.745768))))
        ((R:segstate.parent.ph_ctype is r)
         ((R:segstate.parent.pp.ph_cvox is +)
          ((R:segstate.parent.R:SylStructure.parent.next_accent < 1.2)
           ((R:segstate.parent.R:SylStructure.parent.asyl_out < 1.3)
            ((0.748369 0.0259087))
            ((R:segstate.parent.R:SylStructure.parent.position_type
              is
              single)
             ((1.21757 0.465092))
             ((0.798158 0.176766))))
           ((0.674137 -0.30603)))
          ((R:segstate.parent.R:SylStructure.parent.ssyl_out < 3.6)
           ((R:segstate.parent.R:SylStructure.parent.asyl_in < 1.7)
            ((0.961234 0.205727))
            ((R:segstate.parent.R:SylStructure.parent.R:Syllable.n.syl_onsetsize
              <
              0.1)
             ((1.82878 1.00008))
             ((R:segstate.parent.p.name is iy)
              ((1.1717 0.531779))
              ((1.24682 0.219863)))))
           ((0.952651 0.0144386))))
         ((R:segstate.parent.pp.ph_vheight is 2)
          ((R:segstate.parent.pp.ph_vlng is a)
           ((0.420292 -0.207181))
           ((R:segstate.parent.R:SylStructure.parent.asyl_in < 2.1)
            ((0.498839 -0.297098))
            ((0.705174 -0.498711))))
          ((R:segstate.parent.ph_vfront is 1)
           ((R:segstate.parent.R:SylStructure.parent.stress is 0)
            ((0.37987 -0.49468))
            ((R:segstate.parent.R:SylStructure.parent.R:Syllable.n.lisp_cg_break
              <
              0.3)
             ((0.592165 -0.278194))
             ((0.829113 0.17139))))
           ((R:segstate.parent.R:SylStructure.parent.ssyl_in < 7)
            ((R:segstate.parent.ph_ctype is s)
             ((R:segstate.parent.nn.ph_vlng is l)
              ((R:segstate.parent.n.ph_ctype is n)
               ((1.18468 0.272054))
               ((1.65683 1.02999)))
              ((R:segstate.parent.lisp_onset_glide is 0)
               ((R:segstate.parent.R:SylStructure.parent.R:Syllable.n.syl_onsetsize
                 <
                 0.2)
                ((R:segstate.parent.R:SylStructure.parent.ssyl_in
                  <
                  3.2)
                 ((0.632045 -0.151067))
                 ((1.03242 0.215834)))
                ((R:segstate.parent.R:SylStructure.parent.syl_out
                  <
                  5.2)
                 ((0.703174 0.167892))
                 ((1.06322 0.694916))))
               ((0.539394 -0.0352178))))
             ((R:segstate.parent.p.name is iy)
              ((R:segstate.parent.ph_vheight is 2)
               ((1.68071 0.770308))
               ((R:segstate.parent.R:SylStructure.parent.position_type
                 is
                 single)
                ((R:segstate.parent.R:SylStructure.parent.syl_in < 7.6)
                 ((1.03386 -0.0174527))
                 ((1.41581 0.810155)))
                ((R:segstate.parent.R:SylStructure.parent.R:Syllable.nn.stress
                  is
                  0)
                 ((R:segstate.parent.R:SylStructure.parent.syl_out
                   <
                   4.6)
                  ((0.791854 -0.15621))
                  ((1.08822 0.321178)))
                 ((R:segstate.parent.nn.ph_cvox is +)
                  ((0.921711 -0.1299))
                  ((0.536328 -0.322862))))))
              ((R:segstate.parent.ph_vheight is 2)
               ((0.465417 -0.374542))
               ((R:segstate.parent.nn.ph_cplace is v)
                ((0.832242 -0.334024))
                ((R:segstate.parent.lisp_coda_stop is 0)
                 ((R:segstate.parent.R:SylStructure.parent.syl_out
                   <
                   2.6)
                  ((R:segstate.parent.pp.ph_cvox is +)
                   ((R:segstate.parent.R:SylStructure.parent.R:Syllable.p.syl_codasize
                     <
                     1.2)
                    ((R:segstate.parent.R:SylStructure.parent.R:Syllable.nn.accented
                      is
                      0)
                     ((R:segstate.parent.nn.ph_vrnd is -)
                      ((0.760403 0.280131))
                      ((1.19806 0.216305)))
                     ((0.705586 -0.180723)))
                    ((R:segstate.parent.R:SylStructure.parent.R:Syllable.n.lisp_cg_break
                      <
                      1.2)
                     ((1.52377 0.730491))
                     ((0.967819 0.319634))))
                   ((R:segstate.parent.R:SylStructure.parent.stress
                     is
                     0)
                    ((R:segstate.parent.pp.ph_cplace is a)
                     ((R:segstate.parent.R:SylStructure.parent.ssyl_in
                       <
                       3.3)
                      ((0.715822 -0.0633607))
                      ((0.736171 0.150788)))
                     ((R:segstate.parent.n.ph_ctype is f)
                      ((0.637798 0.0122555))
                      ((0.538672 -0.525157))))
                    ((R:segstate.parent.R:SylStructure.parent.syl_in
                      <
                      6.2)
                     ((1.35737 0.431153))
                     ((R:segstate.parent.R:SylStructure.parent.last_accent
                       <
                       1.5)
                      ((0.86396 -0.0337744))
                      ((0.722294 0.208938))))))
                  ((R:segstate.parent.R:SylStructure.parent.parent.gpos
                    is
                    content)
                   ((R:segstate.parent.R:SylStructure.parent.position_type
                     is
                     single)
                    ((R:segstate.parent.R:SylStructure.parent.R:Syllable.nn.stress
                      is
                      0)
                     ((0.593327 -0.0662962))
                     ((R:segstate.parent.lisp_onset_fric is 0)
                      ((0.975364 0.118821))
                      ((R:segstate.parent.R:SylStructure.parent.syl_out
                        <
                        5.5)
                       ((1.37506 0.765728))
                       ((0.97035 0.368417)))))
                    ((R:segstate.parent.R:SylStructure.parent.next_accent
                      <
                      3)
                     ((R:segstate.parent.pos_in_syl is 1)
                      ((0.760007 0.356967))
                      ((R:segstate.parent.nn.ph_cplace is l)
                       ((0.543299 -0.19231))
                       ((R:segstate.parent.nn.ph_cvox is +)
                        ((R:segstate.parent.R:SylStructure.parent.R:Syllable.nn.lisp_cg_break
                          <
                          0.1)
                         ((0.873935 0.480212))
                         ((R:segstate.parent.R:SylStructure.parent.asyl_out
                           <
                           2.2)
                          ((0.813133 0.191374))
                          ((0.843844 -0.0243659))))
                        ((R:segstate.parent.nn.ph_cplace is 0)
                         ((R:segstate.parent.R:SylStructure.parent.syl_in
                           <
                           7.5)
                          ((R:segstate.parent.R:SylStructure.parent.ssyl_in
                            <
                            3.2)
                           ((0.719575 0.0205927))
                           ((0.963654 0.303659)))
                          ((R:segstate.parent.R:SylStructure.parent.asyl_in
                            <
                            2.1)
                           ((0.674014 0.0842871))
                           ((0.766154 -0.132829))))
                         ((0.661478 -0.144453))))))
                     ((R:segstate.parent.R:SylStructure.parent.last_accent
                       <
                       1.2)
                      ((R:segstate.parent.n.ph_ctype is f)
                       ((0.558666 -0.152979))
                       ((0.839563 0.114955)))
                      ((0.505295 -0.256984)))))
                   ((R:segstate.parent.nn.ph_vrnd is -)
                    ((R:segstate.parent.R:SylStructure.parent.syl_out
                      <
                      5)
                     ((R:segstate.parent.n.ph_ctype is f)
                      ((R:segstate.parent.R:SylStructure.parent.asyl_in
                        <
                        1.2)
                       ((0.997711 -0.149413))
                       ((1.02268 0.155883)))
                      ((0.683961 -0.230023)))
                     ((R:segstate.parent.R:SylStructure.parent.ssyl_out
                       <
                       3.2)
                      ((0.666235 -0.479469))
                      ((R:segstate.parent.nn.ph_vlng is s)
                       ((0.465147 -0.351494))
                       ((R:segstate.parent.R:SylStructure.parent.asyl_out
                         <
                         3.5)
                        ((1.24329 0.0424764))
                        ((0.750473 -0.19674))))))
                    ((R:segstate.parent.R:SylStructure.parent.ssyl_out
                      <
                      5.2)
                     ((R:segstate.parent.p.name is ih)
                      ((R:segstate.parent.R:SylStructure.parent.asyl_in
                        <
                        2.4)
                       ((R:segstate.parent.R:SylStructure.parent.syl_in
                         <
                         6.4)
                        ((R:segstate.parent.n.ph_ctype is 0)
                         ((1.05716 0.0259697))
                         ((0.798808 -0.177145)))
                        ((0.689245 -0.325183)))
                       ((R:segstate.parent.R:SylStructure.parent.syl_in
                         <
                         8.2)
                        ((0.712752 -0.0713404))
                        ((0.98442 0.173914))))
                      ((1.32022 0.405846)))
                     ((1.31552 0.399578))))))
                 ((R:segstate.parent.ph_ctype is l)
                  ((0.999814 0.0966857))
                  ((0.462632 -0.495261))))))))
            ((R:segstate.parent.R:SylStructure.parent.R:Syllable.n.syl_onsetsize
              <
              0.3)
             ((R:segstate.parent.R:SylStructure.parent.position_type
               is
               single)
              ((0.800476 -0.0107131))
              ((R:segstate.parent.nn.ph_vc is +)
               ((0.853759 -0.126786))
               ((R:segstate.parent.R:SylStructure.parent.syl_in < 11.7)
                ((0.452542 -0.474912))
                ((0.629011 -0.313716)))))
             ((R:segstate.parent.R:SylStructure.parent.R:Syllable.nn.lisp_cg_break
               <
               0.3)
              ((R:segstate.parent.ph_ctype is f)
               ((R:segstate.parent.R:SylStructure.parent.R:Syllable.n.accented
                 is
                 0)
                ((0.531623 -0.46709))
                ((R:segstate.parent.pp.ph_cvox is +)
                 ((0.719332 -0.381076))
                 ((0.891148 0.0310972))))
               ((R:segstate.parent.R:SylStructure.parent.syl_in < 12.8)
                ((R:segstate.parent.pos_in_syl is 2)
                 ((0.571147 -0.360394))
                 ((0.738313 -0.0209083)))
                ((R:segstate.parent.R:SylStructure.parent.syl_in
                  <
                  14.4)
                 ((0.932313 0.271305))
                 ((0.94476 -0.0439007)))))
              ((R:segstate.parent.n.ph_ctype is s)
               ((R:segstate.parent.R:SylStructure.parent.next_accent
                 <
                 1.5)
                ((0.665146 -0.251093))
                ((0.525484 -0.00533301)))
               ((R:segstate.parent.R:SylStructure.parent.R:Syllable.n.accented
                 is
                 0)
                ((R:segstate.parent.n.ph_ctype is 0)
                 ((0.751525 0.215045))
                 ((0.609458 -0.103552)))
                ((R:segstate.parent.R:SylStructure.parent.stress is 0)
                 ((0.819748 0.0327881))
                 ((1.38392 0.658086)))))))))))))
      ((R:segstate.parent.R:SylStructure.parent.R:Syllable.n.syl_onsetsize
        <
        0.3)
       ((R:segstate.parent.p.seg_onsetcoda is coda)
        ((R:segstate.parent.R:SylStructure.parent.parent.gpos is cc)
         ((R:segstate.parent.p.ph_ctype is 0)
          ((R:segstate.parent.nn.ph_cvox is -)
           ((0.856707 0.0620362))
           ((R:segstate.parent.R:SylStructure.parent.asyl_in < 2.5)
            ((R:segstate.parent.R:SylStructure.parent.syl_out < 5)
             ((0.483399 -0.276977))
             ((R:segstate.parent.R:SylStructure.parent.R:Syllable.pp.lisp_cg_break
               <
               0.1)
              ((0.47993 -0.348834))
              ((0.40308 -0.506754))))
            ((R:segstate.parent.R:SylStructure.parent.R:Syllable.nn.stress
              is
              0)
             ((0.575366 -0.335116))
             ((R:segstate.parent.R:SylStructure.parent.R:Syllable.n.accented
               is
               0)
              ((0.591889 -0.252268))
              ((1.04868 0.0579474))))))
          ((R:segstate.parent.R:SylStructure.parent.syl_out < 4)
           ((0.257915 -0.578147))
           ((R:segstate.parent.nn.ph_cplace is a)
            ((R:segstate.parent.R:SylStructure.parent.syl_in < 7.6)
             ((0.135706 -0.727906))
             ((0.247332 -0.619726)))
            ((0.0567955 -0.785579)))))
         ((R:segstate.parent.lisp_coda_glide is 0)
          ((R:segstate.parent.seg_onsetcoda is coda)
           ((R:segstate.parent.ph_vfront is 3)
            ((1.12855 0.765806))
            ((R:segstate.parent.n.ph_ctype is r)
             ((R:segstate.parent.nn.ph_cplace is a)
              ((R:segstate.parent.R:SylStructure.parent.last_accent
                <
                1.4)
               ((0.580334 -0.733872))
               ((0.370095 -1.0356)))
              ((0.947857 -0.324905)))
             ((R:segstate.parent.p.ph_vfront is 2)
              ((R:segstate.parent.ph_vfront is 2)
               ((0.621664 -0.349985))
               ((R:segstate.parent.n.ph_vlng is a)
                ((R:segstate.parent.pp.ph_cvox is -)
                 ((1.01797 -0.0702159))
                 ((0.528444 -0.385204)))
                ((R:segstate.parent.R:SylStructure.parent.R:Syllable.pp.accented
                  is
                  0)
                 ((R:segstate.parent.nn.ph_vfront is 2)
                  ((0.703527 -0.195886))
                  ((R:segstate.parent.R:SylStructure.parent.asyl_in
                    <
                    1.2)
                   ((R:segstate.parent.R:SylStructure.parent.asyl_out
                     <
                     1.5)
                    ((1.03131 0.165549))
                    ((0.717755 -0.161727)))
                   ((R:segstate.parent.R:SylStructure.parent.ssyl_in
                     <
                     4.5)
                    ((1.1368 0.4316))
                    ((R:segstate.parent.R:SylStructure.parent.syl_out
                      <
                      4)
                     ((1.09724 0.277264))
                     ((0.686627 -0.0998008))))))
                 ((R:segstate.parent.pos_in_syl is 2)
                  ((R:segstate.parent.R:SylStructure.parent.ssyl_out
                    <
                    2.2)
                   ((0.4469 -0.568269))
                   ((0.642643 -0.0703936)))
                  ((1.12313 0.266168))))))
              ((R:segstate.parent.R:SylStructure.parent.syl_codasize
                <
                1.3)
               ((R:segstate.parent.p.ph_ctype is 0)
                ((0.948823 -0.084115))
                ((1.25353 0.618431)))
               ((R:segstate.parent.p.ph_ctype is n)
                ((R:segstate.parent.pos_in_syl is 0)
                 ((0.998551 0.188647))
                 ((R:segstate.parent.nn.ph_cplace is a)
                  ((0.447698 -0.186535))
                  ((R:segstate.parent.ph_ctype is f)
                   ((R:segstate.parent.lisp_onset_fric is 0)
                    ((0.460839 -0.447587))
                    ((0.738112 -0.368986)))
                   ((R:segstate.parent.R:SylStructure.parent.ssyl_out
                     <
                     1.6)
                    ((0.439227 -0.532657))
                    ((R:segstate.parent.R:SylStructure.parent.syl_in
                      <
                      8.9)
                     ((R:segstate.parent.ph_cvox is +)
                      ((0.169631 -0.772294))
                      ((0.307154 -0.907854)))
                     ((0.282749 -0.644781)))))))
                ((R:segstate.parent.p.name is ao)
                 ((0.663923 -0.578665))
                 ((R:segstate.parent.ph_cvox is +)
                  ((R:segstate.parent.n.ph_vc is +)
                   ((R:segstate.parent.R:SylStructure.parent.ssyl_in
                     <
                     7.2)
                    ((R:segstate.parent.lisp_coda_stop is 0)
                     ((R:segstate.parent.R:SylStructure.parent.R:Syllable.pp.accented
                       is
                       0)
                      ((R:segstate.parent.R:SylStructure.parent.ssyl_out
                        <
                        4.2)
                       ((R:segstate.parent.R:SylStructure.parent.R:Syllable.nn.lisp_cg_break
                         <
                         0.3)
                        ((0.439102 -0.475208))
                        ((0.848082 -0.244705)))
                       ((0.710835 -0.0866113)))
                      ((R:segstate.parent.p.name is ae)
                       ((0.717212 -0.247532))
                       ((0.934467 -0.0138703))))
                     ((R:segstate.parent.pos_in_syl is 2)
                      ((0.293179 -0.441075))
                      ((0.731955 -0.179631))))
                    ((0.424742 -0.535084)))
                   ((R:segstate.parent.lisp_coda_fric is 0)
                    ((R:segstate.parent.R:SylStructure.parent.syl_in
                      <
                      8.8)
                     ((R:segstate.parent.R:SylStructure.parent.R:Syllable.p.syl_codasize
                       <
                       1.2)
                      ((0.629401 -0.172121))
                      ((R:segstate.parent.R:SylStructure.parent.asyl_out
                        <
                        2.2)
                       ((R:segstate.parent.R:SylStructure.parent.R:Syllable.nn.stress
                         is
                         0)
                        ((0.842542 0.00850206))
                        ((0.889042 -0.115823)))
                       ((1.22147 0.281611))))
                     ((R:segstate.parent.R:SylStructure.parent.syl_in
                       <
                       10.4)
                      ((0.576511 -0.460854))
                      ((0.650504 -0.0958437))))
                    ((R:segstate.parent.p.ph_vheight is 2)
                     ((0.674213 -0.0296508))
                     ((R:segstate.parent.R:SylStructure.parent.last_accent
                       <
                       3)
                      ((1.46078 0.489774))
                      ((1.21621 0.119472))))))
                  ((R:segstate.parent.R:SylStructure.parent.R:Syllable.n.accented
                    is
                    0)
                   ((R:segstate.parent.p.name is aa)
                    ((0.537049 -0.521406))
                    ((R:segstate.parent.R:SylStructure.parent.R:Syllable.p.syl_codasize
                      <
                      2.2)
                     ((R:segstate.parent.ph_ctype is s)
                      ((R:segstate.parent.n.ph_vlng is a)
                       ((0.545302 -0.399218))
                       ((R:segstate.parent.R:SylStructure.parent.syl_in
                         <
                         6.6)
                        ((R:segstate.parent.R:SylStructure.parent.syl_in
                          <
                          5.2)
                         ((0.628548 -0.0133597))
                         ((0.578026 -0.280886)))
                        ((R:segstate.parent.n.ph_vlng is s)
                         ((0.59014 -0.0870592))
                         ((R:segstate.parent.R:SylStructure.parent.syl_codasize
                           <
                           2.1)
                          ((0.986074 0.379919))
                          ((0.871183 -0.0105818))))))
                      ((R:segstate.parent.nn.ph_vlng is s)
                       ((R:segstate.parent.R:SylStructure.parent.asyl_out
                         <
                         1.5)
                        ((0.581925 -0.215044))
                        ((R:segstate.parent.ph_vfront is 2)
                         ((0.367951 -0.520651))
                         ((0.308354 -0.658569))))
                       ((R:segstate.parent.ph_vheight is 1)
                        ((0.806286 0.0961866))
                        ((R:segstate.parent.R:SylStructure.parent.ssyl_in
                          <
                          7)
                         ((R:segstate.parent.R:SylStructure.parent.syl_in
                           <
                           6.7)
                          ((R:segstate.parent.pp.ph_vc is +)
                           ((0.325825 -0.435554))
                           ((0.55222 -0.247516)))
                          ((R:segstate.parent.R:SylStructure.parent.R:Syllable.nn.accented
                            is
                            0)
                           ((0.932319 0.0286768))
                           ((0.740999 -0.273861))))
                         ((0.452609 -0.414436))))))
                     ((R:segstate.parent.pp.ph_cvox is +)
                      ((0.252097 -0.630359))
                      ((0.647392 -0.270498)))))
                   ((R:segstate.parent.R:SylStructure.parent.syl_out
                     <
                     3)
                    ((0.180182 -0.688918))
                    ((R:segstate.parent.R:SylStructure.parent.syl_in
                      <
                      7)
                     ((0.624456 -0.169178))
                     ((R:segstate.parent.R:SylStructure.parent.syl_in
                       <
                       8.4)
                      ((0.296218 -0.644768))
                      ((0.58955 -0.384576)))))))))))))
           ((R:segstate.parent.ph_ctype is n)
            ((R:segstate.parent.R:SylStructure.parent.last_accent
              <
              1.6)
             ((R:segstate.parent.R:SylStructure.parent.ssyl_out < 2.1)
              ((R:segstate.parent.R:SylStructure.parent.R:Syllable.n.lisp_cg_break
                <
                0.3)
               ((0.553757 -0.541004))
               ((R:segstate.parent.n.ph_vlng is s)
                ((0.458699 -0.433885))
                ((0.528899 -0.280293))))
              ((0.270062 -0.715644)))
             ((R:segstate.parent.R:SylStructure.parent.R:Syllable.nn.lisp_cg_break
               <
               0.3)
              ((0.626079 -0.303002))
              ((0.912116 -0.0318049))))
            ((R:segstate.parent.p.name is r)
             ((R:segstate.parent.R:SylStructure.parent.stress is 0)
              ((1.13935 -0.055621))
              ((R:segstate.parent.R:SylStructure.parent.next_accent
                <
                1.3)
               ((1.2564 0.550437))
               ((1.49091 0.973897))))
             ((R:segstate.parent.R:SylStructure.parent.lisp_cg_break
               <
               0.1)
              ((R:segstate.parent.lisp_onset_glide is 0)
               ((R:segstate.parent.R:SylStructure.parent.stress is 0)
                ((R:segstate.parent.R:SylStructure.parent.syl_out
                  <
                  4.6)
                 ((R:segstate.parent.n.ph_vlng is a)
                  ((R:segstate.parent.pp.ph_cvox is -)
                   ((0.576299 -0.0747035))
                   ((1.1196 0.262241)))
                  ((R:segstate.parent.p.ph_ctype is n)
                   ((0.737759 -0.393785))
                   ((1.13743 -0.0858539))))
                 ((R:segstate.parent.ph_ctype is s)
                  ((0.811124 -0.262154))
                  ((0.949241 -0.632836))))
                ((R:segstate.parent.n.ph_vlng is l)
                 ((1.07465 0.631267))
                 ((R:segstate.parent.ph_cvox is +)
                  ((0.791089 -0.453425))
                  ((R:segstate.parent.R:SylStructure.parent.last_accent
                    <
                    2.2)
                   ((1.22535 0.0635077))
                   ((1.17665 0.417568))))))
               ((R:segstate.parent.R:SylStructure.parent.ssyl_out
                 <
                 1.2)
                ((1.24599 0.651377))
                ((R:segstate.parent.p.ph_ctype is 0)
                 ((1.16639 0.487883))
                 ((0.981396 0.0879851)))))
              ((R:segstate.parent.p.name is t)
               ((R:segstate.parent.R:SylStructure.parent.R:Syllable.nn.stress
                 is
                 0)
                ((0.837567 -0.0659451))
                ((R:segstate.parent.pp.ph_cvox is -)
                 ((0.396763 -0.613987))
                 ((R:segstate.parent.R:SylStructure.parent.asyl_out
                   <
                   1.3)
                  ((0.664878 -0.286299))
                  ((0.513458 -0.47246)))))
               ((R:segstate.parent.R:SylStructure.parent.asyl_out
                 <
                 3.5)
                ((R:segstate.parent.p.name is ng)
                 ((0.481972 -0.475578))
                 ((R:segstate.parent.p.name is dh)
                  ((1.26746 0.407767))
                  ((R:segstate.parent.p.ph_vrnd is +)
                   ((R:segstate.parent.n.ph_vlng is a)
                    ((0.855795 -0.135926))
                    ((0.995597 0.657536)))
                   ((R:segstate.parent.p.name is l)
                    ((R:segstate.parent.ph_ctype is s)
                     ((0.921674 0.492697))
                     ((0.693834 0.0199526)))
                    ((R:segstate.parent.R:SylStructure.parent.last_accent
                      <
                      3.6)
                     ((R:segstate.parent.R:SylStructure.parent.R:Syllable.nn.stress
                       is
                       0)
                      ((R:segstate.parent.p.ph_vheight is 3)
                       ((0.894807 0.370544))
                       ((R:segstate.parent.p.name is ey)
                        ((0.577981 -0.354081))
                        ((R:segstate.parent.R:SylStructure.parent.syl_codasize
                          <
                          2)
                         ((R:segstate.parent.lisp_onset_glide is 0)
                          ((R:segstate.parent.pp.ph_cplace is a)
                           ((R:segstate.parent.p.name is pau)
                            ((0.73007 -0.319418))
                            ((0.71865 0.002029)))
                           ((R:segstate.parent.R:SylStructure.parent.stress
                             is
                             0)
                            ((R:segstate.parent.R:SylStructure.parent.ssyl_in
                              <
                              4.5)
                             ((1.22313 -0.0123831))
                             ((0.478231 -0.31445)))
                            ((R:segstate.parent.n.ph_vlng is s)
                             ((1.7144 0.596744))
                             ((1.20663 0.136873)))))
                          ((R:segstate.parent.pp.ph_cvox is +)
                           ((1.43835 0.234819))
                           ((R:segstate.parent.nn.ph_cvox is +)
                            ((0.820839 -0.131356))
                            ((0.564947 -0.507945)))))
                         ((1.22542 0.291063)))))
                      ((R:segstate.parent.nn.ph_vfront is 2)
                       ((R:segstate.parent.pp.ph_vheight is 2)
                        ((0.496641 -0.257116))
                        ((R:segstate.parent.R:SylStructure.parent.ssyl_in
                          <
                          5.5)
                         ((0.823455 -0.0640884))
                         ((0.796041 0.273388))))
                       ((R:segstate.parent.R:SylStructure.parent.syl_out
                         <
                         8)
                        ((R:segstate.parent.R:SylStructure.parent.syl_in
                          <
                          12.4)
                         ((R:segstate.parent.p.ph_vlng is s)
                          ((0.403728 -0.506338))
                          ((R:segstate.parent.n.ph_vlng is s)
                           ((R:segstate.parent.R:SylStructure.parent.ssyl_out
                             <
                             1.4)
                            ((0.432881 -0.657249))
                            ((R:segstate.parent.nn.ph_cvox is +)
                             ((R:segstate.parent.p.ph_cplace is a)
                              ((0.852342 0.0290681))
                              ((0.761397 -0.232365)))
                             ((0.417699 -0.577647))))
                           ((R:segstate.parent.R:SylStructure.parent.R:Syllable.nn.lisp_cg_break
                             <
                             1.2)
                            ((R:segstate.parent.R:SylStructure.parent.R:Syllable.n.lisp_cg_break
                              <
                              0.1)
                             ((R:segstate.parent.R:SylStructure.parent.syl_out
                               <
                               4.2)
                              ((1.07169 -0.204989))
                              ((0.495882 -0.660925)))
                             ((R:segstate.parent.p.ph_cvox is -)
                              ((R:segstate.parent.n.ph_vheight is 2)
                               ((1.20177 -0.12149))
                               ((0.683466 -0.427577)))
                              ((R:segstate.parent.R:SylStructure.parent.stress
                                is
                                0)
                               ((0.626335 -0.194667))
                               ((1.06483 0.17152)))))
                            ((0.793423 0.139186)))))
                         ((1.00529 0.0645213)))
                        ((R:segstate.parent.p.ph_ctype is 0)
                         ((1.0441 0.261176))
                         ((0.606343 -0.202924))))))
                     ((R:segstate.parent.R:SylStructure.parent.syl_out
                       <
                       4.2)
                      ((R:segstate.parent.lisp_onset_stop is 0)
                       ((R:segstate.parent.R:SylStructure.parent.next_accent
                         <
                         1.2)
                        ((0.57259 -0.162633))
                        ((0.956425 0.150612)))
                       ((0.533423 -0.369482)))
                      ((R:segstate.parent.R:SylStructure.parent.R:Syllable.nn.lisp_cg_break
                        <
                        0.1)
                       ((0.68903 0.0118563))
                       ((R:segstate.parent.nn.ph_cplace is a)
                        ((0.938133 0.271434))
                        ((1.13652 0.622853))))))))))
                ((R:segstate.parent.R:SylStructure.parent.R:Syllable.nn.lisp_cg_break
                  <
                  0.1)
                 ((R:segstate.parent.R:SylStructure.parent.asyl_in
                   <
                   1.2)
                  ((0.593441 -0.500721))
                  ((0.694509 -0.193508)))
                 ((R:segstate.parent.R:SylStructure.parent.syl_out
                   <
                   8.7)
                  ((0.604987 -0.331512))
                  ((R:segstate.parent.R:SylStructure.parent.syl_in
                    <
                    5.5)
                   ((0.781199 0.168725))
                   ((0.907499 -0.112059)))))))))))
          ((R:segstate.parent.p.ph_vfront is 1)
           ((R:segstate.parent.nn.ph_cplace is 0)
            ((R:segstate.parent.R:SylStructure.parent.syl_in < 6.2)
             ((1.02976 0.253641))
             ((0.66498 -0.197964)))
            ((1.8222 0.854209)))
           ((R:segstate.parent.R:SylStructure.parent.position_type
             is
             final)
            ((R:segstate.parent.ph_cvox is +)
             ((R:segstate.parent.syl_final is 0)
              ((0.403707 -0.691654))
              ((0.51933 -0.297049)))
             ((R:segstate.parent.R:SylStructure.parent.stress is 0)
              ((0.700607 -0.250331))
              ((R:segstate.parent.R:SylStructure.parent.last_accent
                <
                1.2)
               ((0.631136 -0.0483858))
               ((0.669376 0.287686)))))
            ((R:segstate.parent.nn.ph_vfront is 3)
             ((0.74301 -0.4872))
             ((R:segstate.parent.R:SylStructure.parent.R:Syllable.p.syl_codasize
               <
               2.2)
              ((R:segstate.parent.R:SylStructure.parent.ssyl_out < 2.4)
               ((R:segstate.parent.p.name is l)
                ((0.426983 -0.277283))
                ((R:segstate.parent.R:SylStructure.parent.asyl_in
                  <
                  4.2)
                 ((R:segstate.parent.pp.ph_cplace is 0)
                  ((R:segstate.parent.lisp_onset_stop is 0)
                   ((R:segstate.parent.lisp_onset_fric is 0)
                    ((0.780764 0.112126))
                    ((1.36633 0.506921)))
                   ((0.788447 0.0224674)))
                  ((R:segstate.parent.R:SylStructure.parent.R:Syllable.nn.stress
                    is
                    0)
                   ((0.717707 -0.242132))
                   ((R:segstate.parent.R:SylStructure.parent.asyl_out
                     <
                     1.1)
                    ((1.17262 -0.120081))
                    ((1.32972 0.291041)))))
                 ((0.833035 -0.195658))))
               ((R:segstate.parent.n.ph_vlng is l)
                ((1.07064 -0.100179))
                ((R:segstate.parent.n.ph_vlng is s)
                 ((0.942254 0.211294))
                 ((R:segstate.parent.nn.ph_vc is +)
                  ((1.259 0.269508))
                  ((1.51247 0.776023))))))
              ((R:segstate.parent.R:SylStructure.parent.last_accent
                <
                2.5)
               ((R:segstate.parent.pos_in_syl is 0)
                ((0.574365 0.0975667))
                ((0.826162 -0.0775667)))
               ((0.508126 -0.401839)))))))))
        ((R:segstate.parent.lisp_onset_glide is 0)
         ((R:segstate.parent.n.ph_ctype is l)
          ((R:segstate.parent.R:SylStructure.parent.last_accent < 2.1)
           ((R:segstate.parent.ph_vheight is 2)
            ((R:segstate.parent.nn.ph_cvox is -)
             ((R:segstate.parent.R:SylStructure.parent.asyl_in < 3)
              ((0.296267 -0.447477))
              ((0.160849 -0.557813)))
             ((0.209033 -0.692119)))
            ((0.949281 -0.224851)))
           ((R:segstate.parent.ph_vfront is 2)
            ((0.576812 -0.290191))
            ((1.03674 0.211647))))
          ((R:segstate.parent.pp.ph_cplace is b)
           ((R:segstate.parent.R:SylStructure.parent.parent.gpos
             is
             content)
            ((1.44611 0.512744))
            ((2.5975 1.18627)))
           ((R:segstate.parent.R:SylStructure.parent.parent.gpos is in)
            ((R:segstate.parent.R:SylStructure.parent.syl_in < 10.6)
             ((R:segstate.parent.R:SylStructure.parent.syl_codasize
               <
               1.1)
              ((0.9761 0.112111))
              ((R:segstate.parent.pp.ph_cplace is 0)
               ((0.39736 -0.53276))
               ((0.837814 -0.143021))))
             ((0.181925 -0.658825)))
            ((R:segstate.parent.ph_vfront is 1)
             ((R:segstate.parent.R:SylStructure.parent.ssyl_in < 6.2)
              ((R:segstate.parent.n.ph_ctype is r)
               ((R:segstate.parent.nn.ph_vc is +)
                ((0.801432 -0.0629139))
                ((2.25155 1.21428)))
               ((R:segstate.parent.lisp_coda_fric is 0)
                ((R:segstate.parent.p.name is d)
                 ((R:segstate.parent.R:SylStructure.parent.syl_out
                   <
                   4.6)
                  ((1.25102 0.579667))
                  ((0.853491 0.162914)))
                 ((R:segstate.parent.p.name is n)
                  ((0.54817 -0.43992))
                  ((R:segstate.parent.p.name is s)
                   ((0.65052 -0.283496))
                   ((R:segstate.parent.pp.ph_vlng is a)
                    ((R:segstate.parent.R:SylStructure.parent.R:Syllable.nn.lisp_cg_break
                      <
                      0.4)
                     ((R:segstate.parent.R:SylStructure.parent.asyl_in
                       <
                       2)
                      ((0.630139 -0.160786))
                      ((1.16492 0.161774)))
                     ((1.16417 0.445147)))
                    ((R:segstate.parent.lisp_coda_stop is 0)
                     ((R:segstate.parent.R:SylStructure.parent.R:Syllable.nn.accented
                       is
                       0)
                      ((R:segstate.parent.pp.ph_vlng is l)
                       ((0.76862 -0.373864))
                       ((R:segstate.parent.nn.ph_vfront is 2)
                        ((0.628913 -0.27674))
                        ((R:segstate.parent.n.ph_vlng is s)
                         ((0.612262 -0.253449))
                         ((R:segstate.parent.R:SylStructure.parent.syl_out
                           <
                           7)
                          ((0.540089 -0.151507))
                          ((1.36196 0.294231))))))
                      ((R:segstate.parent.R:SylStructure.parent.syl_codasize
                        <
                        1.1)
                       ((R:segstate.parent.R:SylStructure.parent.position_type
                         is
                         single)
                        ((0.742501 0.0505447))
                        ((0.902952 0.28921)))
                       ((0.583269 -0.146926))))
                     ((R:segstate.parent.nn.ph_vc is +)
                      ((R:segstate.parent.R:SylStructure.parent.R:Syllable.pp.lisp_cg_break
                        <
                        0.1)
                       ((0.690792 -0.109089))
                       ((0.75984 -0.0313785)))
                      ((R:segstate.parent.R:SylStructure.parent.next_accent
                        <
                        1.2)
                       ((0.948853 0.132243))
                       ((1.06574 0.384841)))))))))
                ((R:segstate.parent.nn.ph_vc is +)
                 ((R:segstate.parent.R:SylStructure.parent.R:Syllable.p.syl_codasize
                   <
                   1.2)
                  ((0.993511 0.233615))
                  ((0.56353 -0.195336)))
                 ((R:segstate.parent.R:SylStructure.parent.last_accent
                   <
                   2.4)
                  ((R:segstate.parent.R:SylStructure.parent.R:Syllable.p.stress
                    is
                    0)
                   ((1.99365 0.849866))
                   ((1.58996 0.686989)))
                  ((1.10386 0.286989))))))
              ((R:segstate.parent.R:SylStructure.parent.R:Syllable.p.accented
                is
                0)
               ((R:segstate.parent.nn.ph_cplace is a)
                ((R:segstate.parent.R:SylStructure.parent.parent.word_numsyls
                  <
                  2.2)
                 ((1.38293 0.429097))
                 ((0.827238 -0.0890988)))
                ((R:segstate.parent.R:SylStructure.parent.syl_out
                  <
                  2.5)
                 ((0.696963 -0.085072))
                 ((0.463404 -0.367544))))
               ((R:segstate.parent.n.ph_ctype is n)
                ((0.299796 -0.613059))
                ((R:segstate.parent.R:SylStructure.parent.syl_in
                  <
                  14.4)
                 ((0.79445 -0.103763))
                 ((0.273989 -0.511829))))))
             ((R:segstate.parent.ph_ctype is 0)
              ((R:segstate.parent.p.ph_cplace is d)
               ((R:segstate.parent.R:SylStructure.parent.R:Syllable.n.lisp_cg_break
                 <
                 0.3)
                ((R:segstate.parent.R:SylStructure.parent.asyl_out
                  <
                  2.2)
                 ((1.39384 0.0980408))
                 ((2.11754 0.486455)))
                ((3.39485 1.83811)))
               ((R:segstate.parent.R:SylStructure.parent.syl_codasize
                 <
                 2.2)
                ((R:segstate.parent.pp.ph_vlng is a)
                 ((R:segstate.parent.R:SylStructure.parent.R:Syllable.nn.lisp_cg_break
                   <
                   0.3)
                  ((R:segstate.parent.R:SylStructure.parent.syl_in
                    <
                    7.7)
                   ((0.978452 0.570271))
                   ((0.958499 0.119235)))
                  ((R:segstate.parent.p.ph_ctype is f)
                   ((0.95398 0.665796))
                   ((1.27133 1.0432))))
                 ((R:segstate.parent.p.ph_cplace is a)
                  ((R:segstate.parent.R:SylStructure.parent.next_accent
                    <
                    2.4)
                   ((R:segstate.parent.R:SylStructure.parent.ssyl_in
                     <
                     5.5)
                    ((R:segstate.parent.nn.ph_cvox is -)
                     ((R:segstate.parent.R:SylStructure.parent.syl_in
                       <
                       6.2)
                      ((0.88745 0.518663))
                      ((1.49902 0.996278)))
                     ((R:segstate.parent.R:SylStructure.parent.R:Syllable.nn.accented
                       is
                       0)
                      ((R:segstate.parent.ph_vfront is 2)
                       ((1.27406 0.696301))
                       ((0.815202 0.173755)))
                      ((R:segstate.parent.nn.ph_vlng is s)
                       ((1.14834 0.345509))
                       ((0.655925 -0.213502)))))
                    ((R:segstate.parent.R:SylStructure.parent.position_type
                      is
                      single)
                     ((R:segstate.parent.R:SylStructure.parent.syl_out
                       <
                       3.2)
                      ((0.9735 0.0940302))
                      ((1.34605 0.590036)))
                     ((R:segstate.parent.lisp_onset_fric is 0)
                      ((0.660671 -0.221721))
                      ((0.642301 0.0486399)))))
                   ((R:segstate.parent.R:SylStructure.parent.position_type
                     is
                     final)
                    ((1.76193 1.01091))
                    ((1.52614 0.689137))))
                  ((R:segstate.parent.R:SylStructure.parent.ssyl_out
                    <
                    5.6)
                   ((R:segstate.parent.nn.ph_vlng is s)
                    ((R:segstate.parent.n.ph_ctype is n)
                     ((0.671593 -0.149478))
                     ((0.880406 0.105876)))
                    ((R:segstate.parent.pp.ph_vheight is 1)
                     ((1.29804 0.465128))
                     ((R:segstate.parent.R:SylStructure.parent.stress
                       is
                       0)
                      ((R:segstate.parent.p.name is sh)
                       ((0.787936 0.19236))
                       ((0.804481 -0.122299)))
                      ((R:segstate.parent.n.ph_vheight is 1)
                       ((0.669423 -6.81097e-05))
                       ((R:segstate.parent.R:SylStructure.parent.last_accent
                         <
                         2.2)
                        ((R:segstate.parent.ph_vheight is 2)
                         ((1.19314 0.60274))
                         ((1.28149 0.245919)))
                        ((R:segstate.parent.R:SylStructure.parent.R:Syllable.n.lisp_cg_break
                          <
                          0.3)
                         ((0.641611 0.0523542))
                         ((0.951661 0.186007))))))))
                   ((0.642575 -0.248777)))))
                ((R:segstate.parent.R:SylStructure.parent.syl_out < 5)
                 ((R:segstate.parent.ph_vheight is 2)
                  ((0.673224 -0.301741))
                  ((R:segstate.parent.R:SylStructure.parent.ssyl_in
                    <
                    5.4)
                   ((1.01275 0.0459548))
                   ((1.0364 0.0118081))))
                 ((R:segstate.parent.R:SylStructure.parent.R:Syllable.pp.accented
                   is
                   0)
                  ((R:segstate.parent.nn.ph_cvox is +)
                   ((1.20931 0.510785))
                   ((1.01014 0.114071)))
                  ((0.868377 -0.0307574))))))
              ((R:segstate.parent.R:SylStructure.parent.R:Syllable.nn.accented
                is
                0)
               ((R:segstate.parent.R:SylStructure.parent.R:Syllable.nn.lisp_cg_break
                 <
                 0.1)
                ((R:segstate.parent.R:SylStructure.parent.asyl_out
                  <
                  1.3)
                 ((R:segstate.parent.pp.ph_cplace is a)
                  ((0.8789 -0.106618))
                  ((R:segstate.parent.R:SylStructure.parent.position_type
                    is
                    final)
                   ((0.967872 -0.0998635))
                   ((R:segstate.parent.lisp_onset_stop is 0)
                    ((0.762024 0.113518))
                    ((1.07822 0.284542)))))
                 ((1.71863 0.697028)))
                ((R:segstate.parent.R:SylStructure.parent.ssyl_out
                  <
                  2.4)
                 ((R:segstate.parent.n.ph_vheight is 2)
                  ((0.894105 -0.0847696))
                  ((0.50791 -0.304541)))
                 ((R:segstate.parent.n.ph_vheight is 2)
                  ((R:segstate.parent.pp.ph_vheight is 2)
                   ((0.851961 -0.0432091))
                   ((0.556418 -0.325535)))
                  ((R:segstate.parent.R:SylStructure.parent.parent.word_numsyls
                    <
                    2.2)
                   ((1.3103 0.395788))
                   ((0.751218 -0.0625543))))))
               ((R:segstate.parent.R:SylStructure.parent.position_type
                 is
                 mid)
                ((0.453675 -0.480802))
                ((R:segstate.parent.nn.ph_cplace is 0)
                 ((R:segstate.parent.R:SylStructure.parent.syl_in < 9)
                  ((0.749808 -0.182569))
                  ((0.978836 0.261375)))
                 ((R:segstate.parent.R:SylStructure.parent.position_type
                   is
                   final)
                  ((0.513484 -0.374045))
                  ((R:segstate.parent.p.name is s)
                   ((0.780578 -0.273428))
                   ((0.740467 0.0449254))))))))))))
         ((R:segstate.parent.syl_final is 0)
          ((R:segstate.parent.p.name is s)
           ((R:segstate.parent.lisp_coda_stop is 0)
            ((1.02345 0.410283))
            ((0.615526 0.0139803)))
           ((R:segstate.parent.R:SylStructure.parent.syl_codasize
             <
             2.2)
            ((R:segstate.parent.p.name is k)
             ((0.456094 -0.547922))
             ((R:segstate.parent.p.name is f)
              ((0.282452 -0.511406))
              ((R:segstate.parent.nn.ph_vlng is a)
               ((R:segstate.parent.pp.ph_cvox is -)
                ((0.405559 -0.577185))
                ((R:segstate.parent.R:SylStructure.parent.position_type
                  is
                  single)
                 ((0.707616 -0.112039))
                 ((0.52977 -0.350547))))
               ((R:segstate.parent.R:SylStructure.parent.syl_codasize
                 <
                 1.1)
                ((R:segstate.parent.R:SylStructure.parent.R:Syllable.p.lisp_cg_break
                  <
                  0.1)
                 ((0.638214 -0.212765))
                 ((1.56004 0.320729)))
                ((R:segstate.parent.R:SylStructure.parent.R:Syllable.pp.accented
                  is
                  0)
                 ((R:segstate.parent.R:SylStructure.parent.R:Syllable.p.syl_codasize
                   <
                   2.2)
                  ((R:segstate.parent.n.ph_vlng is l)
                   ((0.489741 -0.419731))
                   ((R:segstate.parent.R:SylStructure.parent.R:Syllable.nn.lisp_cg_break
                     <
                     0.3)
                    ((R:segstate.parent.R:SylStructure.parent.ssyl_out
                      <
                      4.2)
                     ((R:segstate.parent.ph_vheight is 1)
                      ((0.463904 -0.296527))
                      ((R:segstate.parent.ph_vfront is 2)
                       ((0.529108 -0.28369))
                       ((0.900517 0.0919917))))
                     ((0.404331 -0.454651)))
                    ((R:segstate.parent.ph_vheight is 2)
                     ((1.21146 0.295805))
                     ((R:segstate.parent.R:SylStructure.parent.last_accent
                       <
                       2.1)
                      ((0.616596 -0.196012))
                      ((0.835025 0.0253646))))))
                  ((0.508054 -0.459882)))
                 ((R:segstate.parent.ph_vheight is 1)
                  ((0.37036 -0.526839))
                  ((R:segstate.parent.R:SylStructure.parent.syl_in
                    <
                    7.9)
                   ((0.707389 -0.104276))
                   ((R:segstate.parent.R:SylStructure.parent.syl_in
                     <
                     12.5)
                    ((R:segstate.parent.p.ph_cplace is a)
                     ((0.474585 -0.273315))
                     ((0.281598 -0.632964)))
                    ((0.676795 -0.139162))))))))))
            ((R:segstate.parent.seg_onsetcoda is coda)
             ((R:segstate.parent.R:SylStructure.parent.ssyl_out < 4.6)
              ((R:segstate.parent.ph_vheight is 1)
               ((0.467047 -0.161977))
               ((R:segstate.parent.n.ph_ctype is s)
                ((0.581022 -0.116165))
                ((R:segstate.parent.R:SylStructure.parent.R:Syllable.p.syl_codasize
                  <
                  1.1)
                 ((0.863314 0.0952962))
                 ((1.04305 0.38507)))))
              ((0.645977 -0.238617)))
             ((0.400472 -0.30314)))))
          ((R:segstate.parent.nn.ph_vlng is s)
           ((R:segstate.parent.R:SylStructure.parent.syl_out < 4.2)
            ((1.28091 0.204295))
            ((1.12874 0.710881)))
           ((R:segstate.parent.p.name is r)
            ((R:segstate.parent.R:SylStructure.parent.position_type
              is
              single)
             ((0.422159 -0.430836))
             ((R:segstate.parent.R:SylStructure.parent.stress is 0)
              ((R:segstate.parent.R:SylStructure.parent.R:Syllable.nn.stress
                is
                0)
               ((0.938239 -0.493205))
               ((R:segstate.parent.nn.ph_cvox is +)
                ((0.938292 -0.226521))
                ((1.32745 0.00874772))))
              ((0.698902 0.0496911))))
            ((R:segstate.parent.R:SylStructure.parent.R:Syllable.p.syl_codasize
              <
              2.2)
             ((R:segstate.parent.R:SylStructure.parent.R:Syllable.nn.lisp_cg_break
               <
               0.3)
              ((R:segstate.parent.R:SylStructure.parent.R:Syllable.p.syl_codasize
                <
                1.1)
               ((R:segstate.parent.p.name is l)
                ((1.44677 0.0870232))
                ((0.765006 -0.159792)))
               ((0.835567 -0.314983)))
              ((R:segstate.parent.R:SylStructure.parent.parent.word_numsyls
                <
                2.2)
               ((R:segstate.parent.R:SylStructure.parent.asyl_in < 2.4)
                ((1.1037 0.488218))
                ((1.14055 0.0928525)))
               ((0.680673 -0.158088))))
             ((1.31864 0.368798))))))))
       ((R:segstate.parent.p.ph_vheight is 2)
        ((R:segstate.parent.ph_cvox is +)
         ((R:segstate.parent.R:SylStructure.parent.syl_onsetsize < 0.3)
          ((R:segstate.parent.R:SylStructure.parent.next_accent < 2.4)
           ((R:segstate.parent.nn.ph_cplace is a)
            ((0.674943 -0.178509))
            ((R:segstate.parent.nn.ph_vrnd is +)
             ((1.18066 0.569471))
             ((R:segstate.parent.pp.ph_cvox is +)
              ((R:segstate.parent.R:SylStructure.parent.R:Syllable.nn.accented
                is
                0)
               ((R:segstate.parent.nn.ph_vfront is 1)
                ((0.455204 -0.380672))
                ((0.914302 -0.0460675)))
               ((R:segstate.parent.R:SylStructure.parent.ssyl_in < 3.7)
                ((0.755263 0.499512))
                ((R:segstate.parent.nn.ph_vfront is 2)
                 ((1.0601 0.264287))
                 ((0.684746 -0.273886)))))
              ((R:segstate.parent.R:SylStructure.parent.R:Syllable.nn.stress
                is
                0)
               ((R:segstate.parent.R:SylStructure.parent.R:Syllable.nn.lisp_cg_break
                 <
                 0.3)
                ((R:segstate.parent.R:SylStructure.parent.R:Syllable.p.syl_codasize
                  <
                  2)
                 ((R:segstate.parent.R:SylStructure.parent.R:Syllable.p.syl_codasize
                   <
                   1.1)
                  ((0.944029 0.313279))
                  ((0.980342 -0.0525782)))
                 ((1.13814 0.58925)))
                ((1.35754 0.713075)))
               ((R:segstate.parent.R:SylStructure.parent.R:Syllable.p.syl_codasize
                 <
                 1.3)
                ((R:segstate.parent.R:SylStructure.parent.ssyl_out
                  <
                  1.4)
                 ((0.791815 0.0551411))
                 ((0.729238 -0.160149)))
                ((R:segstate.parent.R:SylStructure.parent.asyl_in
                  <
                  2.2)
                 ((R:segstate.parent.R:SylStructure.parent.last_accent
                   <
                   3.2)
                  ((0.972456 0.488253))
                  ((0.988417 0.225618)))
                 ((0.814348 0.0584773))))))))
           ((0.673391 -0.2399)))
          ((R:segstate.parent.ph_ctype is n)
           ((R:segstate.parent.n.ph_vlng is a)
            ((0.488156 -0.549987))
            ((R:segstate.parent.pos_in_syl is 3)
             ((R:segstate.parent.R:SylStructure.parent.position_type
               is
               single)
              ((R:segstate.parent.R:SylStructure.parent.asyl_in < 2.5)
               ((R:segstate.parent.R:SylStructure.parent.R:Syllable.pp.lisp_cg_break
                 <
                 0.1)
                ((0.450394 -0.406202))
                ((0.994459 -0.186117)))
               ((0.784468 -0.0556814)))
              ((0.731999 -0.477233)))
             ((R:segstate.parent.R:SylStructure.parent.position_type
               is
               single)
              ((R:segstate.parent.R:SylStructure.parent.ssyl_out < 5.8)
               ((R:segstate.parent.lisp_coda_stop is 0)
                ((R:segstate.parent.R:SylStructure.parent.R:Syllable.nn.accented
                  is
                  0)
                 ((R:segstate.parent.R:SylStructure.parent.ssyl_out
                   <
                   2.2)
                  ((1.07344 0.344323))
                  ((R:segstate.parent.n.ph_ctype is f)
                   ((0.861485 -0.0140404))
                   ((1.1394 0.201681))))
                 ((R:segstate.parent.R:SylStructure.parent.syl_out
                   <
                   3.4)
                  ((0.917847 0.109367))
                  ((0.507699 -0.260407))))
                ((0.529011 -0.373687)))
               ((1.11045 0.618651)))
              ((R:segstate.parent.R:SylStructure.parent.R:Syllable.nn.lisp_cg_break
                <
                0.3)
               ((R:segstate.parent.R:SylStructure.parent.syl_in < 12.2)
                ((R:segstate.parent.R:SylStructure.parent.ssyl_in
                  <
                  4.5)
                 ((0.971122 -0.0800479))
                 ((R:segstate.parent.nn.ph_vlng is a)
                  ((0.768528 0.0143802))
                  ((R:segstate.parent.R:SylStructure.parent.ssyl_out
                    <
                    1.3)
                   ((1.26855 0.282725))
                   ((0.594385 0.158587)))))
                ((0.625292 -0.199794)))
               ((R:segstate.parent.p.name is ey)
                ((0.957228 0.104689))
                ((R:segstate.parent.R:SylStructure.parent.next_accent
                  <
                  2.4)
                 ((R:segstate.parent.nn.ph_vc is +)
                  ((R:segstate.parent.R:SylStructure.parent.R:Syllable.pp.lisp_cg_break
                    <
                    0.1)
                   ((0.800067 -0.072285))
                   ((R:segstate.parent.R:SylStructure.parent.R:Syllable.p.syl_codasize
                     <
                     1.2)
                    ((1.24742 -0.211211))
                    ((0.619245 -0.362498))))
                  ((R:segstate.parent.R:SylStructure.parent.syl_in
                    <
                    5.3)
                   ((0.87672 -0.234079))
                   ((R:segstate.parent.nn.ph_cvox is +)
                    ((0.704229 0.0215764))
                    ((0.723518 0.0664587)))))
                 ((0.750803 -0.356227))))))))
           ((R:segstate.parent.lisp_coda_stop is 0)
            ((R:segstate.parent.ph_ctype is s)
             ((R:segstate.parent.pp.ph_cplace is a)
              ((R:segstate.parent.nn.ph_cvox is -)
               ((0.399444 -0.119437))
               ((R:segstate.parent.p.ph_vfront is 1)
                ((0.624391 -0.33387))
                ((0.731325 -0.168505))))
              ((0.557973 -0.473699)))
             ((R:segstate.parent.R:SylStructure.parent.R:Syllable.p.syl_codasize
               <
               1.2)
              ((R:segstate.parent.lisp_onset_fric is 0)
               ((R:segstate.parent.R:SylStructure.parent.ssyl_out
                 <
                 3.5)
                ((R:segstate.parent.n.ph_vheight is 2)
                 ((1.20563 0.469483))
                 ((R:segstate.parent.R:SylStructure.parent.syl_out
                   <
                   2.2)
                  ((R:segstate.parent.nn.ph_cplace is a)
                   ((0.669177 -0.113621))
                   ((1.11986 0.339604)))
                  ((0.815561 -0.293449))))
                ((R:segstate.parent.pp.ph_cplace is a)
                 ((1.08114 0.235782))
                 ((1.49041 0.804701))))
               ((R:segstate.parent.p.name is ah)
                ((R:segstate.parent.R:SylStructure.parent.R:Syllable.n.lisp_cg_break
                  <
                  0.3)
                 ((0.82898 0.383711))
                 ((0.961688 0.361681)))
                ((R:segstate.parent.R:SylStructure.parent.syl_in
                  <
                  10.5)
                 ((R:segstate.parent.R:SylStructure.parent.asyl_in
                   <
                   3.5)
                  ((R:segstate.parent.R:SylStructure.parent.syl_out
                    <
                    6.6)
                   ((R:segstate.parent.pos_in_syl is 0)
                    ((R:segstate.parent.R:SylStructure.parent.parent.gpos
                      is
                      content)
                     ((0.985199 0.088271))
                     ((0.904095 -0.125783)))
                    ((1.4651 0.500716)))
                   ((R:segstate.parent.nn.ph_cvox is -)
                    ((1.01281 0.00687118))
                    ((0.658821 -0.274749))))
                  ((0.500781 -0.281723)))
                 ((0.745966 -0.305705)))))
              ((R:segstate.parent.R:SylStructure.parent.R:Syllable.pp.lisp_cg_break
                <
                0.1)
               ((0.517037 -0.437695))
               ((R:segstate.parent.p.ph_vfront is 1)
                ((R:segstate.parent.nn.ph_cplace is 0)
                 ((0.593183 -0.235689))
                 ((0.758609 -0.0815568)))
                ((0.965649 0.124029))))))
            ((R:segstate.parent.lisp_onset_fric is 0)
             ((R:segstate.parent.R:SylStructure.parent.R:Syllable.p.syl_codasize
               <
               1.2)
              ((R:segstate.parent.R:SylStructure.parent.ssyl_in < 3.6)
               ((0.988266 0.172772))
               ((R:segstate.parent.n.ph_ctype is 0)
                ((0.651406 0.0319784))
                ((0.545489 -0.427812))))
              ((R:segstate.parent.nn.ph_vfront is 2)
               ((0.742154 -0.132307))
               ((R:segstate.parent.n.ph_ctype is f)
                ((0.879859 0.800782))
                ((R:segstate.parent.R:SylStructure.parent.asyl_out
                  <
                  1.3)
                 ((1.16703 0.363381))
                 ((0.880949 0.106557))))))
             ((R:segstate.parent.R:SylStructure.parent.R:Syllable.nn.stress
               is
               0)
              ((1.27166 0.74127))
              ((0.900814 0.224648)))))))
         ((R:segstate.parent.R:SylStructure.parent.R:Syllable.pp.lisp_cg_break
           <
           0.1)
          ((R:segstate.parent.lisp_onset_fric is 0)
           ((R:segstate.parent.p.ph_vfront is 1)
            ((R:segstate.parent.R:SylStructure.parent.R:Syllable.nn.lisp_cg_break
              <
              0.3)
             ((0.775029 -0.368756))
             ((R:segstate.parent.R:SylStructure.parent.last_accent
               <
               1.8)
              ((0.621695 -0.557021))
              ((0.364746 -0.834173))))
            ((R:segstate.parent.nn.ph_vrnd is -)
             ((0.453589 -0.667635))
             ((1.03792 0.110231))))
           ((R:segstate.parent.R:SylStructure.parent.asyl_in < 3.6)
            ((R:segstate.parent.R:SylStructure.parent.ssyl_in < 4.2)
             ((0.697067 -0.25565))
             ((0.666241 0.153533)))
            ((0.655303 -0.304832))))
          ((R:segstate.parent.R:SylStructure.parent.syl_in < 8.2)
           ((R:segstate.parent.pp.ph_cplace is l)
            ((R:segstate.parent.ph_ctype is s)
             ((R:segstate.parent.nn.ph_cplace is 0)
              ((0.813947 -0.275306))
              ((0.26683 -0.738893)))
             ((R:segstate.parent.pos_in_syl is 2)
              ((1.34959 0.143211))
              ((0.717212 -0.37736))))
            ((R:segstate.parent.p.ph_vfront is 1)
             ((R:segstate.parent.R:SylStructure.parent.asyl_in < 1.2)
              ((R:segstate.parent.R:SylStructure.parent.R:Syllable.nn.accented
                is
                0)
               ((1.03419 0.1771))
               ((1.04462 0.395094)))
              ((R:segstate.parent.nn.ph_cplace is 0)
               ((0.5301 -0.400414))
               ((R:segstate.parent.lisp_onset_fric is 0)
                ((1.05169 0.109538))
                ((0.64346 -0.161676)))))
             ((R:segstate.parent.lisp_coda_fric is 0)
              ((R:segstate.parent.R:SylStructure.parent.R:Syllable.pp.accented
                is
                0)
               ((R:segstate.parent.R:SylStructure.parent.R:Syllable.n.accented
                 is
                 0)
                ((R:segstate.parent.R:SylStructure.parent.R:Syllable.nn.accented
                  is
                  0)
                 ((0.462587 -0.171538))
                 ((0.914266 -0.0667376)))
                ((0.578503 -0.409521)))
               ((0.843223 0.0587184)))
              ((R:segstate.parent.R:SylStructure.parent.ssyl_in < 3.3)
               ((0.582815 -0.270754))
               ((0.534579 -0.616205))))))
           ((R:segstate.parent.R:SylStructure.parent.ssyl_in < 7)
            ((R:segstate.parent.R:SylStructure.parent.ssyl_in < 6.2)
             ((R:segstate.parent.R:SylStructure.parent.ssyl_out < 2.5)
              ((R:segstate.parent.p.name is ey)
               ((0.644359 -0.124154))
               ((R:segstate.parent.R:SylStructure.parent.lisp_cg_break
                 <
                 0.1)
                ((0.632928 -0.00260951))
                ((1.01106 0.518161))))
              ((R:segstate.parent.p.ph_vfront is 1)
               ((0.54778 -0.457658))
               ((0.606775 -0.0762461))))
             ((R:segstate.parent.pp.ph_cvox is +)
              ((1.60729 0.745222))
              ((0.873377 0.243709))))
            ((R:segstate.parent.nn.ph_cvox is +)
             ((0.664969 -0.0182955))
             ((0.5977 -0.352323)))))))
        ((R:segstate.parent.pos_in_syl is 0)
         ((R:segstate.parent.ph_ctype is s)
          ((R:segstate.parent.R:SylStructure.parent.stress is 0)
           ((R:segstate.parent.R:SylStructure.parent.parent.gpos
             is
             content)
            ((R:segstate.parent.p.name is ng)
             ((R:segstate.parent.pp.ph_vheight is 1)
              ((0.303174 -0.951864))
              ((R:segstate.parent.R:SylStructure.parent.R:Syllable.n.accented
                is
                0)
               ((0.386736 -0.799714))
               ((0.643704 -0.527013))))
             ((R:segstate.parent.p.name is l)
              ((R:segstate.parent.R:SylStructure.parent.syl_in < 10.4)
               ((0.691818 0.450547))
               ((0.784116 -0.0789551)))
              ((R:segstate.parent.p.ph_cvox is -)
               ((R:segstate.parent.R:SylStructure.parent.R:Syllable.n.accented
                 is
                 0)
                ((R:segstate.parent.R:SylStructure.parent.syl_in < 10)
                 ((1.05246 0.497772))
                 ((0.816732 -0.120239)))
                ((R:segstate.parent.n.ph_ctype is 0)
                 ((R:segstate.parent.R:SylStructure.parent.R:Syllable.pp.accented
                   is
                   0)
                  ((0.808506 -0.216842))
                  ((0.697702 -0.472342)))
                 ((R:segstate.parent.R:SylStructure.parent.R:Syllable.p.accented
                   is
                   0)
                  ((0.680894 -0.156498))
                  ((0.932779 0.234699)))))
               ((R:segstate.parent.ph_cvox is +)
                ((R:segstate.parent.R:SylStructure.parent.syl_in < 12)
                 ((R:segstate.parent.R:SylStructure.parent.R:Syllable.n.lisp_cg_break
                   <
                   0.3)
                  ((R:segstate.parent.R:SylStructure.parent.asyl_out
                    <
                    2.5)
                   ((0.450909 -0.670804))
                   ((0.537221 -0.424708)))
                  ((R:segstate.parent.p.name is r)
                   ((0.606235 -0.104588))
                   ((R:segstate.parent.R:SylStructure.parent.asyl_out
                     <
                     1.2)
                    ((R:segstate.parent.n.ph_vlng is a)
                     ((0.670726 -0.295573))
                     ((0.74004 -0.092356)))
                    ((R:segstate.parent.R:SylStructure.parent.R:Syllable.n.accented
                      is
                      0)
                     ((0.651538 -0.377125))
                     ((0.33746 -0.589419))))))
                 ((R:segstate.parent.n.ph_ctype is 0)
                  ((0.606156 -0.472317))
                  ((0.247931 -0.86083))))
                ((R:segstate.parent.nn.ph_cvox is -)
                 ((R:segstate.parent.R:SylStructure.parent.asyl_in
                   <
                   2.1)
                  ((R:segstate.parent.R:SylStructure.parent.last_accent
                    <
                    1.8)
                   ((0.222564 -0.751697))
                   ((0.588984 -0.483241)))
                  ((R:segstate.parent.R:SylStructure.parent.asyl_in
                    <
                    3.4)
                   ((0.622603 -0.266423))
                   ((0.641208 -0.387935))))
                 ((R:segstate.parent.nn.ph_cplace is a)
                  ((R:segstate.parent.p.ph_cplace is a)
                   ((R:segstate.parent.p.name is n)
                    ((0.680527 -0.329378))
                    ((0.361837 -0.765983)))
                   ((R:segstate.parent.R:SylStructure.parent.asyl_in
                     <
                     3.6)
                    ((R:segstate.parent.R:SylStructure.parent.R:Syllable.nn.stress
                      is
                      0)
                     ((0.833258 -0.10188))
                     ((0.606111 -0.534827)))
                    ((1.30483 0.24101))))
                  ((R:segstate.parent.R:SylStructure.parent.ssyl_out
                    <
                    1.6)
                   ((R:segstate.parent.R:SylStructure.parent.asyl_in
                     <
                     4.5)
                    ((0.736317 0.454973))
                    ((0.991919 0.112832)))
                   ((R:segstate.parent.pp.ph_vheight is 2)
                    ((0.72105 0.0773138))
                    ((R:segstate.parent.R:SylStructure.parent.R:Syllable.nn.accented
                      is
                      0)
                     ((R:segstate.parent.R:SylStructure.parent.syl_in
                       <
                       7.4)
                      ((0.846891 0.121986))
                      ((0.96529 -0.236685)))
                     ((0.605773 -0.472299)))))))))))
            ((R:segstate.parent.n.ph_vlng is l)
             ((2.31101 1.40073))
             ((R:segstate.parent.p.ph_cvox is -)
              ((R:segstate.parent.R:SylStructure.parent.asyl_out < 3)
               ((R:segstate.parent.pp.ph_cplace is a)
                ((R:segstate.parent.nn.ph_cplace is a)
                 ((0.693905 -0.427968))
                 ((0.851745 -0.0254558)))
                ((R:segstate.parent.p.ph_cplace is a)
                 ((0.788258 -0.103013))
                 ((R:segstate.parent.R:SylStructure.parent.ssyl_out
                   <
                   3.5)
                  ((R:segstate.parent.R:SylStructure.parent.R:Syllable.n.lisp_cg_break
                    <
                    0.3)
                   ((1.01201 0.396905))
                   ((0.925322 0.368587)))
                  ((0.87471 0.0204886)))))
               ((0.617247 -0.574971)))
              ((R:segstate.parent.p.ph_ctype is n)
               ((R:segstate.parent.R:SylStructure.parent.syl_out < 5.8)
                ((R:segstate.parent.R:SylStructure.parent.asyl_in
                  <
                  3.1)
                 ((0.80713 0.187798))
                 ((0.741493 0.47211)))
                ((0.646824 -0.159391)))
               ((R:segstate.parent.nn.ph_cvox is +)
                ((R:segstate.parent.R:SylStructure.parent.syl_in
                  <
                  10.2)
                 ((1.36006 0.841931))
                 ((0.903727 0.387706)))
                ((0.68516 0.184384)))))))
           ((R:segstate.parent.p.name is r)
            ((R:segstate.parent.n.ph_vheight is 1)
             ((0.534749 1.10561))
             ((R:segstate.parent.nn.ph_cvox is +)
              ((1.08291 0.450513))
              ((0.752752 0.0271403))))
            ((R:segstate.parent.p.ph_vlng is l)
             ((0.956886 0.805071))
             ((R:segstate.parent.n.ph_vlng is l)
              ((R:segstate.parent.pp.ph_vheight is 3)
               ((0.963541 0.243107))
               ((R:segstate.parent.R:SylStructure.parent.position_type
                 is
                 final)
                ((0.88602 0.226918))
                ((R:segstate.parent.R:SylStructure.parent.R:Syllable.p.syl_codasize
                  <
                  1.3)
                 ((0.776228 0.127492))
                 ((R:segstate.parent.R:SylStructure.parent.next_accent
                   <
                   1.4)
                  ((R:segstate.parent.p.ph_cplace is a)
                   ((R:segstate.parent.p.ph_ctype is s)
                    ((0.661313 -0.513187))
                    ((0.835451 -0.277986)))
                   ((0.563498 -0.609813)))
                  ((R:segstate.parent.R:SylStructure.parent.asyl_out
                    <
                    1.5)
                   ((0.508201 -0.407965))
                   ((0.852777 0.0150668)))))))
              ((R:segstate.parent.p.name is pau)
               ((R:segstate.parent.pp.ph_cvox is -)
                ((R:segstate.parent.R:SylStructure.parent.syl_codasize
                  <
                  1.2)
                 ((1.00127 0.0820852))
                 ((0.803779 -0.388648)))
                ((R:segstate.parent.lisp_coda_stop is 0)
                 ((R:segstate.parent.n.ph_vheight is 2)
                  ((0.949392 -0.361485))
                  ((R:segstate.parent.R:SylStructure.parent.R:Syllable.n.accented
                    is
                    0)
                   ((0.8962 -0.20226))
                   ((0.808672 0.0188256))))
                 ((R:segstate.parent.R:SylStructure.parent.ssyl_out
                   <
                   3.5)
                  ((R:segstate.parent.n.ph_ctype is 0)
                   ((1.50738 0.0679244))
                   ((1.25367 0.145541)))
                  ((1.1359 0.422073)))))
               ((R:segstate.parent.lisp_coda_stop is 0)
                ((R:segstate.parent.p.name is ay)
                 ((0.844717 0.533815))
                 ((R:segstate.parent.pp.ph_vc is +)
                  ((R:segstate.parent.p.ph_cplace is l)
                   ((R:segstate.parent.R:SylStructure.parent.syl_onsetsize
                     <
                     1.1)
                    ((0.832592 -0.363812))
                    ((1.01864 0.016856)))
                   ((R:segstate.parent.R:SylStructure.parent.ssyl_out
                     <
                     0.8)
                    ((R:segstate.parent.n.ph_vlng is d)
                     ((0.761954 -0.100872))
                     ((R:segstate.parent.nn.ph_vrnd is -)
                      ((1.10741 0.179499))
                      ((1.29558 0.831339))))
                    ((R:segstate.parent.R:SylStructure.parent.last_accent
                      <
                      5.5)
                     ((R:segstate.parent.R:SylStructure.parent.lisp_cg_break
                       <
                       0.1)
                      ((R:segstate.parent.n.ph_ctype is r)
                       ((R:segstate.parent.R:SylStructure.parent.syl_out
                         <
                         5.6)
                        ((0.889899 -0.0247508))
                        ((0.867378 0.140549)))
                       ((R:segstate.parent.pp.ph_vheight is 1)
                        ((1.09896 0.132748))
                        ((R:segstate.parent.R:SylStructure.parent.R:Syllable.nn.lisp_cg_break
                          <
                          0.3)
                         ((1.26856 0.571946))
                         ((1.04345 0.280117)))))
                      ((R:segstate.parent.R:SylStructure.parent.R:Syllable.nn.accented
                        is
                        0)
                       ((R:segstate.parent.R:SylStructure.parent.R:Syllable.nn.lisp_cg_break
                         <
                         0.1)
                        ((0.762546 -0.0302813))
                        ((0.611817 -0.363176)))
                       ((0.922783 0.221191))))
                     ((0.973999 -0.240006)))))
                  ((R:segstate.parent.R:SylStructure.parent.ssyl_out
                    <
                    1.6)
                   ((0.767515 -0.410308))
                   ((R:segstate.parent.R:SylStructure.parent.syl_in
                     <
                     5.6)
                    ((1.15174 -0.182754))
                    ((0.915417 0.195855))))))
                ((R:segstate.parent.R:SylStructure.parent.asyl_out
                  <
                  1.4)
                 ((R:segstate.parent.R:SylStructure.parent.position_type
                   is
                   single)
                  ((R:segstate.parent.R:SylStructure.parent.R:Syllable.nn.lisp_cg_break
                    <
                    0.3)
                   ((1.40367 0.51062))
                   ((2.05207 1.02696)))
                  ((1.17784 0.284873)))
                 ((R:segstate.parent.R:SylStructure.parent.R:Syllable.pp.lisp_cg_break
                   <
                   0.1)
                  ((1.42836 0.716153))
                  ((R:segstate.parent.nn.ph_cvox is +)
                   ((R:segstate.parent.p.ph_ctype is s)
                    ((0.750056 0.218061))
                    ((1.16862 0.212692)))
                   ((R:segstate.parent.R:SylStructure.parent.asyl_out
                     <
                     2.2)
                    ((0.951512 -0.374321))
                    ((0.998569 0.144589))))))))))))
          ((R:segstate.parent.nn.ph_cplace is 0)
           ((R:segstate.parent.p.name is aw)
            ((R:segstate.parent.R:SylStructure.parent.syl_in < 10)
             ((R:segstate.parent.R:SylStructure.parent.R:Syllable.nn.stress
               is
               0)
              ((0.466834 -0.424676))
              ((0.372213 -0.553137)))
             ((0.391305 -0.296927)))
            ((R:segstate.parent.R:SylStructure.parent.parent.gpos
              is
              in)
             ((R:segstate.parent.R:SylStructure.parent.asyl_in < 3.6)
              ((R:segstate.parent.nn.ph_vlng is l)
               ((1.57421 0.609723))
               ((R:segstate.parent.R:SylStructure.parent.syl_codasize
                 <
                 1.1)
                ((0.681142 0.0244624))
                ((R:segstate.parent.R:SylStructure.parent.ssyl_in
                  <
                  5.1)
                 ((R:segstate.parent.ph_vheight is 2)
                  ((0.689569 0.0368471))
                  ((R:segstate.parent.R:SylStructure.parent.ssyl_in
                    <
                    3.2)
                   ((0.91926 -0.18937))
                   ((0.690444 -0.312707))))
                 ((0.519756 -0.348496)))))
              ((R:segstate.parent.pp.ph_vheight is 1)
               ((0.531573 -0.243916))
               ((R:segstate.parent.R:SylStructure.parent.asyl_out
                 <
                 1.2)
                ((0.525777 -0.486604))
                ((0.5073 -0.739316)))))
             ((R:segstate.parent.R:SylStructure.parent.stress is 0)
              ((R:segstate.parent.R:SylStructure.parent.lisp_cg_break
                <
                0.1)
               ((R:segstate.parent.ph_vfront is 2)
                ((R:segstate.parent.R:SylStructure.parent.last_accent
                  <
                  1.4)
                 ((R:segstate.parent.R:SylStructure.parent.asyl_out
                   <
                   2.2)
                  ((R:segstate.parent.R:SylStructure.parent.asyl_in
                    <
                    3.5)
                   ((0.630336 0.0597839))
                   ((0.383471 -0.282606)))
                  ((0.347013 -0.41359)))
                 ((R:segstate.parent.nn.ph_vlng is d)
                  ((0.516205 -0.179426))
                  ((R:segstate.parent.R:SylStructure.parent.asyl_out
                    <
                    1.3)
                   ((0.684824 -0.00448149))
                   ((1.14302 0.342556)))))
                ((R:segstate.parent.R:SylStructure.parent.ssyl_in < 7)
                 ((R:segstate.parent.R:SylStructure.parent.syl_in
                   <
                   7.4)
                  ((0.414021 -0.366272))
                  ((0.353519 -0.588931)))
                 ((0.747074 -0.0978458))))
               ((R:segstate.parent.n.ph_ctype is l)
                ((0.424893 -0.41401))
                ((R:segstate.parent.ph_ctype is f)
                 ((0.768415 -0.212415))
                 ((R:segstate.parent.n.ph_ctype is n)
                  ((0.544142 -0.152591))
                  ((R:segstate.parent.R:SylStructure.parent.ssyl_in
                    <
                    4.6)
                   ((R:segstate.parent.pp.ph_vheight is 1)
                    ((0.625626 0.160448))
                    ((R:segstate.parent.p.ph_ctype is s)
                     ((0.630208 0.200775))
                     ((R:segstate.parent.R:SylStructure.parent.syl_in
                       <
                       5.4)
                      ((1.39222 0.703916))
                      ((1.3437 0.3556)))))
                   ((R:segstate.parent.pp.ph_cplace is 0)
                    ((R:segstate.parent.R:SylStructure.parent.asyl_in
                      <
                      3)
                     ((R:segstate.parent.nn.ph_vlng is s)
                      ((1.22811 0.315488))
                      ((0.79113 0.0999672)))
                     ((0.698925 0.0207092)))
                    ((0.563088 -0.0924891))))))))
              ((R:segstate.parent.lisp_onset_stop is 0)
               ((R:segstate.parent.R:SylStructure.parent.syl_codasize
                 <
                 1.2)
                ((R:segstate.parent.ph_vfront is 2)
                 ((R:segstate.parent.R:SylStructure.parent.last_accent
                   <
                   1.5)
                  ((0.570934 -0.415288))
                  ((0.754984 0.243089)))
                 ((R:segstate.parent.R:SylStructure.parent.R:Syllable.pp.lisp_cg_break
                   <
                   0.1)
                  ((R:segstate.parent.R:SylStructure.parent.last_accent
                    <
                    1.5)
                   ((1.78011 0.74504))
                   ((0.784243 0.0799193)))
                  ((R:segstate.parent.pp.ph_vlng is l)
                   ((0.569329 -0.221512))
                   ((R:segstate.parent.R:SylStructure.parent.R:Syllable.p.stress
                     is
                     0)
                    ((0.697465 -0.180331))
                    ((R:segstate.parent.R:SylStructure.parent.R:Syllable.p.syl_codasize
                      <
                      1.2)
                     ((1.12749 0.516832))
                     ((R:segstate.parent.R:SylStructure.parent.ssyl_in
                       <
                       3.7)
                      ((0.703162 -0.226826))
                      ((R:segstate.parent.pp.ph_vheight is 3)
                       ((0.737004 0.0318573))
                       ((R:segstate.parent.p.name is pau)
                        ((R:segstate.parent.R:SylStructure.parent.syl_in
                          <
                          9)
                         ((1.00575 -0.053529))
                         ((1.29305 0.223645)))
                        ((1.34619 0.382896))))))))))
                ((R:segstate.parent.R:SylStructure.parent.syl_out
                  <
                  2.1)
                 ((1.05459 0.172029))
                 ((R:segstate.parent.R:SylStructure.parent.last_accent
                   <
                   1.4)
                  ((1.83574 0.929241))
                  ((1.28203 0.349443)))))
               ((R:segstate.parent.R:SylStructure.parent.asyl_in < 2.1)
                ((R:segstate.parent.R:SylStructure.parent.asyl_out
                  <
                  2.5)
                 ((0.665197 -0.12506))
                 ((0.537594 -0.487252)))
                ((R:segstate.parent.R:SylStructure.parent.last_accent
                  <
                  1.2)
                 ((0.737156 -0.115126))
                 ((1.37743 0.170246))))))))
           ((R:segstate.parent.R:SylStructure.parent.lisp_cg_break
             <
             0.1)
            ((R:segstate.parent.lisp_onset_glide is 0)
             ((R:segstate.parent.ph_vfront is 2)
              ((R:segstate.parent.R:SylStructure.parent.asyl_out < 2.4)
               ((R:segstate.parent.pp.ph_vc is +)
                ((0.809791 0.135893))
                ((1.6866 0.698682)))
               ((0.571885 -0.150532)))
              ((R:segstate.parent.R:SylStructure.parent.stress is 0)
               ((R:segstate.parent.R:SylStructure.parent.parent.gpos
                 is
                 content)
                ((R:segstate.parent.p.name is z)
                 ((R:segstate.parent.nn.ph_cvox is +)
                  ((0.441995 -0.604472))
                  ((0.401675 -0.591143)))
                 ((R:segstate.parent.pp.ph_cvox is -)
                  ((R:segstate.parent.R:SylStructure.parent.syl_in
                    <
                    12.4)
                   ((R:segstate.parent.R:SylStructure.parent.R:Syllable.nn.lisp_cg_break
                     <
                     0.3)
                    ((0.618683 -0.354853))
                    ((R:segstate.parent.p.name is ae)
                     ((0.663768 -0.453549))
                     ((0.328311 -0.694583))))
                   ((0.595242 -0.041054)))
                  ((R:segstate.parent.R:SylStructure.parent.R:Syllable.n.lisp_cg_break
                    <
                    1.2)
                   ((R:segstate.parent.R:SylStructure.parent.syl_in
                     <
                     7.2)
                    ((R:segstate.parent.R:SylStructure.parent.R:Syllable.pp.lisp_cg_break
                      <
                      0.1)
                     ((0.542793 -0.566022))
                     ((R:segstate.parent.nn.ph_cvox is +)
                      ((R:segstate.parent.R:SylStructure.parent.syl_out
                        <
                        7.2)
                       ((R:segstate.parent.p.name is n)
                        ((0.640051 -0.274478))
                        ((0.512518 -0.431208)))
                       ((0.894833 0.112634)))
                      ((R:segstate.parent.p.ph_cplace is a)
                       ((1.132 0.241756))
                       ((0.780623 -0.195925)))))
                    ((R:segstate.parent.R:SylStructure.parent.ssyl_in
                      <
                      4.4)
                     ((0.58003 -0.506825))
                     ((R:segstate.parent.R:SylStructure.parent.syl_in
                       <
                       12.8)
                      ((R:segstate.parent.lisp_coda_glide is 0)
                       ((R:segstate.parent.nn.ph_cplace is l)
                        ((0.753637 -0.418862))
                        ((R:segstate.parent.R:SylStructure.parent.asyl_out
                          <
                          2.2)
                         ((R:segstate.parent.R:SylStructure.parent.last_accent
                           <
                           1.4)
                          ((1.12163 0.0603663))
                          ((0.628138 -0.225725)))
                         ((0.592989 -0.324379))))
                       ((0.670002 -0.497405)))
                      ((R:segstate.parent.R:SylStructure.parent.syl_out
                        <
                        4.4)
                       ((0.508784 -0.364723))
                       ((0.597835 -0.533476))))))
                   ((R:segstate.parent.nn.ph_cplace is l)
                    ((0.793433 -0.338737))
                    ((R:segstate.parent.R:SylStructure.parent.syl_in
                      <
                      12)
                     ((0.968019 0.261011))
                     ((1.13155 -0.0335364)))))))
                ((1.1121 0.213858)))
               ((R:segstate.parent.ph_cvox is +)
                ((R:segstate.parent.p.name is ay)
                 ((1.24175 0.238738))
                 ((R:segstate.parent.R:SylStructure.parent.last_accent
                   <
                   3.6)
                  ((R:segstate.parent.ph_ctype is a)
                   ((0.725476 -0.746438))
                   ((R:segstate.parent.nn.ph_cvox is +)
                    ((R:segstate.parent.pp.ph_vheight is 2)
                     ((0.736232 -0.224542))
                     ((R:segstate.parent.ph_ctype is f)
                      ((0.94464 -0.656317))
                      ((R:segstate.parent.R:SylStructure.parent.asyl_in
                        <
                        2.2)
                       ((0.90828 -0.114306))
                       ((R:segstate.parent.R:SylStructure.parent.R:Syllable.pp.accented
                         is
                         0)
                        ((0.69355 -0.37281))
                        ((0.480612 -0.540016))))))
                    ((R:segstate.parent.pp.ph_vlng is s)
                     ((1.11504 0.0514571))
                     ((0.685647 -0.288652)))))
                  ((R:segstate.parent.pp.ph_vheight is 2)
                   ((0.958567 -0.251247))
                   ((R:segstate.parent.R:SylStructure.parent.position_type
                     is
                     initial)
                    ((1.13138 0.124699))
                    ((0.802939 -0.151436))))))
                ((R:segstate.parent.R:SylStructure.parent.ssyl_in
                  <
                  7.2)
                 ((R:segstate.parent.n.ph_vheight is 2)
                  ((R:segstate.parent.R:SylStructure.parent.R:Syllable.n.syl_onsetsize
                    <
                    1.1)
                   ((R:segstate.parent.p.ph_ctype is 0)
                    ((0.958388 0.389509))
                    ((R:segstate.parent.pp.ph_vlng is a)
                     ((0.610825 0.270921))
                     ((R:segstate.parent.R:SylStructure.parent.asyl_in
                       <
                       2.5)
                      ((R:segstate.parent.R:SylStructure.parent.syl_out
                        <
                        4.6)
                       ((0.804422 0.283951))
                       ((1.14081 -0.106575)))
                      ((R:segstate.parent.R:SylStructure.parent.syl_in
                        <
                        10)
                       ((0.698206 -0.215942))
                       ((0.89783 -0.122867))))))
                   ((0.783403 0.464142)))
                  ((R:segstate.parent.nn.ph_cvox is +)
                   ((R:segstate.parent.pp.ph_vheight is 3)
                    ((R:segstate.parent.R:SylStructure.parent.R:Syllable.nn.lisp_cg_break
                      <
                      0.3)
                     ((0.794634 -0.083817))
                     ((0.844896 0.223277)))
                    ((R:segstate.parent.R:SylStructure.parent.R:Syllable.p.accented
                      is
                      0)
                     ((R:segstate.parent.R:SylStructure.parent.parent.word_numsyls
                       <
                       3.5)
                      ((R:segstate.parent.n.ph_vlng is l)
                       ((0.925439 -0.292275))
                       ((R:segstate.parent.R:SylStructure.parent.ssyl_in
                         <
                         3.4)
                        ((0.666809 -0.257746))
                        ((R:segstate.parent.R:SylStructure.parent.asyl_in
                          <
                          2.5)
                         ((0.970766 0.120191))
                         ((R:segstate.parent.R:SylStructure.parent.ssyl_in
                           <
                           5.2)
                          ((0.630679 -0.23607))
                          ((1.24679 -0.0375569))))))
                      ((0.713347 -0.34573)))
                     ((0.728563 -0.440076))))
                   ((R:segstate.parent.R:SylStructure.parent.R:Syllable.n.syl_onsetsize
                     <
                     1.2)
                    ((R:segstate.parent.pp.ph_cvox is +)
                     ((R:segstate.parent.R:SylStructure.parent.R:Syllable.nn.lisp_cg_break
                       <
                       0.1)
                      ((0.91874 0.155288))
                      ((0.488002 -0.393412)))
                     ((R:segstate.parent.R:SylStructure.parent.R:Syllable.n.accented
                       is
                       0)
                      ((R:segstate.parent.nn.ph_cplace is a)
                       ((0.905701 0.261332))
                       ((0.592621 -0.0907552)))
                      ((1.4872 0.539263))))
                    ((0.46687 -0.250192)))))
                 ((R:segstate.parent.R:SylStructure.parent.syl_codasize
                   <
                   1.1)
                  ((0.57327 -0.128875))
                  ((R:segstate.parent.n.ph_ctype is 0)
                   ((0.622867 -0.298187))
                   ((0.479948 -0.560961))))))))
             ((R:segstate.parent.R:SylStructure.parent.R:Syllable.p.syl_codasize
               <
               1.2)
              ((R:segstate.parent.n.ph_vlng is s)
               ((1.22526 0.723109))
               ((R:segstate.parent.R:SylStructure.parent.ssyl_in < 5.4)
                ((0.773791 -0.0671411))
                ((1.00472 0.303866))))
              ((R:segstate.parent.R:SylStructure.parent.next_accent
                <
                4.8)
               ((R:segstate.parent.ph_ctype is l)
                ((R:segstate.parent.R:SylStructure.parent.R:Syllable.n.accented
                  is
                  0)
                 ((0.81758 -0.0820504))
                 ((R:segstate.parent.R:SylStructure.parent.R:Syllable.nn.stress
                   is
                   0)
                  ((0.437915 -0.429311))
                  ((0.525229 -0.311168))))
                ((R:segstate.parent.R:SylStructure.parent.R:Syllable.nn.accented
                  is
                  0)
                 ((R:segstate.parent.R:SylStructure.parent.R:Syllable.n.lisp_cg_break
                   <
                   1.2)
                  ((R:segstate.parent.n.ph_vheight is 1)
                   ((R:segstate.parent.pp.ph_vlng is s)
                    ((1.10553 0.160407))
                    ((1.59568 0.645983)))
                   ((R:segstate.parent.R:SylStructure.parent.next_accent
                     <
                     2.4)
                    ((0.837155 -0.00314134))
                    ((1.03339 0.325735))))
                  ((R:segstate.parent.R:SylStructure.parent.syl_in
                    <
                    12.8)
                   ((R:segstate.parent.n.ph_vheight is 2)
                    ((0.724086 -0.052933))
                    ((0.639749 -0.139882)))
                   ((1.28594 0.24467))))
                 ((R:segstate.parent.R:SylStructure.parent.syl_out
                   <
                   3.8)
                  ((0.677251 -0.406295))
                  ((0.837092 0.0662631)))))
               ((0.548721 -0.582207)))))
            ((R:segstate.parent.n.ph_ctype is 0)
             ((R:segstate.parent.p.ph_ctype is n)
              ((R:segstate.parent.ph_cvox is +)
               ((R:segstate.parent.ph_ctype is f)
                ((R:segstate.parent.n.ph_vlng is s)
                 ((R:segstate.parent.n.ph_vheight is 2)
                  ((0.16431 -0.597807))
                  ((1.12012 -0.253186)))
                 ((R:segstate.parent.R:SylStructure.parent.R:Syllable.n.accented
                   is
                   0)
                  ((R:segstate.parent.R:SylStructure.parent.ssyl_in
                    <
                    5.5)
                   ((0.439819 -0.466231))
                   ((0.116724 -0.654645)))
                  ((R:segstate.parent.R:SylStructure.parent.ssyl_out
                    <
                    2.4)
                   ((R:segstate.parent.p.name is n)
                    ((R:segstate.parent.R:SylStructure.parent.R:Syllable.nn.accented
                      is
                      0)
                     ((0.0711567 -0.685538))
                     ((0.0725144 -0.703894)))
                    ((0.124394 -0.657108)))
                   ((R:segstate.parent.R:SylStructure.parent.syl_in
                     <
                     7.1)
                    ((0.131366 -0.616226))
                    ((0.09498 -0.678628))))))
                ((R:segstate.parent.p.name is ng)
                 ((R:segstate.parent.R:SylStructure.parent.R:Syllable.nn.stress
                   is
                   0)
                  ((0.455648 -0.590633))
                  ((0.654828 -0.445465)))
                 ((R:segstate.parent.nn.ph_cvox is +)
                  ((R:segstate.parent.R:SylStructure.parent.R:Syllable.pp.lisp_cg_break
                    <
                    0.1)
                   ((0.841458 -0.197328))
                   ((R:segstate.parent.R:SylStructure.parent.R:Syllable.n.accented
                     is
                     0)
                    ((0.503417 -0.510836))
                    ((0.690273 -0.382118))))
                  ((1.15893 0.096008)))))
               ((R:segstate.parent.R:SylStructure.parent.parent.gpos
                 is
                 content)
                ((R:segstate.parent.R:SylStructure.parent.ssyl_in
                  <
                  3.7)
                 ((0.733058 -0.404876))
                 ((R:segstate.parent.n.ph_vheight is 2)
                  ((0.794981 -0.00978685))
                  ((0.735073 -0.245739))))
                ((R:segstate.parent.R:SylStructure.parent.R:Syllable.pp.accented
                  is
                  0)
                 ((0.882883 0.217613))
                 ((0.676881 0.00385467)))))
              ((R:segstate.parent.R:SylStructure.parent.parent.gpos
                is
                pps)
               ((R:segstate.parent.R:SylStructure.parent.last_accent
                 <
                 5)
                ((R:segstate.parent.pp.ph_vheight is 2)
                 ((0.378451 -0.412057))
                 ((R:segstate.parent.p.ph_cvox is +)
                  ((R:segstate.parent.R:SylStructure.parent.ssyl_in
                    <
                    5.5)
                   ((0.305373 -0.511338))
                   ((0.187264 -0.63713)))
                  ((0.156082 -0.690892))))
                ((0.629083 -0.221301)))
               ((R:segstate.parent.p.name is dh)
                ((1.64989 0.443675))
                ((R:segstate.parent.p.ph_vc is +)
                 ((R:segstate.parent.ph_ctype is n)
                  ((0.556875 -0.470024))
                  ((R:segstate.parent.R:SylStructure.parent.asyl_in
                    <
                    3.6)
                   ((R:segstate.parent.R:SylStructure.parent.R:Syllable.n.lisp_cg_break
                     <
                     0.3)
                    ((1.23038 0.74023))
                    ((R:segstate.parent.ph_cvox is +)
                     ((0.799092 -0.0928437))
                     ((0.858457 0.321231))))
                   ((0.607328 -0.224354))))
                 ((R:segstate.parent.pp.ph_vc is +)
                  ((R:segstate.parent.p.name is s)
                   ((1.51715 0.388301))
                   ((R:segstate.parent.p.name is r)
                    ((R:segstate.parent.R:SylStructure.parent.R:Syllable.nn.stress
                      is
                      0)
                     ((R:segstate.parent.R:SylStructure.parent.asyl_in
                       <
                       1.2)
                      ((1.47384 0.224911))
                      ((0.926818 0.170162)))
                     ((R:segstate.parent.R:SylStructure.parent.last_accent
                       <
                       1.2)
                      ((1.01283 0.111707))
                      ((0.702607 -0.312834))))
                    ((R:segstate.parent.R:SylStructure.parent.asyl_out
                      <
                      3.6)
                     ((R:segstate.parent.R:SylStructure.parent.ssyl_out
                       <
                       5.2)
                      ((R:segstate.parent.R:SylStructure.parent.parent.gpos
                        is
                        content)
                       ((R:segstate.parent.R:SylStructure.parent.syl_out
                         <
                         4)
                        ((R:segstate.parent.p.ph_ctype is s)
                         ((R:segstate.parent.R:SylStructure.parent.syl_in
                           <
                           6.2)
                          ((0.967604 0.253328))
                          ((R:segstate.parent.lisp_coda_stop is 0)
                           ((0.678763 0.0670288))
                           ((0.712618 -0.225329))))
                         ((R:segstate.parent.n.ph_vheight is 2)
                          ((R:segstate.parent.ph_ctype is f)
                           ((0.697523 0.0666331))
                           ((0.596094 -0.222227)))
                          ((R:segstate.parent.ph_ctype is f)
                           ((0.564612 -0.262649))
                           ((0.432883 -0.483905)))))
                        ((R:segstate.parent.R:SylStructure.parent.syl_codasize
                          <
                          2.2)
                         ((R:segstate.parent.ph_ctype is n)
                          ((0.555713 -0.50549))
                          ((R:segstate.parent.R:SylStructure.parent.R:Syllable.n.accented
                            is
                            0)
                           ((R:segstate.parent.R:SylStructure.parent.ssyl_in
                             <
                             3.3)
                            ((R:segstate.parent.R:SylStructure.parent.syl_out
                              <
                              5.2)
                             ((0.899423 0.0213399))
                             ((0.477484 -0.262323)))
                            ((R:segstate.parent.p.ph_ctype is f)
                             ((0.693604 -0.160783))
                             ((R:segstate.parent.n.ph_vheight is 1)
                              ((0.302868 -0.549881))
                              ((0.546192 -0.311951)))))
                           ((R:segstate.parent.R:SylStructure.parent.asyl_out
                             <
                             2.1)
                            ((0.217446 -0.518201))
                            ((0.543315 -0.346021)))))
                         ((0.786593 -0.0924489))))
                       ((R:segstate.parent.nn.ph_cplace is a)
                        ((R:segstate.parent.pp.ph_vheight is 2)
                         ((R:segstate.parent.R:SylStructure.parent.R:Syllable.n.syl_onsetsize
                           <
                           1.2)
                          ((R:segstate.parent.R:SylStructure.parent.syl_codasize
                            <
                            1.1)
                           ((0.549807 -0.258934))
                           ((R:segstate.parent.R:SylStructure.parent.R:Syllable.nn.lisp_cg_break
                             <
                             0.3)
                            ((1.09642 0.267013))
                            ((0.766881 -0.196694))))
                          ((0.389294 -0.458183)))
                         ((R:segstate.parent.R:SylStructure.parent.asyl_in
                           <
                           1.5)
                          ((1.40565 0.584808))
                          ((R:segstate.parent.R:SylStructure.parent.asyl_out
                            <
                            1.2)
                           ((0.905466 -0.210671))
                           ((0.986678 0.210595)))))
                        ((R:segstate.parent.p.name is t)
                         ((R:segstate.parent.R:SylStructure.parent.asyl_in
                           <
                           2.5)
                          ((0.255404 -0.554453))
                          ((0.402166 -0.380128)))
                         ((R:segstate.parent.R:SylStructure.parent.asyl_in
                           <
                           3.5)
                          ((R:segstate.parent.p.name is v)
                           ((0.533189 -0.274271))
                           ((R:segstate.parent.n.ph_vlng is a)
                            ((1.04169 0.22711))
                            ((0.95957 -0.181118))))
                          ((0.629674 -0.306764))))))
                      ((1.16404 0.213398)))
                     ((R:segstate.parent.R:SylStructure.parent.R:Syllable.p.accented
                       is
                       0)
                      ((R:segstate.parent.nn.ph_cvox is +)
                       ((R:segstate.parent.n.ph_vlng is a)
                        ((0.243438 -0.546661))
                        ((R:segstate.parent.R:SylStructure.parent.R:Syllable.n.accented
                          is
                          0)
                         ((0.564023 -0.377912))
                         ((0.79687 -0.154752))))
                       ((R:segstate.parent.R:SylStructure.parent.asyl_in
                         <
                         1.2)
                        ((1.03491 -0.0426544))
                        ((0.735862 -0.142886))))
                      ((0.388171 -0.637921))))))
                  ((R:segstate.parent.R:SylStructure.parent.ssyl_in
                    <
                    6.5)
                   ((R:segstate.parent.nn.ph_cplace is v)
                    ((R:segstate.parent.R:SylStructure.parent.last_accent
                      <
                      1.4)
                     ((0.760028 -0.688213))
                     ((0.603321 -0.345456)))
                    ((R:segstate.parent.R:SylStructure.parent.syl_out
                      <
                      7.8)
                     ((R:segstate.parent.R:SylStructure.parent.R:Syllable.pp.accented
                       is
                       0)
                      ((R:segstate.parent.ph_ctype is f)
                       ((R:segstate.parent.R:SylStructure.parent.syl_in
                         <
                         9.6)
                        ((R:segstate.parent.R:SylStructure.parent.syl_in
                          <
                          8.5)
                         ((R:segstate.parent.p.ph_ctype is s)
                          ((1.0926 0.179336))
                          ((R:segstate.parent.R:SylStructure.parent.R:Syllable.pp.lisp_cg_break
                            <
                            0.1)
                           ((0.968222 0.224441))
                           ((R:segstate.parent.ph_cvox is +)
                            ((1.03036 -0.0539662))
                            ((0.631445 -0.437918)))))
                         ((0.690159 -0.367398)))
                        ((0.858047 0.243471)))
                       ((R:segstate.parent.pp.ph_cplace is a)
                        ((R:segstate.parent.R:SylStructure.parent.syl_in
                          <
                          6.4)
                         ((1.00086 -0.272875))
                         ((R:segstate.parent.n.ph_vlng is l)
                          ((1.04008 0.0837935))
                          ((0.829996 -0.150146))))
                        ((R:segstate.parent.R:SylStructure.parent.R:Syllable.n.accented
                          is
                          0)
                         ((0.847408 -0.356308))
                         ((0.653301 -0.432061)))))
                      ((R:segstate.parent.R:SylStructure.parent.ssyl_in
                        <
                        3.3)
                       ((R:segstate.parent.R:SylStructure.parent.syl_out
                         <
                         4.5)
                        ((0.623051 -0.307593))
                        ((1.83684 0.377413)))
                       ((R:segstate.parent.p.ph_ctype is s)
                        ((R:segstate.parent.n.ph_vlng is l)
                         ((0.701594 -0.209848))
                         ((0.579063 -0.4223)))
                        ((R:segstate.parent.R:SylStructure.parent.syl_out
                          <
                          5.2)
                         ((0.318504 -0.658133))
                         ((0.538064 -0.361816))))))
                     ((R:segstate.parent.R:SylStructure.parent.R:Syllable.pp.lisp_cg_break
                       <
                       0.1)
                      ((R:segstate.parent.R:SylStructure.parent.R:Syllable.p.stress
                        is
                        0)
                       ((0.707617 -0.337192))
                       ((1.10393 0.172695)))
                      ((R:segstate.parent.R:SylStructure.parent.last_accent
                        <
                        1.5)
                       ((R:segstate.parent.n.ph_vheight is 2)
                        ((0.331218 -0.67925))
                        ((R:segstate.parent.R:SylStructure.parent.ssyl_out
                          <
                          5.5)
                         ((0.697609 -0.323575))
                         ((0.565223 -0.631042))))
                       ((0.71868 -0.254696))))))
                   ((R:segstate.parent.n.ph_vheight is 1)
                    ((0.312564 -0.78082))
                    ((R:segstate.parent.R:SylStructure.parent.asyl_out
                      <
                      2.5)
                     ((R:segstate.parent.R:SylStructure.parent.asyl_in
                       <
                       4)
                      ((0.465265 -0.336098))
                      ((1.01589 -0.0101173)))
                     ((0.403218 -0.638235))))))))))
             ((R:segstate.parent.p.name is n)
              ((R:segstate.parent.R:SylStructure.parent.R:Syllable.n.lisp_cg_break
                <
                0.3)
               ((1.39092 0.48875))
               ((R:segstate.parent.R:SylStructure.parent.R:Syllable.pp.lisp_cg_break
                 <
                 0.1)
                ((1.00213 0.24706))
                ((R:segstate.parent.R:SylStructure.parent.syl_codasize
                  <
                  1.2)
                 ((1.25395 0.0614039))
                 ((0.974625 -0.265452)))))
              ((R:segstate.parent.R:SylStructure.parent.parent.gpos
                is
                content)
               ((R:segstate.parent.R:SylStructure.parent.stress is 0)
                ((R:segstate.parent.R:SylStructure.parent.syl_onsetsize
                  <
                  0.3)
                 ((0.243579 -0.595869))
                 ((0.715887 0.0679193)))
                ((R:segstate.parent.p.ph_cplace is a)
                 ((R:segstate.parent.R:SylStructure.parent.ssyl_out
                   <
                   2.5)
                  ((R:segstate.parent.R:SylStructure.parent.asyl_in
                    <
                    2.4)
                   ((0.650305 -0.690595))
                   ((0.710102 -0.111525)))
                  ((R:segstate.parent.R:SylStructure.parent.R:Syllable.p.syl_codasize
                    <
                    2.1)
                   ((1.39164 0.441581))
                   ((0.886637 0.0706539))))
                 ((R:segstate.parent.nn.ph_cvox is +)
                  ((1.12869 0.163904))
                  ((R:segstate.parent.ph_vheight is 3)
                   ((1.04649 0.360837))
                   ((1.125 0.870313))))))
               ((R:segstate.parent.R:SylStructure.parent.syl_in < 13)
                ((R:segstate.parent.lisp_coda_glide is 0)
                 ((R:segstate.parent.ph_vheight is 2)
                  ((R:segstate.parent.lisp_coda_fric is 0)
                   ((R:segstate.parent.R:SylStructure.parent.R:Syllable.pp.accented
                     is
                     0)
                    ((0.347293 -0.256765))
                    ((R:segstate.parent.n.ph_ctype is f)
                     ((0.903966 0.283468))
                     ((0.823989 -0.0112095))))
                   ((R:segstate.parent.p.ph_cplace is a)
                    ((R:segstate.parent.R:SylStructure.parent.R:Syllable.n.accented
                      is
                      0)
                     ((R:segstate.parent.R:SylStructure.parent.syl_in
                       <
                       7.5)
                      ((0.564227 -0.378308))
                      ((0.247599 -0.658812)))
                     ((R:segstate.parent.pp.ph_cplace is a)
                      ((0.212319 -0.666931))
                      ((0.182177 -0.705936))))
                    ((R:segstate.parent.pp.ph_cvox is -)
                     ((0.361643 -0.559677))
                     ((R:segstate.parent.R:SylStructure.parent.R:Syllable.nn.lisp_cg_break
                       <
                       0.3)
                      ((0.360811 -0.354749))
                      ((0.591199 -0.128733))))))
                  ((R:segstate.parent.R:SylStructure.parent.last_accent
                    <
                    4.2)
                   ((R:segstate.parent.lisp_coda_fric is 0)
                    ((R:segstate.parent.p.ph_ctype is s)
                     ((R:segstate.parent.R:SylStructure.parent.R:Syllable.pp.lisp_cg_break
                       <
                       0.1)
                      ((1.09848 0.244341))
                      ((R:segstate.parent.pp.ph_cplace is a)
                       ((0.46622 -0.273561))
                       ((0.824575 0.0606307))))
                     ((R:segstate.parent.ph_vfront is 1)
                      ((R:segstate.parent.R:SylStructure.parent.asyl_in
                        <
                        2.4)
                       ((R:segstate.parent.R:SylStructure.parent.R:Syllable.p.syl_codasize
                         <
                         1.3)
                        ((1.09092 0.151559))
                        ((R:segstate.parent.R:SylStructure.parent.ssyl_out
                          <
                          1.7)
                         ((0.382698 -0.427237))
                         ((R:segstate.parent.R:SylStructure.parent.R:Syllable.p.accented
                           is
                           0)
                          ((0.522409 -0.384286))
                          ((R:segstate.parent.R:SylStructure.parent.R:Syllable.n.accented
                            is
                            0)
                           ((R:segstate.parent.R:SylStructure.parent.syl_in
                             <
                             6.1)
                            ((0.677233 0.0395188))
                            ((0.593714 -0.150606)))
                           ((R:segstate.parent.R:SylStructure.parent.syl_out
                             <
                             6)
                            ((0.786931 -0.187831))
                            ((0.430781 -0.343383)))))))
                       ((R:segstate.parent.R:SylStructure.parent.asyl_out
                         <
                         2.5)
                        ((R:segstate.parent.R:SylStructure.parent.syl_out
                          <
                          4.6)
                         ((R:segstate.parent.R:SylStructure.parent.R:Syllable.p.accented
                           is
                           0)
                          ((0.668342 -0.154923))
                          ((R:segstate.parent.R:SylStructure.parent.ssyl_in
                            <
                            4.2)
                           ((0.402407 -0.320476))
                           ((R:segstate.parent.nn.ph_cplace is a)
                            ((R:segstate.parent.R:SylStructure.parent.R:Syllable.nn.lisp_cg_break
                              <
                              0.3)
                             ((0.309901 -0.484479))
                             ((0.377253 -0.564938)))
                            ((0.455829 -0.41518)))))
                         ((0.259456 -0.562499)))
                        ((R:segstate.parent.R:SylStructure.parent.R:Syllable.n.lisp_cg_break
                          <
                          0.1)
                         ((0.412607 -0.43159))
                         ((R:segstate.parent.R:SylStructure.parent.syl_out
                           <
                           6.4)
                          ((0.440389 -0.322998))
                          ((0.998938 0.0400667))))))
                      ((R:segstate.parent.R:SylStructure.parent.R:Syllable.nn.lisp_cg_break
                        <
                        0.3)
                       ((R:segstate.parent.R:SylStructure.parent.R:Syllable.pp.lisp_cg_break
                         <
                         0.1)
                        ((1.378 0.385023))
                        ((0.665649 -0.0627822)))
                       ((R:segstate.parent.R:SylStructure.parent.ssyl_out
                         <
                         2.5)
                        ((0.767153 -0.00158539))
                        ((0.560883 -0.414797))))))
                    ((R:segstate.parent.R:SylStructure.parent.asyl_out
                      <
                      3)
                     ((R:segstate.parent.ph_vheight is 1)
                      ((1.00011 0.327675))
                      ((0.559729 -0.0587478)))
                     ((0.579995 -0.231021))))
                   ((0.962895 0.361233))))
                 ((R:segstate.parent.p.name is pau)
                  ((0.648977 -0.358498))
                  ((0.388604 -0.726939))))
                ((R:segstate.parent.R:SylStructure.parent.asyl_in
                  <
                  3.2)
                 ((0.519301 -0.313291))
                 ((R:segstate.parent.R:SylStructure.parent.ssyl_out
                   <
                   1.2)
                  ((R:segstate.parent.lisp_coda_fric is 0)
                   ((0.621055 -0.273236))
                   ((0.935538 0.163909)))
                  ((2.8123 0.942921)))))))))))
         ((R:segstate.parent.lisp_onset_glide is 0)
          ((R:segstate.parent.R:SylStructure.parent.parent.gpos
            is
            content)
           ((R:segstate.parent.n.ph_ctype is l)
            ((R:segstate.parent.p.name is hh)
             ((0.241388 -0.781695))
             ((R:segstate.parent.lisp_coda_fric is 0)
              ((R:segstate.parent.R:SylStructure.parent.stress is 0)
               ((R:segstate.parent.pp.ph_vheight is 3)
                ((0.703874 -0.202687))
                ((R:segstate.parent.p.ph_cvox is +)
                 ((R:segstate.parent.R:SylStructure.parent.position_type
                   is
                   initial)
                  ((0.190282 -0.664296))
                  ((R:segstate.parent.R:SylStructure.parent.syl_in
                    <
                    6.6)
                   ((0.168281 -0.579759))
                   ((R:segstate.parent.R:SylStructure.parent.ssyl_in
                     <
                     6.5)
                    ((0.288116 -0.472347))
                    ((R:segstate.parent.pp.ph_vlng is l)
                     ((0.18056 -0.512326))
                     ((0.130208 -0.556555))))))
                 ((R:segstate.parent.p.ph_ctype is f)
                  ((R:segstate.parent.R:SylStructure.parent.ssyl_out
                    <
                    1.6)
                   ((0.246546 -0.447345))
                   ((0.135603 -0.558833)))
                  ((R:segstate.parent.R:SylStructure.parent.R:Syllable.p.accented
                    is
                    0)
                   ((0.447763 -0.233962))
                   ((R:segstate.parent.R:SylStructure.parent.syl_in
                     <
                     8.6)
                    ((0.30266 -0.376728))
                    ((0.215964 -0.469309)))))))
               ((R:segstate.parent.p.name is f)
                ((R:segstate.parent.R:SylStructure.parent.R:Syllable.nn.stress
                  is
                  0)
                 ((R:segstate.parent.nn.ph_vlng is a)
                  ((0.174083 -0.560727))
                  ((0.717581 -0.270022)))
                 ((0.337045 -0.647347)))
                ((R:segstate.parent.R:SylStructure.parent.syl_codasize
                  <
                  1.2)
                 ((R:segstate.parent.nn.ph_vfront is 2)
                  ((R:segstate.parent.p.ph_cplace is l)
                   ((0.630514 -0.598127))
                   ((R:segstate.parent.pp.ph_vc is +)
                    ((0.681009 -0.0380854))
                    ((R:segstate.parent.R:SylStructure.parent.asyl_out
                      <
                      1.5)
                     ((0.644335 -0.394882))
                     ((0.595974 -0.18052)))))
                  ((0.80683 0.0244023)))
                 ((R:segstate.parent.lisp_onset_stop is 0)
                  ((R:segstate.parent.R:SylStructure.parent.last_accent
                    <
                    3.6)
                   ((R:segstate.parent.R:SylStructure.parent.lisp_cg_break
                     <
                     0.1)
                    ((0.507949 -0.391781))
                    ((1.16428 0.14447)))
                   ((0.475168 -0.53693)))
                  ((R:segstate.parent.R:SylStructure.parent.ssyl_in
                    <
                    4.4)
                   ((0.212541 -0.751795))
                   ((0.543207 -0.414679)))))))
              ((R:segstate.parent.p.ph_cvox is -)
               ((R:segstate.parent.pp.ph_vlng is a)
                ((0.566785 -0.0529731))
                ((0.283602 -0.488863)))
               ((1.06204 0.246196)))))
            ((R:segstate.parent.ph_ctype is 0)
             ((R:segstate.parent.lisp_coda_stop is 0)
              ((R:segstate.parent.p.name is g)
               ((R:segstate.parent.R:SylStructure.parent.asyl_in < 1.5)
                ((1.10726 0.747853))
                ((R:segstate.parent.R:SylStructure.parent.ssyl_in
                  <
                  5.1)
                 ((R:segstate.parent.pp.ph_vlng is s)
                  ((0.893079 0.187672))
                  ((0.830323 0.397781)))
                 ((R:segstate.parent.ph_vheight is 2)
                  ((0.755561 0.0182571))
                  ((0.913697 0.151627)))))
               ((R:segstate.parent.lisp_coda_fric is 0)
                ((R:segstate.parent.R:SylStructure.parent.stress is 0)
                 ((R:segstate.parent.R:SylStructure.parent.R:Syllable.n.lisp_cg_break
                   <
                   0.3)
                  ((R:segstate.parent.R:SylStructure.parent.R:Syllable.p.syl_codasize
                    <
                    1.2)
                   ((R:segstate.parent.p.ph_ctype is n)
                    ((0.766787 0.0311192))
                    ((R:segstate.parent.p.ph_cplace is b)
                     ((0.646998 -0.0281817))
                     ((R:segstate.parent.R:SylStructure.parent.R:Syllable.nn.stress
                       is
                       0)
                      ((R:segstate.parent.n.ph_ctype is f)
                       ((0.490371 -0.170313))
                       ((R:segstate.parent.R:SylStructure.parent.ssyl_out
                         <
                         1.4)
                        ((R:segstate.parent.R:SylStructure.parent.position_type
                          is
                          final)
                         ((0.256567 -0.557655))
                         ((0.364348 -0.435239)))
                        ((R:segstate.parent.lisp_onset_fric is 0)
                         ((0.402952 -0.38338))
                         ((0.416297 -0.26192)))))
                      ((R:segstate.parent.R:SylStructure.parent.R:Syllable.p.accented
                        is
                        0)
                       ((0.394502 -0.332562))
                       ((0.537904 -0.0346026))))))
                   ((R:segstate.parent.ph_vheight is 3)
                    ((R:segstate.parent.R:SylStructure.parent.syl_codasize
                      <
                      1.1)
                     ((0.488937 -0.875824))
                     ((0.530536 -0.433354)))
                    ((R:segstate.parent.p.ph_cplace is l)
                     ((0.707253 -0.112064))
                     ((R:segstate.parent.nn.ph_vlng is d)
                      ((0.151895 -0.513937))
                      ((R:segstate.parent.nn.ph_vlng is s)
                       ((R:segstate.parent.R:SylStructure.parent.R:Syllable.nn.accented
                         is
                         0)
                        ((0.248819 -0.469958))
                        ((0.262784 -0.351731)))
                       ((R:segstate.parent.ph_vheight is 1)
                        ((0.43326 -0.160598))
                        ((R:segstate.parent.nn.ph_cvox is -)
                         ((0.319478 -0.471913))
                         ((0.358922 -0.221064)))))))))
                  ((R:segstate.parent.ph_vfront is 1)
                   ((R:segstate.parent.n.ph_ctype is n)
                    ((R:segstate.parent.p.name is n)
                     ((0.231216 -0.600342))
                     ((R:segstate.parent.pp.ph_vheight is 1)
                      ((0.587081 -0.191627))
                      ((R:segstate.parent.R:SylStructure.parent.ssyl_out
                        <
                        5.6)
                       ((R:segstate.parent.R:SylStructure.parent.ssyl_in
                         <
                         4.8)
                        ((R:segstate.parent.R:SylStructure.parent.R:Syllable.nn.lisp_cg_break
                          <
                          0.3)
                         ((0.603376 -0.0945764))
                         ((R:segstate.parent.nn.ph_cplace is a)
                          ((0.277686 -0.54429))
                          ((0.576059 -0.261261))))
                        ((R:segstate.parent.pp.ph_vlng is d)
                         ((0.266892 -0.526773))
                         ((0.420389 -0.367173))))
                       ((0.408135 -0.552469)))))
                    ((R:segstate.parent.nn.ph_vrnd is -)
                     ((R:segstate.parent.n.ph_ctype is s)
                      ((R:segstate.parent.R:SylStructure.parent.asyl_out
                        <
                        2.5)
                       ((R:segstate.parent.nn.ph_vlng is s)
                        ((1.26384 0.208411))
                        ((0.624559 -0.154524)))
                       ((0.521924 -0.222279)))
                      ((R:segstate.parent.R:SylStructure.parent.ssyl_in
                        <
                        4.6)
                       ((0.481813 -0.209877))
                       ((0.37175 -0.430854))))
                     ((R:segstate.parent.n.ph_ctype is s)
                      ((0.53008 -0.156909))
                      ((R:segstate.parent.nn.ph_cvox is +)
                       ((1.44007 0.492734))
                       ((0.604084 -0.046054))))))
                   ((R:segstate.parent.n.ph_ctype is r)
                    ((0.632346 -0.377866))
                    ((R:segstate.parent.n.ph_ctype is n)
                     ((R:segstate.parent.R:SylStructure.parent.position_type
                       is
                       final)
                      ((R:segstate.parent.pp.ph_vheight is 3)
                       ((0.472083 -0.313424))
                       ((R:segstate.parent.pp.ph_cvox is -)
                        ((0.520282 -0.169869))
                        ((R:segstate.parent.R:SylStructure.parent.ssyl_in
                          <
                          4.4)
                         ((R:segstate.parent.p.ph_cvox is +)
                          ((0.784955 0.0390036))
                          ((0.782384 0.326578)))
                         ((R:segstate.parent.R:SylStructure.parent.syl_out
                           <
                           3.4)
                          ((0.553575 0.109736))
                          ((0.51835 -0.0646593))))))
                      ((R:segstate.parent.pp.ph_vlng is s)
                       ((0.734711 0.0567224))
                       ((R:segstate.parent.R:SylStructure.parent.ssyl_in
                         <
                         4.8)
                        ((0.33348 -0.388254))
                        ((R:segstate.parent.p.ph_cvox is +)
                         ((0.447469 -0.082844))
                         ((0.442281 -0.2792))))))
                     ((R:segstate.parent.p.ph_ctype is s)
                      ((R:segstate.parent.R:SylStructure.parent.parent.word_numsyls
                        <
                        3.2)
                       ((R:segstate.parent.R:SylStructure.parent.R:Syllable.p.syl_codasize
                         <
                         1.1)
                        ((1.25067 0.677265))
                        ((R:segstate.parent.pp.ph_cplace is a)
                         ((0.468921 -0.131923))
                         ((0.945598 0.324979))))
                       ((0.662821 -0.0120605)))
                      ((R:segstate.parent.R:SylStructure.parent.syl_out
                        <
                        7.5)
                       ((R:segstate.parent.R:SylStructure.parent.ssyl_out
                         <
                         2.4)
                        ((R:segstate.parent.n.ph_ctype is f)
                         ((0.611294 0.0499788))
                         ((R:segstate.parent.R:SylStructure.parent.syl_in
                           <
                           9.4)
                          ((0.69754 -0.0257291))
                          ((0.327967 -0.277783))))
                        ((0.826832 0.285268)))
                       ((0.624516 -0.162647))))))))
                 ((R:segstate.parent.pp.ph_vc is +)
                  ((R:segstate.parent.nn.ph_cplace is p)
                   ((R:segstate.parent.R:SylStructure.parent.R:Syllable.nn.stress
                     is
                     0)
                    ((1.73327 0.932367))
                    ((0.759433 0.0772369)))
                   ((R:segstate.parent.nn.ph_cplace is v)
                    ((0.807637 -0.363441))
                    ((R:segstate.parent.R:SylStructure.parent.R:Syllable.nn.accented
                      is
                      0)
                     ((R:segstate.parent.R:SylStructure.parent.R:Syllable.p.accented
                       is
                       0)
                      ((R:segstate.parent.p.name is b)
                       ((1.16566 0.275784))
                       ((R:segstate.parent.R:SylStructure.parent.R:Syllable.p.lisp_cg_break
                         <
                         0.1)
                        ((R:segstate.parent.p.name is n)
                         ((0.950665 -0.523907))
                         ((R:segstate.parent.n.ph_ctype is s)
                          ((0.734853 0.176577))
                          ((R:segstate.parent.ph_vfront is 1)
                           ((R:segstate.parent.R:SylStructure.parent.syl_out
                             <
                             2.3)
                            ((R:segstate.parent.n.ph_ctype is f)
                             ((0.591367 -0.0872362))
                             ((0.90317 0.212181)))
                            ((R:segstate.parent.R:SylStructure.parent.syl_codasize
                              <
                              1.1)
                             ((R:segstate.parent.R:SylStructure.parent.ssyl_in
                               <
                               4.6)
                              ((0.656303 0.00470999))
                              ((0.547822 -0.16775)))
                             ((0.403733 -0.290506))))
                           ((0.602913 -0.293881)))))
                        ((R:segstate.parent.lisp_coda_glide is 0)
                         ((R:segstate.parent.ph_vfront is 3)
                          ((R:segstate.parent.R:SylStructure.parent.R:Syllable.pp.accented
                            is
                            0)
                           ((1.08637 0.0945102))
                           ((0.683352 0.419418)))
                          ((R:segstate.parent.nn.ph_vlng is l)
                           ((0.584022 -0.265175))
                           ((R:segstate.parent.R:SylStructure.parent.last_accent
                             <
                             3.7)
                            ((R:segstate.parent.pp.ph_vlng is l)
                             ((0.636105 -0.26217))
                             ((R:segstate.parent.R:SylStructure.parent.syl_out
                               <
                               4.9)
                              ((R:segstate.parent.R:SylStructure.parent.last_accent
                                <
                                2)
                               ((0.724727 0.0185445))
                               ((0.756367 -0.121171)))
                              ((R:segstate.parent.R:SylStructure.parent.asyl_out
                                <
                                3)
                               ((R:segstate.parent.R:SylStructure.parent.syl_out
                                 <
                                 6.2)
                                ((0.940452 0.0693091))
                                ((0.955959 0.267895)))
                               ((0.606739 -0.0605311)))))
                            ((1.19059 0.287475)))))
                         ((0.729386 -0.238346)))))
                      ((1.02171 0.371986)))
                     ((R:segstate.parent.p.name is s)
                      ((R:segstate.parent.ph_vheight is 2)
                       ((0.499467 -0.0551553))
                       ((0.500763 -0.414912)))
                      ((R:segstate.parent.pp.ph_vlng is a)
                       ((R:segstate.parent.ph_vrnd is +)
                        ((0.695562 -0.0499438))
                        ((R:segstate.parent.n.ph_ctype is r)
                         ((1.93329 1.03692))
                         ((R:segstate.parent.ph_vfront is 1)
                          ((1.06655 0.203097))
                          ((1.44854 0.668195)))))
                       ((R:segstate.parent.R:SylStructure.parent.R:Syllable.n.lisp_cg_break
                         <
                         0.1)
                        ((R:segstate.parent.p.ph_cvox is +)
                         ((0.759079 0.0158881))
                         ((1.16007 0.389198)))
                        ((R:segstate.parent.R:SylStructure.parent.last_accent
                          <
                          1.4)
                         ((0.534394 -0.382039))
                         ((0.828352 -0.100423)))))))))
                  ((R:segstate.parent.R:SylStructure.parent.position_type
                    is
                    single)
                   ((R:segstate.parent.p.ph_cplace is a)
                    ((R:segstate.parent.nn.ph_vlng is s)
                     ((0.504822 -0.134182))
                     ((R:segstate.parent.p.name is s)
                      ((0.657922 0.0619765))
                      ((R:segstate.parent.nn.ph_cvox is -)
                       ((1.22137 0.46259))
                       ((1.2204 0.339204)))))
                    ((R:segstate.parent.R:SylStructure.parent.syl_codasize
                      <
                      1.2)
                     ((R:segstate.parent.p.name is hh)
                      ((R:segstate.parent.nn.ph_vlng is s)
                       ((R:segstate.parent.pp.ph_cplace is a)
                        ((0.957979 0.0114218))
                        ((0.410254 -0.412921)))
                       ((R:segstate.parent.nn.ph_vlng is l)
                        ((0.680292 -0.324265))
                        ((R:segstate.parent.R:SylStructure.parent.R:Syllable.p.accented
                          is
                          0)
                         ((0.527159 -0.442756))
                         ((0.331378 -0.511473)))))
                      ((R:segstate.parent.R:SylStructure.parent.syl_in
                        <
                        5.4)
                       ((0.432856 -0.327792))
                       ((R:segstate.parent.R:SylStructure.parent.R:Syllable.p.stress
                         is
                         0)
                        ((0.408602 -0.409136))
                        ((R:segstate.parent.pp.ph_cplace is 0)
                         ((0.277396 -0.504727))
                         ((R:segstate.parent.R:SylStructure.parent.R:Syllable.n.accented
                           is
                           0)
                          ((0.315359 -0.670391))
                          ((0.406426 -0.568188)))))))
                     ((R:segstate.parent.p.ph_cplace is l)
                      ((R:segstate.parent.R:SylStructure.parent.syl_out
                        <
                        4.7)
                       ((1.53002 0.539938))
                       ((0.745024 -0.207797)))
                      ((R:segstate.parent.R:SylStructure.parent.R:Syllable.nn.stress
                        is
                        0)
                       ((R:segstate.parent.R:SylStructure.parent.R:Syllable.n.accented
                         is
                         0)
                        ((1.17711 0.0552496))
                        ((0.624473 -0.27976)))
                       ((R:segstate.parent.R:SylStructure.parent.syl_out
                         <
                         4.5)
                        ((0.358191 -0.543254))
                        ((0.364049 -0.34496)))))))
                   ((R:segstate.parent.nn.ph_vrnd is -)
                    ((R:segstate.parent.ph_vfront is 3)
                     ((R:segstate.parent.ph_vheight is 3)
                      ((R:segstate.parent.R:SylStructure.parent.syl_out
                        <
                        3)
                       ((0.942471 0.215364))
                       ((R:segstate.parent.R:SylStructure.parent.R:Syllable.p.stress
                         is
                         0)
                        ((1.08265 0.57642))
                        ((1.02573 0.776733))))
                      ((R:segstate.parent.n.ph_ctype is s)
                       ((0.857604 0.160732))
                       ((0.884096 -0.207197))))
                     ((R:segstate.parent.R:SylStructure.parent.R:Syllable.p.syl_codasize
                       <
                       2)
                      ((R:segstate.parent.ph_vheight is 2)
                       ((R:segstate.parent.R:SylStructure.parent.R:Syllable.nn.lisp_cg_break
                         <
                         0.4)
                        ((R:segstate.parent.p.ph_ctype is s)
                         ((0.642357 -0.0208971))
                         ((R:segstate.parent.n.ph_ctype is f)
                          ((0.584834 0.0241844))
                          ((1.12377 0.391194))))
                        ((R:segstate.parent.pp.ph_cvox is +)
                         ((R:segstate.parent.n.ph_ctype is f)
                          ((0.533142 -0.0875601))
                          ((0.592004 -0.352788)))
                         ((R:segstate.parent.n.ph_ctype is f)
                          ((0.518674 -0.14327))
                          ((1.14728 0.141175)))))
                       ((R:segstate.parent.pp.ph_cvox is +)
                        ((R:segstate.parent.R:SylStructure.parent.last_accent
                          <
                          2.7)
                         ((R:segstate.parent.p.ph_ctype is f)
                          ((0.802666 -0.0780317))
                          ((0.588513 -0.310017)))
                         ((R:segstate.parent.nn.ph_vlng is a)
                          ((0.900195 0.133186))
                          ((0.572361 -0.153306))))
                        ((R:segstate.parent.R:SylStructure.parent.R:Syllable.nn.accented
                          is
                          0)
                         ((R:segstate.parent.p.ph_cplace is a)
                          ((0.474911 -0.423027))
                          ((0.471749 -0.236453)))
                         ((0.479944 -0.0716896)))))
                      ((R:segstate.parent.pp.ph_cvox is +)
                       ((1.13082 0.443524))
                       ((0.888966 -0.0247135)))))
                    ((R:segstate.parent.R:SylStructure.parent.R:Syllable.p.syl_codasize
                      <
                      1.3)
                     ((1.10254 0.214697))
                     ((R:segstate.parent.nn.ph_cplace is v)
                      ((R:segstate.parent.R:SylStructure.parent.syl_out
                        <
                        2.1)
                       ((0.357677 -0.507536))
                       ((0.557484 -0.291495)))
                      ((R:segstate.parent.ph_vheight is 3)
                       ((R:segstate.parent.n.ph_ctype is r)
                        ((R:segstate.parent.p.name is f)
                         ((0.851859 -0.0446148))
                         ((0.796818 -0.362242)))
                        ((R:segstate.parent.R:SylStructure.parent.asyl_in
                          <
                          2.5)
                         ((0.758162 0.255369))
                         ((0.651801 -0.0429179))))
                       ((R:segstate.parent.p.ph_ctype is s)
                        ((R:segstate.parent.R:SylStructure.parent.syl_in
                          <
                          8)
                         ((0.654233 -0.570186))
                         ((R:segstate.parent.R:SylStructure.parent.last_accent
                           <
                           3.6)
                          ((0.571463 -0.152311))
                          ((0.636215 -0.445666))))
                        ((R:segstate.parent.R:SylStructure.parent.parent.word_numsyls
                          <
                          2.2)
                         ((R:segstate.parent.R:SylStructure.parent.next_accent
                           <
                           1.2)
                          ((0.642913 -0.384621))
                          ((0.465342 -0.141443)))
                         ((R:segstate.parent.p.ph_cplace is a)
                          ((0.408976 -0.178547))
                          ((0.772999 0.152494))))))))))))
                ((R:segstate.parent.R:SylStructure.parent.R:Syllable.p.syl_codasize
                  <
                  1.3)
                 ((R:segstate.parent.p.ph_cplace is a)
                  ((R:segstate.parent.R:SylStructure.parent.syl_out
                    <
                    6.5)
                   ((R:segstate.parent.ph_vfront is 1)
                    ((1.24633 0.496385))
                    ((0.961039 0.0998246)))
                   ((1.56489 0.864205)))
                  ((R:segstate.parent.R:SylStructure.parent.R:Syllable.nn.accented
                    is
                    0)
                   ((0.442832 -0.192468))
                   ((1.59683 0.400726))))
                 ((R:segstate.parent.n.ph_ctype is f)
                  ((R:segstate.parent.p.ph_ctype is f)
                   ((0.635091 -0.0940102))
                   ((R:segstate.parent.R:SylStructure.parent.R:Syllable.nn.accented
                     is
                     0)
                    ((0.85984 0.0781176))
                    ((1.23647 0.419801))))
                  ((R:segstate.parent.R:SylStructure.parent.asyl_in
                    <
                    2.5)
                   ((0.898534 0.0232741))
                   ((0.533149 -0.312194)))))))
              ((R:segstate.parent.n.ph_ctype is n)
               ((R:segstate.parent.R:SylStructure.parent.asyl_in < 3.6)
                ((R:segstate.parent.R:SylStructure.parent.position_type
                  is
                  single)
                 ((1.19011 0.270593))
                 ((R:segstate.parent.R:SylStructure.parent.R:Syllable.n.syl_onsetsize
                   <
                   1.1)
                  ((R:segstate.parent.p.ph_ctype is s)
                   ((0.533589 -0.224618))
                   ((R:segstate.parent.p.ph_cvox is +)
                    ((0.752668 -0.0205347))
                    ((0.706072 -0.12064))))
                  ((0.905044 0.217872))))
                ((R:segstate.parent.R:SylStructure.parent.stress is 0)
                 ((0.530709 -0.152037))
                 ((0.507268 -0.409979))))
               ((R:segstate.parent.p.name is m)
                ((R:segstate.parent.R:SylStructure.parent.asyl_in
                  <
                  3.2)
                 ((R:segstate.parent.ph_vfront is 1)
                  ((0.416083 -0.400807))
                  ((0.460839 -0.140112)))
                 ((1.02675 0.0970052)))
                ((R:segstate.parent.R:SylStructure.parent.lisp_cg_break
                  <
                  0.1)
                 ((R:segstate.parent.p.ph_cvox is +)
                  ((0.781891 0.298616))
                  ((R:segstate.parent.R:SylStructure.parent.stress
                    is
                    0)
                   ((0.410323 -0.305887))
                   ((R:segstate.parent.R:SylStructure.parent.R:Syllable.p.stress
                     is
                     0)
                    ((R:segstate.parent.nn.ph_cplace is a)
                     ((0.661216 0.0384621))
                     ((0.367835 -0.0672905)))
                    ((0.557933 -0.16914)))))
                 ((R:segstate.parent.R:SylStructure.parent.R:Syllable.n.accented
                   is
                   0)
                  ((R:segstate.parent.n.ph_ctype is s)
                   ((R:segstate.parent.p.name is d)
                    ((1.74306 0.710132))
                    ((R:segstate.parent.R:SylStructure.parent.R:Syllable.pp.lisp_cg_break
                      <
                      0.1)
                     ((R:segstate.parent.pp.ph_vc is +)
                      ((R:segstate.parent.R:SylStructure.parent.R:Syllable.p.stress
                        is
                        0)
                       ((1.07301 0.343421))
                       ((1.06739 0.705689)))
                      ((R:segstate.parent.pp.ph_cplace is a)
                       ((0.94954 0.325912))
                       ((0.631878 0.088374))))
                     ((R:segstate.parent.R:SylStructure.parent.syl_in
                       <
                       8.5)
                      ((R:segstate.parent.p.ph_cvox is +)
                       ((R:segstate.parent.R:SylStructure.parent.syl_out
                         <
                         4.4)
                        ((0.93246 0.291283))
                        ((0.658978 0.623509)))
                       ((R:segstate.parent.R:SylStructure.parent.next_accent
                         <
                         2.2)
                        ((R:segstate.parent.pp.ph_cvox is +)
                         ((0.93854 0.340415))
                         ((0.731725 0.132009)))
                        ((0.615505 -0.0709334))))
                      ((R:segstate.parent.R:SylStructure.parent.R:Syllable.nn.lisp_cg_break
                        <
                        1.2)
                       ((0.750911 0.0246829))
                       ((0.632109 -0.0863024))))))
                   ((R:segstate.parent.nn.ph_cvox is +)
                    ((2.54709 1.28717))
                    ((0.949406 0.305693))))
                  ((R:segstate.parent.R:SylStructure.parent.last_accent
                    <
                    2.4)
                   ((R:segstate.parent.ph_vfront is 2)
                    ((0.886943 0.270198))
                    ((R:segstate.parent.p.name is t)
                     ((0.882794 0.220749))
                     ((R:segstate.parent.R:SylStructure.parent.R:Syllable.p.accented
                       is
                       0)
                      ((R:segstate.parent.R:SylStructure.parent.syl_in
                        <
                        5.2)
                       ((0.760624 -0.147202))
                       ((R:segstate.parent.R:SylStructure.parent.syl_in
                         <
                         9)
                        ((1.0074 0.222138))
                        ((0.932244 -0.0135625))))
                      ((0.46808 -0.206833)))))
                   ((1.2732 0.388037))))))))
             ((R:segstate.parent.p.ph_vrnd is -)
              ((R:segstate.parent.pp.ph_cplace is p)
               ((R:segstate.parent.p.name is aa)
                ((R:segstate.parent.nn.ph_cplace is 0)
                 ((1.32011 0.657624))
                 ((1.33712 0.843953)))
                ((0.482315 -0.239197)))
               ((R:segstate.parent.R:SylStructure.parent.position_type
                 is
                 final)
                ((R:segstate.parent.ph_ctype is n)
                 ((R:segstate.parent.p.name is ae)
                  ((0.607224 0.131503))
                  ((1.04977 -0.253617)))
                 ((1.46106 0.630366)))
                ((R:segstate.parent.ph_ctype is r)
                 ((R:segstate.parent.nn.ph_vlng is a)
                  ((0.754711 -0.171009))
                  ((R:segstate.parent.R:SylStructure.parent.R:Syllable.p.syl_codasize
                    <
                    1.2)
                   ((0.949789 0.141719))
                   ((1.08086 0.359037))))
                 ((R:segstate.parent.n.ph_ctype is s)
                  ((R:segstate.parent.R:SylStructure.parent.ssyl_out
                    <
                    1.4)
                   ((R:segstate.parent.R:SylStructure.parent.ssyl_in
                     <
                     6.2)
                    ((R:segstate.parent.R:SylStructure.parent.R:Syllable.nn.lisp_cg_break
                      <
                      0.3)
                     ((0.794478 -0.200101))
                     ((0.817571 0.172761)))
                    ((R:segstate.parent.R:SylStructure.parent.R:Syllable.n.accented
                      is
                      0)
                     ((0.681985 -0.551922))
                     ((0.821371 -0.155772))))
                   ((R:segstate.parent.ph_ctype is s)
                    ((0.634883 -0.678354))
                    ((R:segstate.parent.nn.ph_cvox is -)
                     ((0.456901 -0.467344))
                     ((R:segstate.parent.nn.ph_vrnd is -)
                      ((R:segstate.parent.R:SylStructure.parent.syl_out
                        <
                        4.8)
                       ((0.853945 -0.147245))
                       ((0.394446 -0.43568)))
                      ((0.805775 -0.0393806))))))
                  ((R:segstate.parent.R:SylStructure.parent.syl_out
                    <
                    2.4)
                   ((R:segstate.parent.R:SylStructure.parent.ssyl_in
                     <
                     4.8)
                    ((0.554729 -0.216776))
                    ((R:segstate.parent.R:SylStructure.parent.R:Syllable.pp.accented
                      is
                      0)
                     ((0.816411 0.0324748))
                     ((0.946986 0.354892))))
                   ((R:segstate.parent.R:SylStructure.parent.asyl_out
                     <
                     1.5)
                    ((R:segstate.parent.ph_cvox is +)
                     ((0.735655 -0.163351))
                     ((0.243866 -0.741679)))
                    ((R:segstate.parent.R:SylStructure.parent.R:Syllable.n.lisp_cg_break
                      <
                      0.1)
                     ((R:segstate.parent.nn.ph_vlng is s)
                      ((0.671781 0.0729069))
                      ((R:segstate.parent.ph_ctype is s)
                       ((0.493515 -0.630126))
                       ((0.620841 -0.35171))))
                     ((R:segstate.parent.lisp_onset_stop is 0)
                      ((R:segstate.parent.R:SylStructure.parent.R:Syllable.nn.lisp_cg_break
                        <
                        0.1)
                       ((0.706698 -0.223525))
                       ((R:segstate.parent.nn.ph_vfront is 1)
                        ((0.812044 -0.11014))
                        ((1.68153 0.24773))))
                      ((1.3153 0.324097))))))))))
              ((R:segstate.parent.R:SylStructure.parent.syl_codasize
                <
                3.1)
               ((R:segstate.parent.p.name is r)
                ((R:segstate.parent.R:SylStructure.parent.syl_out
                  <
                  5.5)
                 ((1.16593 0.390085))
                 ((0.960814 -0.0571784)))
                ((R:segstate.parent.ph_cvox is +)
                 ((R:segstate.parent.R:SylStructure.parent.ssyl_out
                   <
                   4.5)
                  ((R:segstate.parent.R:SylStructure.parent.asyl_in
                    <
                    2.4)
                   ((R:segstate.parent.R:SylStructure.parent.R:Syllable.p.syl_codasize
                     <
                     1.3)
                    ((R:segstate.parent.nn.ph_vfront is 2)
                     ((0.377351 -0.480878))
                     ((R:segstate.parent.lisp_coda_glide is 0)
                      ((0.472636 -0.353732))
                      ((0.766169 0.0370574))))
                    ((R:segstate.parent.R:SylStructure.parent.R:Syllable.n.lisp_cg_break
                      <
                      0.3)
                     ((0.398429 -0.588656))
                     ((R:segstate.parent.pp.ph_cvox is +)
                      ((0.385067 -0.281456))
                      ((0.49808 -0.469542)))))
                   ((R:segstate.parent.nn.ph_vrnd is +)
                    ((0.203212 -0.753223))
                    ((R:segstate.parent.p.name is ao)
                     ((R:segstate.parent.R:SylStructure.parent.R:Syllable.nn.accented
                       is
                       0)
                      ((0.737989 -0.279587))
                      ((0.29805 -0.504977)))
                     ((R:segstate.parent.R:SylStructure.parent.asyl_in
                       <
                       3.3)
                      ((R:segstate.parent.pp.ph_vlng is d)
                       ((0.224832 -0.611469))
                       ((0.658186 -0.280432)))
                      ((R:segstate.parent.lisp_onset_fric is 0)
                       ((0.259767 -0.774426))
                       ((0.38104 -0.498326)))))))
                  ((R:segstate.parent.R:SylStructure.parent.syl_out
                    <
                    11)
                   ((R:segstate.parent.R:SylStructure.parent.stress
                     is
                     0)
                    ((1.25321 0.211359))
                    ((0.859555 -0.248346)))
                   ((0.361178 -0.447476))))
                 ((R:segstate.parent.R:SylStructure.parent.parent.word_numsyls
                   <
                   2.5)
                  ((R:segstate.parent.p.ph_ctype is s)
                   ((R:segstate.parent.nn.ph_cplace is a)
                    ((R:segstate.parent.pp.ph_cplace is 0)
                     ((1.79727 0.625595))
                     ((0.575387 -0.00196579)))
                    ((R:segstate.parent.ph_ctype is s)
                     ((1.07582 0.222894))
                     ((R:segstate.parent.R:SylStructure.parent.syl_out
                       <
                       7.5)
                      ((R:segstate.parent.R:SylStructure.parent.asyl_out
                        <
                        1.3)
                       ((R:segstate.parent.R:SylStructure.parent.syl_in
                         <
                         8.8)
                        ((0.462464 -0.382174))
                        ((0.745586 -0.171769)))
                       ((R:segstate.parent.R:SylStructure.parent.R:Syllable.nn.stress
                         is
                         0)
                        ((0.635229 -0.235617))
                        ((R:segstate.parent.nn.ph_vc is +)
                         ((0.674579 -0.136585))
                         ((1.0212 0.105099)))))
                      ((0.58352 -0.354179)))))
                   ((R:segstate.parent.pp.ph_vc is +)
                    ((R:segstate.parent.R:SylStructure.parent.R:Syllable.n.syl_onsetsize
                      <
                      1.2)
                     ((R:segstate.parent.R:SylStructure.parent.ssyl_in
                       <
                       5.4)
                      ((R:segstate.parent.R:SylStructure.parent.R:Syllable.nn.accented
                        is
                        0)
                       ((R:segstate.parent.p.ph_ctype is n)
                        ((0.933756 -0.17067))
                        ((R:segstate.parent.syl_final is 0)
                         ((0.620987 -0.278139))
                         ((R:segstate.parent.R:SylStructure.parent.R:Syllable.p.syl_codasize
                           <
                           1.2)
                          ((R:segstate.parent.R:SylStructure.parent.syl_codasize
                            <
                            1.2)
                           ((0.263394 -0.487287))
                           ((0.487452 -0.739544)))
                          ((0.528262 -0.403603)))))
                       ((R:segstate.parent.R:SylStructure.parent.ssyl_out
                         <
                         4.5)
                        ((R:segstate.parent.lisp_onset_fric is 0)
                         ((0.741238 0.13967))
                         ((0.6903 -0.204171)))
                        ((0.436235 -0.419686))))
                      ((R:segstate.parent.R:SylStructure.parent.R:Syllable.n.accented
                        is
                        0)
                       ((R:segstate.parent.R:SylStructure.parent.position_type
                         is
                         single)
                        ((0.591753 -0.175978))
                        ((0.479978 -0.484673)))
                       ((R:segstate.parent.p.name is s)
                        ((1.3577 0.451035))
                        ((0.427363 -0.310747)))))
                     ((R:segstate.parent.p.ph_ctype is f)
                      ((0.592226 -0.279986))
                      ((0.394339 -0.729716))))
                    ((R:segstate.parent.lisp_coda_fric is 0)
                     ((R:segstate.parent.nn.ph_vlng is l)
                      ((0.639792 -0.380379))
                      ((R:segstate.parent.lisp_coda_stop is 0)
                       ((R:segstate.parent.R:SylStructure.parent.R:Syllable.nn.stress
                         is
                         0)
                        ((R:segstate.parent.R:SylStructure.parent.syl_in
                          <
                          7.9)
                         ((0.765485 -0.00486998))
                         ((0.614338 -0.238493)))
                        ((0.588035 -0.241868)))
                       ((R:segstate.parent.nn.ph_cvox is +)
                        ((0.83908 0.113677))
                        ((0.938654 -0.0762847)))))
                     ((0.848006 0.135745)))))
                  ((R:segstate.parent.ph_ctype is f)
                   ((0.643872 -0.789937))
                   ((R:segstate.parent.R:SylStructure.parent.asyl_in
                     <
                     1.2)
                    ((R:segstate.parent.lisp_onset_fric is 0)
                     ((1.2499 0.248296))
                     ((0.595714 -0.335787)))
                    ((R:segstate.parent.R:SylStructure.parent.R:Syllable.pp.accented
                      is
                      0)
                     ((R:segstate.parent.lisp_onset_stop is 0)
                      ((R:segstate.parent.R:SylStructure.parent.R:Syllable.n.lisp_cg_break
                        <
                        0.3)
                       ((0.516054 -0.472811))
                       ((0.581587 -0.0692384)))
                      ((R:segstate.parent.R:SylStructure.parent.ssyl_in
                        <
                        4.6)
                       ((0.650311 -0.518045))
                       ((R:segstate.parent.nn.ph_cvox is +)
                        ((0.738335 -0.203674))
                        ((R:segstate.parent.R:SylStructure.parent.ssyl_in
                          <
                          5.6)
                         ((0.69132 -0.283546))
                         ((R:segstate.parent.R:SylStructure.parent.ssyl_in
                           <
                           8.5)
                          ((0.514607 -0.598791))
                          ((0.405384 -0.411974)))))))
                     ((R:segstate.parent.R:SylStructure.parent.R:Syllable.n.lisp_cg_break
                       <
                       0.3)
                      ((R:segstate.parent.n.ph_ctype is 0)
                       ((0.745502 -0.357944))
                       ((0.36358 -0.547691)))
                      ((0.523868 -0.702422)))))))))
               ((R:segstate.parent.p.name is l)
                ((0.236568 -0.939099))
                ((R:segstate.parent.lisp_onset_fric is 0)
                 ((R:segstate.parent.nn.ph_cplace is 0)
                  ((0.817896 -0.426873))
                  ((R:segstate.parent.n.ph_ctype is 0)
                   ((0.406805 -0.95693))
                   ((0.594917 -0.704421))))
                 ((R:segstate.parent.p.ph_cvox is +)
                  ((1.04245 -0.166524))
                  ((0.821034 -0.517343)))))))))
           ((R:segstate.parent.pp.ph_vlng is s)
            ((R:segstate.parent.R:SylStructure.parent.R:Syllable.p.syl_codasize
              <
              1.3)
             ((R:segstate.parent.R:SylStructure.parent.syl_in < 10.5)
              ((R:segstate.parent.R:SylStructure.parent.syl_onsetsize
                <
                0.1)
               ((R:segstate.parent.R:SylStructure.parent.asyl_out
                 <
                 2.2)
                ((R:segstate.parent.R:SylStructure.parent.R:Syllable.nn.stress
                  is
                  0)
                 ((0.18558 -0.707856))
                 ((0.769167 -0.458757)))
                ((0.134685 -0.740632)))
               ((0.498904 -0.337731)))
              ((1.04993 -0.0844506)))
             ((R:segstate.parent.R:SylStructure.parent.R:Syllable.p.stress
               is
               0)
              ((R:segstate.parent.R:SylStructure.parent.syl_out < 7.6)
               ((R:segstate.parent.R:SylStructure.parent.R:Syllable.pp.accented
                 is
                 0)
                ((R:segstate.parent.R:SylStructure.parent.R:Syllable.nn.accented
                  is
                  0)
                 ((0.0914513 -0.77403))
                 ((0.223587 -0.668667)))
                ((0.238439 -0.616712)))
               ((0.717512 -0.410806)))
              ((R:segstate.parent.R:SylStructure.parent.syl_out < 4.2)
               ((R:segstate.parent.nn.ph_vfront is 3)
                ((0.102775 -0.764343))
                ((R:segstate.parent.R:SylStructure.parent.R:Syllable.n.accented
                  is
                  0)
                 ((0.396213 -0.760055))
                 ((R:segstate.parent.nn.ph_vfront is 1)
                  ((0.189901 -0.647715))
                  ((0.933636 -0.524601)))))
               ((R:segstate.parent.R:SylStructure.parent.ssyl_out
                 <
                 3.5)
                ((0.429009 -0.915491))
                ((R:segstate.parent.nn.ph_vlng is l)
                 ((0.0103543 -0.795884))
                 ((R:segstate.parent.R:SylStructure.parent.R:Syllable.nn.accented
                   is
                   0)
                  ((0.152247 -0.722053))
                  ((0.620928 -0.643411))))))))
            ((R:segstate.parent.R:SylStructure.parent.parent.gpos
              is
              in)
             ((R:segstate.parent.p.ph_cvox is -)
              ((R:segstate.parent.pp.ph_vc is +)
               ((1.01132 -0.12644))
               ((R:segstate.parent.p.ph_ctype is f)
                ((R:segstate.parent.R:SylStructure.parent.syl_in < 7.6)
                 ((0.0792977 -0.840194))
                 ((R:segstate.parent.R:SylStructure.parent.R:Syllable.nn.stress
                   is
                   0)
                  ((0.080788 -0.825298))
                  ((0.118711 -0.782965))))
                ((R:segstate.parent.R:SylStructure.parent.asyl_in
                  <
                  2.2)
                 ((0.248648 -0.658916))
                 ((0.112465 -0.717357)))))
              ((R:segstate.parent.R:SylStructure.parent.ssyl_out < 3.6)
               ((R:segstate.parent.R:SylStructure.parent.stress is 0)
                ((R:segstate.parent.p.name is b)
                 ((0.573937 -0.664431))
                 ((0.309186 -0.379109)))
                ((R:segstate.parent.nn.ph_vlng is d)
                 ((0.588186 -0.598524))
                 ((R:segstate.parent.nn.ph_cvox is +)
                  ((R:segstate.parent.R:SylStructure.parent.R:Syllable.nn.accented
                    is
                    0)
                   ((0.293058 -0.610034))
                   ((0.832706 -0.091227)))
                  ((R:segstate.parent.p.name is ao)
                   ((R:segstate.parent.R:SylStructure.parent.syl_out
                     <
                     2.2)
                    ((0.643855 -0.233225))
                    ((R:segstate.parent.R:SylStructure.parent.R:Syllable.p.syl_codasize
                      <
                      1.2)
                     ((0.279753 -0.393488))
                     ((0.346171 -0.493142))))
                   ((R:segstate.parent.R:SylStructure.parent.R:Syllable.p.syl_codasize
                     <
                     2.2)
                    ((R:segstate.parent.pp.ph_vheight is 2)
                     ((0.954135 0.124307))
                     ((R:segstate.parent.n.ph_ctype is f)
                      ((R:segstate.parent.R:SylStructure.parent.last_accent
                        <
                        1.2)
                       ((R:segstate.parent.lisp_onset_stop is 0)
                        ((R:segstate.parent.R:SylStructure.parent.R:Syllable.pp.accented
                          is
                          0)
                         ((1.01926 -0.072166))
                         ((1.07523 0.353977)))
                        ((0.547339 -0.155533)))
                       ((0.689767 -0.293293)))
                      ((R:segstate.parent.ph_cvox is +)
                       ((0.892837 0.0607175))
                       ((R:segstate.parent.R:SylStructure.parent.R:Syllable.nn.stress
                         is
                         0)
                        ((0.483957 -0.576844))
                        ((0.545169 -0.332752))))))
                    ((R:segstate.parent.pp.ph_cplace is 0)
                     ((0.878914 -0.106133))
                     ((1.6855 0.740437))))))))
               ((R:segstate.parent.nn.ph_vfront is 3)
                ((0.343554 -0.784677))
                ((R:segstate.parent.n.ph_ctype is f)
                 ((R:segstate.parent.R:SylStructure.parent.R:Syllable.p.stress
                   is
                   0)
                  ((0.809938 0.151967))
                  ((R:segstate.parent.R:SylStructure.parent.R:Syllable.p.syl_codasize
                    <
                    2.2)
                   ((R:segstate.parent.R:SylStructure.parent.R:Syllable.p.accented
                     is
                     0)
                    ((0.552912 -0.404625))
                    ((0.507739 -0.267406)))
                   ((0.393375 -0.568183))))
                 ((R:segstate.parent.ph_cvox is -)
                  ((0.185275 -0.787688))
                  ((R:segstate.parent.pp.ph_cplace is 0)
                   ((R:segstate.parent.R:SylStructure.parent.R:Syllable.nn.accented
                     is
                     0)
                    ((0.252582 -0.649609))
                    ((0.388163 -0.473371)))
                   ((R:segstate.parent.R:SylStructure.parent.syl_in
                     <
                     6.4)
                    ((0.479444 -0.351973))
                    ((0.620055 -0.225635)))))))))
             ((R:segstate.parent.ph_vrnd is -)
              ((R:segstate.parent.n.ph_ctype is f)
               ((R:segstate.parent.ph_vheight is 3)
                ((R:segstate.parent.pp.ph_cvox is +)
                 ((0.465786 -0.337929))
                 ((0.267927 -0.589749)))
                ((R:segstate.parent.pp.ph_vc is +)
                 ((R:segstate.parent.p.name is dh)
                  ((R:segstate.parent.nn.ph_vc is +)
                   ((0.327074 -0.309763))
                   ((0.775872 -0.023603)))
                  ((R:segstate.parent.R:SylStructure.parent.ssyl_in
                    <
                    5.4)
                   ((1.60775 0.598822))
                   ((0.827956 0.106742))))
                 ((R:segstate.parent.nn.ph_vlng is l)
                  ((R:segstate.parent.R:SylStructure.parent.syl_out
                    <
                    4.6)
                   ((0.317278 -0.392331))
                   ((0.523044 -0.278726)))
                  ((R:segstate.parent.p.name is t)
                   ((R:segstate.parent.R:SylStructure.parent.syl_out
                     <
                     5.8)
                    ((R:segstate.parent.R:SylStructure.parent.asyl_in
                      <
                      2.5)
                     ((1.0732 0.280903))
                     ((R:segstate.parent.R:SylStructure.parent.R:Syllable.nn.accented
                       is
                       0)
                      ((0.59696 -0.126665))
                      ((0.58425 0.0327616))))
                    ((R:segstate.parent.R:SylStructure.parent.syl_in
                      <
                      6.2)
                     ((0.650347 0.019449))
                     ((0.439493 -0.228763))))
                   ((R:segstate.parent.nn.ph_cvox is -)
                    ((R:segstate.parent.R:SylStructure.parent.ssyl_out
                      <
                      2.5)
                     ((R:segstate.parent.R:SylStructure.parent.ssyl_in
                       <
                       6.5)
                      ((R:segstate.parent.R:SylStructure.parent.ssyl_out
                        <
                        1.1)
                       ((R:segstate.parent.R:SylStructure.parent.asyl_in
                         <
                         2.2)
                        ((0.609189 -0.16406))
                        ((0.500197 -0.270517)))
                       ((0.384636 -0.357028)))
                      ((0.589139 -0.064861)))
                     ((R:segstate.parent.R:SylStructure.parent.asyl_in
                       <
                       1.2)
                      ((0.476395 -0.138848))
                      ((1.19089 0.258764))))
                    ((R:segstate.parent.pp.ph_cvox is +)
                     ((R:segstate.parent.R:SylStructure.parent.syl_out
                       <
                       6.4)
                      ((R:segstate.parent.R:SylStructure.parent.R:Syllable.nn.accented
                        is
                        0)
                       ((R:segstate.parent.nn.ph_vlng is d)
                        ((0.332447 -0.294102))
                        ((R:segstate.parent.R:SylStructure.parent.syl_in
                          <
                          8.1)
                         ((0.41142 -0.120044))
                         ((0.635893 -0.188092))))
                       ((R:segstate.parent.R:SylStructure.parent.R:Syllable.pp.accented
                         is
                         0)
                        ((0.786709 0.0362568))
                        ((0.385032 -0.245849))))
                      ((0.439835 -0.357549)))
                     ((R:segstate.parent.p.name is hh)
                      ((0.463169 -0.249284))
                      ((R:segstate.parent.R:SylStructure.parent.R:Syllable.nn.lisp_cg_break
                        <
                        0.3)
                       ((0.228796 -0.475035))
                       ((0.335215 -0.376165))))))))))
               ((R:segstate.parent.R:SylStructure.parent.syl_out
                 <
                 10.1)
                ((R:segstate.parent.n.ph_ctype is n)
                 ((R:segstate.parent.nn.ph_vlng is l)
                  ((0.315469 -0.340983))
                  ((R:segstate.parent.nn.ph_vrnd is -)
                   ((R:segstate.parent.R:SylStructure.parent.R:Syllable.pp.accented
                     is
                     0)
                    ((0.217344 -0.479668))
                    ((0.431894 -0.345912)))
                   ((0.254045 -0.554878))))
                 ((R:segstate.parent.R:SylStructure.parent.ssyl_out
                   <
                   4.5)
                  ((R:segstate.parent.n.ph_ctype is 0)
                   ((1.01104 0.115034))
                   ((R:segstate.parent.R:SylStructure.parent.ssyl_in
                     <
                     4.4)
                    ((R:segstate.parent.R:SylStructure.parent.asyl_in
                      <
                      1.2)
                     ((R:segstate.parent.R:SylStructure.parent.R:Syllable.n.lisp_cg_break
                       <
                       0.3)
                      ((0.245382 -0.430849))
                      ((R:segstate.parent.R:SylStructure.parent.last_accent
                        <
                        2.2)
                       ((0.48174 -0.136705))
                       ((R:segstate.parent.nn.ph_vfront is 1)
                        ((0.397249 -0.300786))
                        ((0.544158 -0.255104)))))
                     ((R:segstate.parent.R:SylStructure.parent.ssyl_out
                       <
                       2.2)
                      ((R:segstate.parent.n.ph_ctype is s)
                       ((R:segstate.parent.R:SylStructure.parent.R:Syllable.nn.stress
                         is
                         0)
                        ((0.269885 -0.469715))
                        ((0.366857 -0.320677)))
                       ((0.238209 -0.502391)))
                      ((R:segstate.parent.nn.ph_vfront is 1)
                       ((0.379378 -0.179827))
                       ((R:segstate.parent.R:SylStructure.parent.syl_in
                         <
                         7.6)
                        ((0.29604 -0.4216))
                        ((0.423448 -0.320771))))))
                    ((R:segstate.parent.R:SylStructure.parent.ssyl_in
                      <
                      6.5)
                     ((R:segstate.parent.R:SylStructure.parent.R:Syllable.n.lisp_cg_break
                       <
                       1.2)
                      ((R:segstate.parent.n.ph_ctype is r)
                       ((0.410081 -0.365838))
                       ((R:segstate.parent.R:SylStructure.parent.syl_out
                         <
                         3.2)
                        ((0.298656 -0.310387))
                        ((R:segstate.parent.pp.ph_cplace is a)
                         ((0.404023 -0.225853))
                         ((0.761506 -0.0388627)))))
                      ((R:segstate.parent.R:SylStructure.parent.last_accent
                        <
                        1.8)
                       ((0.734454 -0.0738243))
                       ((1.28633 0.136504))))
                     ((R:segstate.parent.n.ph_ctype is r)
                      ((0.181981 -0.499718))
                      ((R:segstate.parent.nn.ph_vfront is 1)
                       ((0.425936 -0.161941))
                       ((R:segstate.parent.pp.ph_cvox is +)
                        ((R:segstate.parent.pp.ph_cplace is b)
                         ((0.16617 -0.464799))
                         ((0.516087 -0.215466)))
                        ((0.231195 -0.473083))))))))
                  ((R:segstate.parent.R:SylStructure.parent.next_accent
                    <
                    2.4)
                   ((R:segstate.parent.pp.ph_cplace is a)
                    ((R:segstate.parent.R:SylStructure.parent.syl_in
                      <
                      5.4)
                     ((0.398501 -0.384124))
                     ((0.219096 -0.490377)))
                    ((R:segstate.parent.R:SylStructure.parent.asyl_in
                      <
                      1.2)
                     ((0.392422 -0.194316))
                     ((0.392419 -0.376262))))
                   ((0.239201 -0.52534)))))
                ((1.05382 0.137371))))
              ((R:segstate.parent.ph_ctype is s)
               ((R:segstate.parent.R:SylStructure.parent.R:Syllable.n.accented
                 is
                 0)
                ((0.751822 -0.126094))
                ((R:segstate.parent.R:SylStructure.parent.R:Syllable.pp.lisp_cg_break
                  <
                  0.1)
                 ((0.597689 0.0681163))
                 ((R:segstate.parent.nn.ph_vfront is 1)
                  ((1.41898 0.649437))
                  ((1.27844 0.426978)))))
               ((R:segstate.parent.p.ph_cvox is +)
                ((R:segstate.parent.R:SylStructure.parent.syl_out
                  <
                  2.6)
                 ((0.80312 -0.0384407))
                 ((1.02006 0.386796)))
                ((R:segstate.parent.nn.ph_cvox is -)
                 ((R:segstate.parent.nn.ph_cplace is g)
                  ((0.349881 -0.36358))
                  ((R:segstate.parent.nn.ph_cplace is l)
                   ((0.352182 -0.36589))
                   ((R:segstate.parent.R:SylStructure.parent.syl_in
                     <
                     7)
                    ((R:segstate.parent.R:SylStructure.parent.syl_out
                      <
                      3.4)
                     ((0.615979 -0.113457))
                     ((0.701454 0.0981954)))
                    ((R:segstate.parent.R:SylStructure.parent.asyl_out
                      <
                      2.2)
                     ((R:segstate.parent.R:SylStructure.parent.syl_in
                       <
                       8.4)
                      ((0.438106 -0.220718))
                      ((R:segstate.parent.R:SylStructure.parent.R:Syllable.n.lisp_cg_break
                        <
                        0.3)
                       ((0.451562 -0.163354))
                       ((0.549048 -0.0586932))))
                     ((0.43585 -0.291171))))))
                 ((R:segstate.parent.R:SylStructure.parent.asyl_out
                   <
                   2.5)
                  ((R:segstate.parent.R:SylStructure.parent.syl_in
                    <
                    7.4)
                   ((R:segstate.parent.R:SylStructure.parent.R:Syllable.n.accented
                     is
                     0)
                    ((R:segstate.parent.R:SylStructure.parent.R:Syllable.n.lisp_cg_break
                      <
                      0.1)
                     ((0.68885 -0.0559313))
                     ((0.815368 0.0792999)))
                    ((R:segstate.parent.R:SylStructure.parent.syl_codasize
                      <
                      2.1)
                     ((0.872469 0.0228553))
                     ((1.27833 0.62918))))
                   ((R:segstate.parent.R:SylStructure.parent.ssyl_in
                     <
                     5.4)
                    ((R:segstate.parent.ph_ctype is n)
                     ((0.984537 -0.0159972))
                     ((0.69384 -0.311101)))
                    ((R:segstate.parent.R:SylStructure.parent.ssyl_in
                      <
                      7.5)
                     ((0.979375 0.215178))
                     ((0.591386 -0.133653)))))
                  ((R:segstate.parent.R:SylStructure.parent.syl_in
                    <
                    6.4)
                   ((R:segstate.parent.R:SylStructure.parent.R:Syllable.p.syl_codasize
                     <
                     1.3)
                    ((0.718576 -0.191713))
                    ((0.997341 0.0666823)))
                   ((R:segstate.parent.R:SylStructure.parent.ssyl_out
                     <
                     3.2)
                    ((R:segstate.parent.R:SylStructure.parent.R:Syllable.n.lisp_cg_break
                      <
                      0.1)
                     ((0.929506 0.0568915))
                     ((0.511115 -0.323501)))
                    ((0.472713 -0.411347))))))))))))
          ((R:segstate.parent.R:SylStructure.parent.syl_codasize < 2.2)
           ((R:segstate.parent.p.ph_ctype is r)
            ((R:segstate.parent.lisp_coda_stop is 0)
             ((R:segstate.parent.R:SylStructure.parent.parent.gpos
               is
               content)
              ((R:segstate.parent.lisp_coda_glide is 0)
               ((R:segstate.parent.ph_vheight is 3)
                ((R:segstate.parent.pp.ph_cplace is a)
                 ((0.590285 -0.323716))
                 ((R:segstate.parent.n.ph_ctype is n)
                  ((0.6374 -0.266772))
                  ((R:segstate.parent.R:SylStructure.parent.R:Syllable.pp.accented
                    is
                    0)
                   ((R:segstate.parent.R:SylStructure.parent.ssyl_in
                     <
                     4.6)
                    ((0.640993 0.215565))
                    ((0.622091 -0.107554)))
                   ((0.752771 -0.178718)))))
                ((R:segstate.parent.R:SylStructure.parent.position_type
                  is
                  initial)
                 ((R:segstate.parent.R:SylStructure.parent.stress is 0)
                  ((R:segstate.parent.R:SylStructure.parent.R:Syllable.pp.accented
                    is
                    0)
                   ((R:segstate.parent.R:SylStructure.parent.asyl_in
                     <
                     3.6)
                    ((R:segstate.parent.R:SylStructure.parent.R:Syllable.nn.lisp_cg_break
                      <
                      0.3)
                     ((0.251898 -0.544985))
                     ((R:segstate.parent.R:SylStructure.parent.syl_out
                       <
                       4.2)
                      ((0.315453 -0.27592))
                      ((0.303398 -0.508886))))
                    ((0.261861 -0.620865)))
                   ((R:segstate.parent.R:SylStructure.parent.syl_in
                     <
                     9.2)
                    ((R:segstate.parent.pp.ph_cvox is -)
                     ((0.257222 -0.774186))
                     ((0.278544 -0.605509)))
                    ((0.226168 -0.527152))))
                  ((R:segstate.parent.ph_vfront is 3)
                   ((R:segstate.parent.R:SylStructure.parent.asyl_in
                     <
                     3.2)
                    ((0.344423 -0.585516))
                    ((0.297927 -0.452336)))
                   ((R:segstate.parent.R:SylStructure.parent.ssyl_in
                     <
                     3.9)
                    ((0.541749 -0.171837))
                    ((R:segstate.parent.R:SylStructure.parent.ssyl_in
                      <
                      4.8)
                     ((0.372528 -0.562659))
                     ((R:segstate.parent.R:SylStructure.parent.asyl_out
                       <
                       2.2)
                      ((R:segstate.parent.R:SylStructure.parent.asyl_out
                        <
                        1.1)
                       ((R:segstate.parent.lisp_onset_stop is 0)
                        ((R:segstate.parent.pp.ph_cvox is +)
                         ((0.334395 -0.368765))
                         ((0.609062 -0.173473)))
                        ((0.304636 -0.427134)))
                       ((0.439335 -0.570459)))
                      ((0.589828 -0.15488)))))))
                 ((R:segstate.parent.R:SylStructure.parent.asyl_in
                   <
                   2.4)
                  ((R:segstate.parent.nn.ph_vc is +)
                   ((R:segstate.parent.pp.ph_cvox is -)
                    ((R:segstate.parent.pp.ph_cplace is l)
                     ((0.22116 -0.468892))
                     ((0.627217 -0.0788965)))
                    ((R:segstate.parent.n.ph_ctype is s)
                     ((0.550296 -0.302266))
                     ((R:segstate.parent.R:SylStructure.parent.last_accent
                       <
                       1.6)
                      ((0.55235 -0.43279))
                      ((0.271627 -0.690459)))))
                   ((R:segstate.parent.R:SylStructure.parent.next_accent
                     <
                     1.6)
                    ((R:segstate.parent.R:SylStructure.parent.syl_in
                      <
                      6.1)
                     ((0.686555 -0.0918659))
                     ((R:segstate.parent.R:SylStructure.parent.syl_out
                       <
                       5)
                      ((0.555766 -0.355387))
                      ((0.568417 -0.279945))))
                    ((R:segstate.parent.R:SylStructure.parent.next_accent
                      <
                      2.6)
                     ((0.808078 0.146902))
                     ((0.517854 -0.122704)))))
                  ((R:segstate.parent.R:SylStructure.parent.R:Syllable.n.syl_onsetsize
                    <
                    1.2)
                   ((R:segstate.parent.R:SylStructure.parent.syl_in
                     <
                     12.8)
                    ((R:segstate.parent.R:SylStructure.parent.asyl_out
                      <
                      2.5)
                     ((R:segstate.parent.ph_vheight is 1)
                      ((R:segstate.parent.pp.ph_cplace is a)
                       ((0.221721 -0.689864))
                       ((R:segstate.parent.R:SylStructure.parent.syl_onsetsize
                         <
                         1.2)
                        ((0.353485 -0.572112))
                        ((0.408492 -0.365261))))
                      ((R:segstate.parent.R:SylStructure.parent.asyl_in
                        <
                        4.2)
                       ((R:segstate.parent.n.ph_ctype is s)
                        ((0.505301 -0.272933))
                        ((0.286646 -0.290335)))
                       ((0.416864 -0.460516))))
                     ((0.573191 -0.225162)))
                    ((R:segstate.parent.R:SylStructure.parent.asyl_in
                      <
                      4.5)
                     ((0.79193 -0.0863035))
                     ((0.500767 -0.301623))))
                   ((0.30807 -0.575486))))))
               ((R:segstate.parent.p.name is w)
                ((0.634179 -0.336339))
                ((0.249332 -0.813081))))
              ((R:segstate.parent.n.ph_ctype is f)
               ((R:segstate.parent.R:SylStructure.parent.R:Syllable.p.accented
                 is
                 0)
                ((R:segstate.parent.nn.ph_cvox is -)
                 ((R:segstate.parent.R:SylStructure.parent.R:Syllable.n.lisp_cg_break
                   <
                   0.3)
                  ((0.370071 -0.533903))
                  ((0.33232 -0.392506)))
                 ((R:segstate.parent.R:SylStructure.parent.R:Syllable.pp.lisp_cg_break
                   <
                   0.1)
                  ((0.392294 -0.461797))
                  ((R:segstate.parent.ph_vheight is 1)
                   ((0.433297 -0.226792))
                   ((R:segstate.parent.pp.ph_vheight is 1)
                    ((0.750673 -0.315585))
                    ((0.544127 -0.441655))))))
                ((R:segstate.parent.R:SylStructure.parent.syl_out
                  <
                  3.4)
                 ((R:segstate.parent.R:SylStructure.parent.ssyl_in
                   <
                   5.4)
                  ((0.370115 -0.51648))
                  ((0.242133 -0.610489)))
                 ((R:segstate.parent.R:SylStructure.parent.ssyl_in
                   <
                   4.5)
                  ((R:segstate.parent.ph_vheight is 3)
                   ((0.300994 -0.620415))
                   ((R:segstate.parent.R:SylStructure.parent.R:Syllable.n.accented
                     is
                     0)
                    ((0.310707 -0.462189))
                    ((0.311261 -0.353638))))
                  ((0.608538 -0.316142)))))
               ((R:segstate.parent.nn.ph_cplace is d)
                ((R:segstate.parent.R:SylStructure.parent.R:Syllable.p.accented
                  is
                  0)
                 ((0.348708 -0.389166))
                 ((0.245135 -0.607395)))
                ((R:segstate.parent.p.name is r)
                 ((R:segstate.parent.R:SylStructure.parent.R:Syllable.p.syl_codasize
                   <
                   2.1)
                  ((0.201693 -0.719951))
                  ((0.263834 -0.657501)))
                 ((R:segstate.parent.R:SylStructure.parent.ssyl_in
                   <
                   3.6)
                  ((0.235378 -0.526062))
                  ((R:segstate.parent.R:SylStructure.parent.last_accent
                    <
                    1.2)
                   ((R:segstate.parent.lisp_coda_glide is 0)
                    ((0.317488 -0.520914))
                    ((0.476582 -0.651898)))
                   ((0.190676 -0.6786))))))))
             ((R:segstate.parent.R:SylStructure.parent.ssyl_in < 5.1)
              ((R:segstate.parent.R:SylStructure.parent.position_type
                is
                initial)
               ((0.688526 -0.377964))
               ((R:segstate.parent.R:SylStructure.parent.R:Syllable.nn.stress
                 is
                 0)
                ((R:segstate.parent.p.name is r)
                 ((0.734816 -0.0962051))
                 ((0.493098 -0.29885)))
                ((R:segstate.parent.nn.ph_cplace is 0)
                 ((0.792277 0.195155))
                 ((R:segstate.parent.R:SylStructure.parent.R:Syllable.p.syl_codasize
                   <
                   1.2)
                  ((0.602791 -0.224454))
                  ((0.720737 0.0246916))))))
              ((R:segstate.parent.R:SylStructure.parent.syl_out < 2.4)
               ((R:segstate.parent.pp.ph_cvox is +)
                ((0.563614 -0.389461))
                ((0.174088 -0.550517)))
               ((R:segstate.parent.R:SylStructure.parent.R:Syllable.p.syl_codasize
                 <
                 1.2)
                ((0.648003 -0.413061))
                ((0.582456 -0.188805))))))
            ((R:segstate.parent.p.ph_cvox is -)
             ((R:segstate.parent.n.ph_vc is +)
              ((R:segstate.parent.pp.ph_vheight is 3)
               ((R:segstate.parent.R:SylStructure.parent.stress is 0)
                ((0.666405 -0.349418))
                ((1.20857 0.272855)))
               ((R:segstate.parent.R:SylStructure.parent.asyl_in < 2.4)
                ((R:segstate.parent.p.name is k)
                 ((R:segstate.parent.R:SylStructure.parent.last_accent
                   <
                   1.1)
                  ((0.236443 -0.913904))
                  ((R:segstate.parent.pp.ph_cplace is a)
                   ((0.362896 -0.670394))
                   ((0.887127 -0.416215))))
                 ((R:segstate.parent.ph_ctype is l)
                  ((R:segstate.parent.p.name is p)
                   ((0.213491 -0.792216))
                   ((0.369039 -0.575185)))
                  ((R:segstate.parent.R:SylStructure.parent.R:Syllable.n.lisp_cg_break
                    <
                    1.2)
                   ((R:segstate.parent.R:SylStructure.parent.position_type
                     is
                     final)
                    ((0.36214 -0.741496))
                    ((R:segstate.parent.nn.ph_cplace is l)
                     ((R:segstate.parent.R:SylStructure.parent.syl_out
                       <
                       4)
                      ((0.312923 -0.485881))
                      ((0.123033 -0.679763)))
                     ((R:segstate.parent.R:SylStructure.parent.ssyl_in
                       <
                       3.6)
                      ((0.710172 -0.16513))
                      ((R:segstate.parent.R:SylStructure.parent.R:Syllable.nn.stress
                        is
                        0)
                       ((R:segstate.parent.R:SylStructure.parent.syl_out
                         <
                         5.6)
                        ((0.220957 -0.5815))
                        ((0.194882 -0.500681)))
                       ((0.481353 -0.395272))))))
                   ((0.537719 -0.264373)))))
                ((R:segstate.parent.lisp_coda_stop is 0)
                 ((R:segstate.parent.n.ph_vheight is 3)
                  ((R:segstate.parent.R:SylStructure.parent.R:Syllable.n.accented
                    is
                    0)
                   ((0.21051 -0.754132))
                   ((0.487327 -0.549381)))
                  ((R:segstate.parent.pp.ph_cvox is +)
                   ((R:segstate.parent.R:SylStructure.parent.syl_out
                     <
                     3.7)
                    ((R:segstate.parent.R:SylStructure.parent.R:Syllable.p.lisp_cg_break
                      <
                      0.1)
                     ((0.802313 -0.375935))
                     ((0.356422 -0.470457)))
                    ((R:segstate.parent.R:SylStructure.parent.R:Syllable.p.accented
                      is
                      0)
                     ((0.251384 -0.840368))
                     ((0.40463 -0.49752))))
                   ((R:segstate.parent.nn.ph_cplace is l)
                    ((0.280629 -0.546169))
                    ((R:segstate.parent.p.name is p)
                     ((R:segstate.parent.nn.ph_cvox is +)
                      ((0.24608 -0.509945))
                      ((0.494995 -0.320855)))
                     ((R:segstate.parent.R:SylStructure.parent.R:Syllable.nn.accented
                       is
                       0)
                      ((R:segstate.parent.R:SylStructure.parent.R:Syllable.p.lisp_cg_break
                        <
                        0.1)
                       ((0.987814 -0.1847))
                       ((0.938563 0.214614)))
                      ((0.583097 -0.399406)))))))
                 ((R:segstate.parent.R:SylStructure.parent.ssyl_out
                   <
                   2.5)
                  ((0.749863 0.0315129))
                  ((0.329401 -0.423171))))))
              ((R:segstate.parent.R:SylStructure.parent.syl_in < 8.3)
               ((0.662364 0.229077))
               ((0.817576 -0.0943694))))
             ((R:segstate.parent.n.ph_ctype is s)
              ((R:segstate.parent.R:SylStructure.parent.R:Syllable.n.accented
                is
                0)
               ((R:segstate.parent.nn.ph_cvox is -)
                ((0.536971 -0.181578))
                ((R:segstate.parent.R:SylStructure.parent.syl_codasize
                  <
                  1.1)
                 ((R:segstate.parent.R:SylStructure.parent.R:Syllable.nn.lisp_cg_break
                   <
                   0.3)
                  ((0.368468 -0.477418))
                  ((R:segstate.parent.R:SylStructure.parent.R:Syllable.nn.accented
                    is
                    0)
                   ((0.602251 -0.0891783))
                   ((0.514966 -0.396112))))
                 ((R:segstate.parent.R:SylStructure.parent.asyl_in
                   <
                   2.1)
                  ((R:segstate.parent.R:SylStructure.parent.ssyl_in
                    <
                    3.6)
                   ((0.381867 -0.59296))
                   ((0.35187 -0.382835)))
                  ((0.412736 -0.788364)))))
               ((R:segstate.parent.pos_in_syl is 1)
                ((R:segstate.parent.R:SylStructure.parent.syl_out
                  <
                  5.8)
                 ((R:segstate.parent.R:SylStructure.parent.syl_codasize
                   <
                   1.1)
                  ((R:segstate.parent.R:SylStructure.parent.R:Syllable.pp.lisp_cg_break
                    <
                    0.1)
                   ((0.378857 -0.296026))
                   ((0.371124 -0.411158)))
                  ((0.225289 -0.493548)))
                 ((0.424074 -0.166268)))
                ((R:segstate.parent.p.ph_vlng is l)
                 ((0.7333 -0.141093))
                 ((0.810005 0.0405715)))))
              ((R:segstate.parent.R:SylStructure.parent.ssyl_out < 6.4)
               ((R:segstate.parent.p.name is ay)
                ((R:segstate.parent.R:SylStructure.parent.R:Syllable.n.accented
                  is
                  0)
                 ((0.708634 -0.604908))
                 ((0.883871 -0.272171)))
                ((R:segstate.parent.R:SylStructure.parent.position_type
                  is
                  mid)
                 ((R:segstate.parent.R:SylStructure.parent.R:Syllable.nn.accented
                   is
                   0)
                  ((R:segstate.parent.R:SylStructure.parent.R:Syllable.p.accented
                    is
                    0)
                   ((R:segstate.parent.R:SylStructure.parent.R:Syllable.n.accented
                     is
                     0)
                    ((0.707074 -0.24074))
                    ((0.425141 -0.0253884)))
                   ((R:segstate.parent.nn.ph_cvox is +)
                    ((0.609516 -0.223567))
                    ((R:segstate.parent.pp.ph_vheight is 3)
                     ((0.564432 -0.277933))
                     ((0.398156 -0.478479)))))
                  ((0.553438 -0.444713)))
                 ((R:segstate.parent.nn.ph_vlng is d)
                  ((R:segstate.parent.R:SylStructure.parent.R:Syllable.p.accented
                    is
                    0)
                   ((0.720114 -0.0704613))
                   ((0.944269 0.311632)))
                  ((R:segstate.parent.R:SylStructure.parent.asyl_in
                    <
                    3.5)
                   ((R:segstate.parent.R:SylStructure.parent.R:Syllable.nn.lisp_cg_break
                     <
                     1.2)
                    ((R:segstate.parent.R:SylStructure.parent.position_type
                      is
                      single)
                     ((R:segstate.parent.R:SylStructure.parent.R:Syllable.n.lisp_cg_break
                       <
                       0.3)
                      ((0.506551 -0.428998))
                      ((R:segstate.parent.R:SylStructure.parent.R:Syllable.p.stress
                        is
                        0)
                       ((0.679997 0.0731932))
                       ((R:segstate.parent.R:SylStructure.parent.R:Syllable.p.accented
                         is
                         0)
                        ((R:segstate.parent.pos_in_syl is 2)
                         ((0.451133 -0.470226))
                         ((0.585743 -0.256037)))
                        ((0.538574 -0.124601)))))
                     ((R:segstate.parent.n.ph_ctype is f)
                      ((R:segstate.parent.R:SylStructure.parent.syl_in
                        <
                        8.2)
                       ((R:segstate.parent.ph_vheight is 2)
                        ((0.601981 -0.204667))
                        ((0.593369 0.0891895)))
                       ((0.691986 0.441841)))
                      ((R:segstate.parent.R:SylStructure.parent.syl_out
                        <
                        4.6)
                       ((R:segstate.parent.pp.ph_cvox is +)
                        ((0.694878 -0.212832))
                        ((0.416239 -0.457287)))
                       ((R:segstate.parent.seg_onsetcoda is coda)
                        ((R:segstate.parent.nn.ph_cvox is -)
                         ((0.82298 -0.0377283))
                         ((0.763701 -0.251684)))
                        ((R:segstate.parent.n.ph_vlng is s)
                         ((0.2575 -0.0527875))
                         ((1.09409 0.0655963)))))))
                    ((R:segstate.parent.R:SylStructure.parent.last_accent
                      <
                      1.4)
                     ((0.781388 0.319903))
                     ((0.62731 -0.110271))))
                   ((R:segstate.parent.R:SylStructure.parent.R:Syllable.n.lisp_cg_break
                     <
                     0.3)
                    ((R:segstate.parent.R:SylStructure.parent.ssyl_in
                      <
                      6.5)
                     ((0.562103 -0.345019))
                     ((0.552452 -0.559558)))
                    ((R:segstate.parent.pp.ph_cvox is +)
                     ((0.490826 -0.265444))
                     ((R:segstate.parent.R:SylStructure.parent.syl_out
                       <
                       2.2)
                      ((0.734613 0.0674842))
                      ((0.765673 -0.253451)))))))))
               ((1.1021 0.348265))))))
           ((R:segstate.parent.p.name is l)
            ((R:segstate.parent.ph_vfront is 2)
             ((1.50599 0.551784))
             ((R:segstate.parent.R:SylStructure.parent.position_type
               is
               single)
              ((R:segstate.parent.nn.ph_cvox is -)
               ((0.462232 -0.0770081))
               ((1.11314 0.276019)))
              ((0.710066 -0.295869))))
            ((R:segstate.parent.p.name is r)
             ((R:segstate.parent.ph_vrnd is -)
              ((R:segstate.parent.R:SylStructure.parent.syl_out < 2.1)
               ((0.46079 -0.328896))
               ((R:segstate.parent.R:SylStructure.parent.syl_out < 4.8)
                ((1.0406 0.099509))
                ((0.474439 -0.207661))))
              ((1.1121 0.61446)))
             ((R:segstate.parent.R:SylStructure.parent.syl_in < 15.2)
              ((R:segstate.parent.R:SylStructure.parent.ssyl_in < 3.7)
               ((R:segstate.parent.R:SylStructure.parent.asyl_out < 3)
                ((R:segstate.parent.nn.ph_cvox is +)
                 ((0.621152 -0.491469))
                 ((R:segstate.parent.R:SylStructure.parent.R:Syllable.p.stress
                   is
                   0)
                  ((0.977945 0.063774))
                  ((R:segstate.parent.R:SylStructure.parent.asyl_in
                    <
                    1.1)
                   ((0.611716 -0.136435))
                   ((0.290458 -0.419104)))))
                ((R:segstate.parent.pp.ph_vc is +)
                 ((0.345648 -0.723963))
                 ((0.780726 -0.424757))))
               ((R:segstate.parent.p.ph_cplace is l)
                ((R:segstate.parent.ph_vheight is 1)
                 ((0.305417 -0.272003))
                 ((R:segstate.parent.nn.ph_cplace is a)
                  ((R:segstate.parent.R:SylStructure.parent.R:Syllable.nn.lisp_cg_break
                    <
                    0.3)
                   ((0.922234 0.119185))
                   ((0.537314 -0.107039)))
                  ((0.984963 0.29286))))
                ((R:segstate.parent.pp.ph_vheight is 3)
                 ((1.04049 0.134078))
                 ((R:segstate.parent.p.ph_cvox is +)
                  ((R:segstate.parent.R:SylStructure.parent.next_accent
                    <
                    1.2)
                   ((R:segstate.parent.R:SylStructure.parent.syl_out
                     <
                     2.1)
                    ((0.720988 -0.324129))
                    ((0.484748 -0.609816)))
                   ((0.795939 -0.126406)))
                  ((R:segstate.parent.R:SylStructure.parent.R:Syllable.nn.accented
                    is
                    0)
                   ((R:segstate.parent.n.ph_vc is +)
                    ((0.540823 -0.416697))
                    ((R:segstate.parent.R:SylStructure.parent.ssyl_in
                      <
                      4.4)
                     ((0.89993 -0.0873875))
                     ((0.560623 -0.429268))))
                   ((R:segstate.parent.R:SylStructure.parent.syl_in
                     <
                     8)
                    ((0.579427 -0.187608))
                    ((1.07733 0.221892))))))))
              ((0.437342 -0.544753))))))))))))))
  ((R:segstate.parent.seg_onsetcoda is coda)
   ((R:segstate.parent.p.ph_ctype is s)
    ((R:segstate.parent.n.ph_ctype is l)
     ((R:segstate.parent.R:SylStructure.parent.R:Syllable.p.accented
       is
       0)
      ((R:segstate.parent.R:SylStructure.parent.syl_in < 9.5)
       ((1.24759 0.352148))
       ((1.23856 0.0364733)))
      ((0.176436 -0.588721)))
     ((R:segstate.parent.R:SylStructure.parent.stress is 0)
      ((R:segstate.parent.n.ph_ctype is n)
       ((R:segstate.parent.R:SylStructure.parent.ssyl_in < 5.3)
        ((R:segstate.parent.pp.ph_vlng is s)
         ((1.46987 0.908005))
         ((1.10801 0.308638)))
        ((R:segstate.parent.p.name is t)
         ((0.825845 -0.026631))
         ((R:segstate.parent.R:SylStructure.parent.syl_in < 15)
          ((1.47798 0.511445))
          ((0.58723 -0.0839668)))))
       ((R:segstate.parent.p.ph_cplace is a)
        ((R:segstate.parent.pp.ph_cplace is a)
         ((1.30169 0.50506))
         ((R:segstate.parent.R:SylStructure.parent.ssyl_in < 9)
          ((R:segstate.parent.R:SylStructure.parent.asyl_in < 2.1)
           ((1.22295 0.900048))
           ((1.84369 1.28087)))
          ((1.33925 0.742361))))
        ((0.801439 0.26889))))
      ((R:segstate.parent.R:SylStructure.parent.syl_codasize < 2.2)
       ((R:segstate.parent.R:SylStructure.parent.syl_onsetsize < 1.2)
        ((R:segstate.parent.p.name is t)
         ((R:segstate.parent.R:SylStructure.parent.last_accent < 1.2)
          ((1.5432 0.496412))
          ((1.76163 0.906962)))
         ((R:segstate.parent.ph_vheight is 1)
          ((R:segstate.parent.pp.ph_cplace is a)
           ((2.85952 2.0295))
           ((2.2127 1.29937)))
          ((R:segstate.parent.pp.ph_vc is +)
           ((R:segstate.parent.R:SylStructure.parent.ssyl_in < 7.6)
            ((R:segstate.parent.R:SylStructure.parent.asyl_in < 2.5)
             ((1.79094 1.14678))
             ((1.33632 1.36708)))
            ((1.07908 1.11997)))
           ((R:segstate.parent.R:SylStructure.parent.syl_in < 6.4)
            ((1.16385 0.53835))
            ((R:segstate.parent.n.ph_ctype is n)
             ((1.71613 0.876756))
             ((1.70848 1.36074)))))))
        ((1.3196 0.441341)))
       ((R:segstate.parent.nn.ph_cplace is a)
        ((R:segstate.parent.nn.ph_cvox is +)
         ((R:segstate.parent.R:SylStructure.parent.syl_in < 7.5)
          ((1.85539 1.32178))
          ((1.77121 0.92098)))
         ((R:segstate.parent.R:SylStructure.parent.syl_in < 10.5)
          ((1.19288 0.708405))
          ((0.824027 0.330248))))
        ((R:segstate.parent.pp.ph_cvox is -)
         ((1.01996 -0.222015))
         ((1.13325 0.292531)))))))
    ((R:segstate.parent.p.name is pau)
     ((R:segstate.parent.R:SylStructure.parent.asyl_in < 1.5)
      ((1.35455 0.649761))
      ((1.76698 1.64032)))
     ((R:segstate.parent.pos_in_syl is 3)
      ((R:segstate.parent.pp.ph_vlng is s)
       ((R:segstate.parent.R:SylStructure.parent.position_type
         is
         final)
        ((0.473462 -0.757742))
        ((0.804238 0.128803)))
       ((R:segstate.parent.R:SylStructure.parent.syl_onsetsize < 2)
        ((R:segstate.parent.R:SylStructure.parent.R:Syllable.n.accented
          is
          0)
         ((R:segstate.parent.R:SylStructure.parent.R:Syllable.pp.accented
           is
           0)
          ((R:segstate.parent.R:SylStructure.parent.R:Syllable.p.stress
            is
            0)
           ((1.03259 0.658246))
           ((R:segstate.parent.R:SylStructure.parent.ssyl_in < 3.9)
            ((0.770254 -0.0537865))
            ((R:segstate.parent.lisp_coda_stop is 0)
             ((1.37167 0.625077))
             ((1.34742 0.226673)))))
          ((R:segstate.parent.R:SylStructure.parent.ssyl_in < 3.3)
           ((0.766779 0.368213))
           ((0.970932 -0.106657))))
         ((0.810453 -0.162991)))
        ((0.616633 -0.129697))))
      ((R:segstate.parent.n.ph_ctype is f)
       ((R:segstate.parent.p.ph_vlng is a)
        ((R:segstate.parent.R:SylStructure.parent.ssyl_in < 5.5)
         ((1.73429 1.58919))
         ((R:segstate.parent.ph_ctype is n)
          ((1.46678 1.0147))
          ((1.42396 0.487881))))
        ((R:segstate.parent.R:SylStructure.parent.parent.gpos
          is
          content)
         ((R:segstate.parent.pp.ph_vlng is l)
          ((0.800293 0.0664035))
          ((R:segstate.parent.R:SylStructure.parent.syl_onsetsize
            <
            1.2)
           ((R:segstate.parent.ph_vheight is 1)
            ((R:segstate.parent.R:SylStructure.parent.syl_in < 13.2)
             ((R:segstate.parent.R:SylStructure.parent.syl_codasize
               <
               2.2)
              ((1.41636 0.918463))
              ((1.69114 1.30745)))
             ((1.16521 0.566335)))
            ((R:segstate.parent.R:SylStructure.parent.R:Syllable.p.syl_codasize
              <
              2.4)
             ((R:segstate.parent.ph_vfront is 2)
              ((R:segstate.parent.p.name is l)
               ((0.660779 0.281664))
               ((R:segstate.parent.pp.ph_cplace is a)
                ((1.05021 0.56504))
                ((R:segstate.parent.pp.ph_vlng is a)
                 ((1.31665 0.728778))
                 ((1.6194 1.20228)))))
              ((R:segstate.parent.pp.ph_cplace is l)
               ((1.91086 1.13521))
               ((R:segstate.parent.R:SylStructure.parent.last_accent
                 <
                 6.6)
                ((R:segstate.parent.ph_cvox is -)
                 ((R:segstate.parent.R:SylStructure.parent.syl_in < 10)
                  ((0.7164 -0.322068))
                  ((1.63225 0.258492)))
                 ((R:segstate.parent.R:SylStructure.parent.syl_in < 10)
                  ((R:segstate.parent.R:SylStructure.parent.R:Syllable.pp.lisp_cg_break
                    <
                    0.1)
                   ((0.823073 0.371489))
                   ((R:segstate.parent.p.seg_onsetcoda is coda)
                    ((1.74422 1.08461))
                    ((1.51961 0.680296))))
                  ((R:segstate.parent.R:SylStructure.parent.asyl_in
                    <
                    3.6)
                   ((0.838705 0.546921))
                   ((R:segstate.parent.R:SylStructure.parent.syl_in
                     <
                     14)
                    ((0.554084 -0.111276))
                    ((0.899148 0.294915))))))
                ((1.16348 0.889176)))))
             ((0.930239 0.0521479))))
           ((R:segstate.parent.lisp_onset_stop is 0)
            ((1.04949 0.585153))
            ((R:segstate.parent.ph_vheight is 2)
             ((0.709705 0.0141672))
             ((0.885601 0.122685))))))
         ((0.553958 -0.171985))))
       ((R:segstate.parent.n.ph_ctype is l)
        ((R:segstate.parent.R:SylStructure.parent.syl_codasize < 2.2)
         ((R:segstate.parent.R:SylStructure.parent.R:Syllable.p.stress
           is
           0)
          ((R:segstate.parent.R:SylStructure.parent.R:Syllable.pp.accented
            is
            0)
           ((1.38903 0.299082))
           ((3.46421 1.17533)))
          ((R:segstate.parent.p.ph_cvox is +)
           ((0.588499 -0.263025))
           ((1.06611 0.107788))))
         ((R:segstate.parent.R:SylStructure.parent.syl_codasize < 3.1)
          ((R:segstate.parent.R:SylStructure.parent.syl_in < 9.2)
           ((0.4076 -0.602741))
           ((R:segstate.parent.R:SylStructure.parent.syl_in < 16)
            ((1.27641 -0.0389396))
            ((0.394687 -0.463625))))
          ((0.891196 0.136262))))
        ((R:segstate.parent.p.name is iy)
         ((1.46604 0.923277))
         ((R:segstate.parent.R:SylStructure.parent.syl_codasize < 1.3)
          ((R:segstate.parent.R:SylStructure.parent.position_type
            is
            final)
           ((1.69164 1.14379))
           ((R:segstate.parent.R:SylStructure.parent.R:Syllable.nn.stress
             is
             0)
            ((1.62347 0.10084))
            ((1.09457 0.6026))))
          ((R:segstate.parent.R:SylStructure.parent.R:Syllable.n.accented
            is
            0)
           ((R:segstate.parent.R:SylStructure.parent.R:Syllable.p.lisp_cg_break
             <
             0.3)
            ((R:segstate.parent.pos_in_syl is 2)
             ((R:segstate.parent.p.ph_vheight is 3)
              ((1.08628 0.0531432))
              ((R:segstate.parent.n.ph_ctype is n)
               ((0.759141 0.0321022))
               ((R:segstate.parent.lisp_onset_stop is 0)
                ((R:segstate.parent.p.name is ax)
                 ((R:segstate.parent.lisp_coda_fric is 0)
                  ((R:segstate.parent.R:SylStructure.parent.parent.word_numsyls
                    <
                    2.3)
                   ((1.09588 0.0238779))
                   ((0.740041 -0.0843844)))
                  ((0.58129 0.428744)))
                 ((R:segstate.parent.R:SylStructure.parent.ssyl_in
                   <
                   3.6)
                  ((1.01841 0.275414))
                  ((1.56732 0.932787))))
                ((R:segstate.parent.R:SylStructure.parent.syl_in < 8.4)
                 ((R:segstate.parent.R:SylStructure.parent.syl_codasize
                   <
                   2.1)
                  ((0.808544 0.425927))
                  ((1.60034 0.60492)))
                 ((1.7183 1.01116))))))
             ((R:segstate.parent.p.seg_onsetcoda is coda)
              ((R:segstate.parent.p.ph_vlng is a)
               ((1.11438 0.149654))
               ((R:segstate.parent.pp.ph_cplace is a)
                ((R:segstate.parent.R:SylStructure.parent.syl_onsetsize
                  <
                  0.3)
                 ((0.948214 0.135974))
                 ((0.810259 -0.136458)))
                ((0.508838 -0.328315))))
              ((R:segstate.parent.R:SylStructure.parent.last_accent
                <
                2)
               ((R:segstate.parent.n.ph_ctype is s)
                ((R:segstate.parent.p.name is l)
                 ((0.439225 -0.386723))
                 ((R:segstate.parent.R:SylStructure.parent.syl_codasize
                   <
                   2.1)
                  ((0.758048 -0.0143431))
                  ((1.09889 0.519217))))
                ((R:segstate.parent.p.name is n)
                 ((0.995243 -0.143347))
                 ((R:segstate.parent.lisp_coda_fric is 0)
                  ((R:segstate.parent.R:SylStructure.parent.syl_codasize
                    <
                    2.1)
                   ((R:segstate.parent.ph_vfront is 2)
                    ((R:segstate.parent.R:SylStructure.parent.syl_in
                      <
                      13)
                     ((R:segstate.parent.R:SylStructure.parent.syl_in
                       <
                       10.9)
                      ((R:segstate.parent.pp.ph_vlng is d)
                       ((0.802656 0.215129))
                       ((1.01246 0.423485)))
                      ((0.921213 0.473092)))
                     ((R:segstate.parent.R:SylStructure.parent.ssyl_in
                       <
                       9.2)
                      ((0.743853 0.0870567))
                      ((0.946392 0.219429))))
                    ((1.03971 -0.0411235)))
                   ((1.25258 0.590739)))
                  ((R:segstate.parent.R:SylStructure.parent.asyl_in
                    <
                    3.2)
                   ((0.747288 -0.23236))
                   ((1.26002 0.265085))))))
               ((R:segstate.parent.p.ph_cplace is a)
                ((1.61006 0.635911))
                ((0.990599 0.294512))))))
            ((R:segstate.parent.ph_ctype is n)
             ((R:segstate.parent.R:SylStructure.parent.syl_codasize
               <
               2.2)
              ((1.13804 0.454767))
              ((R:segstate.parent.R:SylStructure.parent.asyl_in < 1.4)
               ((0.797753 -0.428773))
               ((R:segstate.parent.p.name is aw)
                ((0.727722 -0.171615))
                ((R:segstate.parent.R:SylStructure.parent.syl_in
                  <
                  10.2)
                 ((0.776318 -0.0674515))
                 ((0.804308 0.344152))))))
             ((R:segstate.parent.R:SylStructure.parent.next_accent
               <
               1.6)
              ((R:segstate.parent.p.name is r)
               ((R:segstate.parent.R:SylStructure.parent.ssyl_in < 4.2)
                ((1.3563 0.545345))
                ((R:segstate.parent.R:SylStructure.parent.R:Syllable.p.syl_codasize
                  <
                  1.3)
                 ((0.639587 -0.579381))
                 ((R:segstate.parent.pp.ph_cvox is -)
                  ((0.895906 0.459628))
                  ((1.12388 -0.00944005)))))
               ((R:segstate.parent.p.name is hh)
                ((R:segstate.parent.n.ph_ctype is n)
                 ((R:segstate.parent.R:SylStructure.parent.R:Syllable.pp.lisp_cg_break
                   <
                   0.1)
                  ((R:segstate.parent.R:SylStructure.parent.R:Syllable.p.stress
                    is
                    0)
                   ((0.522478 -0.346591))
                   ((0.897083 -0.000430976)))
                  ((R:segstate.parent.pp.ph_cvox is +)
                   ((1.19639 0.0622493))
                   ((2.02897 0.511738))))
                 ((2.03242 1.00249)))
                ((R:segstate.parent.n.ph_ctype is n)
                 ((R:segstate.parent.p.ph_cplace is d)
                  ((R:segstate.parent.R:SylStructure.parent.last_accent
                    <
                    3.6)
                   ((1.64433 0.419194))
                   ((0.925768 -0.176212)))
                  ((R:segstate.parent.R:SylStructure.parent.last_accent
                    <
                    3.3)
                   ((R:segstate.parent.R:SylStructure.parent.R:Syllable.pp.lisp_cg_break
                     <
                     0.1)
                    ((2.13563 1.40313))
                    ((R:segstate.parent.R:SylStructure.parent.last_accent
                      <
                      2.1)
                     ((R:segstate.parent.p.seg_onsetcoda is coda)
                      ((2.43061 0.919864))
                      ((1.65849 0.645145)))
                     ((2.1376 1.23958))))
                   ((1.89542 0.676066))))
                 ((R:segstate.parent.pp.ph_vlng is a)
                  ((R:segstate.parent.R:SylStructure.parent.last_accent
                    <
                    2.5)
                   ((1.02247 0.156297))
                   ((0.771281 -0.058654)))
                  ((R:segstate.parent.ph_vheight is 2)
                   ((R:segstate.parent.ph_vfront is 1)
                    ((R:segstate.parent.R:SylStructure.parent.syl_in
                      <
                      10.5)
                     ((2.26002 1.48333))
                     ((1.42041 0.753543)))
                    ((1.09893 0.267494)))
                   ((R:segstate.parent.lisp_coda_glide is 0)
                    ((R:segstate.parent.pos_in_syl is 1)
                     ((R:segstate.parent.nn.ph_cplace is 0)
                      ((R:segstate.parent.R:SylStructure.parent.parent.gpos
                        is
                        content)
                       ((R:segstate.parent.pp.ph_cvox is -)
                        ((1.64317 0.8652))
                        ((1.20826 0.288032)))
                       ((1.07003 0.239827)))
                      ((0.887483 0.0929495)))
                     ((R:segstate.parent.R:SylStructure.parent.syl_in
                       <
                       12.8)
                      ((R:segstate.parent.p.ph_vlng is s)
                       ((1.5471 0.905511))
                       ((R:segstate.parent.ph_vfront is 1)
                        ((R:segstate.parent.pp.ph_vc is +)
                         ((1.82417 0.828361))
                         ((0.981463 0.400952)))
                        ((R:segstate.parent.p.ph_vfront is 3)
                         ((1.0292 0.48815))
                         ((0.803265 -0.0401331)))))
                      ((1.65611 1.08754))))
                    ((R:segstate.parent.p.ph_vheight is 3)
                     ((0.820163 0.0874106))
                     ((R:segstate.parent.nn.ph_cvox is +)
                      ((0.90786 0.056068))
                      ((R:segstate.parent.pp.ph_cplace is a)
                       ((1.7511 0.701629))
                       ((R:segstate.parent.R:SylStructure.parent.ssyl_in
                         <
                         5.1)
                        ((1.03268 0.34818))
                        ((0.599098 0.172833))))))))))))
              ((R:segstate.parent.pp.ph_vc is +)
               ((0.558068 -0.409855))
               ((R:segstate.parent.R:SylStructure.parent.R:Syllable.p.accented
                 is
                 0)
                ((0.798011 -0.140154))
                ((1.63257 0.390883)))))))
           ((R:segstate.parent.ph_cvox is +)
            ((R:segstate.parent.R:SylStructure.parent.R:Syllable.p.syl_codasize
              <
              1.2)
             ((1.06727 0.267257))
             ((0.57317 -0.053604)))
            ((R:segstate.parent.R:SylStructure.parent.R:Syllable.nn.lisp_cg_break
              <
              0.1)
             ((0.628671 -0.376601))
             ((0.574737 -0.0423626))))))))))))
   ((R:segstate.parent.p.ph_vc is +)
    ((R:segstate.parent.R:SylStructure.parent.stress is 0)
     ((R:segstate.parent.lisp_onset_glide is 0)
      ((R:segstate.parent.ph_ctype is f)
       ((R:segstate.parent.R:SylStructure.parent.ssyl_in < 7.8)
        ((R:segstate.parent.p.name is ey)
         ((R:segstate.parent.pp.ph_cvox is +)
          ((0.86258 0.21689))
          ((0.568406 -0.249715)))
         ((R:segstate.parent.p.ph_vfront is 2)
          ((0.938554 -0.0095449))
          ((R:segstate.parent.p.ph_vheight is 1)
           ((1.13232 0.101513))
           ((R:segstate.parent.R:SylStructure.parent.syl_codasize
             <
             1.2)
            ((0.793074 0.185017))
            ((1.12777 0.740782))))))
        ((R:segstate.parent.R:SylStructure.parent.asyl_in < 4.1)
         ((0.877683 -0.285377))
         ((R:segstate.parent.lisp_coda_fric is 0)
          ((R:segstate.parent.R:SylStructure.parent.asyl_in < 5.4)
           ((0.89935 -0.0139679))
           ((1.54588 0.176729)))
          ((0.566252 -0.128498)))))
       ((R:segstate.parent.p.ph_vrnd is +)
        ((R:segstate.parent.R:SylStructure.parent.syl_in < 12.8)
         ((0.658448 -0.138777))
         ((0.72238 0.166636)))
        ((R:segstate.parent.ph_ctype is a)
         ((0.875267 -0.00503842))
         ((R:segstate.parent.R:SylStructure.parent.syl_codasize < 1.3)
          ((R:segstate.parent.ph_ctype is n)
           ((0.549133 -0.406023))
           ((R:segstate.parent.ph_cvox is +)
            ((0.75244 -0.0515174))
            ((R:segstate.parent.R:SylStructure.parent.R:Syllable.pp.accented
              is
              0)
             ((0.411187 -0.456149))
             ((0.61659 -0.146533)))))
          ((R:segstate.parent.R:SylStructure.parent.parent.word_numsyls
            <
            3.2)
           ((R:segstate.parent.p.ph_vheight is 1)
            ((0.467081 -0.542816))
            ((R:segstate.parent.ph_ctype is n)
             ((R:segstate.parent.p.name is ax)
              ((0.675613 -0.288086))
              ((0.476614 -0.476952)))
             ((R:segstate.parent.p.name is ae)
              ((0.515911 -0.335877))
              ((R:segstate.parent.p.ph_vlng is d)
               ((0.562394 -0.267617))
               ((0.63387 -0.112242))))))
           ((R:segstate.parent.lisp_coda_stop is 0)
            ((0.639342 -0.442448))
            ((0.346258 -0.680787))))))))
      ((R:segstate.parent.n.ph_ctype is 0)
       ((R:segstate.parent.ph_ctype is l)
        ((R:segstate.parent.p.name is ih)
         ((1.3132 0.636491))
         ((R:segstate.parent.R:SylStructure.parent.ssyl_in < 5.5)
          ((0.746797 -0.230929))
          ((R:segstate.parent.p.name is ax)
           ((1.00739 0.118746))
           ((1.37673 0.366356)))))
        ((R:segstate.parent.R:SylStructure.parent.ssyl_in < 8)
         ((1.80899 0.977103))
         ((1.50932 0.506931))))
       ((R:segstate.parent.R:SylStructure.parent.syl_in < 12)
        ((0.672193 -0.157491))
        ((R:segstate.parent.p.ph_vheight is 2)
         ((0.800516 0.363945))
         ((0.621414 -0.0145089))))))
     ((R:segstate.parent.ph_ctype is s)
      ((R:segstate.parent.p.name is ax)
       ((R:segstate.parent.ph_cvox is +)
        ((R:segstate.parent.R:SylStructure.parent.ssyl_in < 5.4)
         ((0.985913 0.569848))
         ((R:segstate.parent.R:SylStructure.parent.ssyl_in < 7.2)
          ((0.715966 0.225116))
          ((0.634326 -0.0451953))))
        ((R:segstate.parent.pp.ph_cplace is a)
         ((0.892411 0.247232))
         ((R:segstate.parent.nn.ph_cvox is +)
          ((0.91386 0.67351))
          ((1.05659 0.931451)))))
       ((R:segstate.parent.n.ph_ctype is l)
        ((0.840958 0.343902))
        ((R:segstate.parent.ph_cvox is +)
         ((R:segstate.parent.nn.ph_cvox is +)
          ((R:segstate.parent.p.ph_vfront is 1)
           ((0.65483 0.263311))
           ((0.980707 0.720099)))
          ((1.40511 1.04921)))
         ((R:segstate.parent.R:SylStructure.parent.ssyl_in < 4.5)
          ((1.16147 1.3224))
          ((1.13091 0.931338))))))
      ((R:segstate.parent.R:SylStructure.parent.asyl_in < 3)
       ((R:segstate.parent.p.ph_vlng is d)
        ((1.16084 -0.0114164))
        ((R:segstate.parent.p.ph_vheight is 1)
         ((R:segstate.parent.R:SylStructure.parent.R:Syllable.p.stress
           is
           0)
          ((1.04398 -0.027535))
          ((0.904438 0.371227)))
         ((R:segstate.parent.nn.ph_cplace is a)
          ((R:segstate.parent.R:SylStructure.parent.asyl_in < 1.2)
           ((R:segstate.parent.ph_ctype is r)
            ((1.32222 0.492986))
            ((1.02833 0.671681)))
           ((1.03208 0.00394266)))
          ((R:segstate.parent.p.name is ax)
           ((R:segstate.parent.R:SylStructure.parent.R:Syllable.pp.accented
             is
             0)
            ((R:segstate.parent.R:SylStructure.parent.syl_in < 7.1)
             ((1.2737 0.737683))
             ((1.61411 0.660044)))
            ((0.955857 0.286656)))
           ((1.60183 0.970446))))))
       ((R:segstate.parent.nn.ph_cplace is l)
        ((2.05647 0.827648))
        ((R:segstate.parent.nn.ph_cplace is v)
         ((1.10112 -0.0712389))
         ((R:segstate.parent.pp.ph_cvox is -)
          ((R:segstate.parent.R:SylStructure.parent.ssyl_in < 5.4)
           ((1.13517 0.51215))
           ((R:segstate.parent.nn.ph_cvox is +)
            ((1.01046 0.350254))
            ((1.03551 0.0547227))))
          ((R:segstate.parent.p.ph_vlng is d)
           ((0.971719 0.301999))
           ((R:segstate.parent.R:SylStructure.parent.last_accent < 3.5)
            ((R:segstate.parent.pp.ph_cplace is a)
             ((R:segstate.parent.R:SylStructure.parent.asyl_in < 3.3)
              ((1.50545 0.513431))
              ((0.818275 0.0190767)))
             ((R:segstate.parent.lisp_coda_stop is 0)
              ((0.943263 -0.34541))
              ((0.950222 0.106023))))
            ((0.969839 0.344797))))))))))
    ((R:segstate.parent.p.name is r)
     ((R:segstate.parent.lisp_onset_glide is 0)
      ((R:segstate.parent.R:SylStructure.parent.R:Syllable.pp.accented
        is
        0)
       ((R:segstate.parent.R:SylStructure.parent.stress is 0)
        ((0.727916 0.0271618))
        ((1.08309 0.49637)))
       ((2.05924 1.07684)))
      ((0.884985 -0.0065299)))
     ((R:segstate.parent.ph_ctype is s)
      ((R:segstate.parent.pos_in_syl is 0)
       ((R:segstate.parent.ph_cvox is +)
        ((R:segstate.parent.R:SylStructure.parent.syl_codasize < 1.3)
         ((0.289377 -0.700235))
         ((R:segstate.parent.n.ph_ctype is r)
          ((R:segstate.parent.pp.ph_vlng is s)
           ((1.42155 0.564372))
           ((1.15209 -0.0287393)))
          ((R:segstate.parent.R:SylStructure.parent.R:Syllable.p.lisp_cg_break
            <
            0.3)
           ((0.501974 -0.338601))
           ((R:segstate.parent.pp.ph_vheight is 3)
            ((1.26005 0.226283))
            ((R:segstate.parent.nn.ph_cplace is a)
             ((0.662298 -0.505762))
             ((R:segstate.parent.p.ph_cvox is +)
              ((0.956999 0.130365))
              ((1.00081 -0.0946271))))))))
        ((R:segstate.parent.p.name is m)
         ((0.881225 -0.220704))
         ((R:segstate.parent.R:SylStructure.parent.syl_in < 12.2)
          ((R:segstate.parent.lisp_coda_fric is 0)
           ((R:segstate.parent.p.ph_ctype is s)
            ((1.18297 0.958504))
            ((R:segstate.parent.n.ph_vlng is d)
             ((1.14191 0.239307))
             ((R:segstate.parent.n.ph_ctype is 0)
              ((0.848344 0.823612))
              ((1.25191 0.594444)))))
           ((1.07814 0.217051)))
          ((R:segstate.parent.pp.ph_vlng is s)
           ((0.824684 0.0909852))
           ((0.832669 0.28109))))))
       ((R:segstate.parent.n.ph_vheight is 1)
        ((0.851302 0.0403224))
        ((R:segstate.parent.R:SylStructure.parent.asyl_in < 2.4)
         ((R:segstate.parent.R:SylStructure.parent.syl_in < 6.4)
          ((0.881497 -0.325356))
          ((0.921654 -0.0227824)))
         ((R:segstate.parent.R:SylStructure.parent.syl_in < 12.4)
          ((0.461276 -0.630918))
          ((0.669975 -0.278945))))))
      ((R:segstate.parent.ph_ctype is r)
       ((R:segstate.parent.R:SylStructure.parent.position_type
         is
         final)
        ((R:segstate.parent.pp.ph_cplace is a)
         ((R:segstate.parent.R:SylStructure.parent.R:Syllable.p.accented
           is
           0)
          ((0.367155 -0.587589))
          ((0.476985 -0.276979)))
         ((R:segstate.parent.n.ph_vheight is 1)
          ((0.911285 0.166079))
          ((0.729748 -0.206))))
        ((R:segstate.parent.R:SylStructure.parent.ssyl_in < 9)
         ((R:segstate.parent.R:SylStructure.parent.syl_codasize < 2.2)
          ((R:segstate.parent.R:SylStructure.parent.ssyl_in < 7.2)
           ((R:segstate.parent.R:SylStructure.parent.ssyl_in < 2.1)
            ((0.64702 -0.0688631))
            ((R:segstate.parent.R:SylStructure.parent.R:Syllable.pp.lisp_cg_break
              <
              0.1)
             ((0.541594 -0.0638084))
             ((R:segstate.parent.R:SylStructure.parent.ssyl_in < 5)
              ((1.28437 0.436855))
              ((0.876699 0.176124)))))
           ((1.22856 0.61727)))
          ((0.767674 -0.0946877)))
         ((R:segstate.parent.R:SylStructure.parent.asyl_in < 4.2)
          ((0.691459 0.000646871))
          ((0.780264 -0.241372)))))
       ((R:segstate.parent.R:SylStructure.parent.last_accent < 5.6)
        ((R:segstate.parent.ph_ctype is f)
         ((R:segstate.parent.p.name is z)
          ((R:segstate.parent.nn.ph_cvox is -)
           ((0.58086 -0.531517))
           ((0.750172 -0.104416)))
          ((R:segstate.parent.n.ph_vheight is 1)
           ((R:segstate.parent.R:SylStructure.parent.last_accent < 0.5)
            ((1.63975 0.427704))
            ((R:segstate.parent.p.ph_cplace is v)
             ((0.870508 0.153806))
             ((R:segstate.parent.R:SylStructure.parent.syl_in < 9.2)
              ((0.673931 -0.137302))
              ((0.89799 0.0655512)))))
           ((R:segstate.parent.p.ph_cvox is +)
            ((R:segstate.parent.ph_cvox is +)
             ((R:segstate.parent.p.name is d)
              ((1.26772 0.0578663))
              ((0.66891 -0.373208)))
             ((R:segstate.parent.nn.ph_cplace is 0)
              ((0.813553 -0.125588))
              ((R:segstate.parent.p.ph_ctype is s)
               ((0.768588 -0.0376014))
               ((R:segstate.parent.R:SylStructure.parent.last_accent
                 <
                 1.2)
                ((R:segstate.parent.lisp_coda_stop is 0)
                 ((1.23273 0.0617395))
                 ((1.12763 0.227659)))
                ((0.492452 0.0928395))))))
            ((R:segstate.parent.pp.ph_vheight is 2)
             ((1.08076 0.125621))
             ((R:segstate.parent.R:SylStructure.parent.last_accent
               <
               1.5)
              ((0.944983 -0.512317))
              ((R:segstate.parent.p.ph_cplace is a)
               ((1.06035 0.048012))
               ((0.786877 -0.366471))))))))
         ((R:segstate.parent.R:SylStructure.parent.syl_in < 13)
          ((R:segstate.parent.R:SylStructure.parent.R:Syllable.pp.lisp_cg_break
            <
            0.3)
           ((R:segstate.parent.ph_ctype is n)
            ((0.807506 -0.19668))
            ((R:segstate.parent.R:SylStructure.parent.asyl_in < 2.5)
             ((0.695682 -0.125996))
             ((1.02907 0.452493))))
           ((R:segstate.parent.R:SylStructure.parent.R:Syllable.n.lisp_cg_break
             <
             0.1)
            ((R:segstate.parent.n.ph_vlng is l)
             ((R:segstate.parent.p.ph_ctype is f)
              ((0.712187 -0.244686))
              ((0.754115 -0.0882372)))
             ((R:segstate.parent.pp.ph_vc is +)
              ((R:segstate.parent.R:SylStructure.parent.ssyl_in < 5.6)
               ((R:segstate.parent.p.ph_ctype is s)
                ((0.497299 -0.766409))
                ((0.62978 -0.383208)))
               ((0.817778 -0.273884)))
              ((R:segstate.parent.n.ph_vheight is 2)
               ((0.738219 -0.119154))
               ((0.570649 -0.423477)))))
            ((1.41956 0.254194))))
          ((R:segstate.parent.n.ph_vlng is s)
           ((0.636724 -0.202197))
           ((R:segstate.parent.R:SylStructure.parent.syl_in < 16.2)
            ((R:segstate.parent.p.ph_ctype is s)
             ((0.58904 -0.449733))
             ((0.426167 -0.712079)))
            ((0.603717 -0.276146))))))
        ((R:segstate.parent.lisp_coda_stop is 0)
         ((R:segstate.parent.lisp_coda_fric is 0)
          ((0.603307 -0.278228))
          ((0.622169 -0.479406)))
         ((0.740526 -0.862511)))))))))))
)
)


(provide 'cmu_us_clb_dur)


